(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='WolframDesktop 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       161,          7]
NotebookDataLength[    502844,      12086]
NotebookOptionsPosition[    424102,      10810]
NotebookOutlinePosition[    427514,      10884]
CellTagsIndexPosition[    426859,      10867]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Pronunciation of the integers with full use of the place value system\
\>", "Title",ExpressionUUID->"1110965b-e406-4b23-913b-caea1b8db153"],

Cell["\<\
Thomas Colignatus
http://thomascool.eu
May 9 & 17 & June 28 2018\
\>", "Text",ExpressionUUID->"53ed3239-cdce-41cb-b773-aba1913d217e"],

Cell["\[Copyright] Thomas Cool CC-BY-NC-ND", "Text",ExpressionUUID->"0e72e460-d5c2-4623-8c7c-914108df3a35"],

Cell[TextData[StyleBox["Abstract",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"fd7c1fec-9270-429c-b869-d24a813d2bf5"],

Cell[TextData[{
 "Kids in kindergarten and Grade 1 live in a world of sounds so that the \
pronunciation of numbers is important. When they are learning to read and \
write, the co-ordination of (i) sounds, (ii) numerals and (iii) written words \
is important. We already have the place value system fully in the numerals \
but not yet in pronunciation and written words. The following provides for \
this. The definition should become an ISO standard, though the notebook with \
package is quite simple because of the nature of the issue. The notebook with \
package provides an implementation and transliteration for English, German, \
French, Dutch and Danish, while other languages might employ ",
 StyleBox["Mathematica\[CloseCurlyQuote]",
  FontSlant->"Italic"],
 "s IntegerName and WordTranslation without transliteration. Four levels in \
the curriculum are recognised for which routines are provided: (1) sounds, \
codified by words, (2) learning the numerals, (3) advanced: numerals in \
blocks of three digits, such that 123456 = {1 hundred, 2 ten, 3} thousand & \
{4 hundred, 5 ten, 6}, with the comma pronounced as \[OpenCurlyDoubleQuote]&\
\[CloseCurlyDoubleQuote] too, and (4) accomplished: 123 thousand 456 \
pronounced in above place value manner. The traditional pronunciation has \
level -4."
}], "Text",ExpressionUUID->"ad785611-7ca3-4938-9ef3-2c5520759846"],

Cell[TextData[StyleBox["Keywords",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"bfac5d35-3658-4d6b-8202-ca48f8263c33"],

Cell["\<\
mathematics education, place value system, pronunciation, Common Core, \
Mathematica, Wolfram language, programming, package\
\>", "Text",ExpressionUUID->"bb284214-0fc2-49e8-8783-d70e26c02d2d"],

Cell[TextData[StyleBox["MSC2010",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"410f56da-6bcc-41dc-ad2b-8e5f44c4faeb"],

Cell["97M70 Mathematics education. Behavioral and social sciences", "Text",ExpressionUUID->"2006687d-7625-4c76-8526-ab0dcee587d0"],

Cell[TextData[StyleBox["Cloud",
 FontWeight->"Bold"]], "Text",ExpressionUUID->"f9d66bff-0256-4b09-9bb1-a1e6890e5898"],

Cell["\<\
This notebook with package (updated version) is also available at: \
\>", "Text",ExpressionUUID->"f12a40ba-f0ba-491b-b18e-9f796fee68d5"],

Cell["(1)  http://community.wolfram.com/groups/-/m/t/1334793", "Text",ExpressionUUID->"dea07df1-1224-4b5d-8e1d-3612bfb6f06d"],

Cell["\<\
(2) https://www.wolframcloud.com/objects/thomas-cool/MathEd/2018-05-09-\
Pronunciation-of-integers.nb\
\>", "Text",ExpressionUUID->"72af0cb7-c546-4d8d-ad6b-bb11169c4a7e"],

Cell["\<\
(3) for this notebook with package: https://zenodo.org/record/1244008 or DOI \
10.5281/zenodo.1244008 \
\>", "Text",ExpressionUUID->"c5f2f81c-b24f-4f87-b55b-c6602af526ce"],

Cell["\<\
(4) for the PDF: https://zenodo.org/record/1244063  or DOI \
10.5281/zenodo.1244063 \
\>", "Text",ExpressionUUID->"3b00d2ea-a9ce-41b5-bb91-81476e193c94"],

Cell["\<\
I have not seen this implementation of pronunciation elsewhere (except in \
Chinese though without &), so please refer to these locations so that others \
can find the full documentation.\
\>", "Text",ExpressionUUID->"ef5b0bb9-c5e9-4621-8174-2b0405737f4f"],

Cell[CellGroupData[{

Cell["Contents", "Subsection",ExpressionUUID->"246d232d-27ac-42de-8b3b-54d84ccb08b4"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Introduction"
}], "Subsubsection",ExpressionUUID->"96dc55f3-0879-496d-a4d5-f5c96ddaf69d"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Example in English"
}], "Subsubsection",ExpressionUUID->"31c6b92a-f153-42aa-bb73-0c970917047a"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". History, tradition, assumptions, advantages"
}], "Subsubsection",ExpressionUUID->"0bd3d71c-73fb-4c95-b401-167410e659bd"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". A structure for the curriculum"
}], "Subsubsection",ExpressionUUID->"d5259709-c0f1-464c-bc2c-6ba8d68dedcc"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Zig in German and tig in Dutch"
}], "Subsubsection",ExpressionUUID->"4b7bfaf4-0ecd-4b0e-ba14-efcd40b01b1f"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Translate, transliterate and quality control"
}], "Subsubsection",ExpressionUUID->"d6a90818-0a19-4129-a1eb-954517d1e1f3"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Conversion tables"
}], "Subsubsection",ExpressionUUID->"2fab279a-da74-420e-8abc-ca0e2f78a17d"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". ISO standard"
}], "Subsubsection",ExpressionUUID->"bc9def86-9846-40bd-98cc-5641ae8bd57f"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Conclusions"
}], "Subsubsection",ExpressionUUID->"6bb1c1f9-2ead-443d-8ca5-673d435c5403"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Appendix. The package"
}], "Subsubsection",ExpressionUUID->"ab0ffa05-b85b-403d-8acc-8fa2c7f52163"],

Cell[TextData[{
 
 CounterBox["Subsubsection"],
 ". Literature"
}], "Subsubsection",ExpressionUUID->"ae5bbdd6-7cd3-4399-95e9-a705654b086a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Start (subsection for the initialisation cell with the package)\
\>", "Subsection",ExpressionUUID->"52ee38c9-fbc5-45c8-be38-006fa5ca0a2e"],

Cell[CellGroupData[{

Cell["MathEd`PronounceInteger`", "Subsubsection",ExpressionUUID->"d075f3e1-6e4f-4249-81d3-a501a169675b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "Cool`MathEd`PronounceInteger`"}], " ", 
    "package"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "*******************************************)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Author", ":", " ", 
    RowBox[{"Thomas", " ", "Cool"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Copyright", ":", " ", 
    RowBox[{"Copyright", " ", "2018", " ", "Thomas", " ", "Cool"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Package", " ", "Version"}], ":", "2.0"}], ",", " ", 
    RowBox[{"May", " ", "17", " ", "2018"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", "Version"}], ":", "11.2"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Keywords", ":"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Limitation", ":"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{":", "License", ":", " ", 
     RowBox[{"see", " ", 
      RowBox[{"http", ":"}]}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{"thomascool", ".", "eu"}], "/", "TheEconomicsPack"}], "/", 
     RowBox[{"index", ".", "html"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"BeginPackage", "[", 
     RowBox[{"\"\<Cool`MathEd`PronounceInteger`\>\"", ",", " ", 
      RowBox[{"{", "\"\<Cool`MathEd`H`\>\"", "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Unprotect", "[", 
     RowBox[{
     "PlaceValue", ",", " ", "PlaceValueH", ",", "PronounceIntegers", ",", 
      " ", "SpeakTransliteration", ",", "PlaceValueBlock", ",", " ", 
      "PlaceValueDigits", ",", " ", "PlaceValueDigits$Language", ",", 
      "PronounceIntegerReadMe", ",", " ", "PronounceInteger", ",", " ", 
      "PartialPlaceValue", ",", " ", "PlaceValueTable"}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"LatestPronunciation", "::", "usage"}], " ", "=", " ", 
     "\"\<LatestPronunciation[] contains what a routine in the \
MathEd`PronounceInteger` package could have spoken (but perhaps suppressed by \
an option choice not to speak)\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PronounceIntegerReadMe", "::", "usage"}], "  ", "=", " ", 
     "\"\<PronounceIntegerReadMe[] explains the package\>\""}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"PronounceIntegerReadMe", "[", "]"}], "=", " ", "\n", 
     "\"\<Mathematica already provides for (i) IntegerName[n, \
\\\"language\\\"], (ii) IntegerName[n, \\\"DigitsWords\\\"] for blocks of \
three digits, and (iii) WordTranslation for \\\"negative\\\", and (iv) a \
wealth of expression in IntegerString. These all encode tradition: with 56 = \
fifty-six instead of ten\[CenterDot]five & six, except in IntegerString[n, \\\
\"TraditionalChineseDecimal\\\"]. Also, these all tend to hide the steps in \
the place value system that we want to show. Our routines are:\\n(1) \
PronounceInteger provides a switch between methods, and helps to focus on \
your preferred method\\n(2) PlaceValue (main routine): word based, so that \
the pronunciation is unambiguous for the particular language. It also allows \
transliteration (speaking foreign words with approximations in English)\\n(3) \
PlaceValueDigits: integer based, for when kids go from sounds to reading and \
writing numerals\\n(4)PlaceValueBlock: show in blocks of three digits (quite \
alike DigitsWords, but notice the differences).\\n(5) PlaceValueIntegerName \
builds around IntegerName DigitsWords for full place value speech\\nLikely, \
teaching is best done likely in order (2)-(5) so that first the individual \
steps are shown and then the block form. PM. A routine f stores what is \
spoken in LatestPronunciation[] and may display differently, see the \
documentation of f\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "::", "usage"}], " ", "=", 
     "\"\<PlaceValueRules[\\\"Language\\\"] = {True -> t, \\\"OtherLanguage\\\
\" -> f}, with t = {Negative -> string, And -> \\\"&\\\", N -> {strings for \
0...9}, Power -> {strings for 10, ..., 10^6}}, for the true way of writing \
and pronunciation (when this original language = $Language), and f = {... \
similar ...} for the transliteration into the actual $Language. See the \
examples for \\\"English\\\" (f is not required given $Language = \\\"English\
\\\") and \\\"Dutch\\\" (t <> f).\\nNegative -> how the sign of a negative \
number is written or pronounced\\nAnd-> what string is used to separate the \
product terms of weights and place values\\nN -> {names how the digits 0 ... \
9 are written or pronounced}\\nPower -> {names how 10 ... 10^6 are written or \
pronounced}.\\nSee SpeakTransliteration for checking on \
$Language.\\nImplemented are English, German, French, Dutch and Danish (with \
some guessing on transliteration). The language Amplish has True -> with an \
ampersand in a smaller font, and otherwise English. Englishty has ty for 10 \
pronounced as tee. The languages have (Greek) myriad for 10^4 and (Indian) \
lakh for 10^5\\nPlaceValueRules[] contains the list of languages for which \
there is transliteration\\nPlaceValueRules[Select, item, lan, \
translit:\\\"English\\\"] selects for lan the item (e.g. Power) from both \
True and translit, and gives a rule or list of rules (true -> \
transliteration) for replacement\\nPlaceValueRules[Set, \\\"ToLanguage\\\", \
FromLanguage:\\\"English\\\"] uses IntegerName for the digits and \
WordTranslation for \\\"negative\\\", \\\"and\\\" and \\\"million\\\" and \
imposes myriad and lakh. These routines may take time, and thus one is \
advised to save the result. There is no automation for the \
transliteration\\nPlaceValueRules[Check, \\\"Language\\\"] for another \
language than in PlaceValueRules[\\\"Checked\\\"] will issue a warning that \
the place value pronunciation is generated by automation and hasn't been \
checked on conflicts. When you have done the checking then this list can be \
adapted manually or by AppendTo\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SpeakTransliteration", " ", "::", "usage"}], " ", "=", " ", 
     "\"\<SpeakTransliteration is an option of PlaceValue with default \
$Language. It selects the relevant setting from the PlaceValueRules. If the \
Language option is equal to the transliterator ($Language) then writing and \
speaking will be done from the True rule. When the option Language is set to \
another value, then the integers are written from True but spoken by the \
transliterator\>\""}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "usage"}], " ", "=", " ", 
     "\"\<PlaceValue[n] gives n in the full place value system, as text or in \
Speak, and the latter with pauses for hearing and possible transliteration in \
the system default language (e.g. $Language = English). n is in (-10^7, \
10^7).\\nThe routine is also called with PronounceInteger[n, Level -> \
1]\\nOptions with defaults are:\\nLanguage -> \\\"Amplish\\\" uses \
PlaceValueRules[\\\"Amplish\\\"], see there\\nWordTranslation -> Automatic \
calls IntegerName and WordTranslation when the language is not available in \
PlaceValueRules, which takes some time for initialisation and does not \
provide for transliteration\\nSpeakTransliteration :> $Language (often \
\\\"English\\\"), see there\\nSpeak -> True,\\nLength -> 300, an integer for \
the duration of pause between the positions,\\nJoin -> \\\"\[CenterDot]\\\" \
(unpronounced center dot) between the texts of the weight and place \
value\\nSimplify -> True eliminates terms with 0 weights and replaces 1 P by \
P, for P = 1, 10, ..., 10^6\\nShow -> False does not show the input for \
Speak, so that one reads the words in the language itself and hears the \
transliteration (while reading affects hearing)\\nPronounceInteger[Options, \
\\\"Reset\\\"] resets the options to loading time\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueH", "::", "usage"}], " ", "=", " ", 
     "\"\<PlaceValueH[expr] is PlaceValue[expr /. H -> -1]\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PronounceIntegers", "::", "usage"}], " ", "=", 
     "\"\<PronounceIntegers is obsolete (first version of the package), see \
PlaceValue\>\""}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueDigits$Language", "::", "usage"}], " ", "=", " ", 
     "\"\<PlaceValueDigits$Language[n] pronounces n by using digits for the \
place values rather than words (PlaceValue): n can be as large as Mathematica \
allows, but also relies on how $Language pronounces those integers. In \
English 2 100 is pronounced as \\\"two one-hundred\\\". Option Simplify -> \
True (default) for handling of 0 and 1 weights, StepMonitor -> False \
(default) whether to show an intermediate step, Length -> 300 (default) for \
the pause, Join -> \\\"\[CenterDot]\\\" (default) for connection of terms in \
display (not spoken), Speak -> True (default).\\nThe routine is also called \
as a subroutine by PlaceValueDigits[n], which is also called by \
PronounceInteger[n, Level -> 2]\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueBlock", "::", "usage"}], " ", "=", " ", 
     "\"\<PlaceValueBlock[n] pronounces n in digit blocks of 3, and within \
those blocks in place value manner.\\nThe routine is also called with \
PronounceInteger[n, Level -> 3]\\nFor example 123456 = {{1 hundred & 2 ten & \
3}, thousand} & {4 hundred & 5 ten & 6}. This is like common usage except for \
the integers in 11-99. Option Length -> 300 (default) puts \\\"&\\\" in the \
middle of that pause. Option Power -> {...} by default replaces 100 by \
hundred, 1000 by thousand and 10^6 by million. (This is not done in \
PlaceValueDigits$Language, because there are more words, like for the digits, \
and including the awkward 10^4 and 10^5). The numbers 11-99 use the options \
of PlaceValueDigits$Language, namely to display in numbers and not words. If \
your $Language is not \\\"English\\\", then you might consider to adapt the \
settings manually. The following is an automation \
though:\\nPlaceValueBlock[SetOptions, \\\"language\\\"] sets the options to \
stated \\\"language\\\", using WordTranslation from the current language in \
the Options (default \\\"English\\\")\\nPlaceValueBlock[Options, \
\\\"Reset\\\"] resets to the Options at loading\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueIntegerName", "::", "usage"}], " ", "=", " ", 
     "\"\<PlaceValueIntegerName[n] lets IntegerName[n, \\\"DigitsWords\\\"] \
make the blocks of 3 digits, and then calls PlaceValue on these digits. \
IntegerName DigitsWords uses text for Abs[n] < 1000, and we follow this. The \
block bases of thousand, million etcetera are translated by WordTranslation. \
The text displayed has blocks of digits, with block bases separated by option \
And -> \\\", \\\" (default). This option is not passed on to PlaceValue for \
speech of the blocks. The spoken text can be recovered from \
LatestPronunciation[]. Transliteration is called but will slow the \
execution\\nThe routine is also called with PronounceInteger[n, Level -> 4]\>\
\""}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PronounceInteger", "::", "usage"}], " ", "=", " ", 
     "\"\<PronounceInteger[n] pronounces n. Options are passed on to the \
routine that is called, except: if the chosen Language is equal to $Language \
then it is not passed on. It uses first the Level and then the Method setting \
in the options, default Level -> 1, Method -> PlaceValue. Option All -> {...} \
gives the methods in the MathEd`PronounceInteger` package. See the \
documentation per routine. If you want to specify the selection by Method -> \
routine name, select also Level -> 0. Perhaps easier to remember than the \
routine names, and taking advantage of the levels of understanding, you can \
also specify the Level -> lev:\\nchosen =Switch[lev, \\n 1, PlaceValue,\\n 2, \
PlaceValueDigits,\\n 3, PlaceValueBlock,\\n 4, PlaceValueIntegerName,\\n-4, \
PartialPlaceValue,\\n_, Null];\\n If none of these is used (say with Level -> \
0) then the Method -> m option is used. If no method is in the list that All \
provided: $Failed\>\""}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PartialPlaceValue", "::", "usage"}], " ", "=", " ", 
     "\"\<PartialPlaceValue[n] has the traditional pronunciation and words of \
the numbers 11-99, thus in opposite order of the place value system, when \
speaking the number from Left To Right, and morphing of words. It calls \
IntegerName with DigitsWords. If Abs[n] < 1000 then there are words only, and \
higher n get combinations of both digit blocks and words for digit block \
values (thousand, million). Option defaults are Language -> \\\"English\\\" \
and Speak -> True. Speak apparently fails on the hyphen and thus this \
replaced by a space. Speak[-10] says Minus 10 but IntegerName uses Negative \
10. There is no transliteration.\\nThe routine is also called with \
PronounceInteger[n, Level -> -4]\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueDigits", "::", "usage"}], " ", "=", " ", 
     "\"\<PlaceValueDigits[n] pronounces n by PlaceValue[n] and displays by \
PlaceValueDigits$Language[n]\\nOptions are passed on to said routines, and \
see their own options, like Simplify and Show\\nOwn options are Speak -> True \
(default), Print -> True (default) prints the outcome of PlaceValue[n]. \
LatestPronunciation[Print] stores what is printed\\nThe routine is also \
called with PronounceInteger[n, Level -> 2]\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueTable", "::", "usage"}], " ", "=", " ", 
     "\"\<PlaceValueTable[{n}] gives a table of {n} with rows {n, \
pronunciation in PlaceValue, PV Digits, traditional pronunciation}. Options \
are passed on to PlaceValue (default Speak -> True) and \
PartialPlaceValue(default Speak -> False)\\nPlaceValueTable[n] gives the \
table with only n\\nPlaceValueTable[Row, n || {n}] gives the rows as lists \
only\\nPlaceValueTable[First, n] gives {n, PV, PV Digits}\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "::", "wrn"}], " ", "=", " ", 
     "\"\<Warning: automated translation of `1` and not carefully checked on \
conflicts and peculiarities\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", 
      RowBox[{"Check", ",", " ", "lan_String"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"PlaceValueRules", "[", "\"\<Checked\>\"", "]"}], ",", " ", 
          "lan"}], "]"}]}], ",", " ", 
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"PlaceValueRules", "::", "wrn"}], ",", " ", "lan"}], "]"}]}],
       "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueTable", "[", 
     RowBox[{"First", ",", " ", "n_Integer", ",", " ", "opts___Rule"}], "]"}],
     " ", ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"n", ",", " ", 
      RowBox[{"PlaceValue", "[", 
       RowBox[{"n", ",", " ", "opts"}], "]"}], ",", " ", 
      RowBox[{"PlaceValueDigits", "[", 
       RowBox[{"n", ",", " ", 
        RowBox[{"Print", " ", "\[Rule]", " ", "False"}], ",", " ", 
        RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", "opts"}], 
       "]"}]}], "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueTable", "[", 
     RowBox[{"Row", ",", " ", "n_Integer", ",", " ", "opts___Rule"}], "]"}], 
    " ", ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"n", ",", " ", "\"\< \>\"", ",", " ", 
      RowBox[{"PlaceValue", "[", 
       RowBox[{"n", ",", " ", "opts"}], "]"}], ",", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"PlaceValueDigits", "[", 
       RowBox[{"n", ",", " ", 
        RowBox[{"Print", " ", "\[Rule]", " ", "False"}], ",", " ", 
        RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", "opts"}], 
       "]"}], ",", "\[IndentingNewLine]", "  ", "\"\< \>\"", ",", 
      RowBox[{"PartialPlaceValue", "[", 
       RowBox[{"n", ",", " ", "opts", ",", " ", 
        RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueTable", "[", 
     RowBox[{"Row", ",", " ", 
      RowBox[{"{", "n__Integer", "}"}], ",", " ", "opts___Rule"}], "]"}], " ",
     ":=", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"PlaceValueTable", "[", 
       RowBox[{"Row", ",", "#", ",", " ", "opts"}], "]"}], "&"}], " ", "/@", 
     " ", 
     RowBox[{"{", "n", "}"}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueTable", "[", " ", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"PlaceValueTable", "[", " ", 
     RowBox[{
      RowBox[{"{", "n", "}"}], ",", " ", "opts"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueTable", "[", 
     RowBox[{
      RowBox[{"{", "n__Integer", "}"}], ",", " ", "opts___Rule"}], "]"}], " ",
     ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PlaceValueRules", "[", 
       RowBox[{"Check", ",", " ", 
        RowBox[{
         RowBox[{"Language", " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValue", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"TableForm", "[", 
       RowBox[{
        RowBox[{"PlaceValueTable", "[", 
         RowBox[{"Row", ",", " ", 
          RowBox[{"{", "n", "}"}], ",", " ", "opts"}], "]"}], ",", "opts", 
        ",", " ", 
        RowBox[{"TableSpacing", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"1.5", ",", " ", "3"}], "}"}]}], ",", "\[IndentingNewLine]",
         " ", 
        RowBox[{"TableHeadings", " ", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"None", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Integer\>\"", ",", " ", "\"\<\>\"", ",", " ", 
             "\"\<Place Value\>\"", ",", " ", "\"\<PV Digits\>\"", ",", " ", 
             "\"\<\>\"", ",", " ", "\"\<Traditional\>\""}], "}"}]}], 
          "}"}]}]}], "]"}]}], ")"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PlaceValueDigits", "]"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
       RowBox[{"Print", " ", "\[Rule]", " ", "True"}]}], "}"}]}], " ", ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueDigits", "[", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "res", ",", " ", "speakq", ",", "  ", "toshow", ",", " ", "prq"}], 
       "}"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"split", " ", "show", " ", "and", " ", "speak"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"speakq", ",", " ", "prq"}], "}"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Speak", ",", " ", "Print"}], "}"}], " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValueDigits", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"toshow", " ", "=", " ", 
        RowBox[{"PlaceValueDigits$Language", "[", 
         RowBox[{"n", ",", " ", 
          RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", "opts"}],
          "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", "  ", 
        RowBox[{"PlaceValue", "[", 
         RowBox[{"n", ",", " ", 
          RowBox[{"Speak", " ", "\[Rule]", " ", "speakq"}], ",", " ", 
          "opts"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"prq", " ", "===", " ", "True"}], ",", "  ", 
         RowBox[{
          RowBox[{
           RowBox[{"LatestPronunciation", "[", "Print", "]"}], " ", "=", " ", 
           "res"}], ";", 
          RowBox[{"Print", "[", "res", "]"}]}]}], "]"}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"LatestPronunciation", "[", "]"}], " ", "set", " ", "by", 
         " ", 
         RowBox[{"P", ".", "V", ".", "O", "."}]}], " ", "*)"}], 
       "\[IndentingNewLine]", "toshow"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PartialPlaceValue", "]"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Language", " ", "\[Rule]", " ", "\"\<English\>\""}], ",", " ", 
       RowBox[{"Speak", " ", "\[Rule]", " ", "True"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PartialPlaceValue", "[", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", " ", "lan", ",", " ", "speakq", ",", " ", "rul"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"lan", ",", " ", "speakq"}], "}"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Language", ",", " ", "Speak"}], "}"}], " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PartialPlaceValue", "]"}]}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"rul", " ", "=", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "$Language", ",", " ", "\"\<Amplish\>\"", ",", " ", 
              "\"\<Englishty\>\""}], "}"}], ",", " ", "lan"}], "]"}], ",", 
          " ", "\[IndentingNewLine]", 
          RowBox[{"ToExpression", "[", "\"\<Sequence[]\>\"", "]"}], ",", " ", 
          RowBox[{"Language", " ", "\[Rule]", " ", "lan"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", "  ", 
        RowBox[{"IntegerName", "[", 
         RowBox[{"n", ",", " ", 
          RowBox[{"{", "\"\<DigitsWords\>\"", "}"}], ",", " ", "rul"}], 
         "]"}]}], " ", ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"StringReplace", "[", 
         RowBox[{"res", ",", " ", 
          RowBox[{"\"\<\[Hyphen]\>\"", " ", "\[Rule]", " ", "\"\< \>\""}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"LatestPronunciation", "[", "]"}], " ", "=", "res"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"speakq", ",", " ", 
         RowBox[{"Speak", "[", "res", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", "res"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PronounceInteger", "]"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Level", " ", "\[Rule]", " ", "1"}], ",", " ", 
       RowBox[{"Method", " ", "\[Rule]", " ", "PlaceValue"}], ",", " ", 
       RowBox[{"Language", " ", "\[Rule]", " ", "\"\<English\>\""}], ",", 
       "  ", "\[IndentingNewLine]", 
       RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
       RowBox[{"All", " ", "\[Rule]", " ", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
         "PlaceValue", ",", " ", "PlaceValueH", ",", " ", "PlaceValueDigits", 
          ",", "\[IndentingNewLine]", "PlaceValueDigits$Language", ",", 
          "PlaceValueBlock", ",", "\[IndentingNewLine]", 
          "PlaceValueIntegerName", ",", " ", "PartialPlaceValue", ",", " ", 
          "PlaceValueTable"}], "}"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PronounceInteger", "::", "unk"}], " ", "=", " ", 
     "\"\<Unknown Level -> `1` and Method -> `2`\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PronounceInteger", "[", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "m", ",", " ", "lan", ",", " ", "all", ",", " ", "rul", ",", " ", 
        "res", ",", " ", "speakq", ",", " ", "lev", ",", " ", "k"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "lev", ",", " ", "m", ",", " ", "lan", ",", " ", "all", ",", " ", 
          "speakq"}], "}"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "Level", ",", " ", "Method", ",", " ", "Language", ",", " ", "All",
             ",", " ", "Speak"}], "}"}], " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PronounceInteger", "]"}]}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"rul", " ", "=", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lan", " ", "===", " ", "$Language"}], ",", " ", 
          RowBox[{"ToExpression", "[", "\"\<Sequence[]\>\"", "]"}], ",", " ", 
          RowBox[{"Language", " ", "\[Rule]", " ", "lan"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"k", " ", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{
         "lev", ",", " ", "\[IndentingNewLine]", "1", ",", " ", "PlaceValue", 
          ",", "\[IndentingNewLine]", "2", ",", " ", "PlaceValueDigits", ",", 
          "\[IndentingNewLine]", "3", ",", " ", "PlaceValueBlock", ",", 
          "\[IndentingNewLine]", "4", ",", " ", "PlaceValueIntegerName", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"-", "4"}], ",", " ", "PartialPlaceValue", ",", 
          "\[IndentingNewLine]", "_", ",", " ", "Null"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"MemberQ", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", " ", "1", ",", " ", "2", ",", " ", "3", 
             ",", " ", "4"}], "}"}], ",", " ", "lev"}], "]"}], ",", " ", 
         RowBox[{"Return", "[", 
          RowBox[{"k", "[", 
           RowBox[{"n", ",", " ", "rul", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "speakq"}], ",", " ", 
            "opts"}], "]"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "routines", " ", "that", " ", "have", " ", "not", " ", "been", " ", 
         "assigned", " ", "a", " ", "level"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"MemberQ", "[", 
          RowBox[{"all", ",", " ", "m"}], "]"}], ",", " ", 
         RowBox[{"Return", "[", 
          RowBox[{"m", "[", 
           RowBox[{"n", ",", " ", "rul", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "speakq"}], ",", " ", 
            "opts"}], "]"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"PronounceInteger", "::", "unk"}], ",", " ", "lev", ",", " ",
          "m"}], "]"}], ";", " ", "\[IndentingNewLine]", "$Failed"}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PlaceValueIntegerName", "]"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Language", " ", "\[Rule]", " ", "\"\<English\>\""}], ",", " ", 
       RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
       RowBox[{"And", " ", "\[Rule]", " ", "\"\<, \>\""}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"pvoin", "[", 
      RowBox[{"x_", ",", " ", "lan_String"}], "]"}], " ", ":=", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"lan", " ", "===", " ", "\"\<English\>\""}], ",", " ", "x", 
       ",", "\[IndentingNewLine]", 
       RowBox[{"First", "[", 
        RowBox[{"WordTranslation", "[", 
         RowBox[{"x", ",", " ", 
          RowBox[{"\"\<English\>\"", " ", "\[Rule]", " ", "lan"}]}], "]"}], 
        "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"pvoin", "[", 
      RowBox[{"x_", ",", " ", "lan_String", ",", " ", "rul_"}], "]"}], " ", ":=",
      " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"lan", " ", "===", " ", "\"\<English\>\""}], ",", " ", "x", 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"First", "[", 
          RowBox[{"WordTranslation", "[", 
           RowBox[{"x", ",", " ", 
            RowBox[{"\"\<English\>\"", " ", "\[Rule]", " ", "lan"}]}], "]"}], 
          "]"}], ")"}], " ", "/.", " ", "rul"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueIntegerName", "[", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "lan", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"lan", "=", " ", 
        RowBox[{
         RowBox[{"Language", " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValueIntegerName", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"lan", " ", "===", " ", "$Language"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlaceValueIntegerName", "[", 
          RowBox[{"\"\<Fast\>\"", ",", " ", "n", ",", " ", "opts"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"PlaceValueIntegerName", "[", 
          RowBox[{"\"\<Slow\>\"", ",", " ", "n", ",", " ", "opts"}], "]"}]}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueIntegerName", "[", 
     RowBox[{"\"\<Fast\>\"", ",", " ", "n_Integer", ",", " ", "opts___Rule"}],
      "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "res", ",", " ", "lan", ",", " ", "speakq", ",", " ", "rul", ",", " ", 
        "toshow", ",", " ", "tospeak", ",", " ", "and", ",", "nopts", ",", 
        " ", "na"}], "}"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "IntegerName", " ", "in", " ", "English", " ", "displays", " ", 
         "blocks", " ", "of", " ", "3", " ", "digits"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"but", " ", "for", " ", "values", " ", 
          RowBox[{"Abs", "[", "n", "]"}]}], " ", "<", " ", 
         RowBox[{
         "1000", " ", "and", " ", "in", " ", "\[IndentingNewLine]", 
          "translation", " ", "it", " ", "switches", " ", "to", " ", 
          RowBox[{"names", ".", " ", "We"}], " ", "need", " ", "the", " ", 
          "digits"}]}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"lan", ",", " ", "speakq", ",", " ", "and"}], "}"}], " ", 
        "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Language", ",", " ", "Speak", ",", " ", "And"}], "}"}], 
          " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValueIntegerName", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Check", "[", 
        RowBox[{
         RowBox[{"IntegerName", "[", 
          RowBox[{"0", ",", " ", "\"\<Words\>\"", ",", " ", 
           RowBox[{"Language", " ", "->", " ", "lan"}]}], "]"}], ",", " ", 
         RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"speakq", " ", "=", " ", 
        RowBox[{"speakq", " ", "===", " ", "True"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"StringQ", "[", "and", "]"}]}], ",", "  ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"PlaceValue", "::", "str"}], " ", ",", " ", "And", ",", 
            " ", "and"}], "]"}], ";", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nopts", " ", "=", " ", 
        RowBox[{"Sequence", " ", "@@", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", "opts", "}"}], " ", "/.", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Rule", "[", 
              RowBox[{"And", ",", " ", "x_"}], "]"}], " ", "\[RuleDelayed]", 
             " ", 
             RowBox[{"Sequence", "[", "]"}]}], ")"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"rul", " ", "=", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lan", " ", "===", " ", "$Language"}], ",", " ", 
          RowBox[{"ToExpression", "[", "\"\<Sequence[]\>\"", "]"}], ",", " ", 
          RowBox[{"Language", " ", "\[Rule]", " ", "lan"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", "n", "]"}], " ", "<", " ", "1000"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Return", "[", 
          RowBox[{"PlaceValue", "[", 
           RowBox[{"n", ",", " ", "rul", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "speakq"}], ",", " ", 
            "nopts"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"IntegerName", "[", 
            RowBox[{"n", ",", " ", 
             RowBox[{"{", 
              RowBox[{"\"\<DigitsWords\>\"", ",", " ", "\"\<English\>\""}], 
              "}"}]}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"StringSplit", "[", "res", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"toshow", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"DigitQ", "[", "#", "]"}], ",", " ", "#", ",", " ", 
               RowBox[{
                RowBox[{"pvoin", "[", 
                 RowBox[{"#", ",", " ", "lan"}], "]"}], "<>", "and"}]}], 
              "]"}], "&"}], " ", "/@", " ", "res"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"toshow", " ", "=", " ", 
           RowBox[{"StringJoin", " ", "@@", "  ", 
            RowBox[{"Riffle", "[", 
             RowBox[{"toshow", " ", ",", " ", "\"\<  \>\""}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"na", "=", " ", 
           RowBox[{"StringLength", "[", "and", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"StringTake", "[", 
              RowBox[{"toshow", ",", " ", 
               RowBox[{"-", "na"}]}], "]"}], " ", "===", "  ", "and"}], ",", 
            " ", 
            RowBox[{"toshow", " ", "=", " ", 
             RowBox[{"StringDrop", "[", 
              RowBox[{"toshow", ",", " ", 
               RowBox[{"-", "na"}]}], "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"DigitQ", "[", "#", "]"}], ",", " ", 
               RowBox[{"ToExpression", "[", "#", "]"}], ",", " ", 
               RowBox[{
                RowBox[{"pvoin", "[", 
                 RowBox[{"#", ",", " ", "lan"}], "]"}], "<>", " ", "and"}]}], 
              "]"}], "&"}], " ", "/@", " ", "res"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"re", "-", 
            RowBox[{
            "introduce", " ", "English", " ", "because", " ", "of", " ", 
             "Amplish"}]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"res", " ", "/.", " ", 
            RowBox[{"x_Integer", " ", "\[RuleDelayed]", " ", 
             RowBox[{"PlaceValue", "[", 
              RowBox[{"x", ",", " ", "rul", ",", " ", 
               RowBox[{"Language", " ", "\[Rule]", " ", "\"\<English\>\""}], 
               ",", " ", 
               RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
               "nopts"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"tospeak", " ", "=", " ", 
           RowBox[{"StringJoin", " ", "@@", "  ", 
            RowBox[{"Riffle", "[", 
             RowBox[{"res", ",", " ", "\"\<  \>\""}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"StringTake", "[", 
              RowBox[{"tospeak", ",", " ", 
               RowBox[{"-", "na"}]}], "]"}], " ", "===", "  ", "and"}], ",", 
            " ", 
            RowBox[{"tospeak", " ", "=", " ", 
             RowBox[{"StringDrop", "[", 
              RowBox[{"tospeak", ",", " ", 
               RowBox[{"-", "na"}]}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"LatestPronunciation", "[", "]"}], "=", " ", "tospeak"}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"speakq", " ", "===", " ", "True"}], ",", " ", 
         RowBox[{"Speak", "[", "tospeak", "]"}]}], "]"}], ";", " ", 
       "\[IndentingNewLine]", "toshow"}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueIntegerName", "[", 
     RowBox[{"\"\<Slow\>\"", ",", " ", "n_Integer", ",", " ", "opts___Rule"}],
      "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "res", ",", " ", "lan", ",", " ", "speakq", ",", " ", "rul", ",", " ", 
        "toshow", ",", " ", "tospeak", ",", " ", "and", ",", "na", ",", " ", 
        "nopts", ",", " ", "sp", ",", " ", "h", ",", " ", "trans", ",", " ", 
        "las"}], "}"}], ",", " ", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "IntegerName", " ", "in", " ", "English", " ", "displays", " ", 
         "blocks", " ", "of", " ", "3", " ", "digits"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"but", " ", "for", " ", "values", " ", 
          RowBox[{"Abs", "[", "n", "]"}]}], " ", "<", " ", 
         RowBox[{
         "1000", " ", "and", " ", "in", " ", "\[IndentingNewLine]", 
          "translation", " ", "it", " ", "switches", " ", "to", " ", 
          RowBox[{"names", ".", " ", "We"}], " ", "need", " ", "the", " ", 
          "digits"}]}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"lan", ",", " ", "speakq", ",", " ", "and"}], "}"}], " ", 
        "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Language", ",", " ", "Speak", ",", " ", "And"}], "}"}], 
          " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValueIntegerName", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Check", "[", 
        RowBox[{
         RowBox[{"IntegerName", "[", 
          RowBox[{"0", ",", " ", "\"\<Words\>\"", ",", " ", 
           RowBox[{"Language", " ", "->", " ", "lan"}]}], "]"}], ",", " ", 
         RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"speakq", " ", "=", " ", 
        RowBox[{"speakq", " ", "===", " ", "True"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"StringQ", "[", "and", "]"}]}], ",", "  ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"PlaceValue", "::", "str"}], " ", ",", " ", "And", ",", 
            " ", "and"}], "]"}], ";", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nopts", " ", "=", " ", 
        RowBox[{"Sequence", " ", "@@", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", "opts", "}"}], " ", "/.", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Rule", "[", 
              RowBox[{"And", ",", " ", "x_"}], "]"}], " ", "\[RuleDelayed]", 
             " ", 
             RowBox[{"Sequence", "[", "]"}]}], ")"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"rul", " ", "=", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lan", " ", "===", " ", "$Language"}], ",", " ", 
          RowBox[{"ToExpression", "[", "\"\<Sequence[]\>\"", "]"}], ",", " ", 
          RowBox[{"Language", " ", "\[Rule]", " ", "lan"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", "n", "]"}], " ", "<", " ", "1000"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Return", "[", 
          RowBox[{"PlaceValue", "[", 
           RowBox[{"n", ",", " ", "rul", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "speakq"}], ",", " ", 
            "nopts"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"IntegerName", "[", 
            RowBox[{"n", ",", " ", 
             RowBox[{"{", 
              RowBox[{"\"\<DigitsWords\>\"", ",", " ", "\"\<English\>\""}], 
              "}"}]}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"StringSplit", "[", "res", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", "toshow", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"toshow", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"DigitQ", "[", "#", "]"}], ",", " ", "#", ",", " ", 
               RowBox[{
                RowBox[{"pvoin", "[", 
                 RowBox[{"#", ",", " ", "lan"}], "]"}], "<>", " ", "and"}]}], 
              "]"}], "&"}], " ", "/@", " ", "res"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"toshow", " ", "=", " ", 
           RowBox[{"StringJoin", " ", "@@", "  ", 
            RowBox[{"Riffle", "[", 
             RowBox[{"toshow", " ", ",", " ", "\"\<  \>\""}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"na", "=", " ", 
           RowBox[{"StringLength", "[", "and", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"StringTake", "[", 
              RowBox[{"toshow", ",", " ", 
               RowBox[{"-", "na"}]}], "]"}], " ", "===", "  ", "and"}], ",", 
            " ", 
            RowBox[{"toshow", " ", "=", " ", 
             RowBox[{"StringDrop", "[", 
              RowBox[{"toshow", ",", " ", 
               RowBox[{"-", "na"}]}], "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", "tospeak", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"h", "[", "x_", "]"}], " ", ":=", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Speak", "[", "x", "]"}], ";", "x"}], ")"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"sp", "[", "x_", "]"}], " ", ":=", " ", 
           RowBox[{"If", "[", 
            RowBox[{"speakq", ",", " ", 
             RowBox[{
              RowBox[{"Hold", "[", "h", "]"}], "[", "x", "]"}], ",", " ", 
             "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"trans", " ", "=", " ", 
           RowBox[{"PlaceValueRules", "[", 
            RowBox[{"Select", ",", "Power", ",", " ", "lan"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"trans", " ", "===", " ", "$Failed"}], " ", "||", " ", 
             RowBox[{"!", "speakq"}]}], ",", " ", 
            RowBox[{"trans", " ", "=", " ", 
             RowBox[{"ToExpression", "[", "\"\<Sequence[]\>\"", "]"}]}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"DigitQ", "[", "#", "]"}], ",", " ", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Hold", "[", " ", "PlaceValue", "]"}], "[", 
                RowBox[{
                 RowBox[{"ToExpression", "[", "#", "]"}], ",", " ", "rul", 
                 ",", " ", 
                 RowBox[{"Speak", " ", "\[Rule]", " ", "speakq"}], ",", " ", 
                 RowBox[{"Show", " ", "\[Rule]", " ", "True"}], ",", " ", 
                 "nopts"}], "]"}], ",", "\[IndentingNewLine]", 
               RowBox[{"sp", "[", 
                RowBox[{
                 RowBox[{"pvoin", "[", 
                  RowBox[{"#", ",", " ", "lan", ",", " ", "trans"}], "]"}], "<>",
                  " ", "and"}], "]"}]}], "]"}], "&"}], " ", "/@", " ", 
            "res"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{
           "clean", " ", "up", " ", "if", " ", "last", " ", "is", " ", "a", 
            " ", "base", " ", "with", " ", "and"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"las", " ", "=", " ", 
           RowBox[{"Last", "[", "res", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"las", " ", "=", " ", 
           RowBox[{"las", " ", "/.", " ", 
            RowBox[{"x_String", " ", "\[RuleDelayed]", " ", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"StringTake", "[", 
                 RowBox[{"x", ",", " ", 
                  RowBox[{"-", "na"}]}], "]"}], " ", "===", "  ", "and"}], 
               ",", " ", 
               RowBox[{"StringDrop", "[", 
                RowBox[{"x", ",", " ", 
                 RowBox[{"-", "na"}]}], "]"}], ",", " ", "x"}], "]"}]}]}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"Drop", "[", 
              RowBox[{"res", ",", " ", 
               RowBox[{"-", "1"}]}], "]"}], ",", " ", "las"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"ReleaseHold", "[", "res", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"tospeak", " ", "=", " ", 
           RowBox[{"StringJoin", " ", "@@", "  ", 
            RowBox[{"Riffle", "[", 
             RowBox[{"res", ",", " ", "\"\<  \>\""}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"LatestPronunciation", "[", "]"}], "=", " ", "tospeak"}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "toshow"}]}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PlaceValueDigits$Language", "]"}], " ", "=", 
     " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Length", " ", "\[Rule]", " ", "300"}], ",", " ", 
        RowBox[{"Simplify", " ", "\[Rule]", " ", "True"}], ",", " ", 
        RowBox[{"Join", " ", "\[Rule]", " ", "\"\<\[CenterDot]\>\""}], ",", 
        " ", 
        RowBox[{"And", " ", "\[Rule]", " ", "\"\<&\>\""}], ",", " ", 
        RowBox[{"StepMonitor", " ", "\[Rule]", " ", "False"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Speak", " ", "\[Rule]", " ", "True"}]}], "}"}], " ", "//", 
      " ", "Sort"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueDigits$Language", "[", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "g", ",", " ", "h", ",", " ", "len", ",", " ", "res", ",", " ", 
        "pause", ",", " ", "simpq", ",", " ", "np", ",", " ", "join", ",", 
        " ", "smq", ",", " ", "temp", ",", " ", "speakq", ",", " ", "and", 
        ",", " ", "paund"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "simpq", ",", " ", "pause", ",", " ", "join", ",", " ", "smq", ",", 
          " ", "speakq", ",", " ", "and"}], "}"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "Simplify", ",", " ", "Length", ",", " ", "Join", ",", " ", 
            "StepMonitor", ",", " ", "Speak", ",", " ", "And"}], "}"}], " ", "/.",
           " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValueDigits$Language", "]"}]}]}], " ", 
       ";", "\[IndentingNewLine]", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"StringQ", "[", "and", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"PlaceValue", "::", "str"}], ",", " ", "\"\<and\>\"", ",",
             " ", "and"}], "]"}], ";", " ", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"join", " ", "=", " ", 
        RowBox[{"StringJoin", "[", 
         RowBox[{"\"\< \>\"", ",", " ", "join", ",", " ", "\"\< \>\""}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"NumberQ", "[", "pause", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"pause", " ", "=", " ", 
          RowBox[{"\"\< <silence msec=\\\"\>\"", " ", "<>", " ", 
           RowBox[{"ToString", "[", "pause", "]"}], " ", "<>", " ", 
           "\"\<\\\"/> \>\""}]}], " ", ",", "\[IndentingNewLine]", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"PlaceValue", "::", "pau"}], ",", " ", "pause"}], "]"}], 
          ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"h", " ", "=", " ", 
        RowBox[{"IntegerDigits", "[", "n", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", " ", "=", " ", 
        RowBox[{"Length", "[", "h", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"g", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"10", "^", "k"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"k", ",", " ", "0", ",", " ", "len"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"g", " ", "=", " ", 
        RowBox[{"Reverse", "[", 
         RowBox[{"Take", "[", 
          RowBox[{"g", ",", " ", "len"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"Inner", "[", 
         RowBox[{"times", ",", " ", "h", ",", " ", "g", ",", " ", "TheSum"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "no", " ", "speaking", " ", "since", " ", "wrong", " ", "pauses"}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"smq", " ", "===", " ", "True"}], " ", ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"temp", " ", "=", " ", 
           RowBox[{"ToString", "[", "res", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"temp", " ", "=", " ", 
           RowBox[{"StringReplace", "[", 
            RowBox[{"temp", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"ToString", "[", "times", "]"}], " ", "\[Rule]", " ", 
                "\"\<times\>\""}], ",", " ", 
               RowBox[{
                RowBox[{"ToString", "[", "TheSum", "]"}], " ", "\[Rule]", 
                " ", "\"\<TheSum\>\""}]}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Print", "[", "temp", "]"}], ";"}]}], " ", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Speak", "[", "temp", "]"}], " ", "*)"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"simpq", " ", "===", " ", "True"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"res", " ", "/.", " ", 
            RowBox[{
             RowBox[{"times", "[", 
              RowBox[{"0", ",", " ", "x_"}], "]"}], " ", "\[RuleDelayed]", 
             " ", 
             RowBox[{"Sequence", "[", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"res", " ", "/.", " ", 
            RowBox[{
             RowBox[{"times", "[", " ", 
              RowBox[{"1", ",", " ", "x_"}], "]"}], " ", "\[RuleDelayed]", 
             " ", "x"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"res", " ", "/.", " ", 
            RowBox[{
             RowBox[{"times", "[", " ", 
              RowBox[{"x_", ",", " ", "1"}], "]"}], " ", "\[RuleDelayed]", 
             " ", "x"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"n", " ", "===", " ", "0"}], ",", " ", 
            RowBox[{"res", " ", "=", " ", 
             RowBox[{"{", "0", "}"}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
        "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"res", " ", "/.", " ", 
         RowBox[{"TheSum", " ", "\[Rule]", " ", "List"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"paund", " ", "=", " ", 
        RowBox[{
        "pause", " ", "<>", " ", "\"\< \>\"", " ", "<>", " ", "and", " ", "<>",
          " ", "\"\<   \>\""}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"StringJoin", "[", 
           RowBox[{"paund", ",", " ", 
            RowBox[{"ToString", "[", "#", "]"}]}], "]"}], "&"}], " ", "/@", 
         " ", "res"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"StringJoin", " ", "@@", " ", "res"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"StringDrop", "[", 
         RowBox[{"res", ",", "  ", 
          RowBox[{"StringLength", "[", "paund", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"n", " ", "<", " ", "0"}], ",", "  ", 
         RowBox[{"res", " ", "=", " ", 
          RowBox[{"StringJoin", "[", 
           RowBox[{"\"\<negative \>\"", ",", " ", "res"}], "]"}]}]}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"StringReplace", "[", 
         RowBox[{"res", ",", " ", 
          RowBox[{"{", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"ToString", "[", "TheSum", "]"}], "\[Rule]", " ", 
             "\"\<\>\""}], ",", " ", 
            RowBox[{
             RowBox[{"ToString", "[", "times", "]"}], "\[Rule]", " ", 
             "\"\<\>\""}], ",", "  ", 
            RowBox[{"\"\<, \>\"", " ", "\[Rule]", "  ", "join"}], ",", " ", 
            RowBox[{"\"\<[\>\"", " ", "\[Rule]", " ", "\"\<\>\""}], ",", " ", 
            RowBox[{"\"\<]\>\"", " ", "\[Rule]", " ", "\"\<\>\""}]}], "}"}]}],
          "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"speakq", " ", "===", " ", "True"}], ",", " ", 
         RowBox[{"Speak", "[", "res", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"LatestPronunciation", "[", "]"}], " ", "=", "res"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"res", ",", " ", 
         RowBox[{"pause", " ", "\[Rule]", " ", "\"\<  \>\""}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PronounceIntegers", "[", "x__", "]"}], " ", ":=", " ", 
    RowBox[{"PlaceValue", "[", "x", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueH", "[", 
     RowBox[{"n_", ",", " ", "opts___Rule"}], "]"}], " ", ":=", " ", 
    RowBox[{"PlaceValue", "[", 
     RowBox[{
      RowBox[{"n", " ", "/.", " ", 
       RowBox[{"H", " ", "\[Rule]", " ", 
        RowBox[{"-", "1"}]}]}], ",", " ", "opts"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"digits", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<zero\>\"", ",", " ", "\"\<one\>\"", ",", " ", "\"\<two\>\"", ",", 
       " ", "\"\<three\>\"", ",", " ", "\"\<four\>\"", ",", " ", 
       "\"\<five\>\"", ",", " ", "\"\<six\>\"", ",", " ", "\"\<seven\>\"", 
       ",", " ", "\"\<eight\>\"", ",", " ", "\"\<nine\>\""}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powers", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<ten\>\"", ",", " ", "\"\<hundred\>\"", ",", " ", 
       "\"\<thousand\>\"", ",", " ", "\"\<myriad\>\"", ",", " ", 
       "\"\<lakh\>\"", ",", " ", "\"\<million\>\""}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "[", "IntegerDigits", "]"}], " ", "=", " ", 
     "digits"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "[", "Power", "]"}], " ", "=", " ", "powers"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "amp", " ", "=", "  ", "\"\<\!\(\*StyleBox[\"&\",FontSize->10]\)\>\""}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<English\>\"", "]"}], "  ", "=", " ",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"True", " ", "\[Rule]", "  ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negative\>\""}], ",", 
         "  ", 
         RowBox[{"And", "  ", "\[Rule]", " ", "\"\<&\>\""}], ",", " ", 
         RowBox[{"N", " ", "\[Rule]", " ", "digits"}], ",", " ", 
         RowBox[{"Power", " ", "\[Rule]", "  ", "powers"}]}], "}"}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<Amplish\>\"", "]"}], "  ", "=", " ",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"True", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negative\>\""}], ",", 
          "  ", 
          RowBox[{"And", "  ", "\[Rule]", " ", "amp"}], ",", " ", 
          RowBox[{"N", " ", "\[Rule]", " ", "digits"}], ",", " ", 
          RowBox[{"Power", " ", "\[Rule]", "  ", "powers"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"\"\<English\>\"", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negative\>\""}], ",", 
          "  ", 
          RowBox[{"And", "  ", "\[Rule]", "  ", "\"\<&\>\""}], ",", " ", 
          RowBox[{"N", " ", "\[Rule]", " ", "digits"}], ",", " ", 
          RowBox[{"Power", " ", "\[Rule]", "  ", "powers"}]}], "}"}]}]}], 
      "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<Englishty\>\"", "]"}], "  ", "=", 
     " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"True", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negative\>\""}], ",", 
          "  ", 
          RowBox[{"And", "  ", "\[Rule]", " ", "amp"}], ",", " ", 
          RowBox[{"N", " ", "\[Rule]", " ", "digits"}], ",", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<ty\>\"", ",", " ", "\"\<hundred\>\"", ",", " ", 
             "\"\<thousand\>\"", ",", " ", "\"\<myriad\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<million\>\""}], "}"}]}]}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"\"\<English\>\"", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negative\>\""}], ",", 
          "  ", 
          RowBox[{"And", "  ", "\[Rule]", "  ", "\"\<&\>\""}], ",", " ", 
          RowBox[{"N", " ", "\[Rule]", " ", "digits"}], ",", " ", 
          RowBox[{"Power", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<tee\>\"", ",", " ", "\"\<hundred\>\"", ",", " ", 
             "\"\<thousand\>\"", ",", " ", "\"\<myriad\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<million\>\""}], "}"}]}]}], 
         "}"}]}]}], "\[IndentingNewLine]", "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"not", " ", "\"\<English\>\""}], ","}], " ", "*)"}], " ", 
       RowBox[{
       "\"\<Dutch\>\"", ",", " ", "\"\<French\>\"", ",", " ", 
        "\"\<German\>\"", ",", " ", "\"\<Danish\>\"", ",", " ", 
        "\"\<Amplish\>\"", ",", " ", "\"\<Englishty\>\""}], "}"}], " ", "//", 
      " ", "Sort"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<Checked\>\"", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"{", "\"\<English\>\"", "}"}], " ", "~", "Join", "~", "  ", 
      RowBox[{"PlaceValueRules", "[", "]"}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<Dutch\>\"", "]"}], "  ", "=", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"True", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<min\>\""}], " ", 
          RowBox[{"(*", " ", "\"\<negatief\>\"", " ", "*)"}], ",", " ", 
          RowBox[{"And", "  ", "\[Rule]", " ", "amp"}], ",", " ", 
          RowBox[{"(*", "\"\<en\>\"", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<nul\>\"", ",", " ", "\"\<een\>\"", ",", " ", "\"\<twee\>\"", 
             ",", " ", "\"\<drie\>\"", ",", " ", "\"\<vier\>\"", ",", " ", 
             "\"\<vijf\>\"", ",", " ", "\"\<zes\>\"", ",", " ", 
             "\"\<zeven\>\"", ",", " ", "\"\<acht\>\"", ",", " ", 
             "\"\<negen\>\""}], "}"}]}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<tig\>\"", ",", " ", "\"\<honderd\>\"", ",", " ", 
             "\"\<duizend\>\"", ",", " ", "\"\<myriad\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<miljoen\>\""}], "}"}]}]}], 
         "}"}]}], ",", "  ", "\[IndentingNewLine]", 
       RowBox[{"\"\<English\>\"", "\[Rule]", "  ", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<min\>\""}], " ", 
          RowBox[{"(*", "\"\<nayguhteef\>\"", "*)"}], ",", " ", 
          RowBox[{"And", " ", "\[Rule]", " ", "\"\<n\>\""}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<nuhl\>\"", ",", " ", "\"\<ayn\>\"", ",", " ", "\"\<tway\>\"",
              ",", " ", "\"\<dree\>\"", ",", " ", "\"\<fear\>\"", ",", " ", 
             "\"\<vaif\>\"", ",", " ", "\"\<zes\>\"", " ", ",", 
             "\"\<zayven\>\"", ",", "  ", "\"\<ahgt\>\"", 
             RowBox[{"(*", 
              RowBox[{"\"\<akht\>\"", " ", "\"\<ugt\>\""}], "*)"}], ",", 
             "  ", "\"\<naigen\>\""}], " ", "}"}]}], ",", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<tikgh\>\"", ",", " ", "\"\<hon dairt\>\"", ",", " ", 
             "\"\<duuzand\>\"", ",", " ", "\"\<myriad\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<milyoon\>\""}], "}"}]}]}], 
         "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"deux", " ", "as", " ", "in", " ", "bird"}], ",", " ", 
     RowBox[{
     "but", " ", "no", " ", "way", " ", "to", " ", "get", " ", "it"}]}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<French\>\"", "]"}], "  ", "=", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"True", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negative\>\""}], " ", 
          ",", " ", 
          RowBox[{"And", "  ", "\[Rule]", "  ", "amp"}], ",", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"And", " ", "\[Rule]", " ", "\"\<et\>\""}], ","}], " ", 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<zero\>\"", ",", " ", "\"\<un\>\"", ",", " ", "\"\<deux\>\"", 
             ",", " ", "\"\<trois\>\"", ",", " ", "\"\<quatre\>\"", ",", " ", 
             "\"\<cinq\>\"", ",", " ", "\"\<six\>\"", ",", " ", 
             "\"\<sept\>\"", ",", " ", "\"\<huit\>\"", ",", " ", 
             "\"\<neuf\>\""}], " ", "}"}]}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<dix\>\"", ",", " ", "\"\<cent\>\"", ",", " ", 
             "\"\<mille\>\"", ",", " ", "\"\<myriade\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<million\>\""}], "}"}]}]}], 
         "}"}]}], ",", "  ", "\[IndentingNewLine]", 
       RowBox[{"\"\<English\>\"", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<nayguhteef\>\""}], 
          ",", " ", 
          RowBox[{"And", " ", "\[Rule]", " ", "\"\<ayh\>\""}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<zeyrouh\>\"", ",", " ", "\"\<uhnn\>\"", ",", " ", 
             "\"\<duh\>\"", ",", " ", "\"\<trouwah\>\"", ",", " ", 
             "\"\<kahtruh\>\"", ",", " ", "\"\<saink\>\"", ",", " ", 
             "\"\<sees\>\"", ",", " ", "\"\<seht\>\"", ",", " ", 
             "\"\<weet\>\"", ",", " ", "\"\<neuhf\>\""}], " ", "}"}]}], ",", 
          " ", "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<dees\>\"", ",", " ", "\"\<sun\>\"", ",", " ", "\"\<meel\>\"",
              ",", " ", "\"\<meeri udd\>\"", ",", " ", "\"\<lakh\>\"", ",", 
             " ", "\"\<meelyon\>\""}], "}"}]}]}], "}"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<German\>\"", "]"}], "  ", "=", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"True", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negativ\>\""}], " ", 
          ",", " ", 
          RowBox[{"And", "  ", "\[Rule]", " ", "amp"}], ",", " ", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"And", " ", "\[Rule]", " ", "\"\<und\>\""}], ","}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<null\>\"", ",", " ", "\"\<ein\>\"", ",", " ", "\"\<zwei\>\"",
              ",", " ", "\"\<drei\>\"", ",", " ", "\"\<vier\>\"", ",", " ", 
             "\"\<fuenf\>\"", ",", " ", "\"\<sechs\>\"", ",", " ", 
             "\"\<sieb\>\"", ",", " ", "\"\<acht\>\"", ",", " ", 
             "\"\<neun\>\""}], " ", "}"}]}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<zig\>\"", ",", " ", "\"\<hundert\>\"", ",", " ", 
             "\"\<tausend\>\"", ",", " ", "\"\<myriad\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<million\>\""}], "}"}]}]}], 
         "}"}]}], ",", "  ", "\[IndentingNewLine]", 
       RowBox[{"\"\<English\>\"", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<nayguhteef\>\""}], 
          ",", " ", 
          RowBox[{"And", " ", "\[Rule]", " ", "\"\<oond\>\""}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<noul\>\"", ",", " ", "\"\<ayen\>\"", ",", " ", 
             "\"\<tsvwaayie\>\"", ",", " ", "\"\<dryie\>\"", ",", " ", 
             "\"\<fear\>\"", ",", " ", "\"\<fuihnf\>\"", ",", " ", 
             "\"\<sex\>\"", ",", " ", "\"\<sieb\>\"", ",", " ", 
             "\"\<akht\>\"", ",", " ", "\"\<noin\>\""}], " ", "}"}]}], ",", 
          " ", "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<tzeeg\>\"", ",", " ", "\"\<hoondert\>\"", ",", " ", 
             "\"\<tausand\>\"", ",", " ", "\"\<myriad\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<meelyohn\>\""}], "}"}]}]}], 
         "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValueRules", "[", "\"\<Danish\>\"", "]"}], "  ", "=", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"True", " ", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<negativ\>\""}], " ", 
          ",", " ", 
          RowBox[{"And", "  ", "\[Rule]", " ", "amp"}], ",", " ", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"And", " ", "\[Rule]", " ", "\"\<og\>\""}], ","}], "*)"}],
           "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<nul\>\"", ",", " ", "\"\<en\>\"", ",", " ", "\"\<to\>\"", 
             ",", " ", "\"\<tre\>\"", ",", " ", "\"\<fire\>\"", ",", " ", 
             "\"\<fem\>\"", ",", " ", "\"\<seks\>\"", ",", " ", "\"\<syv\>\"",
              ",", " ", "\"\<otte\>\"", ",", " ", "\"\<ni\>\""}], " ", 
            "}"}]}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<ti\>\"", ",", " ", "\"\<hundrede\>\"", ",", " ", 
             "\"\<tusind\>\"", ",", " ", "\"\<myriade\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<million\>\""}], "}"}]}]}], 
         "}"}]}], ",", "  ", "\[IndentingNewLine]", 
       RowBox[{"\"\<English\>\"", "\[Rule]", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", "\"\<nayguhtew\>\""}], ",",
           " ", 
          RowBox[{"And", " ", "\[Rule]", " ", "\"\<oh\>\""}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<nul\>\"", ",", " ", "\"\<ayn\>\"", ",", " ", "\"\<toh\>\"", 
             ",", " ", "\"\<trya\>\"", ",", " ", "\"\<fear\>\"", ",", " ", 
             "\"\<fem\>\"", ",", " ", "\"\<sex\>\"", ",", " ", "\"\<suwe\>\"",
              ",", " ", "\"\<ude\>\"", ",", " ", "\"\<knee\>\""}], " ", 
            "}"}]}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{
            "\"\<tee\>\"", ",", " ", "\"\<hoonah\>\"", ",", " ", 
             "\"\<toosind\>\"", ",", " ", "\"\<myriade\>\"", ",", " ", 
             "\"\<lakh\>\"", ",", " ", "\"\<meelyohn\>\""}], "}"}]}]}], 
         "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueRules", "[", 
     RowBox[{"Set", ",", " ", "lan_String", ",", " ", 
      RowBox[{"org_String:", "\"\<English\>\""}]}], "]"}], " ", " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", " ", "f", ",", " ", "g", ",", " ", "zero"}], "}"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Check", "[", 
        RowBox[{
         RowBox[{"IntegerName", "[", 
          RowBox[{"0", ",", " ", "\"\<Words\>\"", ",", " ", 
           RowBox[{"Language", " ", "->", " ", "lan"}]}], "]"}], ",", " ", 
         RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f", "[", "x_", "]"}], " ", ":=", " ", 
        RowBox[{"IntegerName", "[", 
         RowBox[{"x", ",", " ", "\"\<Words\>\"", ",", " ", 
          RowBox[{"Language", " ", "->", " ", "lan"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g", "[", "x_", "]"}], " ", ":=", " ", 
        RowBox[{"First", "[", 
         RowBox[{"WordTranslation", "[", 
          RowBox[{"x", ",", " ", 
           RowBox[{"org", " ", "\[Rule]", " ", "lan"}]}], "]"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Negative", " ", "\[Rule]", " ", 
           RowBox[{"g", "[", "\"\<negative\>\"", "]"}]}], ",", " ", 
          RowBox[{"And", " ", "\[Rule]", " ", 
           RowBox[{"g", "[", "\"\<and\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"N", " ", "\[Rule]", " ", 
           RowBox[{"(", 
            RowBox[{"f", " ", "/@", " ", 
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", " ", "9"}], "]"}]}], ")"}]}], ",", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"Power", " ", "\[Rule]", "  ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"f", "[", "10", "]"}], ",", " ", 
             RowBox[{"f", "[", "100", "]"}], ",", " ", 
             RowBox[{"f", "[", "100", "]"}], ",", " ", "\"\<myriad\>\"", ",", 
             " ", "\"\<lakh\>\"", ",", "  ", 
             RowBox[{"g", "[", "\"\<million\>\"", "]"}]}], "}"}]}]}], 
         "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{
         RowBox[{"PlaceValueRules", "[", "]"}], ",", " ", "lan"}], "]"}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"PlaceValueRules", "[", 
        RowBox[{"Check", ",", " ", "lan"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Set", "[", 
        RowBox[{
         RowBox[{"PlaceValueRules", "[", "lan", "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"True", " ", "\[Rule]", " ", "res"}], ",", "  ", 
           RowBox[{"org", " ", "\[Rule]", " ", "res"}]}], "}"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueRules", "[", 
     RowBox[{"Select", ",", " ", "item_", ",", " ", "lan_String", ",", " ", 
      RowBox[{"trans_String:", "\"\<English\>\""}]}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", " ", "true"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"PlaceValueRules", "[", "]"}], ",", " ", "lan"}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"res", " ", "=", " ", 
          RowBox[{"PlaceValueRules", "[", "lan", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"true", " ", "=", " ", 
          RowBox[{"True", " ", "/.", " ", "res"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"true", " ", "=", " ", 
          RowBox[{"item", " ", "/.", " ", "true"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"res", " ", "=", " ", 
          RowBox[{"trans", " ", "/.", " ", "res"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"res", " ", "=", " ", 
          RowBox[{"item", "/.", " ", "res"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Thread", "[", 
          RowBox[{"true", " ", "\[Rule]", " ", "res"}], "]"}]}], ",", " ", 
        "$Failed"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"compose", "[", 
     RowBox[{
     "digits_List", ",", " ", "lis_List", ",", " ", "pause_String", ",", " ", 
      "s_Integer", ",", " ", "neg_String", ",", " ", "and_String"}], "]"}], 
    " ", ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"combination", ",", " ", "paund"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"paund", " ", "=", " ", 
        RowBox[{
        "pause", " ", "<>", " ", "\"\< \>\"", "  ", "<>", " ", "and", " ", "<>",
          " ", "\"\<  \>\""}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"combination", " ", "=", "  ", 
        RowBox[{"MapThread", "[", 
         RowBox[{"StringJoin", ",", " ", 
          RowBox[{"{", 
           RowBox[{"digits", " ", ",", " ", "lis"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"combination", " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"paund", " ", "<>", " ", "#"}], "  ", "&"}], "/@", " ", 
         "combination"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"combination", " ", "=", " ", 
        RowBox[{"StringJoin", " ", "@@", " ", "combination"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"combination", " ", "=", " ", 
        RowBox[{"StringDrop", "[", 
         RowBox[{"combination", ",", " ", 
          RowBox[{"StringLength", "[", "paund", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"s", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{
         "neg", " ", "<>", " ", "pause", " ", "<>", " ", "combination"}], ",",
          " ", "combination"}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PlaceValue", "]"}], " ", "=", " ", 
     RowBox[{"reset", " ", "=", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", " ", "\[Rule]", " ", "False"}], ",", " ", 
         RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Amplish\>\""}], ",", 
         " ", 
         RowBox[{
         "SpeakTransliteration", "  ", "\[RuleDelayed]", " ", "$Language"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Length", " ", "\[Rule]", " ", "300"}], " ", 
         RowBox[{"(*", " ", 
          RowBox[{"was", " ", "\"\< <silence msec=\\\"300\\\"/> \>\""}], " ", 
          "*)"}], ",", " ", "\[IndentingNewLine]", 
         RowBox[{"Simplify", " ", "\[Rule]", "  ", "True"}], ",", " ", 
         RowBox[{"Join", " ", "\[Rule]", " ", "\"\<\[CenterDot]\>\""}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"WordTranslation", " ", "\[Rule]", " ", "Automatic"}]}], 
        "}"}], "  ", "//", " ", "Sort"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValue", "[", 
     RowBox[{"Options", ",", " ", "\"\<Reset\>\""}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Unprotect", "[", "PlaceValue", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Options", "[", "PlaceValue", "]"}], " ", "=", " ", "reset"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Protect", "[", "PlaceValue", "]"}], ";", " ", "reset"}], " ", 
     ")"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "rul"}], " ", "=", " ", 
     "\"\<No list of rules found for `1` `2`\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "int"}], " ", "=", " ", 
     "\"\<Initialisation with IntegerName and WordTranslation: please \
wait\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "len"}], " ", "=", " ", 
     "\"\<Length of `1` is not `2` but `3`\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "num"}], " ", "=", " ", 
     "\"\<No list of names found for `1` `2`\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "not"}], " ", "=", " ", 
     "\"\<Not tested: Speak with other than $Language\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "ran"}], " ", "=", " ", 
     "\"\<Integer not in domain -`1` < `2` < `1`\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "pau"}], " ", "=", " ", 
     "\"\<Pause length `1` must be a number\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "::", "str"}], " ", "=", " ", 
     "\"\<Symbol for `1` is `2` but must be a string\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"inputtest", "[", 
     RowBox[{
     "ns_", ",", " ", "ps_", ",", " ", "type_", ",", " ", "neg_", ",", " ", 
      "and_"}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"ListQ", "[", "ns", "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"PlaceValue", "::", "num"}], " ", ",", " ", 
           RowBox[{"{", 
            RowBox[{"type", ",", "\"\<digits\>\""}], "}"}], ",", " ", "ns"}], 
          "]"}], ";", 
         RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"ListQ", "[", "ps", "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"PlaceValue", "::", "num"}], " ", ",", 
           RowBox[{"{", 
            RowBox[{"type", ",", "\"\<powers\>\""}], "}"}], ",", " ", "ps"}], 
          "]"}], ";", 
         RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "ns", "]"}], " ", "=!=", " ", "10"}], ",", 
        " ", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"PlaceValue", "::", "len"}], " ", ",", 
           RowBox[{"{", 
            RowBox[{"type", ",", "\"\<digits\>\""}], "}"}], ",", " ", "10", 
           ",", " ", 
           RowBox[{"Length", "[", "ns", "]"}]}], "]"}], ";", " ", 
         RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "ps", "]"}], " ", "=!=", " ", "6"}], ",", " ", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"PlaceValue", "::", "len"}], " ", ",", " ", 
           RowBox[{"{", 
            RowBox[{"type", ",", "\"\<powers\>\""}], "}"}], ",", " ", "6", 
           ",", " ", 
           RowBox[{"Length", "[", "ps", "]"}]}], "]"}], ";", " ", 
         RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "  ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"StringQ", "[", "neg", "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"PlaceValue", "::", "str"}], ",", " ", "\"\<negative\>\"", 
           ",", " ", "neg"}], "]"}], ";", " ", 
         RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"StringQ", "[", "and", "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"PlaceValue", "::", "str"}], ",", " ", "\"\<and\>\"", ",", 
           " ", "and"}], "]"}], ";", " ", 
         RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";"}], 
     "\[IndentingNewLine]", "  ", ")"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pihelper", "[", 
     RowBox[{
     "n_Integer", ",", " ", "neg_String", ",", " ", "ipause_String", ",", " ",
       "nsi_List", ",", " ", "psi_List", ",", " ", "simpq_", ",", " ", 
      "join_String", ",", " ", "speakq_", ",", " ", "and_String"}], "]"}], 
    " ", ":=", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "pause", ",", " ", "s", ",", " ", "powers", ",", " ", "d", ",", " ", 
        "digits", ",", " ", "len", ",", " ", "lis", ",", " ", "sel", ",", " ",
         "h", ",", " ", "zeros", ",", " ", "pos", ",", " ", "ns", " ", ",", 
        " ", "ps"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pause", " ", "=", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"speakq", " ", "=!=", " ", "True"}], ",", " ", "\"\< \>\"", 
          ",", " ", "ipause"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"s", " ", "=", " ", 
        RowBox[{"Sign", "[", "n", "]"}]}], ";", " ", 
       RowBox[{"ns", " ", "=", " ", "nsi"}], ";", " ", 
       RowBox[{"ps", " ", "=", " ", "psi"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"**", " ", "actual"}], " ", "***)"}], "\[IndentingNewLine]", 
       RowBox[{"PrependTo", "[", 
        RowBox[{"ps", ",", " ", 
         RowBox[{"ns", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"powers", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"10", "^", "k"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"k", ",", " ", "0", ",", " ", "6"}], "}"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"d", "=", " ", 
        RowBox[{"IntegerDigits", "[", "n", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"digits", " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"ns", "[", 
           RowBox[{"[", 
            RowBox[{"#", "+", "1"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
         "d"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"len", " ", "=", " ", 
        RowBox[{"Length", "[", "d", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"lis", " ", "=", " ", 
        RowBox[{"Take", "[", 
         RowBox[{"ps", ",", " ", "len"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "basically", " ", "finished", " ", "but", " ", "simplification"}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", "1", " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"simpq", " ", "===", " ", "True"}], ",", "  ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"h", " ", "=", " ", 
           RowBox[{"Last", "[", "d", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"ns", ",", " ", "\"\<\>\""}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"d", " ", "=", " ", 
           RowBox[{"d", " ", "/.", " ", 
            RowBox[{"1", " ", "\[Rule]", " ", "10"}]}]}], "  ", ";", 
          "\[IndentingNewLine]", 
          RowBox[{"digits", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"ns", "[", 
              RowBox[{"[", 
               RowBox[{"#", "+", "1"}], "]"}], "]"}], "&"}], " ", "/@", " ", 
            "d"}]}], ";", " ", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"h", " ", "=!=", " ", "1"}], ",", " ", 
            RowBox[{"(*", 
             RowBox[{
              RowBox[{
              "then", " ", "not", " ", "removed", " ", "at", " ", "the", " ", 
               "last", " ", "position"}], ",", " ", 
              RowBox[{"and", " ", "thus", " ", "adjust", " ", "lis"}]}], 
             "*)"}], "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"lis", " ", "=", " ", 
              RowBox[{
               RowBox[{"{", "\"\<\>\"", "}"}], " ", "~", "Join", "~", " ", 
               RowBox[{"Rest", "[", "lis", "]"}]}]}], ";"}]}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{"reverse", ":", " ", 
             RowBox[{"india", " ", "and", " ", "arabia"}]}], " ", "*)"}], " ",
            "\[IndentingNewLine]", "]"}]}]}], "]"}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{"end", " ", "simpq"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"lis", " ", "=", "  ", 
        RowBox[{"Reverse", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"join", " ", "<>", " ", "#"}], "  ", "&"}], "/@", " ", 
          "lis"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", "0", " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"simpq", " ", "===", " ", "True"}], " ", "&&", " ", 
          RowBox[{"d", " ", "=!=", " ", 
           RowBox[{"{", "0", "}"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"zeros", " ", "=", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"#", " ", "===", " ", "0"}], ",", " ", "0", ",", " ", 
               "1"}], "]"}], "&"}], " ", "/@", " ", "d"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"pos", " ", "=", " ", 
           RowBox[{"Position", "[", 
            RowBox[{"zeros", ",", " ", "1"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pos", " ", "=!=", " ", 
             RowBox[{"{", "}"}]}], ",", "  ", 
            RowBox[{"(*", 
             RowBox[{"superfluous", " ", "..."}], "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"digits", " ", "=", " ", 
              RowBox[{"Extract", "[", 
               RowBox[{"digits", ",", " ", "pos"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"lis", " ", "=", " ", 
              RowBox[{"Extract", "[", 
               RowBox[{"lis", ",", " ", "pos"}], "]"}]}], ";"}]}], 
           "\[IndentingNewLine]", "]"}]}]}], "]"}], ";", " ", 
       RowBox[{"(*", 
        RowBox[{"end", " ", "simpq"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"compose", "[", 
        RowBox[{
        "digits", ",", " ", "lis", ",", " ", "pause", ",", " ", "s", ",", " ",
          "neg", ",", " ", "and"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValue", "[", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Catch", "[", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "ns", ",", " ", "ps", ",", " ", "speakq", ",", "  ", "combination", 
         ",", " ", "pause", ",", " ", "neg", ",", " ", "simpq", ",", " ", 
         "join", ",", " ", "translit", ",", " ", "lan", ",", " ", "rul", ",", 
         "  ", "lanrul", ",", " ", "nottested", ",", " ", "showq", ",", " ", 
         "missingq", ",", " ", "and"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "speakq", ",", " ", "pause", ",", " ", "simpq", ",", " ", "join", 
           ",", " ", "translit", ",", " ", "lan", ",", " ", "showq", ",", " ",
            "missingq"}], "}"}], "  ", "=", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "Speak", ",", " ", "Length", ",", " ", "Simplify", ",", " ", 
             "Join", ",", "SpeakTransliteration", ",", " ", "Language", ",", 
             " ", "Show", ",", " ", "WordTranslation"}], "}"}], " ", "/.", 
           " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
          RowBox[{"Options", "[", "PlaceValue", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"**", " ", "input"}], " ", "and", " ", "testing", " ", "of",
           " ", "it"}], " ", "***)"}], "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "also", " ", "test", " ", "even", " ", "when", " ", "not", " ", 
          "spoken"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"NumberQ", "[", "pause", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"pause", " ", "=", " ", 
           RowBox[{"\"\< <silence msec=\\\"\>\"", " ", "<>", " ", 
            RowBox[{"ToString", "[", "pause", "]"}], " ", "<>", " ", 
            "\"\<\\\"/> \>\""}]}], " ", ",", "\[IndentingNewLine]", " ", 
          RowBox[{
           RowBox[{"Message", "[", 
            RowBox[{
             RowBox[{"PlaceValue", "::", "pau"}], ",", " ", "pause"}], "]"}], 
           ";", 
           RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", "n", "]"}], " ", ">", " ", 
           RowBox[{
            RowBox[{"10", "^", "7"}], "-", "1"}]}], ",", " ", 
          RowBox[{
           RowBox[{"Message", "[", 
            RowBox[{
             RowBox[{"PlaceValue", "::", "ran"}], ",", "  ", "\"\<10^7\>\"", 
             ",", " ", "n"}], "]"}], ";", 
           RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"nottested", " ", "=", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"speakq", " ", "===", " ", "True"}], " ", "&&", " ", 
           RowBox[{"translit", " ", "=!=", " ", "$Language"}]}], ")"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"nottested", ",", " ", 
          RowBox[{"Message", "[", 
           RowBox[{"PlaceValue", "::", "not"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"if", " ", 
          RowBox[{"lan", " ", "<>", " ", "$Language"}], " ", "then", " ", 
          "write", " ", "in", " ", "lan", " ", "True", " ", "or", " ", 
          "speak", " ", "in", " ", "translit"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"lanrul", " ", "=", "  ", 
         RowBox[{"PlaceValueRules", "[", "lan", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"ListQ", "[", "lanrul", "]"}]}], ",", " ", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Message", "[", 
            RowBox[{
             RowBox[{"PlaceValue", "::", "rul"}], " ", ",", " ", 
             "\"\<language\>\"", ",", " ", "lan"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"missingq", " ", "===", " ", "Automatic"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Message", "[", 
               RowBox[{"PlaceValue", "::", "int"}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"Check", "[", 
               RowBox[{
                RowBox[{"IntegerName", "[", 
                 RowBox[{"0", ",", " ", "\"\<Words\>\"", ",", " ", 
                  RowBox[{"Language", " ", "->", " ", "lan"}]}], "]"}], ",", 
                " ", 
                RowBox[{"Throw", "[", "$Failed", "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"PlaceValueRules", "[", 
               RowBox[{"Set", ",", "lan"}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Throw", "[", "$Failed", "]"}]}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lan", " ", "===", " ", "translit"}], ",", " ", 
          RowBox[{"translit", " ", "=", " ", "True"}]}], "]"}], ";", " ", 
        RowBox[{"(*", "key", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "using", " ", "a", " ", "switch", " ", "in", " ", "case", " ", 
          "only", " ", "one", " ", "call", " ", "suffices"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"rul", " ", "=", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"speakq", " ", "===", " ", "True"}], ")"}], ",", " ", 
            "translit", ",", " ", "True"}], "]"}], " ", "/.", " ", 
          "lanrul"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"ListQ", "[", "rul", "]"}]}], ",", " ", 
          RowBox[{
           RowBox[{"Message", "[", 
            RowBox[{
             RowBox[{"PlaceValue", "::", "rul"}], " ", ",", 
             RowBox[{"{", 
              RowBox[{"translit", ",", " ", "True"}], "}"}], ",", " ", 
             "rul"}], "]"}], ";", 
           RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ns", ",", " ", "ps", ",", "  ", "neg", ",", " ", "and"}], 
          "}"}], "  ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "N", ",", " ", "Power", ",", " ", "Negative", ",", " ", "And"}], 
            "}"}], " ", "/.", " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", "rul"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"inputtest", "[", 
         RowBox[{
         "ns", ",", " ", "ps", ",", " ", "speakq", ",", " ", "neg", ",", " ", 
          "and"}], "]"}], " ", ";", "\[IndentingNewLine]", 
        RowBox[{"combination", " ", "=", " ", 
         RowBox[{"pihelper", "[", 
          RowBox[{
          "n", ",", " ", "neg", ",", " ", "pause", ",", " ", "ns", ",", " ", 
           "ps", ",", " ", "simpq", ",", " ", "join", ",", " ", "speakq", ",",
            " ", "and"}], "]"}]}], " ", ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"LatestPronunciation", "[", "]"}], " ", "=", "combination"}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"speakq", " ", "=!=", " ", "True"}], ",", " ", 
          "\[IndentingNewLine]", "combination", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Speak", "[", "combination", "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"showq", " ", "===", " ", "True"}], ",", " ", 
             "combination", ",", "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "redo", " ", "the", " ", "whole", " ", "thing", " ", "for", " ",
                "the", " ", "written", " ", "version"}], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "overdone", " ", "to", " ", "turn", " ", "this", " ", "into", 
               " ", "a", " ", "subroutine"}], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"rul", " ", "=", " ", 
               RowBox[{"True", " ", "/.", " ", "lanrul"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"!", 
                 RowBox[{"ListQ", "[", "rul", "]"}]}], ",", " ", 
                RowBox[{
                 RowBox[{"Message", "[", 
                  RowBox[{
                   RowBox[{"PlaceValue", "::", "rul"}], " ", ",", 
                   RowBox[{"{", 
                    RowBox[{"translit", ",", " ", "True"}], "}"}], ",", " ", 
                   "rul"}], "]"}], ";", 
                 RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"ns", ",", " ", "ps", ",", "  ", "neg", ",", "and"}], 
                "}"}], "  ", "=", " ", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                  "N", ",", " ", "Power", ",", " ", "Negative", ",", " ", 
                   "And"}], "}"}], " ", "/.", " ", 
                 RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", "rul"}]}], ";",
               "\[IndentingNewLine]", 
              RowBox[{"inputtest", "[", 
               RowBox[{
               "ns", ",", " ", "ps", ",", " ", "False", ",", " ", "neg", ",", 
                " ", "and"}], "]"}], " ", ";", "\[IndentingNewLine]", 
              RowBox[{"combination", " ", "=", " ", 
               RowBox[{"pihelper", "[", 
                RowBox[{
                "n", ",", " ", "neg", ",", " ", "pause", ",", " ", "ns", ",", 
                 " ", "ps", ",", " ", "simpq", ",", " ", "join", ",", " ", 
                 "False", ",", "and"}], "]"}]}]}]}], " ", 
            "\[IndentingNewLine]", "]"}]}]}], "]"}]}]}], " ", 
      RowBox[{"(*", "endif", "*)"}], "\[IndentingNewLine]", "]"}], "]"}]}], 
   " ", 
   RowBox[{"(*", 
    RowBox[{"end", " ", "catch", " ", "module"}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], "]"}], " ", ":=", 
    " ", 
    RowBox[{"{", "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "y_", ",", " ", "x_"}], "}"}], "]"}], " ", ":=", 
    " ", 
    RowBox[{"{", " ", 
     RowBox[{"myspeak", "[", 
      RowBox[{
       RowBox[{"y", " ", "*", " ", "10"}], " ", "+", " ", "x"}], "]"}], 
     "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", 
      RowBox[{"z_", ",", " ", "0", ",", " ", "0"}], "}"}], "]"}], " ", ":=", 
    " ", 
    RowBox[{"{", 
     RowBox[{"speak", "[", 
      RowBox[{
       RowBox[{"ToString", "[", "z", "]"}], " ", "<>", "  ", "hundred"}], 
      "]"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", 
      RowBox[{"z_", ",", " ", "y_", ",", " ", "x_"}], "}"}], "]"}], " ", ":=",
     " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"speak", "[", 
       RowBox[{
        RowBox[{"ToString", "[", "z", "]"}], " ", "<>", " ", "hundred"}], 
       "]"}], ",", " ", "nfx", ",", " ", 
      RowBox[{"myspeak", "[", 
       RowBox[{
        RowBox[{"y", " ", "*", " ", "10"}], " ", "+", " ", "x"}], "]"}]}], 
     "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0"}], "}"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", 
      RowBox[{"y_", ",", " ", "x_"}], "}"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", 
     RowBox[{"myspeak", "[", 
      RowBox[{
       RowBox[{"y", " ", "*", " ", "10"}], " ", "+", " ", "x"}], "]"}], 
     "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", "0", "}"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tosimp", "[", 
     RowBox[{"{", "x_", "}"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", 
     RowBox[{"speak", "[", "x", "]"}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tospeak", "[", 
     RowBox[{"{", 
      RowBox[{"z_", ",", " ", "y_", ",", " ", "x_"}], "}"}], "]"}], " ", ":=",
     " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"speak", "[", 
       RowBox[{
        RowBox[{"ToString", "[", "z", "]"}], " ", "<>", " ", "hundred"}], 
       "]"}], ",", "nfx", ",", "  ", 
      RowBox[{"myspeak", "[", 
       RowBox[{
        RowBox[{"y", " ", "*", " ", "10"}], " ", "+", " ", "x"}], "]"}]}], 
     "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tospeak", "[", 
     RowBox[{"{", 
      RowBox[{"y_", ",", " ", "x_"}], "}"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", 
     RowBox[{"myspeak", "[", 
      RowBox[{
       RowBox[{"y", " ", "*", " ", "10"}], " ", "+", " ", "x"}], "]"}], 
     "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tospeak", "[", 
     RowBox[{"{", "x_", "}"}], "]"}], " ", ":=", " ", 
    RowBox[{"{", 
     RowBox[{"speak", "[", "x", "]"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"this", " ", "applies", " ", "to", " ", "g"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tospeak", "[", "1", "]"}], " ", ":=", " ", "one"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tospeak", "[", "x_Integer", "]"}], " ", ":=", " ", 
    RowBox[{"speak", "[", "x", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PlaceValueBlock", "]"}], " ", "=", " ", 
     RowBox[{"resetblock", " ", "=", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Language", "  ", "\[Rule]", " ", "\"\<Amplish\>\""}], ",", 
         " ", 
         RowBox[{"And", " ", "\[Rule]", " ", "\"\<&\>\""}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Length", " ", "\[Rule]", " ", "300"}], ",", " ", 
         RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
         RowBox[{"Join", "  ", "\[Rule]", " ", "\"\<\[CenterDot]\>\""}], ",", 
         " ", 
         RowBox[{"Simplify", " ", "\[Rule]", " ", "True"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Power", " ", "\[Rule]", "  ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"10", "^", "6"}], " ", "\[Rule]", " ", 
             "\"\<million\>\""}], ",", " ", 
            RowBox[{
             RowBox[{"10", "^", "3"}], " ", "\[Rule]", " ", 
             "\"\<thousand\>\""}], ",", " ", 
            RowBox[{"100", " ", "->", " ", "\"\<hundred\>\""}]}], "}"}]}]}], 
        "}"}], " ", "//", " ", "Sort"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueBlock", "[", 
     RowBox[{"Options", ",", " ", "\"\<Reset\>\""}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Unprotect", "[", "PlaceValueBlock", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Options", "[", "PlaceValueBlock", "]"}], " ", "=", " ", 
       "resetblock"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Protect", "[", "PlaceValueBlock", "]"}], ";", " ", 
      "resetblock"}], " ", ")"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueBlock", "[", 
     RowBox[{"SetOptions", ",", " ", "lan_String"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "rul", ",", " ", "numbers", ",", " ", "words", ",", " ", "trans", ",", 
        " ", "default"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"default", ",", " ", "rul"}], "}"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Language", ",", " ", "Power"}], "}"}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValueBlock", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"numbers", ",", " ", "words"}], "}"}], " ", "=", " ", 
        RowBox[{"Transpose", "[", 
         RowBox[{"rul", " ", "/.", " ", 
          RowBox[{"Rule", " ", "\[Rule]", " ", "List"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"trans", " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"WordTranslation", "[", 
           RowBox[{"#", ",", " ", 
            RowBox[{"default", " ", "\[Rule]", " ", "lan"}]}], "]"}], "&"}], 
         " ", "/@", " ", "words"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"trans", " ", "=", " ", 
        RowBox[{"First", " ", "/@", " ", "trans"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"SetOptions", "[", 
        RowBox[{"PlaceValueBlock", ",", " ", 
         RowBox[{"Language", " ", "\[Rule]", " ", "lan"}], ",", " ", 
         RowBox[{"Power", " ", "\[Rule]", " ", 
          RowBox[{"Thread", "[", 
           RowBox[{"numbers", " ", "\[Rule]", " ", "trans"}], "]"}]}]}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlaceValueBlock", "[", 
     RowBox[{"n_Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "h", ",", " ", "len", ",", " ", "g", ",", " ", "q", ",", " ", "p", ",",
         " ", "res", ",", " ", "pause", ",", " ", "rep", ",", " ", "speakq", 
        ",", " ", "join", ",", " ", "rule100", ",", " ", "simpq", ",", " ", 
        "and", ",", " ", "paund"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "pause", ",", " ", "rep", ",", " ", "speakq", ",", " ", "join", ",", 
          " ", "simpq", ",", " ", "and"}], "}"}], "  ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "Length", ",", " ", "Power", ",", " ", "Speak", ",", " ", "Join", 
            ",", " ", "Simplify", ",", " ", "And"}], "}"}], " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "PlaceValueBlock", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hundred", " ", "=", " ", 
        RowBox[{
        "\"\< \>\"", " ", "<>", " ", "join", " ", "<>", " ", "\"\< \>\"", " ",
          "<>", "  ", 
         RowBox[{"(", 
          RowBox[{"100", " ", "/.", " ", "rep"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"StringQ", "[", "and", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"PlaceValue", "::", "str"}], ",", " ", "\"\<and\>\"", ",",
             " ", "and"}], "]"}], ";", " ", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"rule100", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"100", " ", "/.", " ", "rep"}], ")"}], " ", "\[Rule]", 
         "  ", "\"\<100\>\""}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"speakq", " ", "=", " ", 
        RowBox[{"speakq", " ", "===", " ", "True"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"NumberQ", "[", "pause", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"pause", " ", "=", " ", 
          RowBox[{"\"\< <silence msec=\\\"\>\"", " ", "<>", " ", 
           RowBox[{"ToString", "[", 
            RowBox[{"Round", "[", 
             RowBox[{"pause", "/", "2"}], "]"}], "]"}], " ", "<>", " ", 
           "\"\<\\\"/> \>\""}]}], " ", ",", "\[IndentingNewLine]", " ", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"PlaceValue", "::", "pau"}], ",", " ", "pause"}], "]"}], 
          ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"h", " ", "=", " ", 
        RowBox[{"IntegerDigits", "[", "n", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", " ", "=", " ", 
        RowBox[{"Length", "[", "h", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"g", " ", "=", " ", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"10", "^", "k"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"k", ",", " ", "0", ",", " ", 
             RowBox[{"len", "-", "1"}], ",", " ", "3"}], "}"}]}], "]"}], " ", 
         "//", "Reverse"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"p", " ", "=", " ", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"Reverse", "[", "h", "]"}], ",", " ", 
          RowBox[{"UpTo", "[", "3", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"p", " ", "=", " ", 
        RowBox[{"Reverse", "[", 
         RowBox[{"Reverse", " ", "/@", " ", "p"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"simpq", " ", "===", " ", "True"}], ",", " ", 
         RowBox[{"q", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"u", "/@", " ", 
             RowBox[{"(", 
              RowBox[{"tosimp", " ", "/@", " ", "p"}], ")"}]}], ")"}], "  ", "/.",
            " ", 
           RowBox[{
            RowBox[{"u", "[", 
             RowBox[{"{", "}"}], "]"}], " ", "\[RuleDelayed]", " ", 
            RowBox[{"u", "[", "]"}]}]}]}]}], " ", "]"}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"simpq", " ", "=!=", " ", "True"}], ",", " ", 
         RowBox[{"q", " ", "=", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"u", "/@", " ", 
             RowBox[{"(", 
              RowBox[{"tospeak", " ", "/@", " ", "p"}], ")"}]}], ")"}], "  ", 
           "/.", " ", 
           RowBox[{
            RowBox[{"u", "[", 
             RowBox[{"{", "}"}], "]"}], " ", "\[RuleDelayed]", " ", 
            RowBox[{"u", "[", "]"}]}]}]}]}], " ", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"g", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{"u", " ", "/@", " ", 
          RowBox[{"(", 
           RowBox[{"tospeak", " ", "/@", " ", "g"}], ")"}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{
         RowBox[{"Inner", "[", 
          RowBox[{"w", ",", " ", "q", ",", "  ", "g", ",", "  ", "head"}], 
          "]"}], "/.", " ", 
         RowBox[{"u", " ", "\[Rule]", " ", "Sequence"}]}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{
         RowBox[{"res", " ", "/.", " ", 
          RowBox[{
           RowBox[{"w", "[", "]"}], " ", "\[RuleDelayed]", " ", 
           RowBox[{"Sequence", "[", "]"}]}]}], "  ", "/.", " ", 
         RowBox[{
          RowBox[{"w", "[", 
           RowBox[{"speak", "[", "y_", "]"}], "]"}], " ", "\[RuleDelayed]", 
          " ", 
          RowBox[{"Sequence", "[", "]"}]}]}]}], ";", "  ", 
       RowBox[{"(*", 
        RowBox[{"zero", " ", "weights"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", 
        RowBox[{
         RowBox[{"res", " ", "/.", "  ", 
          RowBox[{"w", " ", "\[Rule]", " ", "List"}]}], " ", "/.", " ", 
         RowBox[{"head", " ", "\[Rule]", " ", "List"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"res", " ", "/.", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x___List", ",", " ", "one"}], "}"}], " ", 
          "\[RuleDelayed]", " ", "x"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"speakq", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sp", "[", "x_", "]"}], " ", ":=", " ", 
          RowBox[{"Hold", "[", 
           RowBox[{
            RowBox[{"Speak", "[", "x", "]"}], ";", " ", "x"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sp", "[", "x_", "]"}], " ", ":=", " ", 
          RowBox[{"Hold", "[", "x", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"mysp", "[", "x_", "]"}], " ", ":=", " ", 
        RowBox[{"Hold", "[", 
         RowBox[{"PlaceValueDigits$Language", "[", 
          RowBox[{"x", ",", " ", 
           RowBox[{"Evaluate", "[", 
            RowBox[{
             RowBox[{"Speak", " ", "\[Rule]", " ", "speakq"}], ",", " ", 
             RowBox[{"And", " ", "\[Rule]", " ", "and"}], ",", "  ", "opts"}],
             "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"never", " ", "show", " ", "the", " ", "pause"}], " ", "*)"}],
        "\[IndentingNewLine]", 
       RowBox[{"paund", " ", "=", " ", 
        RowBox[{"pause", " ", "<>", "and", " ", "<>", " ", "pause"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"and", " ", "=", " ", 
        RowBox[{"\"\< \>\"", "<>", "and", "<>", "\"\< \>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"Riffle", "[", 
         RowBox[{"res", ",", " ", 
          RowBox[{"If", "[", 
           RowBox[{"speakq", ",", " ", 
            RowBox[{"Hold", "[", 
             RowBox[{
              RowBox[{"Speak", "[", "paund", "]"}], ";", " ", "and"}], "]"}], 
            ",", " ", "and"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"n", " ", "<", " ", "0"}], ",", " ", 
         RowBox[{"PrependTo", "[", 
          RowBox[{"res", ",", " ", 
           RowBox[{"Hold", "[", 
            RowBox[{
             RowBox[{"Speak", "[", "\"\<negative\>\"", "]"}], ";", 
             "\"\<negative\>\""}], "]"}]}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"res", " ", "/.", " ", "rep"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"res", " ", "/.", " ", 
         RowBox[{"nfx", " ", "\[Rule]", " ", 
          RowBox[{"sp", "[", "and", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"res", " ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"myspeak", " ", "\[Rule]", " ", "mysp"}], ",", " ", 
           RowBox[{"speak", " ", "\[Rule]", " ", "sp"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"LatestPronunciation", "[", "Hold", "]"}], " ", "=", "res"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"ReleaseHold", "[", "res", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"LatestPronunciation", "[", "]"}], " ", "=", "res"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "=", " ", 
        RowBox[{"res", " ", "/.", " ", 
         RowBox[{"(", 
          RowBox[{"rep", " ", "/.", " ", 
           RowBox[{
            RowBox[{"Rule", "[", 
             RowBox[{"a_", ",", " ", "b_"}], "]"}], " ", "\[RuleDelayed]", 
            " ", 
            RowBox[{"Rule", "[", 
             RowBox[{"b", ",", " ", "a"}], "]"}]}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", " ", "/.", " ", 
        RowBox[{"x_String", " ", "\[RuleDelayed]", " ", 
         RowBox[{"StringReplace", "[", 
          RowBox[{"x", ",", " ", "rule100"}], "]"}]}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"End", "[", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", 
     RowBox[{
     "PlaceValue", ",", " ", "PlaceValueH", ",", " ", "PronounceIntegers", 
      ",", " ", "SpeakTransliteration", ",", " ", "PlaceValueBlock", ",", " ",
       "PlaceValueDigits", ",", " ", "PlaceValueDigits$Language", ",", 
      "PronounceIntegerReadMe", ",", " ", "PronounceInteger", ",", " ", 
      "PartialPlaceValue", ",", " ", "PlaceValueTable"}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EndPackage", "[", "]"}], ";"}]}]}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"4112cb82-c406-4110-8422-7e3c3855a3b7"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "Get","noopen",
    "\"Cannot open \\!\\(\\*FormBox[\\\"\\\\\\\"Cool`MathEd`H`\\\\\\\"\\\", \
TraditionalForm]\\).\"",2,363,81,32540151164407676168,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"c1f7fedc-513e-44cd-9d2d-390b9ac4bdcf"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["MathEd`CCSSMath`", "Subsubsection",ExpressionUUID->"99653670-056e-4c55-bfa7-b66c61a7319c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "Cool`MathEd`CCSSMath`"}], " ", "package"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "*******************************************)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Author", ":", " ", 
    RowBox[{"Thomas", " ", "Cool"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Copyright", ":", " ", 
    RowBox[{
     RowBox[{"Copyright", " ", "2018", " ", "Thomas", " ", "Cool"}], " ", "-",
      " ", 
     RowBox[{
     "except", " ", "for", " ", "CCSS", " ", "texts", " ", "of", " ", 
      "course"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Package", " ", "Version"}], ":", " ", "1.0"}], ",", " ", 
    RowBox[{"May", " ", "16", " ", "2018"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", "Version"}], ":", "11.2"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{":", "Reference", ":", " ", "http", ":"}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"www", ".", "corestandards", ".", "org"}], "/", "Math"}], "/", 
      "Content"}], "/", "NBT"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Keywords", ":"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{":", "Limitation", ":"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{":", "License", ":", " ", 
     RowBox[{"see", " ", 
      RowBox[{"http", ":"}]}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{"thomascool", ".", "eu"}], "/", "TheEconomicsPack"}], "/", 
     RowBox[{"index", ".", "html"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"BeginPackage", "[", 
     RowBox[{"\"\<Cool`MathEd`CCSSMath`\>\"", ",", " ", 
      RowBox[{"{", "\"\<Cool`MathEd`PronounceInteger`\>\"", "}"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Unprotect", "[", 
     RowBox[{"CCSSMathContent", ",", " ", "CCSSMathExercise"}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "::", "usage"}], " ", "=", " ", 
     "\"\<CCSSMathContent[domain, grade, labels] quotes the CCCSS standards \
for the domain and grade.\\nCCSSMathContent[] contains the list what is \
included in the package. Only included is NBT = Number & Operations in Base \
Ten, and then only for Kindergarten, Grade 1 and a bit of Grade 2\>\""}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathExercise", "::", "usage"}], " ", "=", " ", 
     "\"\<CCSSMathExercise[n, ..., m, opts] passes the numbers on to a \
routine that recognises the CCSSMathContent labels in opts, see \
Options[CCSSMathExercise] and CCSSMathContent. When Show -> True then the \
CCSSMathContent on those labels is shown (default \
False)\\nCCSSMathExercice[n, m:10] for \\\"Grade\\\" -> \\\"Kindergarten\\\" \
or \\\"Grade 1\\\" counts from m to n. Defaults Speak -> False, IntegerDigits \
-> False (if True, the exercise question shows digits, but still speaks full \
place value)\>\""}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "CCSSMathExercise", "]"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Domain", " ", "\[Rule]", " ", "\"\<NBT\>\""}], ",", " ", 
       RowBox[{"\"\<Grade\>\"", " ", "\[Rule]", " ", "\"\<Kindergarten\>\""}],
        ",", " ", 
       RowBox[{"\"\<Code\>\"", " ", "\[Rule]", " ", "\"\<A.1\>\""}], ",", " ", 
       RowBox[{"Show", " ", "\[Rule]", " ", "False"}], ",", " ", 
       RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
       RowBox[{"IntegerDigits", "\[Rule]", " ", "False"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CCSSMathExercise", "[", 
     RowBox[{"n__Integer", ",", " ", "opts___Rule"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sq", ",", " ", "kind", ",", " ", "res"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"kind", " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<Grade\>\"", ",", "Domain", ",", " ", "\"\<Code\>\""}],
            "}"}], " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "CCSSMathExercise", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sq", " ", "=", " ", 
        RowBox[{
         RowBox[{"Show", " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "CCSSMathExercise", "]"}]}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"sq", " ", "===", " ", "True"}], ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"res", " ", "=", " ", 
           RowBox[{"CCSSMathContent", " ", "@@", " ", "kind"}]}], ";", " ", 
          RowBox[{"Print", "[", "res", "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"CCSSMathExercise", "[", 
        RowBox[{"n", ",", "  ", "kind", ",", " ", "opts"}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathExercise", "::", "ran"}], " ", "=", " ", 
     "\"\<Number `1` must be in range `2`\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CCSSMathExercise", "[", 
     RowBox[{"n_Integer", ",", "m___Integer", " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Kindergarten\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", 
        "\"\<A.1\>\""}], "}"}], ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"10", " ", "<", " ", "n", " ", "<", " ", "20"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"CCSSMathExercise", "[", 
       RowBox[{
       "\"\<Kindergarten\>\"", ",", " ", "Count", ",", " ", "n", ",", "m", 
        ",", " ", "opts"}], "]"}], " ", ",", " ", 
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"CCSSMathExercise", "::", "ran"}], ",", " ", "n", ",", " ", 
        "\"\<11-19\>\""}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CCSSMathExercise", "[", 
     RowBox[{
     "\"\<Kindergarten\>\"", ",", " ", "Count", ",", "xtext_String", ",", " ",
       "basetext_String", ",", " ", "ytext_String"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
     "\"\<You know the numbers yyy and base, and how to speak them. You now \
count yyy up from base, and then you find the number xxx. You now learn to \
speak the number xxx.\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<xxx\>\"", " ", "\[Rule]", "  ", "xtext"}], ",", " ", 
        RowBox[{"\"\<base\>\"", " ", "->", " ", "basetext"}], ",", " ", 
        RowBox[{"\"\<yyy\>\"", " ", "\[Rule]", "  ", "ytext"}]}], "}"}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CCSSMathExercise", "[", 
     RowBox[{
     "\"\<Kindergarten\>\"", ",", " ", "Count", ",", " ", "x_Integer", ",", 
      " ", 
      RowBox[{"base_Integer:", "10"}], ",", " ", "opts___Rule"}], "]"}], " ", 
    ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "xtext", ",", " ", "basetext", ",", " ", "ytext", ",", " ", "digits", 
        ",", " ", "speakq", ",", " ", "f", ",", " ", "famp", ",", " ", "fpv", 
        ",", " ", "toshow", ",", " ", "tospeak"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"digits", ",", " ", "speakq"}], "}"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"IntegerDigits", ",", " ", "Speak"}], "}"}], " ", "/.", 
          " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "CCSSMathExercise", "]"}]}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"fpv", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"PlaceValue", "[", 
           RowBox[{"#", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
            RowBox[{"Language", " ", "\[Rule]", " ", "\"\<English\>\""}], ",",
             " ", "opts"}], "]"}], "&"}], ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"famp", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"PlaceValue", "[", 
           RowBox[{"#", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
            RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Amplish\>\""}], ",",
             " ", "opts"}], "]"}], "&"}], ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"to", " ", "show"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"f", " ", "=", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"digits", " ", "===", " ", "False"}], ",", " ", "famp", ",",
           " ", "ToString"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xtext", ",", " ", "basetext", ",", " ", "ytext"}], "}"}], 
        " ", "=", " ", 
        RowBox[{"f", " ", "/@", " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", "base", ",", " ", 
           RowBox[{"x", " ", "-", " ", "base"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"toshow", " ", "=", " ", 
        RowBox[{"CCSSMathExercise", "[", 
         RowBox[{
         "\"\<Kindergarten\>\"", ",", " ", "Count", ",", "xtext", ",", " ", 
          "basetext", ",", " ", "ytext"}], "]"}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"to", " ", "speak"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"speakq", " ", "===", " ", "True"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xtext", ",", " ", "basetext", ",", " ", "ytext"}], "}"}],
            " ", "=", " ", 
           RowBox[{"fpv", " ", "/@", " ", 
            RowBox[{"{", 
             RowBox[{"x", ",", " ", "base", ",", " ", 
              RowBox[{"x", " ", "-", " ", "base"}]}], "}"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"tospeak", " ", "=", " ", 
           RowBox[{"CCSSMathExercise", "[", 
            RowBox[{
            "\"\<Kindergarten\>\"", ",", " ", "Count", ",", "xtext", ",", " ",
              "basetext", ",", " ", "ytext"}], "]"}]}], " ", ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"LatestPronunciation", "[", "]"}], " ", "=", " ", 
           "tospeak"}], ";", "\[IndentingNewLine]", 
          RowBox[{"Speak", "[", "tospeak", "]"}]}]}], "\[IndentingNewLine]", 
        "]"}], ";", " ", "\[IndentingNewLine]", "toshow"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CCSSMathExercise", "[", 
     RowBox[{"n_Integer", ",", " ", "m___Integer", ",", " ", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", "\"\<A.1\>\""}], 
       "}"}], ",", " ", "opts___Rule"}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"0", " ", "<=", " ", "n", " ", "<=", " ", "120"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"CCSSMathExercise", "[", 
       RowBox[{"Count", ",", " ", "n", ",", " ", "m", ",", " ", "opts"}], 
       "]"}], " ", ",", " ", 
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"CCSSMathExercise", "::", "ran"}], ",", " ", "n", ",", " ", 
        "\"\<0-120\>\""}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CCSSMathExercise", "[", 
     RowBox[{
     "Count", ",", "xtext_String", ",", " ", "basetext_String", ",", " ", 
      "ytext_String"}], "]"}], " ", ":=", "\[IndentingNewLine]", 
    RowBox[{"StringReplace", "[", 
     RowBox[{
     "\"\<You know the numbers yyy and base, and how to write and speak them. \
You now count yyy up from base, and then you find the number xxx. You now \
learn to write and speak the number xxx.\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<xxx\>\"", " ", "\[Rule]", "  ", "xtext"}], ",", " ", 
        RowBox[{"\"\<base\>\"", " ", "->", " ", "basetext"}], ",", " ", 
        RowBox[{"\"\<yyy\>\"", " ", "\[Rule]", "  ", "ytext"}]}], "}"}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CCSSMathExercise", "[", 
     RowBox[{"Count", ",", " ", "x_Integer", ",", " ", 
      RowBox[{"base_Integer:", "10"}], ",", " ", "opts___Rule"}], "]"}], " ", 
    ":=", " ", "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "xtext", ",", " ", "basetext", ",", " ", "ytext", ",", " ", "digits", 
        ",", " ", "speakq", ",", " ", "f", ",", " ", "famp", ",", " ", "fpv", 
        ",", " ", "toshow", ",", " ", "tospeak"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"digits", ",", " ", "speakq"}], "}"}], " ", "=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"IntegerDigits", ",", " ", "Speak"}], "}"}], " ", "/.", 
          " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "CCSSMathExercise", "]"}]}]}], " ", ";", 
       "\[IndentingNewLine]", 
       RowBox[{"fpv", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"PlaceValue", "[", 
           RowBox[{"#", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
            RowBox[{"Language", " ", "\[Rule]", " ", "\"\<English\>\""}], ",",
             " ", "opts"}], "]"}], "&"}], ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"famp", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"PlaceValue", "[", 
           RowBox[{"#", ",", " ", 
            RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
            RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Amplish\>\""}], ",",
             " ", "opts"}], "]"}], "&"}], ")"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"to", " ", "show"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"f", " ", "=", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"digits", " ", "===", " ", "False"}], ",", " ", "famp", ",",
           " ", "ToString"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xtext", ",", " ", "basetext", ",", " ", "ytext"}], "}"}], 
        " ", "=", " ", 
        RowBox[{"f", " ", "/@", " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", "base", ",", " ", 
           RowBox[{"x", " ", "-", " ", "base"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"toshow", " ", "=", " ", 
        RowBox[{"CCSSMathExercise", "[", 
         RowBox[{
         "Count", ",", "xtext", ",", " ", "basetext", ",", " ", "ytext"}], 
         "]"}]}], " ", ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"to", " ", "speak"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"speakq", " ", "===", " ", "True"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xtext", ",", " ", "basetext", ",", " ", "ytext"}], "}"}],
            " ", "=", " ", 
           RowBox[{"fpv", " ", "/@", " ", 
            RowBox[{"{", 
             RowBox[{"x", ",", " ", "base", ",", " ", 
              RowBox[{"x", " ", "-", " ", "base"}]}], "}"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"tospeak", " ", "=", " ", 
           RowBox[{"CCSSMathExercise", "[", 
            RowBox[{
            "Count", ",", "xtext", ",", " ", "basetext", ",", " ", "ytext"}], 
            "]"}]}], " ", ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"LatestPronunciation", "[", "]"}], " ", "=", " ", 
           "tospeak"}], ";", "\[IndentingNewLine]", 
          RowBox[{"Speak", "[", "tospeak", "]"}]}]}], "\[IndentingNewLine]", 
        "]"}], ";", " ", "\[IndentingNewLine]", "toshow"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Kindergarten\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1\>\""}],
         "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.A\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.B\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.C\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.3\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<C.4\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<C.5\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<C.6\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1.A\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1.B\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.2\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.3\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.4\>\""}], 
        "]"}], ",", 
       RowBox[{"List", "[", 
        RowBox[{
        "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.5\>\""}], 
        "]"}]}], "}"}]}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Kindergarten\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1\>\""}], 
      "]"}], "=", " ", 
     "\"\<Work with numbers 11-19 to gain foundations for place value. \
CCSS.Math.Content.K.NBT.A.1.\\n  Compose and decompose numbers from 11 to 19 \
into ten ones and some further ones, e.g., by using objects or drawings, and \
record each composition or decomposition by a drawing or equation (such as 18 \
= 10 + 8); understand that these numbers are composed of ten ones and one, \
two, three, four, five, six, seven, eight, or nine ones.\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1\>\""}], "]"}],
      "=", "\"\<Extend the counting sequence. CCSS.Math.Content.1.NBT.A.1\n  \
Count to 120, starting at any number less than 120. In this range, read and \
write numerals and represent a number of objects with a written \
numeral.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2\>\""}], "]"}],
      "=", "\"\<Understand place value. CCSS.Math.Content.1.NBT.B.2\n\
Understand that the two digits of a two-digit number represent amounts of \
tens and ones. Understand the following as special cases: B.2.A, B.2.B, B.2.C\
\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.A\>\""}], 
      "]"}], "=", 
     "\"\<Understand place value. CCSS.Math.Content.1.NBT.B.2.A\n  10 can be \
thought of as a bundle of ten ones \[LongDash] called a \\\"ten.\\\"\>\""}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.B\>\""}], 
      "]"}], "=", "\[IndentingNewLine]", 
     "\"\<Understand place value. CCSS.Math.Content.1.NBT.B.2.B\n  The \
numbers from 11 to 19 are composed of a ten and one, two, three, four, five, \
six, seven, eight, or nine ones.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.C\>\""}], 
      "]"}], "=", 
     "\"\<Understand place value. CCSS.Math.Content.1.NBT.B.2.C\nThe numbers \
10, 20, 30, 40, 50, 60, 70, 80, 90 refer to one, two, three, four, five, six, \
seven, eight, or nine tens (and 0 ones)\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.3\>\""}], "]"}],
      "=", "\"\<Understand place value. CCSS.Math.Content.1.NBT.B.3\n  \
Compare two two-digit numbers based on meanings of the tens and ones digits, \
recording the results of comparisons with the symbols >, =, and <.\n  Use \
place value understanding and properties of operations to add and subtract.\>\
\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<C.4\>\""}], "]"}],
      "=", "\"\<Use place value understanding and properties of operations to \
add and subtract. CCSS.Math.Content.1.NBT.C.4\n  Add within 100, including \
adding a two-digit number and a one-digit number, and adding a two-digit \
number and a multiple of 10, using concrete models or drawings and strategies \
based on place value, properties of operations, and/or the relationship \
between addition and subtraction; relate the strategy to a written method and \
explain the reasoning used. Understand that in adding two-digit numbers, one \
adds tens and tens, ones and ones; and sometimes it is necessary to compose a \
ten.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<C.5\>\""}], "]"}],
      "=", "\"\<Use place value understanding and properties of operations to \
add and subtract. \[IndentingNewLine]CCSS.Math.Content.1.NBT.C.5\n  Given a \
two-digit number, mentally find 10 more or 10 less than the number, without \
having to count; explain the reasoning used.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<C.6\>\""}], "]"}],
      "=", "\"\<Use place value understanding and properties of operations to \
add and subtract. CCSS.Math.Content.1.NBT.C.6\nSubtract multiples of 10 in \
the range 10-90 from multiples of 10 in the range 10-90 (positive or zero \
differences), using concrete models or drawings and strategies based on place \
value, properties of operations, and/or the relationship between addition and \
subtraction; relate the strategy to a written method and explain the \
reasoning used.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1\>\""}], "]"}],
      "=", "\"\<Understand place value. CCSS.Math.Content.2.NBT.A.1\n\
Understand that the three digits of a three-digit number represent amounts of \
hundreds, tens, and ones; e.g., 706 equals 7 hundreds, 0 tens, and 6 ones. \
Understand the following as special cases: A.1.A, A.1.B\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1.A\>\""}], 
      "]"}], "=", 
     "\"\<Understand place value. CCSS.Math.Content.2.NBT.A.1.A\n  100 can be \
thought of as a bundle of ten tens \[LongDash] called a \
\\\"hundred.\\\"\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1.B\>\""}], 
      "]"}], "=", 
     "\"\<Understand place value. CCSS.Math.Content.2.NBT.A.1.B\n  The \
numbers 100, 200, 300, 400, 500, 600, 700, 800, 900 refer to one, two, three, \
four, five, six, seven, eight, or nine hundreds (and 0 tens and 0 \
ones).\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.2\>\""}], "]"}],
      "=", "\"\<Understand place value. CCSS.Math.Content.2.NBT.A.2\n  Count \
within 1000; skip-count by 5s, 10s, and 100s.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.3\>\""}], "]"}],
      "=", "\"\<Understand place value. CCSS.Math.Content.2.NBT.A.3\n  Read \
and write numbers to 1000 using base-ten numerals, number names, and expanded \
form.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.4\>\""}], "]"}],
      "=", "\"\<Understand place value. CCSS.Math.Content.2.NBT.A.4\n  \
Compare two three-digit numbers based on meanings of the hundreds, tens, and \
ones digits, using >, =, and < symbols to record the results of comparisons.\n\
  Use place value understanding and properties of operations to add and \
subtract.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{
      "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.5\>\""}], "]"}],
      "=", "\"\<Use place value understanding and properties of operations to \
add and subtract. CCSS.Math.Content.2.NBT.B.5\n  Fluently add and subtract \
within 100 using strategies based on place value, properties of operations, \
and/or the relationship between addition and subtraction.\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{"\"\<Grade 3\>\"", ",", "\"\<OA\>\"", ",", "\"\<D.9\>\""}], 
      "]"}], "=", 
     "\"\<Solve problems involving the four operations, and identify and \
explain patterns in arithmetic. CCSS.Math.Content.3.OA.D.9\nIdentify \
arithmetic patterns (including patterns in the addition table or \
multiplication table), and explain them using properties of \
operations.\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"CCSSMathContent", "[", 
      RowBox[{"\"\<Grade 4\>\"", ",", "\"\<NBT\>\"", ",", "\"\<A.2\>\""}], 
      "]"}], "=", 
     "\"\<Generalize place value understanding for multi-digit whole numbers. \
CCSS.Math.Content.4.NBT.A.2\nRead and write multi-digit whole numbers using \
base-ten numerals, number names, and expanded form. Compare two multi-digit \
numbers based on meanings of the digits in each place, using >, =, and < \
symbols to record the results of comparisons.\>\""}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"End", "[", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", 
     RowBox[{"CCSSMathContent", ",", " ", "CCSSMathExercise"}], "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"EndPackage", "[", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"9c565fd4-0e21-4f4e-914f-f64cbcc3a450"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Introduction"
}], "Section",
 PageBreakAbove->True,ExpressionUUID->"0dd112e9-598c-413c-aea5-87e8e977a8fe"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Key example"
}], "Subsection",ExpressionUUID->"1e1ec74f-a963-41a0-bf1d-5e0ff7b6927f"],

Cell["A picture says more than a thousand words:", "Text",ExpressionUUID->"487e95d3-28c2-43e6-83fa-fddef96c9531"],

Cell[TextData[{
 "\t\t\t\t\t25 = 2 \[Times] 10  +  5 = two\[CenterDot]ten  ",
 StyleBox["&",
  FontSize->12],
 "  five"
}], "Text",ExpressionUUID->"ecf6d698-d179-4414-a345-996fee89356a"],

Cell["The default is Speak \[Rule] True.", "Text",ExpressionUUID->"d83e9444-11fc-4c1f-befd-d348d97c1ab8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValue", "[", "25", "]"}], " "}]], "Input",ExpressionUUID->\
"b9dcefdb-9fe4-4f8f-847f-9f18b2978ce1"],

Cell[BoxData[
 FormBox["\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  five\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"8156d6e1-a676-4fb8-8900-\
21c5c0009b71"]
}, Open  ]],

Cell[TextData[{
 "The connectives \[OpenCurlyDoubleQuote]",
 StyleBox["&",
  FontSize->14],
 "\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]\[CenterDot]\
\[CloseCurlyDoubleQuote] are used to codify the sound, and differ from the \
operators \[OpenCurlyDoubleQuote]plus\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]group\[CloseCurlyDoubleQuote] (multi-plus, repeat, \
times), since + and \[Times] have commutation, association and distribution. "
}], "Text",ExpressionUUID->"3b3fea65-ab55-4762-802c-b187f741cd44"],

Cell["\<\
The center dot (\[CenterDot]) is unpronounced. The trailing center dot is \
deliberate and indicates the ghost of the departed one. The strict use of the \
place value system is that 1 is actually 1 of 1 (also distinguishing numbers \
and digits). Normally we simplify, but we should be able to show how the \
system actually works.\
\>", "Text",ExpressionUUID->"86c94d93-d624-4106-ba73-7a61a8a33b6f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValue", "[", 
   RowBox[{"25", ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
    RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"53c959e0-9559-4b74-9c48-2ab62059dfe4"],

Cell[BoxData[
 FormBox["\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  five\[CenterDot]one\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"66243b1f-423a-4e55-a32d-\
e7f44be6ce47"]
}, Open  ]],

Cell[TextData[{
 "The ampersand (",
 StyleBox["&",
  FontSize->12],
 ") will surprise native speakers of English but derives from quite some \
consideration. German (\[OpenCurlyDoubleQuote]und\[CloseCurlyDoubleQuote]), \
Dutch (\[OpenCurlyDoubleQuote]en\[CloseCurlyDoubleQuote]) and Danish (\
\[OpenCurlyDoubleQuote]og\[CloseCurlyDoubleQuote]) have the \
\[OpenCurlyDoubleQuote]",
 StyleBox["&",
  FontSize->14],
 "\[CloseCurlyDoubleQuote] connective and for good reason. See the discussion \
of the connectives below. "
}], "Text",ExpressionUUID->"b3ff9fa1-655c-4d10-9789-5fc7e5406571"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueTable", "[", 
   RowBox[{"25", ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}], " "}]], "Input",\
ExpressionUUID->"ba1b1cb9-663a-4da7-b328-64618ca93e42"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"25", "\<\" \"\>", "\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  five\[CenterDot]\"\>", "\<\"2 \
\[CenterDot] 10   &   5\"\>", "\<\" \"\>", "\<\"twenty five\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Speak -> False, TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"7f29fdbb-c195-4ca8-b094-98151ca53b70"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueTable", "[", 
   RowBox[{"25", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Danish\>\""}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "True"}]}], "]"}], " "}]], "Input",E\
xpressionUUID->"f921f5a4-ea27-49d0-a128-424b071ec5e3"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"25", "\<\" \"\>", "\<\"to\[CenterDot]ti  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  fem\[CenterDot]\"\>", "\<\"2 \
\[CenterDot] 10   &   5\"\>", "\<\" \"\>", "\<\"fem\[DiscretionaryHyphen]og\
\[DiscretionaryHyphen]tyve\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Language -> "Danish", Speak -> True, TableSpacing -> {1.5, 3},
      TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"067942c9-3657-4650-b80e-63765c88c237"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Kids live in a world of sounds"
}], "Subsection",ExpressionUUID->"91e94ea6-b1db-4cfb-9b27-f9d6d9649e43"],

Cell["\<\
A number consists of sound, numeral, word (that records the sound). Kids in \
kindergarten and Grade 1 live in a world of sounds so that the pronunciation \
of numbers is important. When they are learning to read and write, the \
co-ordination of (i) sounds, (ii) numerals and (iii) written words \
(subvocalisation but still sounds) is important. We already have the place \
value system fully in the numerals but not yet in pronunciation and words. \
\>", "Text",ExpressionUUID->"49eba1e0-8fa2-43d4-9e07-329ee218e128"],

Cell[TextData[{
 "The place value system puts digits in positions, with the digit being the ",
 StyleBox["weight",
  FontSlant->"Italic"],
 " and the position the ",
 StyleBox["place value",
  FontSlant->"Italic"],
 " (in our case a power of 10). The traditional pronunciation  has these \
breaches upon the full use of the place value system:"
}], "Text",ExpressionUUID->"bc6494a7-ef26-4e3f-997e-e800f0f656c2"],

Cell[CellGroupData[{

Cell["\<\
On order: nine-teen instead of ten & nine. (Rule: speak the highest place \
value first.)\
\>", "Item",ExpressionUUID->"6d69999e-ce2b-498d-a6ff-d9f5120156cd"],

Cell["\<\
On weights: twenty instead of two\[CenterDot]ten. (Rule: speak the weight of \
the place value.)\
\>", "Item",ExpressionUUID->"341704d0-c22f-44d6-91a0-b78a7448644a"]
}, Open  ]],

Cell[TextData[{
 "We do not have to assume that kids must learn ",
 StyleBox["formal",
  FontSlant->"Italic"],
 " multiplication (grouping) and the table and the powers of 10 before they \
can work with the numbers and the place value system. But it is another thing \
to hide the very structure that is the object of learning. It is better to \
use the full place value system, which will support the involved learning of \
arithmetic."
}], "Text",ExpressionUUID->"fa841478-fd6b-4c4c-aaac-57b00491c9f5"],

Cell[TextData[{
 "The US Common Core State Standards (2018) rightly wants for kindergarten: \
\[OpenCurlyDoubleQuote]Work with numbers 11-19 to gain foundations for place \
value: CCSS.Math.Content.K.NBT.A.1.\[CloseCurlyDoubleQuote] They do not say \
that they implement only a ",
 StyleBox["partial ",
  FontSlant->"Italic"],
 "and not the",
 StyleBox[" full ",
  FontSlant->"Italic"],
 "place value system. "
}], "Text",ExpressionUUID->"54d34f58-6386-44c1-9016-830bdbcc1311"],

Cell["\<\
PM. The West reads and writes from left to right, while the numbers came from \
a region in India that read and wrote from right to left. We can leave this \
phenomenon as it is because there is advantage in beginning the pronunciation \
with the highest place value with nonzero weight.\
\>", "Text",ExpressionUUID->"1e329243-b5c9-4a00-a177-a126f8a0d8b9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". What this notebook with package provides"
}], "Subsection",ExpressionUUID->"bba2cd9b-2289-4a33-a057-9849ebc5f9ca"],

Cell[TextData[{
 "This notebook with package provides an implementation for English, German, \
French, Dutch and Danish. For these languages there is a transliteration in \
English. For other languages ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s ",
 StyleBox["IntegerName",
  FontWeight->"Bold"],
 " and ",
 StyleBox["WordTranslation",
  FontWeight->"Bold"],
 " can be used for an automated translation, see the examples for Italian and \
Spanish, but then without transliteration. Only needed are 18 terms, for \
sign, \[OpenCurlyDoubleQuote]&\[CloseCurlyDoubleQuote], ten digits and the \
powers of 10 to a million (for our main application). The ampersand (&) is \
quite universal but will be pronounced differently, and the center dot (\
\[CenterDot]) remains unpronounced."
}], "Text",ExpressionUUID->"4fb0f751-25d5-45a2-8abf-16ca40aeef87"],

Cell["\<\
The reason to have more languages is that this is an international issue, \
though fragmented over the languages. A windfall benefit is that the reader \
and listener may experience a little bit how it would be for kids to rely on \
sounds  to learn about numbers and their structure.\
\>", "Text",ExpressionUUID->"303a250e-8a73-42af-b1fa-f58f84b6c2ee"],

Cell["\<\
Colignatus (2015b, 2018a) manually typed out conversion tables for English, \
German, French, Dutch and Danish. This close reading is important since \
natural languages (and their language committees) develop peculiarities, \
while there also can be conflicts between current pronunciation and the \
simple elaboration with 10, see German zehn | zig and Dutch tien | tig below. \
Adapting to another language than those checked ones may still cause such \
conflicts for the proposed full use of the place value system. The feature of \
transliteration started out for presentation (of the checked languages) but \
appears to be important as a gateway for quality control (of unchecked \
languages) as well.\
\>", "Text",ExpressionUUID->"2264fa0f-616e-4eec-bcd6-4b86a0108e0e"],

Cell["\<\
The US Common Core (2018) has negative numbers only in Grade 6, and Holland \
and the UK only in Grade 7 (junior highschool). For us it remains useful to \
include the negative sign too.\
\>", "Text",ExpressionUUID->"7bfe0b1f-a7e9-46bb-8aa3-4c6145f6dd41"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". A natural language as a dialect of mathematics"
}], "Subsection",ExpressionUUID->"a73b2d3b-ce13-4734-892c-77f397e0e0ec"],

Cell["\<\
We tend to use the term \[OpenCurlyDoubleQuote]natural language\
\[CloseCurlyDoubleQuote] but we should not forget that scores of influential \
authors and committees have been working on the traditional pronunciation of \
the natural numbers. When there is scope for improvement then it can be \
discussed. This is not an issue of spelling reform but an issue of \
mathematics education. Arithmetic and number sense are not only about \
numerals and the operations but also about how you pronounce the numbers, \
especially for kids who cannot read or write yet, and how it percolates into \
later thought (that might be \[OpenCurlyDoubleQuote]subvocalised speaking\
\[CloseCurlyDoubleQuote]).\
\>", "Text",ExpressionUUID->"ff0a68e1-2a0b-43ce-ab01-a5b4aeb32a95"],

Cell[TextData[{
 "The suggestion is that schools indeed embrace this ",
 StyleBox["full use of the place value system",
  FontSlant->"Italic"],
 ", so that language at school is the ",
 StyleBox["language of arithmetic",
  FontSlant->"Italic"],
 ", and so that the common language on the numbers used at home can be \
regarded as a ",
 StyleBox["dialect ",
  FontSlant->"Italic"],
 "of this language of arithmetic. Kids can deal with such differences in \
language. It is 12 years after the implementation from kindergarten and up \
that the national judicial system must have worked out whether the \
pronunciation of arithmetic would also be relevant and acceptable for legal \
issues. "
}], "Text",ExpressionUUID->"735852bd-f236-422a-b9c1-5a381234cf5a"],

Cell[TextData[{
 "Colignatus (2015a),",
 StyleBox[" A child wants nice and no mean numbers",
  FontSlant->"Italic"],
 ". (To adapt to the amendment of (2018a).)"
}], "Item",ExpressionUUID->"94f8756e-daaa-4e4f-8790-d1ba35e77ae0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". The need for an ISO standard"
}], "Subsection",ExpressionUUID->"b6c1b807-a846-4ff4-87e3-416ceca123d3"],

Cell[TextData[{
 "The system proposed here is simple but still supports a",
 StyleBox[" full use of the place value system",
  FontSlant->"Italic"],
 " for education in kindergarten and elementary school. It must become an ISO \
standard, so that educators and textbook & software publishers but also \
researchers have stability of their environment. Even when schools would not \
implement the system (so fast), researchers and teacher trainers require a \
standard to correct their research findings for confounding by the natural \
languages. The definition of this standard is given here, and this notebook \
with package only provide an implementation:"
}], "Text",ExpressionUUID->"89fd7572-8524-486a-8e7e-9d8e0220d5e3"],

Cell[CellGroupData[{

Cell[TextData[{
 "Colignatus (2015b, 2018a), ",
 StyleBox["The need for a standard for the mathematical pronunciation of the \
natural numbers. Suggested principles of design. Implementation for English, \
German, French, Dutch and Danish.",
  FontSlant->"Italic"]
}], "Item",ExpressionUUID->"0230ee19-1dfe-45c6-aa79-c8d4a4c16134"],

Cell["\<\
The amendment in 2018a is the use of the connectives, see below.\
\>", "Item",ExpressionUUID->"600ae17d-0b29-421d-ba4c-bbfdc78eca52"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Discussion on content and a technical report"
}], "Subsection",ExpressionUUID->"988f6a96-55af-4e9f-a24a-bf4f1559c21f"],

Cell["\<\
The suggestion for a full place value system was motivated by education. The \
package implements this, and this notebook contains much of a technical \
discussion on how to use the package. However, the very reason to make the \
suggestion derives from education, and we should not forget about this very \
motivation. This notebook thus also looks at how the package might be applied \
for the Common Core State Standards (2018). We can identify 4 levels of \
number sense relevant for pronunciation and the full use of the place value \
system that are supported by 4 routines in the package. This discussion is \
not intended as a comment on the curriculum or as a suggestion how the \
curriculum might look like. \
\>", "Text",ExpressionUUID->"45afc111-e0ee-475c-8ca7-df42cdc34b2e"],

Cell[TextData[{
 "This present discussion on content does not discuss the fundamentals for \
the standard, and the reader is referred to (2015ab, 2018a) for the more \
involved discussion. This present notebook with package provides for a \
software implementation in ",
 StyleBox["Mathematica, ",
  FontSlant->"Italic"],
 "and we concentrate on the latter. "
}], "Text",ExpressionUUID->"09e6f83a-a972-4c7c-a94f-1092fd9e6fb4"],

Cell["\<\
Though the package contains the full system - with the definition that must \
become an ISO standard - it has practical limitations. The main purpose of \
this notebook is to set some first steps towards implementation and to \
circulate the idea. Programming on language is quite involved, and \
implementing change even more. \
\>", "Text",ExpressionUUID->"d25bab45-7bbc-466b-85b8-0256bc341be2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Transliteration for a quick impression"
}], "Subsection",ExpressionUUID->"7cc5b000-8bc3-4631-834d-ba9036bf91e9"],

Cell[TextData[{
 "When you install ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "you select your ",
 StyleBox["$Language",
  FontWeight->"Bold"],
 " in the Preferences. You can change the Preferences for another language \
and then do a restart. A setting of $Language will also provide for such \
pronunciation of the digits and numerals, though in traditional fashion. The \
routines provided here should give access to the full place value system of \
your $Language, though with these warnings: (i) except for the comment on \
quality control (see above), (ii) and perhaps except for the setting of some \
options, likely an adaptation of the connectives (see below). I did not test \
changing $Language from \
\[OpenCurlyDoubleQuote]English\[CloseCurlyDoubleQuote]."
}], "Text",ExpressionUUID->"380647f6-90cd-41e8-845e-72ad21b02db7"],

Cell["\<\
At times it is an acceptable and faster way to transliterate words. Tourists \
are familiar with transliterations in their tourist guides. For example, \
French \"deux\" is pronounced in English as \"duh\". We use this \
transliteration now since it provides for a quick impression (without \
restart) how the full use of the place value system would look also in some \
other languages. This helps to identify that this is an international issue \
that is served by an ISO standard. Indeed, other languages are also included \
in the proposal Colignatus (2015b, 2018a) but it makes a difference to \
actually hear it pronounced.\
\>", "Text",ExpressionUUID->"906bc46f-aada-418b-a5e9-e8800c06cdd9"],

Cell[TextData[{
 "The transliteration must be defined for the $Language in your installment \
of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". The package basically allows for different settings, yet has been \
developed while using $Language = \"English\"."
}], "Text",ExpressionUUID->"e8711d02-2fae-4d4b-bc90-55088a17eb88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Structure of the paper"
}], "Subsection",ExpressionUUID->"e929eedc-11e0-4ff2-bc7d-7d0e918cd8f8"],

Cell[TextData[{
 "Below, I briefly indicate some history and other researchers. The main \
section explains the working of the package. It will be most instructive \
though to start with examples that highlight the properties. The main body of \
the text will use English, French and German while there will be a bit more \
later about Dutch and Danish. The definitions of the routines are printed in \
the ",
 StyleBox["Appendix",
  FontWeight->"Bold"],
 ". The standard routines in ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "provide for a link to the current (traditional) pronunciation in the \
natural languages. The traditional (wrong) pronunciation and notation has \
received quite some support, but let us now look at the full use of the place \
value system."
}], "Text",ExpressionUUID->"fcad33ca-c784-42f4-b3c2-83710c406a75"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Example in English"
}], "Section",ExpressionUUID->"c29187d0-3770-4c0e-976a-29922c1313d1"],

Cell[TextData[{
 "The following describes our implementation (and not the English language as \
it is). There could be a difference between the output that the package \
generates, intended for interactive learning, and texts that a textbook could \
show. For example, a textbook could have two\[CenterDot]ten ",
 StyleBox["&",
  FontSize->14],
 " five but the package may put in some more blanks. "
}], "Text",ExpressionUUID->"3805e500-f573-49a4-963c-4ea6f59cb210"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Speaking and writing"
}], "Subsection",ExpressionUUID->"0445ed59-fdf5-44ad-91c0-486d8862e318"],

Cell["\<\
There is a difference between speaking and writing. Speaking uses a pause. \
The present pause might be a bit long, but this length was pleasant for the \
transliteration of other languages. The routines tend to have default Speak \
\[Rule] True, but you can turn it off. The routines show the words in the \
chosen language and not the transliterations, unless you explicitly ask for \
the transliterations.\
\>", "Text",ExpressionUUID->"2a8331c4-6590-4bd5-b739-d5833ec4f1c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValue", "[", "21", "]"}], "   ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"default", " ", "Speak"}], " ", "\[Rule]", " ", "True"}], " ", 
   "*)"}]}]], "Input",ExpressionUUID->"df2b09f7-8abb-4fca-875a-71ab7c893f58"],

Cell[BoxData[
 FormBox["\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]one\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"0625218f-5c93-4339-997b-\
9d62ac583feb"]
}, Open  ]],

Cell["\<\
The routines store what was spoken (or often what could have been spoken if \
not turned off).\
\>", "Text",ExpressionUUID->"46250b33-7cde-4fd4-bc77-ad74dbf650b2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"ece5902d-17cb-49da-9fea-f45b679bcec7"],

Cell[BoxData[
 FormBox["\<\"two\[CenterDot]ten <silence msec=\\\"300\\\"/>  &  \
\[CenterDot]one\"\>", TraditionalForm]], "Output",ExpressionUUID->"1cece410-\
dfa8-4492-8502-51812205dfc9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Simplify"
}], "Subsection",ExpressionUUID->"43c76aa7-07f4-436d-8b20-3f2b045a4f45"],

Cell["\<\
For the place value system, it is important to recognise that 1 is actualy 1 \
of 1 (with a conceptual difference between digits and single digit numbers). \
After a short while this meticulous accuracy becomes annoying whence we \
simplify. It is advisable to teach the place value system, but it is also \
acceptable to simplify \[OpenCurlyDoubleQuote]one hundred\
\[CloseCurlyDoubleQuote] into \[OpenCurlyDoubleQuote]hundred\
\[CloseCurlyDoubleQuote], and to pronounce 10 as \[OpenCurlyDoubleQuote]ten\
\[CloseCurlyDoubleQuote] and not as \[OpenCurlyDoubleQuote]0 hundred, 1 ten, \
0 one\[CloseCurlyDoubleQuote]. Nevertheless, for teaching it is important to \
show both the whole system and its simplification. The trailing dot appears \
to be a quite useful indicator of this simplification.\
\>", "Text",ExpressionUUID->"c556b3db-951d-4eae-ab26-b6f6d47f30e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"1", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Expressi\
onUUID->"7de09d7b-40fa-4e60-a213-0dc437fde753"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]one\"\>", TraditionalForm]], "Output",ExpressionUUID->"e40bd333-ea67-44d6-93df-dd35caacf148"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"1", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Expre\
ssionUUID->"70412bae-e9f3-4fe1-9179-ca3e61113aad"],

Cell[BoxData[
 FormBox["\<\"one\[CenterDot]one\"\>", TraditionalForm]], "Output",ExpressionU\
UID->"bf8f1673-685b-4834-8d61-923ddeaeb138"]
}, Open  ]],

Cell["\<\
Above, there has been simplification of 21, indicated by a trailing dot.\
\>", "Text",ExpressionUUID->"6f2b26f8-4529-4bb4-94db-d32981b75c83"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"21", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Expre\
ssionUUID->"552adb81-1644-4af8-8132-0b59ef18807f"],

Cell[BoxData[
 FormBox["\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  one\[CenterDot]one\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"fa1175ce-45f4-4971-89cb-\
abea54ef8d12"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Traditional pronunciation"
}], "Subsection",ExpressionUUID->"7b35ad4d-dce9-46ae-93d5-fb183b16ecd1"],

Cell[TextData[{
 "PartialPlaceValue calls ",
 StyleBox["Mathematica\[CloseCurlyQuote]",
  FontSlant->"Italic"],
 "s IntegerName and gives the traditional pronunciation."
}], "Text",ExpressionUUID->"8cb59db9-b2df-4a89-9d55-3b509f1619f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartialPlaceValue", "[", "123", "]"}]], "Input",ExpressionUUID->"5f51e00c-0bc5-479b-81d0-c887dcb2a780"],

Cell[BoxData[
 FormBox["\<\"one hundred twenty three\"\>", TraditionalForm]], "Output",Expre\
ssionUUID->"eb1ba351-6390-4a42-9620-58fb3fe9cd4a"]
}, Open  ]],

Cell["PlaceValue gives the full place value pronunciation.", "Text",ExpressionUUID->"4f934c31-d37f-410a-b26c-68ffcb643f04"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", "123", "]"}]], "Input",ExpressionUUID->"73860c66-4e9c-40c8-8da3-d00cfa7280cf"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]hundred  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  three\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"4e72be79-d1c0-460d-8df4-\
47bcf3cad7ad"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". The connectives"
}], "Subsection",ExpressionUUID->"5c6e1d23-19c9-4620-b079-49de39a95326"],

Cell[TextData[{
 "The connectives \[OpenCurlyDoubleQuote]",
 StyleBox["&",
  FontSize->14],
 "\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]\[CenterDot]\
\[CloseCurlyDoubleQuote] have an important role. They differ from the \
operators \[OpenCurlyDoubleQuote]plus\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]group\[CloseCurlyDoubleQuote] (multi-plus, repeat, \
times), since + and \[Times] have commutation, association and distribution."
}], "Text",ExpressionUUID->"f5bfa632-1452-48c6-bd91-1bd60e955ce9"],

Cell[CellGroupData[{

Cell[TextData[{
 "The ampersand (",
 StyleBox["&",
  FontSize->14],
 ") is the ghost of addition, but simply \[OpenCurlyDoubleQuote]and\
\[CloseCurlyDoubleQuote], and not the operator \[OpenCurlyDoubleQuote]plus\
\[CloseCurlyDoubleQuote] with all its properties. The ampersand should be \
pronounced, namely to separate the place value positions. It is already \
(often) pronounced in German, Dutch and Danish. Other languages better adopt \
this practice too. Remember that we are speaking about the language of \
arithmetic to be used in school and not about an integral language reform \
(that would evolve)."
}], "Item",ExpressionUUID->"b5d7dede-c018-431c-945a-77ec7b526585"],

Cell[TextData[{
 "The center dot (not pronounced) is the ghost of multiplication of the ",
 StyleBox["weight ",
  FontSlant->"Italic"],
 "and the ",
 StyleBox["place value",
  FontSlant->"Italic"],
 ". Remember: 5 days 2 hamburgers is not the same as 2 days 5 hamburgers."
}], "Item",ExpressionUUID->"a0bdb8b3-cafa-4e8f-9375-d0d2624bd52d"]
}, Open  ]],

Cell[TextData[{
 "Kids in kindergarten and Grade 1 live in a world of sounds. Thus they \
should be provided with the &-separator of the place value positions, so that \
they have this anchor on which is what. For adults and native speakers of \
English it may seem superfluous. Indeed, I myself in (2015a, footnote 10, and \
2015b before the amendment in 2018a) found the use of \[OpenCurlyDoubleQuote]",
 StyleBox["&",
  FontSize->14],
 "\[CloseCurlyDoubleQuote] \[OpenCurlyDoubleQuote]distractive\
\[CloseCurlyDoubleQuote]. My proposal then was to use the center dot for \
\[OpenCurlyDoubleQuote]",
 StyleBox["&",
  FontSize->14],
 "\[CloseCurlyDoubleQuote] too: thus without the distinction and merely as an \
unpronounced connective, as 25 = two\[CenterDot]ten\[CenterDot]five. However, \
in reconsideration, the empirical observation is that the ",
 StyleBox["&",
  FontSize->14],
 "-separator really is there. Its existence must be acknowledged instead of \
hidden from sight."
}], "Text",ExpressionUUID->"7f5a2dfd-f772-4430-95da-210a2a05c975"],

Cell[TextData[{
 "Namely, in natural language, putting two terms alongside, like in 2 km, \
means scalar multiplication. In multiplication as grouping, kids learn to use \
the times-symbol, but we do not write 2 \[Times] km. Later students will \
learn that 2 ",
 StyleBox["a ",
  FontSlant->"Italic"],
 "is multiplication in general, also dropping the times-symbol. If they would \
have been trained by the pronunciation of the very numbers (and ",
 StyleBox["a ",
  FontSlant->"Italic"],
 "in 2",
 StyleBox["a ",
  FontSlant->"Italic"],
 "would be a number, in this scenario like ",
 StyleBox["a ",
  FontSlant->"Italic"],
 "= 25 = two\[CenterDot]ten five, thus without the \[OpenCurlyDoubleQuote]",
 StyleBox["&",
  FontSize->14],
 "\[CloseCurlyDoubleQuote]) then we create a conundrum: (1) within \
\[OpenCurlyDoubleQuote]",
 StyleBox["a ",
  FontSlant->"Italic"],
 "= 25 = two\[CenterDot]ten five\[CloseCurlyDoubleQuote] the lack of an \
interfix means addition and (ii) outside of this, in 2 ",
 StyleBox["a,",
  FontSlant->"Italic"],
 " the lack of an interfix means multiplication ? We should not create \
conundrums. Thus 25 =  two\[CenterDot]ten ",
 StyleBox["&",
  FontSize->14],
 " five. It should help understand 2 \[Times] 25. Perhaps adults might not \
speak the ampersand but for kindergarten and elementary school it is part of \
the system."
}], "Text",ExpressionUUID->"a9559296-90a2-4556-ae52-1632331a0a79"],

Cell[TextData[{
 "Indeed, in kindergarten and Grade 1 kids will tend to focus on the ",
 StyleBox["&",
  FontSize->14],
 " as an important new symbol in their universe, but this is not \
\[OpenCurlyDoubleQuote]distractive\[CloseCurlyDoubleQuote] but only \
fortunate, because it will form a stepping stone for the later learning on \
addition, i.e. using plus. Eventually they would tend to focus on the figures \
in the numbers and not the connectives. "
}], "Text",ExpressionUUID->"243dde8e-401a-4829-af2c-5cbbaf22091e"],

Cell["\<\
NB. The ampersand is remarkably large in common fonts (like upper case), and \
it is better displayed in a smaller font (like lower case). It appears that \
Speak cannot deal with a Stylebox in the strings that we are using. The \
solution was to create the language \[OpenCurlyDoubleQuote]Amplish\
\[CloseCurlyDoubleQuote], that has the True form with the smaller font for \
the ampersand, and that is transliterated in English in the default font. \
This worked fine, and thus all languages here have the smaller ampersand \
(which might cause that one has to adapt the package to work under a \
different $Language). The functionality of providing transliteration was \
useful here too. This only applies for the routines PlaceValue and \
PlaceValueRules.  It is useful to know for the option settings. Check the \
visual difference:\
\>", "Text",ExpressionUUID->"ba77a262-9e02-4ebe-84dd-0597f36b987b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValue", "[", 
   RowBox[{"25", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Amplish\>\""}]}], "]"}], 
  "  ", 
  RowBox[{"(*", "default", "*)"}]}]], "Input",ExpressionUUID->"647cab1b-2283-\
4126-b662-8853cec28d0a"],

Cell[BoxData[
 FormBox["\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  five\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"6cb79d3e-47e9-4306-b69c-\
a0939ca9f769"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"25", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<English\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"196f9d1e-2cf1-4aed-9156-b3c6027910fa"],

Cell[BoxData[
 FormBox["\<\"two\[CenterDot]ten  &  five\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"c2621e02-8ba2-476c-ae03-\
768468c801aa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Do not use ones, tens, hundreds"
}], "Subsection",ExpressionUUID->"cc063477-9ac1-4798-94c4-fbbceb0a1278"],

Cell["The Common Core (2018) has:", "Text",ExpressionUUID->"5a0fbbb8-b8ab-48cb-b50f-d4ef212c772f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.C\>\""}], 
  "]"}]], "Input",ExpressionUUID->"4b9163b8-9c51-4603-a7b4-b84101e2540a"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.1.NBT.B.2.C\\nThe \
numbers 10, 20, 30, 40, 50, 60, 70, 80, 90 refer to one, two, three, four, \
five, six, seven, eight, or nine tens (and 0 ones)\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"dd2dbb38-7ea1-451a-833b-\
5d0615950e08"]
}, Open  ]],

Cell["\<\
CCSS writes about \[OpenCurlyDoubleQuote]tens\[CloseCurlyDoubleQuote], and \
elsewhere also about \[OpenCurlyDoubleQuote]ones\[CloseCurlyDoubleQuote].  \
CCSS likely can be so sloppy since common English has \
\[OpenCurlyDoubleQuote]twenty\[CloseCurlyDoubleQuote] instead of \
\[OpenCurlyDoubleQuote]two\[CenterDot]tens\[CloseCurlyDoubleQuote] etcetera. \
If English had adopted such system with the plurals of the bases, with a \
multitude of s\[CloseCurlyQuote]s, then the abuse might be noticed sooner.\
\>", "Text",ExpressionUUID->"08304d7b-3d76-4aff-908d-1f6809b6d510"],

Cell["\<\
For CCSS \"two \[Times] three\" should also be \"twos \[Times] threes\", \
because the two implies that the threes are plural, and the three implies \
that the twos are plural. It shows that one doesn\[CloseCurlyQuote]t \
understand what a number is. Instead of \[OpenCurlyDoubleQuote]5 tens\
\[CloseCurlyDoubleQuote] one better says \[OpenCurlyDoubleQuote]5 of ten\
\[CloseCurlyDoubleQuote], since \[OpenCurlyDoubleQuote]of\
\[CloseCurlyDoubleQuote] means grouping (multiplication).\
\>", "Text",ExpressionUUID->"4de7d702-3eeb-4f8f-a8fb-376252a8507e"],

Cell["\<\
The use of \[OpenCurlyDoubleQuote]ones\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]tens\[CloseCurlyDoubleQuote] pre-dates the development \
of the place value system, and is not supported in pronunciation, since the \
numbers 11-19 are properly pronounced in place value manner. The proper \
expression for 20 is 2\[CenterDot]10, and we speak the base, which is 10 and \
not \[OpenCurlyDoubleQuote]tens\[CloseCurlyDoubleQuote]. One should avoid \
speaking about \[OpenCurlyDoubleQuote]ones\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]tens\[CloseCurlyDoubleQuote]. These plurals arise in a \
context when teachers are groping for a way of expression, but those words \
are confusing for kids as if these words would really be defined. Likely this \
is similar to 1 car versus 2 cars, but a base has a different linguistic \
treatment. (We are not pronouncing telephone numbers by rattling of the \
digits either.) \
\>", "Text",ExpressionUUID->"eeb8064d-bee0-4297-814c-af1e28145b19"],

Cell["\<\
Remember that a puzzle is only complete when all pieces are in the proper \
places. When something has a logical structure then people are bound to get \
at least one piece wrong and develop an emotional hangup on it, and each \
person or nation another piece. There is no other solution than to clarify \
the logical structure.\
\>", "Text",ExpressionUUID->"346ef331-a884-4afc-90c3-9f73028bf231"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Myriad and lakh"
}], "Subsection",ExpressionUUID->"01f3cc8e-5b87-4a67-a39a-aa2c6385aa6f"],

Cell[TextData[{
 "The figure 10,000 tends to be pronounced commonly as \
\[OpenCurlyDoubleQuote]ten thousand\[CloseCurlyDoubleQuote]. Remarkably, \
there are no specific terms for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"4", " "}]], TraditionalForm]],ExpressionUUID->
  "4e05b950-5259-41f2-a254-71fb805dc4d9"],
 "and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "c2b4abd5-e8fc-4766-8881-e172ea00240a"],
 " in all the languages in the package. Perhaps French may have a more common \
acceptance of the Greek myriad = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["100", "2"], TraditionalForm]],ExpressionUUID->
  "886e28a3-eb7d-4e62-9e64-e06cd10f28ac"],
 ". This is another breach of the place value system. Wikipedia (a portal and \
no source) observes the lack too, and mentions Greek myriad and Indian lakh. \
I have adopted these words for the languages mentioned in the packages too. \
It takes some adjustment to hear 500,000 being pronounced as 5 lakh, but such \
adjustment is the very purpose of the exercise. It is not an urgent issue for \
kindergarten though."
}], "Text",ExpressionUUID->"42b1b1a8-8cd2-400e-afea-8e1af079e58c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"500000", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Expressi\
onUUID->"d1960197-0d36-4bba-a4e6-db9d9e48dd54"],

Cell[BoxData[
 FormBox["\<\"five\[CenterDot]lakh\"\>", TraditionalForm]], "Output",Expressio\
nUUID->"d2d7747f-5e7d-4580-9b47-8def21be22e6"]
}, Open  ]],

Cell["\<\
These names are used in the main method that pronounces each entry \
separately. When the blocks of 3 digits are pronounced then they are \
superfluous.\
\>", "Text",ExpressionUUID->"c206a2e1-6ad8-4ae0-8fb1-1abcc8cde826"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". The sign"
}], "Subsection",ExpressionUUID->"eb6e4bef-9ea3-4c61-88f3-59b52d4c1375"],

Cell[TextData[{
 "The proper pronunciation of the minus sign in numbers is \
\[OpenCurlyDoubleQuote]negative\[CloseCurlyDoubleQuote], because \
\[OpenCurlyDoubleQuote]minus\[CloseCurlyDoubleQuote] is used for the binary \
operation. ",
 StyleBox["Mathematica\[CloseCurlyQuote]",
  FontSlant->"Italic"],
 "s IntegerName gives the number and uses \[OpenCurlyDoubleQuote]negative\
\[CloseCurlyDoubleQuote] indeed. "
}], "Text",ExpressionUUID->"89d5c969-dfa9-43ee-ac0b-b4a575c1451f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartialPlaceValue", "[", 
  RowBox[{"-", "10"}], "]"}]], "Input",ExpressionUUID->"e2e59768-238c-40db-\
9e76-ccea608d0a32"],

Cell[BoxData[
 FormBox["\<\"negative ten\"\>", TraditionalForm]], "Output",ExpressionUUID->"c37a6f46-2661-4731-9641-b6eafa57232d"]
}, Open  ]],

Cell["\<\
The new routines allow us to show the structure of the place value system.\
\>", "Text",ExpressionUUID->"2500b78d-e9cb-402f-be8b-1528e441fa9e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{
   RowBox[{"-", "10"}], ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Expre\
ssionUUID->"7a2beffd-2778-47c7-87d4-047f3d5e6ca9"],

Cell[BoxData[
 FormBox["\<\"negative one\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  zero\[CenterDot]one\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"174e5f35-ff6a-491e-a084-\
b56a0b00c3a4"]
}, Open  ]],

Cell[TextData[{
 "Unfortunately ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "uses Minus[",
 StyleBox["x",
  FontSlant->"Italic"],
 "] for -",
 StyleBox["x, ",
  FontSlant->"Italic"],
 "and also pronounces it that way (it may pronounce the format in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " rather than the number). Wikipedia (a portal and no source) regards \
\[OpenCurlyDoubleQuote]negative\[CloseCurlyDoubleQuote] as American English, \
but the better diagnosis is that British English is imprecise. Dutch can \
distinguish 7 minus 10 = min 3."
}], "Text",ExpressionUUID->"3a094066-ab51-4c99-8d9f-58d319b13d09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Minus"}]], "Input",ExpressionUUID->"b3e80d07-da23-4663-954c-8e571179f2f9"],

Cell[BoxData[
 RowBox[{"\<\"\\!\\(\\*RowBox[{\\\"-\\\", StyleBox[\\\"x\\\", \
\\\"TI\\\"]}]\\) is the arithmetic negation of \\!\\(\\*StyleBox[\\\"x\\\", \
\\\"TI\\\"]\\). \"\>", "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Minus"]}]], "Print", "PrintUsage",
 CellTags->
  "Info2763735558483-8910602",ExpressionUUID->"043ce143-e795-4438-95b6-\
2474e72c4506"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Minus", "[", "10", "]"}], ",", " ", 
   RowBox[{"-", "10"}]}], "}"}]], "Input",ExpressionUUID->"27dc0cbc-b833-4b8f-\
b770-2455e0f0b5c9"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "10"}], ",", 
    RowBox[{"-", "10"}]}], "}"}], TraditionalForm]], "Output",ExpressionUUID->\
"60d53781-b256-49d9-a7bd-7820f95ddb75"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Speak", "[", "%", "]"}]], "Input",ExpressionUUID->"edc64ae3-7042-430b-9a89-8082677eb6c0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". History, tradition, assumptions, advantages"
}], "Section",ExpressionUUID->"9bc235b9-232e-43d1-bb84-f4341e0d750e"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". History of proposals for change"
}], "Subsection",ExpressionUUID->"94b27791-69d3-4415-b3e1-3c192d0e4922"],

Cell["\<\
Jane Austen (1775-1817) apparently still wrote \[OpenCurlyDoubleQuote]three \
and twenty\[CloseCurlyDoubleQuote] insteady of \
\[OpenCurlyDoubleQuote]twenty-three\[CloseCurlyDoubleQuote]. The English \
speaking people are lucky that they managed the change on the order (major) \
though unlucky with the loss of \[OpenCurlyDoubleQuote]and\
\[CloseCurlyDoubleQuote] (minor).\
\>", "Text",ExpressionUUID->"d647f5d3-6533-4748-b118-5fba05fbad57"],

Cell["Norway managed the change in the 1950s.", "Text",ExpressionUUID->"26b3fe64-adf5-43cf-8b81-b019296f6831"],

Cell["\<\
Fred Schuh (1875-1966) of TU Delft proposed this in the 1950s in Holland but \
he didn\[CloseCurlyQuote]t convince the minister of education. I am not aware \
of other Dutch authors who propose this nowadays.\
\>", "Text",ExpressionUUID->"179da817-2c98-46ef-9433-fb7f09d357b9"],

Cell["\<\
In Germany there is a small movement with Lothar Gerritzen and Peter Morfeld \
to change their \"ein und zwanzig\" (perhaps no blanks) into something more \
useful: https://zwanzigeins.jetzt. Originally they thought about using \
\[OpenCurlyDoubleQuote]zwanzigeins\[CloseCurlyDoubleQuote] (apparently no \
blanks) but they are open to alternatives and hope to attain a more developed \
proposal at the end of 2018. Recently they provided support for this present \
research on getting an ISO standard, see \
https://zwanzigeins.jetzt/infos/normung-der-aussprache\
\>", "Text",ExpressionUUID->"2c6eaaaf-c4f9-45bb-8365-e2c7daada348"],

Cell["\<\
In Denmark there are Lisser Rye Ejersbo and Morten Misfeldt (2015), at \
Aarhus. Ejersbo recommends the recent book of the 23rd ICMI conference,  \
Bussi & Sun (eds) (2018). See \
http://vbn.aau.dk/da/publications/danish-number-names-and-number-concepts(\
7b79a70d-d42b-49dc-af1f-75775c9292f6)/export.html  \
\>", "Text",ExpressionUUID->"2beb69e7-54ae-491b-a5e4-0fa11b2236ee"],

Cell[TextData[{
 "China uses the place value system in the form of Level 2 discussed below. I \
am only kicking in open doors. It might be an option to translate a number \
first into Chinese and then transcribe back, see Uy (2003) . However, this \
present notebook with package gives more control and includes didactic \
notions. Chinese does not pronounce the connective \[OpenCurlyDoubleQuote]&\
\[CloseCurlyDoubleQuote] (though it is implied) and we should better use it. ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "already provides this routine."
}], "Text",ExpressionUUID->"5ed6f032-3142-4ea7-bcfe-7accdfbad360"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"IntegerString", "[", 
     RowBox[{
      RowBox[{"10", "^", "k"}], ",", " ", 
      "\"\<TraditionalChineseDecimal\>\""}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"k", ",", " ", "0", ",", " ", "4"}], "}"}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"65d786cb-b678-4d96-b490-4fca86d2f7db"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"\:4e00\"\>", ",", "\<\"\:4e00\:3007\"\>", 
    ",", "\<\"\:4e00\:3007\:3007\"\>", 
    ",", "\<\"\:4e00\:3007\:3007\:3007\"\>", 
    ",", "\<\"\:4e00\:3007\:3007\:3007\:3007\"\>"}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"53b54c6c-1738-4075-8779-\
03fe98f6ba02"]
}, Open  ]],

Cell["\<\
Fateman (2013) discusses computerised speaking of math, with a proper \
distinction between how we currently pronounce the numbers and how we \
\[OpenCurlyDoubleQuote]should\[CloseCurlyDoubleQuote] do this. It is much \
wider and deeper than my  present purposes.\
\>", "Text",ExpressionUUID->"81f968cb-c384-4e77-975a-8307036dd988"],

Cell[TextData[{
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "provides routines IntegerName and WordTranslation but we cannot always use \
them, since (i) we must avoid the breaches, put terms into proper order and \
get rid of \[OpenCurlyDoubleQuote]twenty\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]ten thousand\[CloseCurlyDoubleQuote], and (ii) we want \
to show the intermediate steps without simplification so that kids can see \
what the place value system actually is."
}], "Text",ExpressionUUID->"5f39bdd4-c055-4e60-bca1-fbe25173a2ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Tradition is not without reason but still counterproductive"
}], "Subsection",ExpressionUUID->"6b048eb2-34bd-4579-b6e6-528db64337fb"],

Cell["\<\
Traditional pronunciation and its didactics are not without reason. \
\>", "Text",ExpressionUUID->"935a18bf-5fa4-4c76-a5e5-8baf49a2c194"],

Cell["\<\
Kids start with 0-10, in which 10 is a new name \"ten\" and not \"1\
\[CenterDot]ten\" and then simplified. These kids would use grouping \
(multiplication) but have no developed vocabulary and command on this. When \
continuing with 11-20 (\"eleven\" is \"one left over\" after 10) and speaking \
from right to left (and perhaps writing so too), they write 19 and in the \
conventional dialect speak \"nine-teen\", which fits the order of their low \
numbers writing from right to left. Our reference to left and right is tricky \
since kids might still be struggling with which is what. \"Twenty\" again is \
a single notion, since kids might not have command of multiplication yet. In \
English kids make the switch to \"speak the highest place value first\" at \
20. In German and Dutch they do so at 100. This focus might make sense in \
kindergarten and Grade 1, if we neglect the existence of other numbers, or if \
we neglect that the same kids in kindergarten and Grade 1 grow up and have to \
learn those other numbers too.\
\>", "Text",ExpressionUUID->"63040f28-5111-4761-ab97-152fb962842c"],

Cell[TextData[{
 "If kids in kindergarten and elementary really started out writing from \
right to left in general, also for words, from the argument that empirical \
research has shown that this would be easier for them, then one might have an \
argument that 13 best is pronounced from right to left. Likely though, the \
order survives from the Fibonacci\[CloseCurlyQuote]s ",
 StyleBox["Liber Abaci ",
  FontSlant->"Italic"],
 "of 1202. Not only the current order but also the traditional pronunciation \
is simply ",
 StyleBox["imposed ",
  FontSlant->"Italic"],
 "upon them, with the only argument that school teaches tradition for the \
sake of tradition. A change may require retraining kindergarten teachers who \
may be weak on arithmetic anyway yet this is a one-time investment with major \
persistent benefits."
}], "Text",ExpressionUUID->"9c6c37ec-3fc8-4bfe-bd35-fd76c70fa01c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Assumptions"
}], "Subsection",ExpressionUUID->"9aca25fe-dd40-4e70-aa44-a575bf12270b"],

Cell["Full use of the place value system:", "Text",ExpressionUUID->"0aef7ed1-9670-47f4-bf3a-506f159b53d0"],

Cell[CellGroupData[{

Cell["\<\
does not require kids to understand formal multiplication and have command of \
the table of 10 and later the powers of 10, but only adopts a pronunciation \
and way of writing of both numerals and words that support this later \
development rather than hindering it\
\>", "ItemNumbered",ExpressionUUID->"346e11b5-772f-464d-a12d-938d9d5c0696"],

Cell["\<\
makes the switch to \"spreak the highest place value first\" already at 10 \
(and not 20 or 100), which is precisely the moment when the phenomenon occurs \
for the first time, and which thus establishes the system without exception \
(and kids can be told about this rule)\
\>", "ItemNumbered",ExpressionUUID->"9d9bfa05-4fe2-4349-beb1-4d886b35efe8"],

Cell["\<\
recognises that \"teen\" and \"ty\" (indeed in the world of sounds) are \
useful indicators for value (compare: three, thirteen, thirty, third) but \
sees more profit in fully using the place value system so that value \
transpires from the structure in the pronunciation rather than from employing \
different sounds (since sounds can also sabotage and obscure the structure).\
\>", "ItemNumbered",ExpressionUUID->"6ef8f8e7-2545-4100-b21a-e4e959bba670"]
}, Open  ]],

Cell[TextData[{
 "This approach makes the assumption that kids can acquire a structure. This \
is a weak assumption since kids can already acquire language and a sense of \
reality that are filled with all kinds of structures. If kids can learn \
something illogical then they should be able to learn something logical. \
Chinese kids learn the place value system on a regular basis. Our topic is \
not really an issue of empirical research but one of traditional thinking in \
the world of educators and researchers. Complications are: The latter world \
of education may have little command of mathematics and think that tradition \
already captures mathematics. ",
 StyleBox["Sacrosanct ",
  FontSlant->"Italic"],
 "means: high respect for something that you do not grasp. Mathematicians \
dealing with arithmetic in school may think abstractly and have no background \
in empirics, and focus on learning the numerals."
}], "Text",ExpressionUUID->"b0e2ae2e-6dbe-452a-92fd-2835cf97f689"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Main advantages"
}], "Subsection",ExpressionUUID->"bfb9559f-90b0-46a6-8e2e-c20ce34c8adc"],

Cell[TextData[{
 "To teach the place value system, it is advisable",
 StyleBox[" to actually use it",
  FontSlant->"Italic"],
 "."
}], "Text",ExpressionUUID->"69ab1a50-14a3-4e08-b46d-b1d2f18bf95b"],

Cell[CellGroupData[{

Cell["\<\
Pronuncation (that kids start with) would be co-ordinated with the numerals, \
and later with the written words. (Number: pronunciation, numeral, word.)\
\>", "Item",ExpressionUUID->"d37940bf-bb42-40e6-8bd3-14df0ada7f69"],

Cell["\<\
The workflow is into a single direction, and does not jump around.\
\>", "Item",ExpressionUUID->"899de977-6de4-42e7-8a92-c6eccdaa6fc1"],

Cell["\<\
Merely speaking a number aloud can already solve calculation questions. (For \
many kids: thinking may be \[OpenCurlyDoubleQuote]subvocalised speaking\
\[CloseCurlyDoubleQuote], as reading is subvocalised.)\
\>", "Item",ExpressionUUID->"c1d95ff5-b1b5-4f23-a87c-9f0f0c4d47b8"],

Cell["\<\
Current co-ordination failures (i.e. the breaches) often are not discussed so \
that kids simply do not know why they find issues complicated, and they are \
groping in the dark. \
\>", "Item",ExpressionUUID->"17403635-c9b7-4087-bb58-4c3891aa67c0"],

Cell["\<\
There will be a sizeable savings in teaching and learning time, that can be \
spent on real issues.\
\>", "Item",ExpressionUUID->"ff4337a3-91d0-4ccf-9ad9-b5c681e94283"],

Cell["\<\
Research on mathematical skill and number sense is highly contaminated by \
this pronunciation issue. Much research draws invalid conclusions. Doing good \
research is quite impossible because you cannot simply experiment on kids by \
first training them on your own theory on the place value method. We neither \
can compare international results when there is such variety and invalidity. \
(In studies in Holland and Denmark, kids were observed to use English, and \
telling others to do so too, because they better understood the numbers in \
that way.) \
\>", "Item",ExpressionUUID->"5d17c17d-0c00-4c6f-894a-c72c899dbccc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". A structure for the curriculum"
}], "Section",ExpressionUUID->"4a412ffe-af5c-46b1-94b9-ff88bd86348c"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Overview"
}], "Subsection",ExpressionUUID->"20099128-3e67-47b6-ab16-8b027a5da642"],

Cell["\<\
This notebook with package is not intended as a course on the full place \
value system for kindergarten and elementary school. Teachers would tend to \
start with discussion in print for their first orientation. Colignatus \
(2015b, 2018a) is such an introduction, and provides tables for the \
pronunciation of the integers in the full place value system, for English, \
German, French, Dutch and Danish. This notebook with package supplements this \
material with the ability of sound (basically in $Language, but for practical \
purposes now in transliteration). We mimick the situations that kids would be \
in, at different levels of competence. The purpose of this Section is to \
indicate which aspect of the place value system is highlighted by what \
routine. \
\>", "Text",ExpressionUUID->"0c977753-9ad9-4eba-aa84-192f09d146f5"],

Cell["\<\
We will quote from: http://www.corestandards.org/Math/Content/NBT.\
\>", "Text",ExpressionUUID->"694eda90-70c4-4ebf-828c-2b9d550a1261"],

Cell[TextData[{
 "Below we start with counting but of course quickly meet with the transition \
from counting to addition. We focus on the pronunciation and leave this \
transition aside, though there is a clear link of course between the \
ampersand and plus. See Colignatus (2018b),",
 StyleBox[" Tables for addition and subtraction with better use of the place \
value system.",
  FontSlant->"Italic"]
}], "Text",ExpressionUUID->"8d3bf81f-7434-46b4-b7e2-501e3479a8b9"],

Cell["\<\
For the curriculum on the place value system we can recognise a structure \
with the following levels. Per level there is a supporting routine. We first \
discuss the levels, and later collect them into a switching routine. This \
switching routine can now be used for a quick overview of what the routines \
do. These examples use higher numbers merely to show the properties. \
Obviously kids start with 0-10 but such a number doesn\[CloseCurlyQuote]t \
highlight what the routine does.\
\>", "Text",ExpressionUUID->"85084bd2-33ad-41ef-bf0f-c6aa929ca7d7"],

Cell[TextData[{
 StyleBox["Level 1.",
  FontWeight->"Bold"],
 " Sounds only (kids cannot read and write). Words record the sounds for us. \
Speaking them gives their world."
}], "Text",ExpressionUUID->"f7e1b50b-d5a2-424e-b350-af9bc11bf905"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PronounceInteger", "[", 
   RowBox[{"12", ",", " ", 
    RowBox[{"Level", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}], "   ", 
  RowBox[{"(*", 
   RowBox[{"overview", " ", "without", " ", "Speak"}], "*)"}]}]], "Input",Expr\
essionUUID->"d8907cdd-9117-4abf-9abd-569d01b6354c"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
two\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->"5f2ab644-\
988e-42eb-8e22-3068140b9b33"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Level 2. ",
  FontWeight->"Bold"],
 "Learning the digits and numerals (already having the sounds for the digits)."
}], "Text",ExpressionUUID->"964d9393-3efe-4d24-aa28-55be8c51b878"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PronounceInteger", "[", 
   RowBox[{"1234", ",", " ", 
    RowBox[{"Level", " ", "\[Rule]", " ", "2"}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
    RowBox[{"Print", " ", "\[Rule]", " ", "False"}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"overview", " ", "without", " ", "Speak"}], "*)"}]}]], "Input",Expr\
essionUUID->"746055d1-97de-4e7e-8148-b399c36dc8db"],

Cell[BoxData[
 FormBox["\<\"1000   &   2 \[CenterDot] 100   &   3 \[CenterDot] 10   &   4\"\
\>", TraditionalForm]], "Output",ExpressionUUID->"328bc891-5796-4f38-a362-\
18cc17b7b207"]
}, Open  ]],

Cell["Also learning how to write the words.", "Text",ExpressionUUID->"b2117fb7-6441-43e6-bc03-5e076953c376"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PronounceInteger", "[", 
   RowBox[{"1234", ",", " ", 
    RowBox[{"Level", " ", "\[Rule]", " ", "2"}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}], " ", 
  RowBox[{"(*", "default", "*)"}]}]], "Input",ExpressionUUID->"5890e320-5a7e-\
4d3e-a600-8466ba0b5d9b"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]thousand  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\
\\)  two\[CenterDot]hundred  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
three\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  four\
\[CenterDot]\"\>", TraditionalForm]], "Print",ExpressionUUID->"564da209-d86f-\
4223-8134-c4d18c8b41f0"],

Cell[BoxData[
 FormBox["\<\"1000   &   2 \[CenterDot] 100   &   3 \[CenterDot] 10   &   4\"\
\>", TraditionalForm]], "Output",ExpressionUUID->"4c3388b0-feda-47b7-9fb2-\
922b5bedec29"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Level 3.",
  FontWeight->"Bold"],
 " Advanced: putting digits in blocks of three. (There are slightly special \
lists because we want to Speak \[OpenCurlyDoubleQuote]one hundred\
\[CloseCurlyDoubleQuote] instead of \[OpenCurlyDoubleQuote]one one-hundred\
\[CloseCurlyDoubleQuote].)"
}], "Text",ExpressionUUID->"63fcc16b-acb8-4168-9277-5b59083f19c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PronounceInteger", "[", 
   RowBox[{"123456", ",", " ", 
    RowBox[{"Level", " ", "\[Rule]", " ", "3"}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"overview", " ", "without", " ", "Speak"}], "*)"}]}]], "Input",Expr\
essionUUID->"82340650-ca07-4857-8144-a77135944e01"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"1 \[CenterDot] 100\"\>", ",", "\<\" & \"\>", 
        ",", "\<\"2 \[CenterDot] 10    &    3\"\>"}], "}"}], ",", "1000"}], 
     "}"}], ",", "\<\" & \"\>", ",", 
    RowBox[{"{", 
     RowBox[{"\<\"4 \[CenterDot] 100\"\>", ",", "\<\" & \"\>", 
      ",", "\<\"5 \[CenterDot] 10    &    6\"\>"}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"34052035-bee6-422c-8f83-\
e99b24137354"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Level 4.",
  FontWeight->"Bold"],
 " Accomplished: using blocks of three digits (but pronounced in full place \
value)."
}], "Text",ExpressionUUID->"71d3ac8e-55ef-436d-bbe0-7b5b0dc888e9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PronounceInteger", "[", 
   RowBox[{"123456", ",", " ", 
    RowBox[{"Level", " ", "\[Rule]", " ", "4"}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"overview", " ", "without", " ", "Speak"}], "*)"}]}]], "Input",Expr\
essionUUID->"f38f47df-64e4-4a7f-98eb-f4fe94489899"],

Cell[BoxData[
 FormBox["\<\"123  thousand,   456\"\>", TraditionalForm]], "Output",Expressio\
nUUID->"548f51b9-0c29-4156-8cfa-2efbcd4d6942"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"df51ef84-b5b1-46c8-a3e0-e427d0aee6a9"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]hundred  &  two\[CenterDot]ten  &  \
three\[CenterDot]  thousand,   four\[CenterDot]hundred  &  \
five\[CenterDot]ten  &  six\[CenterDot]\"\>", TraditionalForm]], "Output",Expr\
essionUUID->"4d7816e7-5ebf-4f2c-bafa-b22af234bee0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 1. Sounds"
}], "Subsection",ExpressionUUID->"b6075ff2-9966-426c-8684-dc5859e78e67"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". No reading and writing yet"
}], "Subsubsection",ExpressionUUID->"00dd9bf8-be7d-463f-9e4c-e0c53cff59b5"],

Cell["\<\
Kids in kindergarten start with pronunciation. They cannot read and write \
yet. Their sounds are encoded in words but only the teacher would know how to \
write those words. The teacher must get used to the full place value system, \
and will first rely on written words. The advantage of using words is that \
the pronunciation becomes unambiguous for the particular language. \
\>", "Text",ExpressionUUID->"9cee747e-50db-4809-9a37-b2bd523b3e50"],

Cell["\<\
The main routine supports this situation by using words for pronunciation and \
transliteration.  We produce the sounds that kids would hear and what they \
would copy in rehearsing, and we print the spoken words in the chosen \
language for the sake of the teacher. The routine speaks in $Language (here \
\"English\") but may use transliteration.\
\>", "Text",ExpressionUUID->"f6813346-eb48-4311-9c18-fb96113eca9c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PlaceValue", "[", 
    RowBox[{"#", ",", " ", 
     RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], "]"}], 
   "&"}], " ", "/@", " ", 
  RowBox[{"Range", "[", 
   RowBox[{"0", ",", " ", "10"}], "]"}]}]], "Input",ExpressionUUID->"91dc0935-\
4e39-4372-84ef-ef8e6680f05a"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"zero\[CenterDot]\"\>", ",", "\<\"\[CenterDot]un\"\>", 
    ",", "\<\"deux\[CenterDot]\"\>", ",", "\<\"trois\[CenterDot]\"\>", 
    ",", "\<\"quatre\[CenterDot]\"\>", ",", "\<\"cinq\[CenterDot]\"\>", 
    ",", "\<\"six\[CenterDot]\"\>", ",", "\<\"sept\[CenterDot]\"\>", 
    ",", "\<\"huit\[CenterDot]\"\>", ",", "\<\"neuf\[CenterDot]\"\>", 
    ",", "\<\"\[CenterDot]dix\"\>"}], "}"}], TraditionalForm]], "Output",Expre\
ssionUUID->"3c2ed4d4-b86c-40fa-9fbc-5c90f5f20abe"]
}, Open  ]],

Cell["\<\
Rehearsing the sequence will cause kids to regard these words as a sequence, \
and the sequence can be related to other phenomena.\
\>", "Text",ExpressionUUID->"8cd7c4c1-8db9-4992-9338-7c852a45cad6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Common Core on 11-19 in sounds"
}], "Subsubsection",ExpressionUUID->"609d3b65-d60a-49ea-9be8-c10fef60f024"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathContent", "[", 
   RowBox[{
   "\"\<Kindergarten\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", "\"\<A.1\>\""}],
    "]"}], " "}]], "Input",ExpressionUUID->"065ba12a-ca68-4f5d-b0a4-\
654e6a2e8450"],

Cell[BoxData[
 FormBox["\<\"Work with numbers 11-19 to gain foundations for place value. \
CCSS.Math.Content.K.NBT.A.1.\\n  Compose and decompose numbers from 11 to 19 \
into ten ones and some further ones, e.g., by using objects or drawings, and \
record each composition or decomposition by a drawing or equation (such as 18 \
= 10 + 8); understand that these numbers are composed of ten ones and one, \
two, three, four, five, six, seven, eight, or nine ones.\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"4e59eb58-ea9f-4bc6-8e53-\
7ecb9c20fe3e"]
}, Open  ]],

Cell[TextData[{
 "Observe that CCSS speaks about \[OpenCurlyDoubleQuote]ten ones\
\[CloseCurlyDoubleQuote] instead of \[OpenCurlyDoubleQuote]ten of one\
\[CloseCurlyDoubleQuote], and see the rejection of \
\[OpenCurlyDoubleQuote]ones\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]tens\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]hundreds\[CloseCurlyDoubleQuote] above. Kids can \
collect ten apples in a basket of ten. They can agree that there are ",
 StyleBox["ten of 1 apple",
  FontSlant->"Italic"],
 " and ",
 StyleBox["1 basket of ten apples",
  FontSlant->"Italic"],
 ". If kids can count, then they also should know what they are counting \
(fingers, cars, baskets), and thus it is proper to explicitly discuss with \
them what to take as unit of account. Taking the basket of ten as the base, \
they may accept that a number is spoken as \[OpenCurlyDoubleQuote]one of ten\
\[CloseCurlyDoubleQuote] but simplified to ten since this is the base. "
}], "Text",ExpressionUUID->"b2ae56d9-c3a6-41ed-9d2e-15b94e57888d"],

Cell["\<\
Instead of rehearsing all numbers from 0 to 20, we speak a small selection \
now.\
\>", "Text",ExpressionUUID->"648e850d-8e3a-4447-80f4-9a49d62e8f46"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"PlaceValue", " ", "/@", " ", 
    RowBox[{"Range", "[", 
     RowBox[{"8", ",", " ", "13"}], "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input",ExpressionUUID->"35de6c14-80a0-4170-854a-\
b68a845b5d86"],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {"\<\"eight\[CenterDot]\"\>"},
       {"\<\"nine\[CenterDot]\"\>"},
       {"\<\"\[CenterDot]ten\"\>"},
       {"\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
\[CenterDot]one\"\>"},
       {"\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
two\[CenterDot]\"\>"},
       {"\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
three\[CenterDot]\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]], TraditionalForm]], "Output",ExpressionUUID->\
"053d7979-2d7b-4d56-8f5a-60eacccfecb6"]
}, Open  ]],

Cell["The latter in French.", "Text",ExpressionUUID->"32ee2273-cdf3-4c01-b71b-49551cc11abb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"PlaceValue", "[", 
      RowBox[{"#", ",", " ", 
       RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], "]"}], 
     "&"}], " ", "/@", " ", 
    RowBox[{"Range", "[", 
     RowBox[{"8", ",", " ", "13"}], "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input",ExpressionUUID->"1dcd136e-c3ba-49c1-9aef-\
ebb80b4012e1"],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {"\<\"huit\[CenterDot]\"\>"},
       {"\<\"neuf\[CenterDot]\"\>"},
       {"\<\"\[CenterDot]dix\"\>"},
       {"\<\"\[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
\[CenterDot]un\"\>"},
       {"\<\"\[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
deux\[CenterDot]\"\>"},
       {"\<\"\[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
trois\[CenterDot]\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]], TraditionalForm]], "Output",ExpressionUUID->\
"7c9c9708-c735-46d3-9f41-f1f09b2c227e"]
}, Open  ]],

Cell["\<\
If your $Language = \[OpenCurlyDoubleQuote]English\[CloseCurlyDoubleQuote] \
too, then you can verify that the latter French words were transliterated in \
English.\
\>", "Text",ExpressionUUID->"eb2121f3-2532-4724-847f-2306d4556c29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LatestPronunciation", "[", "]"}], " "}]], "Input",ExpressionUUID->\
"e1730899-887e-4900-9b2e-0ea1ffb66249"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]dees <silence msec=\\\"300\\\"/>  ayh  trouwah\
\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->"63d8b033-286e-\
4029-84ac-eef7de50f1ed"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". A possible exercise still in speaking only"
}], "Subsubsection",ExpressionUUID->"0de9ce23-f82f-4d55-affa-822226b49844"],

Cell["\<\
The following exercise is only in English and not in the other languages. The \
routine has the answer of the sum as input. In this case we select an outcome \
less than 20.\
\>", "Text",ExpressionUUID->"9bb5582d-85b2-4419-b335-e00f782268d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathExercise", "[", 
   RowBox[{"15", ",", " ", "12", ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "True"}]}], "]"}], "  "}]], "Input",\
ExpressionUUID->"b81b6343-d8b6-423b-8fa8-3b2a693f2385"],

Cell[BoxData[
 FormBox["\<\"You know the numbers three\[CenterDot] and \[CenterDot]ten  \\!\
\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  two\[CenterDot], and how to speak \
them. You now count three\[CenterDot] up from \[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  two\[CenterDot], and then you \
find the number \[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\) \
 five\[CenterDot]. You now learn to speak the number \[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  five\[CenterDot].\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"a0b248a0-7e58-414d-9840-\
156fdf40c640"]
}, Open  ]],

Cell["The exercise is done by speaking the counts.", "Text",ExpressionUUID->"a7a13187-88ce-4f32-9925-299c97142882"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"PlaceValue", " ", "/@", " ", 
    RowBox[{"Range", "[", 
     RowBox[{"12", ",", " ", "15"}], "]"}]}], ")"}], " ", "//", " ", 
  "MatrixForm"}]], "Input",ExpressionUUID->"62e9ab46-c5f6-41f6-b120-\
e6ce80282555"],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {"\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
two\[CenterDot]\"\>"},
       {"\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
three\[CenterDot]\"\>"},
       {"\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
four\[CenterDot]\"\>"},
       {"\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
five\[CenterDot]\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]], TraditionalForm]], "Output",ExpressionUUID->\
"50d37373-76cc-43b8-b2b2-0640c0225d34"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 2. Sounds and numerals, and then reading and writing"
}], "Subsection",ExpressionUUID->"7171cda5-7314-4844-a237-3ce0ab43dae2"],

Cell["\<\
At the second level, kids learn to read and write the digits 0, ..., 9 and \
the numerals 0, ..., 9. \
\>", "Text",ExpressionUUID->"e0d63fa3-e2e9-46cf-98e6-1117524b421c"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Showing the numeral and speaking it"
}], "Subsubsection",ExpressionUUID->"e93157d5-55bd-41a7-8ffa-9b43a5d631be"],

Cell["\<\
The first step mimicks this learning process by showing the numeral and \
speaking the (transliterated) word. Running this routine often might cause \
that the association between the sound and the picture is transferred into \
human memory.\
\>", "Text",ExpressionUUID->"51339582-505d-4c0a-a70b-fa346043fe10"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"4", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}], ",", " ", 
    RowBox[{"Print", " ", "\[Rule]", " ", "False"}]}], "]"}], " "}]], "Input",\
ExpressionUUID->"a97a72a1-e7ae-44d6-8317-3412ba2382b2"],

Cell[BoxData[
 FormBox["\<\"4\"\>", TraditionalForm]], "Output",ExpressionUUID->"e8fec481-1fb2-41df-b461-72fc955aed7c"]
}, Open  ]],

Cell["\<\
Of course, this does not yet give information about how this 4 relates to the \
other numbers. We are only discussing the link between the pronunciation \
(often already known) and the figure.\
\>", "Text",ExpressionUUID->"68d7e4f7-f987-458a-8db0-3515b993a368"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Showing the numeral, speaking it, and learning the word"
}], "Subsubsection",ExpressionUUID->"8ebb4aa7-c54c-4a55-8676-cfc71de6a025"],

Cell["\<\
In a second step kids also learn the word. The routine shows the numeral and \
official word, and speaks the (transliterated) word. Again, running the \
routine often might cause that the association is transferred into human \
memory. I do not want to imply that kids first must learn to write the word \
before they can continue with the numerals. This only intends to show that \
the routines can support such learning, assuming having or getting command of \
sounds.\
\>", "Text",ExpressionUUID->"2f008cf7-cdf0-4d9a-b947-54175c8c8e86"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"4", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}]}], "]"}], 
  "  ", 
  RowBox[{"(*", 
   RowBox[{"Print", " ", "default"}], "*)"}]}]], "Input",ExpressionUUID->\
"69d36f59-9a44-4946-b193-92140f35a7ae"],

Cell[BoxData[
 FormBox["\<\"quatre\[CenterDot]\"\>", TraditionalForm]], "Print",ExpressionUU\
ID->"0a13abbe-e1f1-4a05-a9c2-0be87ded9779"],

Cell[BoxData[
 FormBox["\<\"4\"\>", TraditionalForm]], "Output",ExpressionUUID->"b75fd066-4c5f-4cf6-b46f-8e07b9be3f86"]
}, Open  ]],

Cell["\<\
The following statement collects the input, what has been printed and spoken, \
and the output. \
\>", "Text",ExpressionUUID->"ff5fb0e6-1e17-4fa2-a4cb-3db8bb7941bd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", " ", 
   RowBox[{"LatestPronunciation", "[", "Print", "]"}], ",", " ", 
   RowBox[{"LatestPronunciation", "[", "]"}], ",", " ", "result"}], 
  "}"}]], "Input",ExpressionUUID->"9c9cafbd-da33-478c-a456-4065f9fc36bb"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "4", ",", "\<\"quatre\[CenterDot]\"\>", ",", "\<\"kahtruh\[CenterDot]\"\>",
     ",", "\<\"4\"\>"}], "}"}], TraditionalForm]], "Output",ExpressionUUID->\
"fbf7ab07-6a57-4f74-b93d-04a87a91c581"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". The digit / numeral by itself is not place value yet"
}], "Subsubsection",ExpressionUUID->"9652df6a-7977-4c8e-9f14-1029bfe6a62c"],

Cell["\<\
Observe that digits do not have a trailing dot. Learning the digits differs \
from learning the numbers in a place value system. The digits could also be \
used in another system.\
\>", "Text",ExpressionUUID->"553827b3-29db-4fd8-92cc-539687e082fd"],

Cell["\<\
It depends upon didactics and empirical research whether it is useful at this \
stage to discuss that 4 can also be understood as 4\[CenterDot]1 in full \
place value system. Likely this would be totally confusing. I advise against \
this, and I actually do not think that research on this would be so urgent.\
\>", "Text",ExpressionUUID->"c9530776-4cdd-432e-97c4-699efc470239"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"4", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}], ",", " ", 
    RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}]}], "]"}], 
  "  "}]], "Input",ExpressionUUID->"ed5e9ce3-6cba-419e-ac75-4ee741f64488"],

Cell[BoxData[
 FormBox["\<\"quatre\[CenterDot]un\"\>", TraditionalForm]], "Print",Expression\
UUID->"595bf77b-23d5-4ddb-8545-9136ae3748c8"],

Cell[BoxData[
 FormBox["\<\"4 \[CenterDot] 1\"\>", TraditionalForm]], "Output",ExpressionUUI\
D->"68683e03-434a-46dc-84e8-09612c93181c"]
}, Open  ]],

Cell[TextData[{
 "The latter gives the new number denoted in the place value system (though \
not yet constructed at this stage), its unsimplified pronunciation, and its \
decomposition in the ",
 StyleBox["weighted ",
  FontSlant->"Italic"],
 "place values. Do not use this here. It only becomes a useful insight when \
the system is already quite developed. I only mention it here to issue the \
warning not to use it here."
}], "Text",ExpressionUUID->"6f80745c-f5fa-44c4-ac8b-bd37bba5421d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Introducing the symbol 10"
}], "Subsubsection",ExpressionUUID->"5bea8501-aad3-4c16-bb76-1f68329c71cf"],

Cell[TextData[{
 "Once the digits and numbers 0 ... 9 have been mastered (to a sufficient \
degree to move on) there is the crucial step of ",
 StyleBox["creating ",
  FontSlant->"Italic"],
 "the positional system, moving into the numerals of 10 ... 20. "
}], "Text",ExpressionUUID->"3b9aef76-e058-465a-a8a9-9810d0a5910a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.A\>\""}], 
  "]"}]], "Input",ExpressionUUID->"fddcc00c-b76f-467c-b782-5a2a77d044d3"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.1.NBT.B.2.A\\n  10 \
can be thought of as a bundle of ten ones \[LongDash] called a \\\"ten.\\\"\"\
\>", TraditionalForm]], "Output",ExpressionUUID->"46869671-519a-43da-afee-\
84b8c7fe52a9"]
}, Open  ]],

Cell["\<\
CCSS seems confused between (i) learning what ten is and (ii) learning how to \
write it in numeral and word. CCSS again speaks about \
\[OpenCurlyDoubleQuote]ten ones\[CloseCurlyDoubleQuote] instead of \
\[OpenCurlyDoubleQuote]ten of one\[CloseCurlyDoubleQuote].\
\>", "Text",ExpressionUUID->"f4d8a76f-cba7-461c-bd31-ffcb9019004c"],

Cell["\<\
Likely Grade 1 has already been counting from zero to ten because of the \
fingers. In that case the sound \[OpenCurlyDoubleQuote]ten\
\[CloseCurlyDoubleQuote]with its numerical meaning would have been introduced \
above already. (Remember CCSS.Math.Content.K.NBT.A.1 above !) The crux here \
is to relate the familiar sound to the new picture of 10 (writing is drawing \
small pictures). The teacher can explain that there are ten digits 0, ..., 9, \
and that we need a new symbol for ten, and that this new symbol is 10. This \
will not be the telephone number \[OpenCurlyDoubleQuote]one-zero\
\[CloseCurlyDoubleQuote] but a written \[OpenCurlyDoubleQuote]10\
\[CloseCurlyDoubleQuote] is pronounced as \[OpenCurlyDoubleQuote]ten\
\[CloseCurlyDoubleQuote].\
\>", "Text",ExpressionUUID->"2dac7f7e-47fe-4a8d-b7cf-78c9b39f6dc6"],

Cell["\<\
Running this routine often might cause that the association between the sound \
and the picture is transferred into human memory. (It is important to \
identify the moments and methods of learning.)\
\>", "Text",ExpressionUUID->"45fe0134-4c59-4f96-a74f-8e4a34574701"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueDigits", "[", "10", "]"}]], "Input",ExpressionUUID->"c18bd992-16b8-4b2b-8258-347bdfabe396"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]ten\"\>", TraditionalForm]], "Print",ExpressionUUID->"130edf95-d811-43ff-9749-4f2405a898a8"],

Cell[BoxData[
 FormBox["\<\"10\"\>", TraditionalForm]], "Output",ExpressionUUID->"803120c3-2a9e-453a-9040-fddcfbed113e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueDigits", "[", 
  RowBox[{"10", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"62685af1-a9f5-42be-9110-283cecd078ff"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]dix\"\>", TraditionalForm]], "Print",ExpressionUUID->"b82508f5-a283-47f4-a047-022aea9277fd"],

Cell[BoxData[
 FormBox["\<\"10\"\>", TraditionalForm]], "Output",ExpressionUUID->"40c7ba99-759e-416a-a2df-6377096d85ed"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Building up 11-19 as symbols"
}], "Subsubsection",ExpressionUUID->"d722c049-1f66-4458-9438-b9a0719bb9a6"],

Cell["\<\
Having 10, it is easy to say that additional counts 1, ..., 9 will be \
recorded in the position of the 0. Again, kids have already learned aspects \
about the numbers 11, ..., 19 entirely in their world of sounds (see the \
subsection above), and the learning goal now is to read and write the \
figures. A major issue is to write (from left to right) first the 1 and then \
the additional count, The 1 is higher because it represents 10. The shortcut \
(pons asinorum) is that the count is recorded in the place of the 0.\
\>", "Text",ExpressionUUID->"d982c666-1b30-4f9a-9343-30700e1454d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.B\>\""}], 
  "]"}]], "Input",ExpressionUUID->"a9e156fa-e7f7-453f-8b11-286107c21333"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.1.NBT.B.2.B\\n  The \
numbers from 11 to 19 are composed of a ten and one, two, three, four, five, \
six, seven, eight, or nine ones.\"\>", TraditionalForm]], "Output",ExpressionU\
UID->"f5097882-a022-4d48-9d1d-ae7080433ce2"]
}, Open  ]],

Cell["Basically we have vector addition. ", "Text",ExpressionUUID->"81ef40d8-8690-4dea-9767-3478150e6e33"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", " ", "0"}], "}"}], " ", "+", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "count"}], "}"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"10", " ", "+", " ", "count"}], ",", " ", 
    RowBox[{"decomposed", " ", "by", " ", "positions"}]}], " ", 
   "*)"}]}]], "Input",ExpressionUUID->"9198b1e4-f9e3-4c44-8018-102e5ecb0f95"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"1", ",", "count"}], "}"}], TraditionalForm]], "Output",ExpressionU\
UID->"539d41a6-3bab-46ee-84c4-5b285c988cc8"]
}, Open  ]],

Cell["\<\
It might become feasible to show the kids numerals in a question like this.\
\>", "Text",ExpressionUUID->"1a3fff84-58fd-42d5-a150-35ddce1433eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathExercise", "[", 
   RowBox[{"15", ",", " ", "12", ",", 
    RowBox[{"\"\<Grade\>\"", " ", "\[Rule]", " ", "\"\<Grade 1\>\""}], ",", 
    "  ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
    RowBox[{"IntegerDigits", " ", "\[Rule]", " ", "True"}]}], "]"}], 
  "  "}]], "Input",ExpressionUUID->"92dc2178-eb30-4555-a43b-69b5b5a5adde"],

Cell[BoxData[
 FormBox["\<\"You know the numbers 3 and 12, and how to write and speak them. \
You now count 3 up from 12, and then you find the number 15. You now learn to \
write and speak the number 15.\"\>", TraditionalForm]], "Output",ExpressionUUI\
D->"390bae47-9475-4bc8-b517-f65c442c66c7"]
}, Open  ]],

Cell["\<\
The above was spoken in full place value manner. You might recognise the \
larger ampersand.\
\>", "Text",ExpressionUUID->"32c7683e-588f-48fa-8be1-b0cdfcf8e207"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"e1cbe624-113a-4866-b622-21fa117a1e18"],

Cell[BoxData[
 FormBox["\<\"You know the numbers three\[CenterDot] and \[CenterDot]ten  &  \
two\[CenterDot], and how to write and speak them. You now count three\
\[CenterDot] up from \[CenterDot]ten  &  two\[CenterDot], and then you find \
the number \[CenterDot]ten  &  five\[CenterDot]. You now learn to write and \
speak the number \[CenterDot]ten  &  five\[CenterDot].\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"20c3ef7d-89ef-4a52-8b13-\
bb25a87f45b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{
    RowBox[{"inp", " ", "=", " ", "15"}], ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], 
   "]"}]}]], "Input",ExpressionUUID->"50a4dd90-121c-4d0a-aee1-9ee1727eb044"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
cinq\[CenterDot]\"\>", TraditionalForm]], "Print",ExpressionUUID->"57baf03f-\
6a8f-45c4-842f-3414915083ca"],

Cell[BoxData[
 FormBox["\<\"10   &   5\"\>", TraditionalForm]], "Output",ExpressionUUID->"a1fd3c4a-d77b-4af1-9a9d-3652246f200f"]
}, Open  ]],

Cell[TextData[{
 "We thus have the new number denoted in the place value system, its \
pronunciation, and its decomposition in the ",
 StyleBox["weighted ",
  FontSlant->"Italic"],
 "place values."
}], "Text",ExpressionUUID->"695e9a4b-8a0c-4782-8f4c-a1fbec7d6846"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"inp", ",", " ", 
   RowBox[{"LatestPronunciation", "[", "Print", "]"}], ",", "  ", "result"}], 
  "}"}]], "Input",ExpressionUUID->"778d8007-2f12-4286-b661-1ebce43a7347"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "15", ",", "\<\"\[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\
\\)  cinq\[CenterDot]\"\>", ",", "\<\"10   &   5\"\>"}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"b6a5914e-4f8b-4c58-aa62-\
d689c25bfdfa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Introducing 20"
}], "Subsubsection",ExpressionUUID->"b0c59fac-3b79-4458-95a5-46f5cd50cd6b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2\>\""}], 
  "]"}]], "Input",ExpressionUUID->"82fc7d7d-e766-4cf7-9e4d-ac23154dc2a2"],

Cell[BoxData[
 FormBox["\<\"Understand place value. \
CCSS.Math.Content.1.NBT.B.2\\nUnderstand that the two digits of a two-digit \
number represent amounts of tens and ones. Understand the following as \
special cases: B.2.A, B.2.B, B.2.C\"\>", TraditionalForm]], "Output",Expressio\
nUUID->"c513b212-1867-44b9-bb0e-9b45f7c77861"]
}, Open  ]],

Cell["\<\
After 9, we have no longer digits available to record at the position zero, \
and we make the transition of the position.\
\>", "Text",ExpressionUUID->"a22580b8-1a64-45c9-8655-c40fcaf5bba1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", " ", "0"}], "}"}], " ", "+", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", " ", "0"}], "}"}], "   ", 
  RowBox[{"(*", " ", 
   RowBox[{"10", " ", "+", " ", 
    RowBox[{"10", " ", "decomposed", " ", "by", " ", "positions"}]}], 
   "*)"}]}]], "Input",ExpressionUUID->"d8c58980-68ae-4810-8670-666e2f66ba60"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"2", ",", "0"}], "}"}], TraditionalForm]], "Output",ExpressionUUID-\
>"a2f0ede1-fea3-41b6-866b-e0024d0ceb2e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathExercise", "[", 
   RowBox[{
    RowBox[{"inp", " ", "=", " ", "20"}], ",", " ", "19", ",", 
    RowBox[{"\"\<Grade\>\"", " ", "\[Rule]", " ", "\"\<Grade 1\>\""}], ",", 
    "  ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
    RowBox[{"IntegerDigits", " ", "\[Rule]", " ", "True"}]}], "]"}], 
  "  "}]], "Input",ExpressionUUID->"c199917b-34a1-4d9e-b593-53458073f86a"],

Cell[BoxData[
 FormBox["\<\"You know the numbers 1 and 19, and how to write and speak them. \
You now count 1 up from 19, and then you find the number 20. You now learn to \
write and speak the number 20.\"\>", TraditionalForm]], "Output",ExpressionUUI\
D->"0d50918c-e843-48db-8b7d-7ad25e5c67b5"]
}, Open  ]],

Cell["\<\
From the rehearsing the sequences before, the kid likely already knows that \
20 comes after 19. The present learning goal is how to record the sound using \
digits. \
\>", "Text",ExpressionUUID->"10ee2aba-0e42-4b6c-ba32-78c64915ad7b"],

Cell["\<\
It depends upon empirics how much can be discussed about place value \
arithmetic. We have: 19 + 1 = 10 + 9 + 1 = 10 + 10 = 20. Thus we unpack 19, \
reorder, pack 9 + 1 and pack 10 + 10 .\
\>", "Text",ExpressionUUID->"c6571559-3bea-4132-a184-dc485be3866c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"inp", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}]}], "]"}], 
  "  "}]], "Input",ExpressionUUID->"98036e58-347d-4066-9499-cba85784c5b5"],

Cell[BoxData[
 FormBox["\<\"deux\[CenterDot]dix\"\>", TraditionalForm]], "Print",ExpressionU\
UID->"02e07513-bdb0-4380-8cc8-03d438a2eb65"],

Cell[BoxData[
 FormBox["\<\"2 \[CenterDot] 10\"\>", TraditionalForm]], "Output",ExpressionUU\
ID->"a7927da9-1af3-4be8-9d93-9830c47617a8"]
}, Open  ]],

Cell[TextData[{
 "We thus have the new number denoted in the place value system, its \
pronunciation, and its decomposition in the ",
 StyleBox["weighted ",
  FontSlant->"Italic"],
 "place values."
}], "Text",ExpressionUUID->"fac85fff-a7ff-480c-bf2e-1938294dca2c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"inp", ",", " ", 
   RowBox[{"LatestPronunciation", "[", "Print", "]"}], ",", "  ", "result"}], 
  "}"}]], "Input",ExpressionUUID->"745167d9-693c-4458-8456-2f61cdaeae70"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "20", ",", "\<\"deux\[CenterDot]dix\"\>", 
    ",", "\<\"2 \[CenterDot] 10\"\>"}], "}"}], TraditionalForm]], "Output",Exp\
ressionUUID->"7ca81047-f3a1-47dd-9af8-9cb60beedc8c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Building up 21-29"
}], "Subsubsection",ExpressionUUID->"2bbf40a1-a00e-4476-ad05-6fe8c0b1a077"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2\>\""}], 
  "]"}]], "Input",ExpressionUUID->"e1d99c5a-c53d-43bd-9388-83c933321112"],

Cell[BoxData[
 FormBox["\<\"Understand place value. \
CCSS.Math.Content.1.NBT.B.2\\nUnderstand that the two digits of a two-digit \
number represent amounts of tens and ones. Understand the following as \
special cases: B.2.A, B.2.B, B.2.C\"\>", TraditionalForm]], "Output",Expressio\
nUUID->"df6d65ac-90c7-43ba-8395-07b86747da31"]
}, Open  ]],

Cell["\<\
See Colignatus (2018b) for tables of addition and subtraction with full use \
of place value.\
\>", "Text",ExpressionUUID->"ed2351a8-ce52-49e4-b679-21fbc89ab550"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "2"}], "}"}], " ", "+", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", " ", "4"}], "}"}], "   "}]], "Input",ExpressionUUID->\
"580fc20e-5d8d-46af-9a3b-fc5af60ef4e3"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], TraditionalForm]], "Output",ExpressionUUID-\
>"2960ec3d-ec78-4778-8f7e-811f3e55a9de"]
}, Open  ]],

Cell["\<\
The excercise mentions counting but we are not looking at the shift from \
counting to addition here. Numerals are shown but the exercise is pronounced \
in full place value manner.\
\>", "Text",ExpressionUUID->"9eddf69b-39d1-4e4c-9d3b-957103fd8764"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathExercise", "[", 
   RowBox[{
    RowBox[{"inp", " ", "=", "26"}], ",", " ", "12", ",", " ", 
    RowBox[{"\"\<Grade\>\"", " ", "\[Rule]", " ", "\"\<Grade 1\>\""}], ",", 
    "  ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
    RowBox[{"IntegerDigits", " ", "\[Rule]", " ", "True"}]}], "]"}], 
  "  "}]], "Input",ExpressionUUID->"132950b4-57d1-4a64-852e-d544916e305b"],

Cell[BoxData[
 FormBox["\<\"You know the numbers 14 and 12, and how to write and speak \
them. You now count 14 up from 12, and then you find the number 26. You now \
learn to write and speak the number 26.\"\>", TraditionalForm]], "Output",Expr\
essionUUID->"972baa13-f46a-4509-b1c4-1b900aad6a77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"18d64e6b-0bce-42da-a555-b6d4217fb64d"],

Cell[BoxData[
 FormBox["\<\"You know the numbers \[CenterDot]ten  &  four\[CenterDot] and \
\[CenterDot]ten  &  two\[CenterDot], and how to write and speak them. You now \
count \[CenterDot]ten  &  four\[CenterDot] up from \[CenterDot]ten  &  two\
\[CenterDot], and then you find the number two\[CenterDot]ten  &  six\
\[CenterDot]. You now learn to write and speak the number two\[CenterDot]ten  \
&  six\[CenterDot].\"\>", TraditionalForm]], "Output",ExpressionUUID->\
"f4841150-e8fa-4a72-aa02-2a891604ebd3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"inp", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}]}], "]"}], 
  "  "}]], "Input",ExpressionUUID->"ac01a06d-89b7-468b-93df-c6b02c12edbf"],

Cell[BoxData[
 FormBox["\<\"deux\[CenterDot]dix  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  six\[CenterDot]\"\>", 
  TraditionalForm]], "Print",ExpressionUUID->"94f5635a-d808-4200-acbf-\
bca31f9ddc54"],

Cell[BoxData[
 FormBox["\<\"2 \[CenterDot] 10   &   6\"\>", TraditionalForm]], "Output",Expr\
essionUUID->"4daf9995-0220-4e29-a365-3765c2ed23f6"]
}, Open  ]],

Cell[TextData[{
 "We thus have the new number denoted in the place value system, its \
pronunciation, and its decomposition in the ",
 StyleBox["weighted ",
  FontSlant->"Italic"],
 "place values."
}], "Text",ExpressionUUID->"1c8dda7a-b411-4251-a10c-1977836433c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"inp", ",", " ", 
   RowBox[{"LatestPronunciation", "[", "Print", "]"}], ",", "  ", "result"}], 
  "}"}]], "Input",ExpressionUUID->"248ee813-082e-41e5-ba68-09855e6ca3e9"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "26", ",", "\<\"deux\[CenterDot]dix  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  six\[CenterDot]\"\>", 
    ",", "\<\"2 \[CenterDot] 10   &   6\"\>"}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"3b20cbe2-ccf9-420e-8ed0-\
fa9349c77148"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". The table of 10"
}], "Subsubsection",ExpressionUUID->"46528caa-27d2-4cfe-87cf-4052604cf2aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<B.2.C\>\""}], 
  "]"}]], "Input",ExpressionUUID->"06e3744c-610c-44ab-acf6-6ea405b68fd7"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.1.NBT.B.2.C\\nThe \
numbers 10, 20, 30, 40, 50, 60, 70, 80, 90 refer to one, two, three, four, \
five, six, seven, eight, or nine tens (and 0 ones)\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"fffe576c-d47a-4d08-963f-\
dc95ec56f10a"]
}, Open  ]],

Cell["\<\
See the comment above on avoiding \[OpenCurlyDoubleQuote]tens\
\[CloseCurlyDoubleQuote], and how the \[OpenCurlyDoubleQuote]s\
\[CloseCurlyDoubleQuote] would pollute the table of ten.\
\>", "Text",ExpressionUUID->"b92ffefc-3c12-4575-9d5e-a3429281e93d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueTable", "[", 
  RowBox[{
   RowBox[{"Range", "[", 
    RowBox[{"10", ",", " ", "90", ",", " ", "10"}], "]"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"2808490d-434f-4223-9c5f-64c0c3d85d64"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"10", "\<\" \"\>", "\<\"\[CenterDot]dix\"\>", "\<\"10\"\>", "\<\" \
\"\>", "\<\"dix\"\>"},
      {"20", "\<\" \"\>", "\<\"deux\[CenterDot]dix\"\>", "\<\"2 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"vingt\"\>"},
      {"30", "\<\" \"\>", "\<\"trois\[CenterDot]dix\"\>", "\<\"3 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"trente\"\>"},
      {"40", "\<\" \"\>", "\<\"quatre\[CenterDot]dix\"\>", "\<\"4 \
\[CenterDot] 10\"\>", "\<\" \"\>", "\<\"quarante\"\>"},
      {"50", "\<\" \"\>", "\<\"cinq\[CenterDot]dix\"\>", "\<\"5 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"cinquante\"\>"},
      {"60", "\<\" \"\>", "\<\"six\[CenterDot]dix\"\>", "\<\"6 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"soixante\"\>"},
      {"70", "\<\" \"\>", "\<\"sept\[CenterDot]dix\"\>", "\<\"7 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"soixante-dix\"\>"},
      {"80", "\<\" \"\>", "\<\"huit\[CenterDot]dix\"\>", "\<\"8 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"quatre-vingts\"\>"},
      {"90", "\<\" \"\>", "\<\"neuf\[CenterDot]dix\"\>", "\<\"9 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"quatre-vingt-dix\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Language -> "French", TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"4df7738c-7629-4f49-ac0e-f592ce8bd879"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PlaceValueTable"}]], "Input",ExpressionUUID->"ee9f1025-d55a-4048-adda-8686d2046cec"],

Cell[BoxData["\<\"PlaceValueTable[{n}] gives a table of {n} with rows {n, \
pronunciation in PlaceValue, PV Digits, traditional pronunciation}. Options \
are passed on to PlaceValue (default Speak -> True) and \
PartialPlaceValue(default Speak -> False)\\nPlaceValueTable[n] gives the \
table with only n\\nPlaceValueTable[Row, n || {n}] gives the rows as lists \
only\\nPlaceValueTable[First, n] gives {n, PV, PV Digits}\"\>"], "Print", \
"PrintUsage",
 CellTags->
  "Info3203735558484-8910602",ExpressionUUID->"96dfcb63-cb9f-4512-8b27-\
21e5ca0fd224"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Building up the positional system"
}], "Subsubsection",ExpressionUUID->"591deedf-0e88-449e-a19a-bddc2dd6bc64"],

Cell[TextData[{
 "We now repeat the above, in ever higher numbers, with the next place value \
transition at ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "2"], TraditionalForm]],ExpressionUUID->
  "22dbc2b0-8023-4bc6-931b-4ca5fc6cdd53"],
 "."
}], "Text",ExpressionUUID->"bc0e795b-6a79-43ea-8319-ba760a8dfea2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 1\>\"", ",", " ", "\"\<NBT\>\"", ",", "\"\<A.1\>\""}], 
  "]"}]], "Input",ExpressionUUID->"ac814927-5f81-4f18-b903-ecf189dc5015"],

Cell[BoxData[
 FormBox["\<\"Extend the counting sequence. CCSS.Math.Content.1.NBT.A.1\\n  \
Count to 120, starting at any number less than 120. In this range, read and \
write numerals and represent a number of objects with a written numeral.\"\>",
   TraditionalForm]], "Output",ExpressionUUID->"5bd87bf8-7c0c-48b7-9ad4-\
57e380326195"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}], " ", "+", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "count10", ",", " ", "count1"}], "}"}], 
  "  "}]], "Input",ExpressionUUID->"f596ef5c-4719-40bc-b80c-f6aa99c4641a"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"1", ",", "count10", ",", "count1"}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"8e74a459-15f5-4434-9c4b-\
5777eb4dd4d8"]
}, Open  ]],

Cell["The following is spoken in full place value manner.", "Text",ExpressionUUID->"681f2c5f-018a-4523-90dc-f56c9fabbd95"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathExercise", "[", 
   RowBox[{"120", ",", " ", "119", ",", 
    RowBox[{"\"\<Grade\>\"", " ", "\[Rule]", " ", "\"\<Grade 1\>\""}], ",", 
    "  ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "True"}], ",", " ", 
    RowBox[{"IntegerDigits", " ", "\[Rule]", " ", "True"}]}], "]"}], 
  "  "}]], "Input",ExpressionUUID->"8c0196a6-2d3c-498f-997c-93bce5d7cc49"],

Cell[BoxData[
 FormBox["\<\"You know the numbers 1 and 119, and how to write and speak \
them. You now count 1 up from 119, and then you find the number 120. You now \
learn to write and speak the number 120.\"\>", TraditionalForm]], "Output",Exp\
ressionUUID->"3bf086ff-37f9-4b48-9ce1-ed294ab67686"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"4e888634-e0fd-4ca1-ac43-f1362c3faaf2"],

Cell[BoxData[
 FormBox["\<\"You know the numbers \[CenterDot]one and \[CenterDot]hundred  & \
 \[CenterDot]ten  &  nine\[CenterDot], and how to write and speak them. You \
now count \[CenterDot]one up from \[CenterDot]hundred  &  \[CenterDot]ten  &  \
nine\[CenterDot], and then you find the number \[CenterDot]hundred  &  two\
\[CenterDot]ten. You now learn to write and speak the number \
\[CenterDot]hundred  &  two\[CenterDot]ten.\"\>", TraditionalForm]], "Output",\
ExpressionUUID->"50ca85c5-658b-425c-a5bc-c8f4188b5dff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{
    RowBox[{"inp", " ", "=", " ", "120"}], ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], 
   "]"}]}]], "Input",ExpressionUUID->"ee736929-c8f7-47f7-976b-25a1970ddbab"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]cent  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
deux\[CenterDot]dix\"\>", TraditionalForm]], "Print",ExpressionUUID->\
"060cb966-4ff5-440c-98c9-ffdb6f09d258"],

Cell[BoxData[
 FormBox["\<\"100   &   2 \[CenterDot] 10\"\>", TraditionalForm]], "Output",Ex\
pressionUUID->"62dfa048-ced0-4078-90bc-eb4d0000e499"]
}, Open  ]],

Cell[TextData[{
 "We thus have the new number denoted in the place value system, its \
pronunciation, and its decomposition in the ",
 StyleBox["weighted ",
  FontSlant->"Italic"],
 "place values."
}], "Text",ExpressionUUID->"18c15f9a-a436-43c5-b940-206436e943c2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"inp", ",", " ", 
   RowBox[{"LatestPronunciation", "[", "Print", "]"}], ",", "  ", "result"}], 
  "}"}]], "Input",ExpressionUUID->"0e32f3eb-aef4-4fdb-9f7d-cc6cac1f416e"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "120", ",", "\<\"\[CenterDot]cent  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  deux\[CenterDot]dix\"\>", 
    ",", "\<\"100   &   2 \[CenterDot] 10\"\>"}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"75c468fb-4016-417e-903c-\
dfef234f9a0a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Grade 2 and 100"
}], "Subsubsection",ExpressionUUID->"05484817-48c1-45ee-a43c-591854ebf263"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathContent", "[", 
   RowBox[{
   "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", "\"\<A.1.A\>\""}], 
   "]"}], " "}]], "Input",ExpressionUUID->"034cf3d3-c2f9-4a6d-a1ed-\
64dced0bb330"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.2.NBT.A.1.A\\n  100 \
can be thought of as a bundle of ten tens \[LongDash] called a \\\"hundred.\\\
\"\"\>", TraditionalForm]], "Output",ExpressionUUID->"a379467f-55ab-43c1-b6c0-\
d94a81c0cd9e"]
}, Open  ]],

Cell[TextData[{
 "Surprisingly, CCSS requires kids of Grade 1 to count to 120 but CCSS also \
wants that the word \[OpenCurlyDoubleQuote]hundred\[CloseCurlyDoubleQuote] is \
mentioned only in Grade 2 ? Likely kids at that stage would also know that \
100 is 10 of 10. My impression is: CCSS wants Grade 2 to grow aware that 100 \
features in the place value system precisely because it is a power of 10. My \
other impression is that it suffices to show the role of 10, 100, 1000 \
etcetera but discuss the power structure only later. Often you better use \
something first, so that the explanation can better be understood once you \
know what it is about. Dutch mathematician and teacher Gerrit Mannoury \
(1867-1956): \[OpenCurlyDoubleQuote]The meaning of words is their use.\
\[CloseCurlyDoubleQuote] (my transscription) - and this was later also seen \
by Ludwig Wittgenstein (1889-1951), and likely before by C.S. Peirce \
(1839-1914) though I do not have a quote. Do not wait too long with the \
explanation otherwise students develop awkward misunderstandings and habits. \
My third impression is that CCSS is pernicious on grouping. They avoid the \
term \[OpenCurlyDoubleQuote]grouping\[CloseCurlyDoubleQuote] (multiplication) \
but use \[OpenCurlyDoubleQuote]bundling\[CloseCurlyDoubleQuote], as a lawyer \
might suggest that bundling doesn\[CloseCurlyQuote]t necessarily mean \
grouping, and hide definitions to make it seem serious. My suggestion is to \
do a proper table of 10, so that also 10 of 10 = 100 = hundred is included \
(and not limit this to 90 as in CCSS.Math.Content.1.NBT.B.2.C above). In the \
full place value, 100 is not decomposed in ten\[CenterDot]ten. But we \
obviously want kids to know this. At some point it can be explained that \
using ten digits to construct numerals causes the use of the powers of ten. A \
square of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "2"], TraditionalForm]],ExpressionUUID->
  "383a3de3-cb37-4c84-bfb9-102841515bcc"],
 " and a cube of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "3"], TraditionalForm]],ExpressionUUID->
  "faa650f2-57d7-4d95-9735-ab340a206d71"],
 " should not be hard to grasp. PM. Tradition simplifies for one 1 but \
curiously doesn\[CloseCurlyQuote]t simplify fully for one 100."
}], "Text",ExpressionUUID->"3c860288-f9b8-4606-bada-4ec2c0ccfb34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueTable", "[", "100", "]"}]], "Input",ExpressionUUID->"f2d7dfb0-e103-424a-a21d-4eb821a7765f"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"100", "\<\" \"\>", "\<\"\[CenterDot]hundred\"\>", "\<\"100\"\>", \
"\<\" \"\>", "\<\"one hundred\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"b163b91a-771c-45a3-b371-ebe2381bc91e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueTable", "[", 
  RowBox[{"100", ",", " ", 
   RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Expre\
ssionUUID->"5d269c41-c069-4858-8d78-e42db63545cb"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"100", "\<\" \"\>", "\<\"one\[CenterDot]hundred  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  zero\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  zero\[CenterDot]one\"\>", \
"\<\"1 \[CenterDot] 100   &   0 \[CenterDot] 10   &   0 \[CenterDot] 1\"\>", \
"\<\" \"\>", "\<\"one hundred\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Simplify -> False, TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"7c913e5b-4d6c-4494-9004-fd4b36d1c2f6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Grade 2 and 100 - 1000"
}], "Subsubsection",ExpressionUUID->"8eb32512-3527-4892-8ece-be2eb6806b10"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{
  "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", "\"\<A.1\>\""}], 
  "]"}]], "Input",ExpressionUUID->"d68013cb-997c-4413-945f-2bc1e2bfe156"],

Cell[BoxData[
 FormBox["\<\"Understand place value. \
CCSS.Math.Content.2.NBT.A.1\\nUnderstand that the three digits of a \
three-digit number represent amounts of hundreds, tens, and ones; e.g., 706 \
equals 7 hundreds, 0 tens, and 6 ones. Understand the following as special \
cases: A.1.A, A.1.B\"\>", TraditionalForm]], "Output",ExpressionUUID->\
"06ee8e2e-96c2-40fa-ba9c-23a2cf6a95fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"706", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"987589d0-ae9a-485b-8a5e-e65187e2395c"],

Cell[BoxData[
 FormBox["\<\"sept\[CenterDot]cent  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\
\\)  six\[CenterDot]\"\>", TraditionalForm]], "Print",ExpressionUUID->\
"51d1256e-8361-4789-95fd-0402f26cb673"],

Cell[BoxData[
 FormBox["\<\"7 \[CenterDot] 100   &   6\"\>", TraditionalForm]], "Output",Exp\
ressionUUID->"8f54addc-c8ec-4671-826d-862c6dc8ed59"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"706", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}], ",", " ", 
    RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"c3f9859a-da0b-454e-b66b-5e27f28484f3"],

Cell[BoxData[
 FormBox["\<\"sept\[CenterDot]cent  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\
\\)  zero\[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  six\
\[CenterDot]un\"\>", TraditionalForm]], "Print",ExpressionUUID->"c6a76f4a-\
11c2-4801-a247-06784347dcc1"],

Cell[BoxData[
 FormBox["\<\"7 \[CenterDot] 100   &   0 \[CenterDot] 10   &   6 \[CenterDot] \
1\"\>", TraditionalForm]], "Output",ExpressionUUID->"1eebc6f6-cd44-4648-b5d4-\
5adc82b9f7eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathContent", "[", 
   RowBox[{
   "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", "\"\<A.1.B\>\""}], 
   "]"}], " "}]], "Input",ExpressionUUID->"63a94733-70e4-470c-9fb3-\
cfbe385fd083"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.2.NBT.A.1.B\\n  The \
numbers 100, 200, 300, 400, 500, 600, 700, 800, 900 refer to one, two, three, \
four, five, six, seven, eight, or nine hundreds (and 0 tens and 0 ones).\"\>",
   TraditionalForm]], "Output",ExpressionUUID->"294b49b4-f8c4-43ba-9e51-\
6ee28a765b31"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathContent", "[", 
   RowBox[{
   "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", "\"\<A.2\>\""}], 
   "]"}], " "}]], "Input",ExpressionUUID->"715f91be-5329-436c-bba1-\
fcd25b73bbf8"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.2.NBT.A.2\\n  Count \
within 1000; skip-count by 5s, 10s, and 100s.\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"b21d8dee-33d2-4f13-b380-\
afc51f38aa93"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CCSSMathContent", "[", 
   RowBox[{
   "\"\<Grade 2\>\"", ",", " ", "\"\<NBT\>\"", ",", " ", "\"\<A.3\>\""}], 
   "]"}], " "}]], "Input",ExpressionUUID->"6ea02b12-bd0a-4866-8199-\
af242193f653"],

Cell[BoxData[
 FormBox["\<\"Understand place value. CCSS.Math.Content.2.NBT.A.3\\n  Read \
and write numbers to 1000 using base-ten numerals, number names, and expanded \
form.\"\>", TraditionalForm]], "Output",ExpressionUUID->"ff866c11-e477-4d20-\
b6de-6ce6262f9000"]
}, Open  ]],

Cell["\<\
From the Glossary: \[OpenCurlyDoubleQuote]Expanded form. A multi-digit number \
is expressed in expanded form when it is written as a sum of single-digit \
multiples of powers of ten. For example, 643 = 600 + 40 + 3.\
\[CloseCurlyDoubleQuote]\
\>", "Text",ExpressionUUID->"2bec78bd-5339-4af1-b598-cfee68f92045"],

Cell["Our routines allow digging deeper.", "Text",ExpressionUUID->"50aeabdd-2ac4-4b0c-8937-f899fea1eb05"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"643", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}], ",", " ", 
    RowBox[{"And", " ", "\[Rule]", " ", "\"\<+\>\""}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"1d0e4ddc-7f3e-4f9e-855c-095c37b7c101"],

Cell[BoxData[
 FormBox["\<\"six\[CenterDot]cent  +  quatre\[CenterDot]dix  +  trois\
\[CenterDot]\"\>", TraditionalForm]], "Print",ExpressionUUID->"f2a98d8e-e590-\
406b-91ab-072aefdcfaee"],

Cell[BoxData[
 FormBox["\<\"6 \[CenterDot] 100   +   4 \[CenterDot] 10   +   3\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"6ad64a62-0c37-47c2-931a-\
e9bdaeefcee0"]
}, Open  ]],

Cell[TextData[{
 "We already had this in \[OpenCurlyDoubleQuote]&\[CloseCurlyDoubleQuote] but \
CCSS only knows about \[OpenCurlyDoubleQuote]+\[OpenCurlyDoubleQuote]. My \
suggestion is that kids know about secret codes, and thus know about the \
distinction between ",
 StyleBox["content ",
  FontSlant->"Italic"],
 "and ",
 StyleBox["coding",
  FontSlant->"Italic"],
 ". They should be able to understand that \[OpenCurlyDoubleQuote]&\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]\[CenterDot]\
\[CloseCurlyDoubleQuote] are used to encode the pronunciation of the numbers \
and that \[OpenCurlyDoubleQuote]+\[OpenCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]\[Times]\[CloseCurlyDoubleQuote] are the operators \
with properties of commutation, association and distribution.  If they don\
\[CloseCurlyQuote]t get it then it is the objective of education that they \
get it. Watching movies with secret codes is an acquired taste."
}], "Text",ExpressionUUID->"e484ecd1-e9cd-4b74-9490-cfcd7459473d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Grades 3 & 4 and 100 - 1000"
}], "Subsubsection",ExpressionUUID->"1483cda4-d9d3-4a44-9125-55e79daf70a2"],

Cell["\<\
Grade 3 has multiplication and Grade 4 is more aware of complexities.\
\>", "Text",ExpressionUUID->"8fb764ca-8d43-4617-905f-2155f5179324"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 3\>\"", ",", "\"\<OA\>\"", ",", "\"\<D.9\>\""}], 
  "]"}]], "Input",ExpressionUUID->"dc2bbbc6-1a9d-4a8c-87c8-37e66c9319bf"],

Cell[BoxData[
 FormBox["\<\"Solve problems involving the four operations, and identify and \
explain patterns in arithmetic. CCSS.Math.Content.3.OA.D.9\\nIdentify \
arithmetic patterns (including patterns in the addition table or \
multiplication table), and explain them using properties of operations.\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"29c8efc7-c16e-43e8-8da2-\
12f929849255"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CCSSMathContent", "[", 
  RowBox[{"\"\<Grade 4\>\"", ",", "\"\<NBT\>\"", ",", "\"\<A.2\>\""}], 
  "]"}]], "Input",ExpressionUUID->"60611759-60fc-4002-81b5-9007fa4e39e6"],

Cell[BoxData[
 FormBox["\<\"Generalize place value understanding for multi-digit whole \
numbers. CCSS.Math.Content.4.NBT.A.2\\nRead and write multi-digit whole \
numbers using base-ten numerals, number names, and expanded form. Compare two \
multi-digit numbers based on meanings of the digits in each place, using >, \
=, and < symbols to record the results of comparisons.\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"37a1df66-eb29-48dc-8592-\
a20af64de3b9"]
}, Open  ]],

Cell["\<\
Students are now up to a discussion of the full place value system using \
their command of numbers and multiplication. This shows how the place value \
system works, though using $Language for the (single) StepMonitor and again \
using \[OpenCurlyDoubleQuote]+\[OpenCurlyDoubleQuote]. We might show with and \
without simplification. \
\>", "Text",ExpressionUUID->"f0044f46-e979-47e0-b55a-37539ea30660"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"643", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", "  ", "\"\<French\>\""}], ",", " ", 
    RowBox[{"StepMonitor", " ", "\[Rule]", " ", "True"}], ",", " ", 
    RowBox[{"And", " ", "\[Rule]", " ", "\"\<+\>\""}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"934f8134-8089-4ab5-8457-25ec2d90df05"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox["\<\"TheSum[times[6, 100], times[4, 10], times[3, 1]]\"\>", 
  TraditionalForm]], "Print",ExpressionUUID->"490b7cae-66b6-4b0b-a6a8-\
30d40fd1d8d8"],

Cell[BoxData[
 FormBox["\<\"six\[CenterDot]cent  +  quatre\[CenterDot]dix  +  trois\
\[CenterDot]\"\>", TraditionalForm]], "Print",ExpressionUUID->"69e8ea8f-a3cf-\
45ba-95fb-db103f55dde2"]
}, Open  ]],

Cell[BoxData[
 FormBox["\<\"6 \[CenterDot] 100   +   4 \[CenterDot] 10   +   3\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"b3847a16-e2df-467b-9f3c-\
fa69156f76a6"]
}, Open  ]],

Cell[TextData[{
 "PM. The place value system speaks all positions separately, e.g. also ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"4", " "}]], TraditionalForm]],ExpressionUUID->
  "9c9846e3-7071-440a-ae44-6a52b0f7c2c5"],
 "and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "4fea5093-6931-4973-bf59-a533a0be477b"],
 ". We write out all zeros (1000) and do not use exponents since we assume \
that kids haven\[CloseCurlyQuote]t had exponents yet but they can count the \
number of zeros.  The following obviously is not for 2nd Grade, but it shows \
how the routine works. The spoken and written version is actually the Chinese \
method, see Uy (2003), though with the added feature here of the ampersand \
infixes. We have freedom to choose the infix (but a StyleBox will not work)."
}], "Text",ExpressionUUID->"b49077ca-6b02-4a88-9378-78a023dc473c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueDigits", "[", 
   RowBox[{"1115124", ",", " ", 
    RowBox[{"And", " ", "\[Rule]", " ", "\"\<,\>\""}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"eda2b5a8-d45d-42d9-84d3-40fc487dd85f"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]million  ,  \[CenterDot]lakh  ,  \[CenterDot]myriad \
 ,  five\[CenterDot]thousand  ,  \[CenterDot]hundred  ,  two\[CenterDot]ten  \
,  four\[CenterDot]\"\>", TraditionalForm]], "Print",ExpressionUUID->\
"5a4c5ea1-553f-4d47-ad25-c2e0a8aff11b"],

Cell[BoxData[
 FormBox["\<\"1000000    \[CenterDot]   100000    \[CenterDot]   10000    \
\[CenterDot]   5 \[CenterDot] 1000    \[CenterDot]   100    \[CenterDot]   2 \
\[CenterDot] 10    \[CenterDot]   4\"\>", TraditionalForm]], "Output",Expressi\
onUUID->"9230a58e-c345-40e3-9b00-23248d50a1cd"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 3. Blocks of three digits"
}], "Subsection",ExpressionUUID->"5128a79c-86b8-48b6-b623-08d20270bbdf"],

Cell["\<\
I did not see the following in the CCSS but may have overlooked it. \
\>", "Text",ExpressionUUID->"c2b45a0e-2aa3-40e0-8c14-79c24ad4a49e"],

Cell[TextData[{
 "The students learn higher numbers, and how to pronounce them by blocks of 3 \
digits. This convention is efficient - and avoids the need for special names \
for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "4"], TraditionalForm]],ExpressionUUID->
  "cc28b862-ec3c-4611-8e98-46419a4ee5fc"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "c1c5e5be-140c-4c4a-8d03-54fa6c3ffddd"],
 ". The insertion of \[OpenCurlyDoubleQuote]and\[CloseCurlyDoubleQuote] \
between the blocks and their weights provides a useful resting pause. "
}], "Text",ExpressionUUID->"67dc3e69-6c39-4b26-bbc2-7ab2ba49f189"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", " ", "=", " ", 
  RowBox[{"PlaceValueBlock", "[", "654121", "]"}]}]], "Input",ExpressionUUID->\
"4d528889-e970-4416-aa32-b09af8bf0023"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"6 \[CenterDot] 100\"\>", ",", "\<\" & \"\>", 
        ",", "\<\"5 \[CenterDot] 10    &    4\"\>"}], "}"}], ",", "1000"}], 
     "}"}], ",", "\<\" & \"\>", ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1 \[CenterDot] 100\"\>", ",", "\<\" & \"\>", 
      ",", "\<\"2 \[CenterDot] 10    &    1\"\>"}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"e272cea3-8282-4d80-ba26-\
ff5e5ebaee6d"]
}, Open  ]],

Cell["\<\
For larger values we might display without the ampersand (which is the form \
in the Abstract).\
\>", "Text",ExpressionUUID->"c554c114-b47f-40f3-9b51-4e3cf55a7a37"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueBlock", "[", 
   RowBox[{"654121", ",", " ", 
    RowBox[{"And", " ", "\[Rule]", " ", "\"\<\>\""}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}], " "}]], "Input",\
ExpressionUUID->"595ffcb3-f424-4cb1-8e18-46769d31881d"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"6 \[CenterDot] 100\"\>", ",", "\<\"  \"\>", 
        ",", "\<\"5 \[CenterDot] 10        4\"\>"}], "}"}], ",", "1000"}], 
     "}"}], ",", "\<\"  \"\>", ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1 \[CenterDot] 100\"\>", ",", "\<\"  \"\>", 
      ",", "\<\"2 \[CenterDot] 10        1\"\>"}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"71c2a99d-0c0f-4349-9bed-\
3c6c13007666"]
}, Open  ]],

Cell["\<\
The layout of these lists has the following explanation: The routine \
PlaceValueBlock only uses $Language. The package was written with $Language = \
\[OpenCurlyDoubleQuote]English\[CloseCurlyDoubleQuote].  It appears that \
Speak[100] is \[OpenCurlyDoubleQuote]one hundred\[CloseCurlyDoubleQuote] and \
Speak[1\[CenterDot]100] thus is \[OpenCurlyDoubleQuote]one one-hundred\
\[CloseCurlyDoubleQuote]. The \[OpenCurlyDoubleQuote]one one-hundred\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]one one-thousand\
\[CloseCurlyDoubleQuote] were so annoying, if not confusing, in combination \
with pronouncing the three digits and their place values, that I changed to \
\[OpenCurlyDoubleQuote]hundred\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]thousand\[CloseCurlyDoubleQuote] in speech. \
\>", "Text",ExpressionUUID->"da3a354f-d534-42c7-acca-362c64379bd4"],

Cell[TextData[{
 "There is a difference between what we want ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "to Speak (with the infixes) and what we want to Show now (at the head of \
the expression). The following is somewhat okay.  "
}], "Text",ExpressionUUID->"3eb0a9a7-16ca-4685-914c-d29535248cf6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TreeForm", "[", 
  RowBox[{"result", "/.", " ", 
   RowBox[{
    RowBox[{"List", "[", 
     RowBox[{"x_", ",", " ", "\"\< & \>\"", ",", " ", "y_"}], "]"}], " ", 
    "\[RuleDelayed]", " ", 
    RowBox[{"(", 
     RowBox[{"x", " ", "~", "\"\< & \>\"", "~", " ", "y"}], ")"}]}]}], 
  "]"}]], "Input",ExpressionUUID->"de96333a-9b11-4195-9ebc-23479e453499"],

Cell[BoxData[
 FormBox[
  GraphicsBox[
   TagBox[
    GraphicsComplexBox[{{2.071419837175451, 2.259730731464128}, {
     1.129865365732064, 1.5064871543094187`}, {0.7532435771547095, 
     0.7532435771547092}, {0., 0.}, {0.7532435771547095, 0.}, {
     1.506487154309419, 0.}, {1.506487154309419, 0.7532435771547092}, {
     3.012974308618838, 1.5064871543094187`}, {2.259730731464128, 
     0.7532435771547092}, {3.012974308618838, 0.7532435771547092}, {
     3.766217885773547, 0.7532435771547092}}, {
      {RGBColor[0.55, 0.45, 0.45], 
       LineBox[{{1, 2}, {1, 8}, {2, 3}, {2, 7}, {3, 4}, {3, 5}, {3, 6}, {8, 
        9}, {8, 10}, {8, 11}}]}, {
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox["\<\" & \"\>", "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 1],
         TagBox[
          RowBox[{"\" & \"", "(", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"{", 
                    
                    RowBox[{
                    "\"6 \[CenterDot] 100\"", ",", "\" & \"", ",", 
                    "\"5 \[CenterDot] 10    &    4\""}], "}"}], ",", "1000"}],
                 "}"}], ",", 
              RowBox[{"{", 
                
                RowBox[{
                 "\"1 \[CenterDot] 100\"", ",", "\" & \"", ",", 
                  "\"2 \[CenterDot] 10    &    1\""}], "}"}]}], ")"}], 
          HoldForm]],
        Annotation[#, 
         HoldForm[
          
          " & "[{{"6 \[CenterDot] 100", " & ", "5 \[CenterDot] 10    &    4"},
             1000}, {
           "1 \[CenterDot] 100", " & ", "2 \[CenterDot] 10    &    1"}]], 
         "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox["List", "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 2],
         TagBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                
                RowBox[{
                 "\"6 \[CenterDot] 100\"", ",", "\" & \"", ",", 
                  "\"5 \[CenterDot] 10    &    4\""}], "}"}], ",", "1000"}], 
            "}"}], HoldForm]],
        Annotation[#, 
         HoldForm[{{
           "6 \[CenterDot] 100", " & ", "5 \[CenterDot] 10    &    4"}, 
           1000}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox["List", "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 3],
         TagBox[
          RowBox[{"{", 
            
            RowBox[{"\"6 \[CenterDot] 100\"", ",", "\" & \"", ",", 
              "\"5 \[CenterDot] 10    &    4\""}], "}"}], HoldForm]],
        Annotation[#, 
         HoldForm[{
          "6 \[CenterDot] 100", " & ", "5 \[CenterDot] 10    &    4"}], 
         "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["\<\"6 \[CenterDot] 100\"\>",
             HoldForm], "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 4],
         TagBox["\"6 \[CenterDot] 100\"", HoldForm]],
        Annotation[#, 
         HoldForm["6 \[CenterDot] 100"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["\<\" & \"\>",
             HoldForm], "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 5],
         TagBox["\" & \"", HoldForm]],
        Annotation[#, 
         HoldForm[" & "], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["\<\"5 \[CenterDot] 10    &    4\"\>",
             HoldForm], "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 6],
         TagBox["\"5 \[CenterDot] 10    &    4\"", HoldForm]],
        Annotation[#, 
         HoldForm["5 \[CenterDot] 10    &    4"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["1000",
             HoldForm], "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 7],
         TagBox["1000", HoldForm]],
        Annotation[#, 
         HoldForm[1000], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox["List", "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 8],
         TagBox[
          RowBox[{"{", 
            
            RowBox[{"\"1 \[CenterDot] 100\"", ",", "\" & \"", ",", 
              "\"2 \[CenterDot] 10    &    1\""}], "}"}], HoldForm]],
        Annotation[#, 
         HoldForm[{
          "1 \[CenterDot] 100", " & ", "2 \[CenterDot] 10    &    1"}], 
         "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["\<\"1 \[CenterDot] 100\"\>",
             HoldForm], "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 9],
         TagBox["\"1 \[CenterDot] 100\"", HoldForm]],
        Annotation[#, 
         HoldForm["1 \[CenterDot] 100"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["\<\" & \"\>",
             HoldForm], "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 10],
         TagBox["\" & \"", HoldForm]],
        Annotation[#, 
         HoldForm[" & "], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["\<\"2 \[CenterDot] 10    &    1\"\>",
             HoldForm], "TraditionalForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            BackFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.023529411764705882`],
            FontColor->GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 11],
         TagBox["\"2 \[CenterDot] 10    &    1\"", HoldForm]],
        Annotation[#, 
         HoldForm["2 \[CenterDot] 10    &    1"], "Tooltip"]& ]}}],
    Annotation[#, 
     VertexCoordinateRules -> {{2.071419837175451, 2.259730731464128}, {
      1.129865365732064, 1.5064871543094187`}, {0.7532435771547095, 
      0.7532435771547092}, {0., 0.}, {0.7532435771547095, 0.}, {
      1.506487154309419, 0.}, {1.506487154309419, 0.7532435771547092}, {
      3.012974308618838, 1.5064871543094187`}, {2.259730731464128, 
      0.7532435771547092}, {3.012974308618838, 0.7532435771547092}, {
      3.766217885773547, 0.7532435771547092}}]& ],
   AspectRatio->NCache[2 17^Rational[-1, 2], 0.48507125007266594`],
   FormatType:>StandardForm,
   FrameTicks->Automatic,
   ImageSize->{474., Automatic},
   PlotRange->All,
   PlotRangePadding->Scaled[0.1]], TraditionalForm]], "Output",ExpressionUUID-\
>"53390e67-c232-4044-90f0-6a4d2d3fe66f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 4. Daily use"
}], "Subsection",ExpressionUUID->"d409d666-f9d1-46f3-aa29-4da3bf7bbffd"],

Cell[TextData[{
 "In the final phase kids are mastering or have mastered the place value \
system. The following routine adopts the convention of ",
 StyleBox["Mathematica\[CloseCurlyQuote]",
  FontSlant->"Italic"],
 "s IntegerName: absolute values less than 1000 are given as words \
(effectively PlaceValue), and higher values are combinations of blocks of \
digits and their bases in words (thousand, million, etc.). This allows high \
numbers. The block bases can be submitted to WordTranslation. Drawbacks: (i) \
The use of another language is relatively slow because of WordTranslation. \
(ii) Transliteration was included later and wasn\[CloseCurlyQuote]t designed \
for speed.  PM. We separate the digit bases by a comma. This option for And \
can be adapted but is not passed on to PlaceValue."
}], "Text",ExpressionUUID->"da8c6be7-17e1-4cff-a50c-842f679eefeb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueIntegerName", "[", 
  RowBox[{"99", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"5b8764a3-6e8c-4b03-9a32-9c2b0cfcfa52"],

Cell[BoxData[
 FormBox["\<\"neuf\[CenterDot]dix  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  neuf\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"83ea1dd0-4ed5-4a58-aaf2-\
9b38cce9295d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueIntegerName", "[", 
   RowBox[{"1011", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], "]"}], 
  "   ", 
  RowBox[{"(*", " ", 
   RowBox[{"above", " ", "999"}], " ", "*)"}]}]], "Input",ExpressionUUID->\
"2bd840c2-18df-421b-a83d-7fae286434db"],

Cell[BoxData[
 FormBox["\<\"1  mille,   11\"\>", TraditionalForm]], "Output",ExpressionUUID->"4cdef6a9-df46-453e-8567-1f01e33584ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"7fcea02b-7f21-4e3e-900d-47b4226b5420"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]uhnn  meel,   \[CenterDot]dees <silence \
msec=\\\"300\\\"/>  ayh  \[CenterDot]uhnn\"\>", TraditionalForm]], "Output",Ex\
pressionUUID->"2679c25c-b185-45e8-8205-4e9e1d3c0a14"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueIntegerName", "[", "1090011", "]"}], " "}]], "Input",Expr\
essionUUID->"c42d101d-bab2-4128-8efb-b45e73012779"],

Cell[BoxData[
 FormBox["\<\"1  million,   90  thousand,   11\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"17412603-e159-43f7-ac63-\
14075829e6a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"4274ff67-c668-4cc8-9111-bdd071eaf35b"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]one  million,   nine\[CenterDot]ten  thousand,   \
\[CenterDot]ten  &  \[CenterDot]one\"\>", TraditionalForm]], "Output",Expressi\
onUUID->"8e17b798-16e4-44bb-ae6f-4822248b6839"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueIntegerName", "[", 
   RowBox[{"1234451011", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}], ",", " ", 
    RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}], " "}]], "Input",\
ExpressionUUID->"1fbcdf36-a6c4-47a3-a8df-925333cbc222"],

Cell[BoxData[
 FormBox["\<\"1  billion,   234  million,   451  mille,   11\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"374f0cc8-eb72-45bc-936b-\
02a02ddbaa9b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"c5a24b7b-395e-4fa4-82a2-7e0a34cae9bc"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]un  billion,   deux\[CenterDot]cent  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  trois\[CenterDot]dix  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  quatre\[CenterDot]  million,   \
quatre\[CenterDot]cent  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  cinq\
\[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]un \
 mille,   \[CenterDot]dix  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
\[CenterDot]un\"\>", TraditionalForm]], "Output",ExpressionUUID->"44488c95-\
7736-4003-ae7e-c81dc0ebab65"]
}, Open  ]],

Cell["\<\
Just to be sure: WordTranslation provided two possibilities, and the routine \
always takes the first.\
\>", "Text",ExpressionUUID->"db3f5bbf-c03d-4fc3-a206-7609c7f62278"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WordTranslation", "[", 
  RowBox[{"\"\<billion\>\"", ",", " ", 
   RowBox[{"\"\<English\>\"", " ", "\[Rule]", " ", "\"\<French\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"58fcf938-df65-47f5-82ae-435d84c6211f"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"billion\"\>", ",", "\<\"milliard\"\>"}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"6a6e1324-e3e1-4eba-bda3-\
1424c1a1e7dd"]
}, Open  ]],

Cell[TextData[{
 "The LatestPronunciation[] gives  words in French without transliteration \
into English, because of the option Speak \[Rule] False. Speaking it in \
English will be far removed from the actual pronunciation in French. If you \
want a transliteration then use Speak \[Rule] True, or Level 1 again (that \
also drops the first \[OpenCurlyDoubleQuote]un\[CloseCurlyDoubleQuote]). In \
all cases transliteration is restricted to absolute numbers less than ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "7"], TraditionalForm]],ExpressionUUID->
  "2b497394-d4ac-48d3-afc1-bb19671bad64"],
 " (and thus \[OpenCurlyDoubleQuote]billion\[CloseCurlyDoubleQuote] is \
pronounced in English)."
}], "Text",ExpressionUUID->"9e362fc2-62e4-455e-805a-f553bdfd505f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level -4. Traditional pronunciation"
}], "Subsection",ExpressionUUID->"d0938189-c7e5-4bda-9fa5-57b5c97b1aa0"],

Cell[TextData[{
 "Traditional pronunciation uses the place value system partially, with \
breaches of order and structure. Given the diagnosis in my booklet (2015a)",
 StyleBox[" A child wants nice and no mean numbers",
  FontSlant->"Italic"],
 ", it was tempting to use the name MeanNumbers for the tradition routine, \
but there is a difference between an expressive book title and programming, \
and thus I settled for PartialPlaceValue. It is at level -4. Conventionally \
it uses the blocks of 3 digits. The routine uses ",
 StyleBox["Mathematica\[CloseCurlyQuote]",
  FontSlant->"Italic"],
 "s IntegerName using DigitsWords and adopts its convention: For -1000 < ",
 StyleBox["n ",
  FontSlant->"Italic"],
 "< 1000 only words are shown but for higher absolute values the blocks of \
digits are shown. Drawback: no transliteration."
}], "Text",ExpressionUUID->"3d0321a8-af34-4234-a28b-4749ab365ea4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PartialPlaceValue", "[", "321", "]"}], " "}]], "Input",ExpressionUU\
ID->"66096ffe-2cfb-4998-8ffb-66cb9c9bda4b"],

Cell[BoxData[
 FormBox["\<\"three hundred twenty one\"\>", TraditionalForm]], "Output",Expre\
ssionUUID->"5905d083-d635-45e8-843a-cad15cb91eea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PartialPlaceValue", "[", "654321", "]"}], " "}]], "Input",Expressio\
nUUID->"d24aa631-6f58-45e2-9291-8fdacbf19ae2"],

Cell[BoxData[
 FormBox["\<\"654 thousand 321\"\>", TraditionalForm]], "Output",ExpressionUUI\
D->"6e17b94c-8a09-4053-b7c1-b137262ca554"]
}, Open  ]],

Cell["\<\
Speak stops when meeting a hyphen, and thus hyphens are replaced by blanks. \
Unfortunately for other languages, IntegerName concatenates the words. It is \
too involved to undo this.\
\>", "Text",ExpressionUUID->"cc4f1ced-1e77-49bd-9ab6-a24660a9c72c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PartialPlaceValue", "[", 
   RowBox[{"21", ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<German\>\""}]}], "]"}], 
  " "}]], "Input",ExpressionUUID->"0be9186f-13c1-4f3e-b14e-e76e400455e4"],

Cell[BoxData[
 FormBox["\<\"ein\[DiscretionaryHyphen]und\[DiscretionaryHyphen]zwanzig\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"9b0c905c-9737-4142-a2a2-\
9abdbb507816"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"StringReplace", "[", 
   RowBox[{"%", ",", " ", 
    RowBox[{"\"\<und\>\"", " ", "\[Rule]", " ", "\"\< oond \>\""}]}], "]"}], 
  "  ", "//", " ", "Speak"}]], "Input",ExpressionUUID->"ee89d6d4-a3f1-438c-\
bf71-e23c93f43a0f"],

Cell["\<\
When kids have classes on programming, writing code, it might be a nice \
suggestion to let them program the way how they pronounce the integers in the \
full place value system, and how their parents pronounce them in the dialect \
of traditional English. \
\>", "Text",ExpressionUUID->"c627f30b-2015-4aca-b6b1-b805270b303b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". One switching routine to rule them all"
}], "Subsection",ExpressionUUID->"8bad2782-878a-4ef6-8f2e-da2214184846"],

Cell[TextData[{
 "When you are new to these routines (like I was while writing them) then it \
may be easy to get lost for a moment. With some structure it is easier to see \
how they hang together. Therefor, PronounceInteger is a switching routine for \
selecting Level \[Rule] ",
 StyleBox["level, ",
  FontSlant->"Italic"],
 "with above levels 1, 2, 3, 4 and -4."
}], "Text",ExpressionUUID->"1a2d834a-ae54-4442-ab29-d5a50c3228a2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PronounceInteger"}]], "Input",ExpressionUUID->"02f7d83f-2908-4ffd-aae2-724910e5223b"],

Cell[BoxData["\<\"PronounceInteger[n] pronounces n. Options are passed on to \
the routine that is called, except: if the chosen Language is equal to \
$Language then it is not passed on. It uses first the Level and then the \
Method setting in the options, default Level -> 1, Method -> PlaceValue. \
Option All -> {...} gives the methods in the MathEd`PronounceInteger` \
package. See the documentation per routine. If you want to specify the \
selection by Method -> routine name, select also Level -> 0. Perhaps easier \
to remember than the routine names, and taking advantage of the levels of \
understanding, you can also specify the Level -> lev:\\nchosen =Switch[lev, \
\\n 1, PlaceValue,\\n 2, PlaceValueDigits,\\n 3, PlaceValueBlock,\\n 4, \
PlaceValueIntegerName,\\n-4, PartialPlaceValue,\\n_, Null];\\n If none of \
these is used (say with Level -> 0) then the Method -> m option is used. If \
no method is in the list that All provided: $Failed\"\>"], "Print", \
"PrintUsage",
 CellTags->
  "Info3563735558490-8910602",ExpressionUUID->"2a1cb0a9-a9c7-4119-9f7f-\
ea39e103b018"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PronounceInteger", "]"}]], "Input",ExpressionUUID->"98a4f569-1aee-47e5-8829-45fa1c76a3b5"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Level", "\[Rule]", "1"}], ",", 
    RowBox[{"Method", "\[Rule]", "PlaceValue"}], ",", 
    RowBox[{"Language", "\[Rule]", "\<\"English\"\>"}], ",", 
    RowBox[{"Speak", "\[Rule]", "True"}], ",", 
    RowBox[{"All", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "PlaceValue", ",", "PlaceValueH", ",", "PlaceValueDigits", ",", 
       "PlaceValueDigits$Language", ",", "PlaceValueBlock", ",", 
       "PlaceValueIntegerName", ",", "PartialPlaceValue", ",", 
       "PlaceValueTable"}], "}"}]}]}], "}"}], TraditionalForm]], "Output",Expr\
essionUUID->"ec09b18f-84a8-4055-8849-34944ad32d69"]
}, Open  ]],

Cell["\<\
Who knows about PlaceValue or PlaceValueTable would tend to call them \
directly, but the following serves as an illustration. Observe the special \
role of the Language option. We may set the option to say \
\[OpenCurlyDoubleQuote]Italian\[CloseCurlyDoubleQuote], and then \
PronounceInteger will call the routines with that setting. However, when the \
call uses Language \[Rule] $Language, then the option is not passed on, and \
the option settings of the subroutines take precedence. PlaceValue has its \
own setting Language \[Rule] \[OpenCurlyDoubleQuote]Amplish\
\[CloseCurlyDoubleQuote], and thus we can still get the ampersand in smaller \
FontSize.\
\>", "Text",ExpressionUUID->"cbc6375d-546d-402e-906c-51ed00e06447"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PronounceInteger", "[", "12", "]"}]], "Input",ExpressionUUID->"bfc1c241-c9f9-434b-ad6c-da83d88a4256"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
two\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->"660ca2e7-\
7459-4e21-aad8-9406d9997325"]
}, Open  ]],

Cell[TextData[{
 "PlaceValueTable itself would not include the traditional pronunciation but \
this call via PronounceInteger inserts the option Speak \[Rule] True. Note: \
\[OpenCurlyDoubleQuote]twelve\[CloseCurlyDoubleQuote] is \
\[OpenCurlyDoubleQuote]two left over after 10\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]ten ",
 StyleBox["&",
  FontSize->14],
 " two\[CloseCurlyDoubleQuote] then is clearer."
}], "Text",ExpressionUUID->"636e9d70-0ae5-41df-bff6-ea9bb25233fb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PronounceInteger", "[", 
  RowBox[{"12", ",", " ", 
   RowBox[{"Level", " ", "\[Rule]", " ", "0"}], ",", " ", 
   RowBox[{"Method", " ", "\[Rule]", " ", "PlaceValueTable"}]}], 
  "]"}]], "Input",ExpressionUUID->"e96e8982-3d26-4816-b456-bc8ceddddb9a"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"12", "\<\" \"\>", "\<\"\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  two\[CenterDot]\"\>", "\<\"10   \
&   2\"\>", "\<\" \"\>", "\<\"twelve\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Speak -> True, Level -> 0, Method -> 
     Cool`MathEd`PronounceInteger`PlaceValueTable, TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"c7676061-10fd-4579-a72e-0d34adf99869"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Zig in German and tig in Dutch"
}], "Section",
 PageBreakAbove->True,ExpressionUUID->"bc449713-0b45-4467-a8ea-429d8541c9a7"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Conflict of traditional and proper pronunciation"
}], "Subsection",ExpressionUUID->"f73020d9-1320-49f5-8228-6af9c32d7eba"],

Cell["\<\
For English, traditional 19 = nine-teen and place value 90 = \
nine\[CenterDot]ten (traditionally ninety) are not in conflict.\
\>", "Text",ExpressionUUID->"8db0c156-f703-41f6-a2fd-a2bb88c73380"],

Cell["\<\
For German, traditional 19 = neun-zehn and place value 90 = \
neun\[CenterDot]zehn (traditionally neunzig) are in conflict. Making a \
transition will cause much confusion. Dutch has the same problem. \
\>", "Text",ExpressionUUID->"12594fa6-be6c-4c2c-9b16-9ddeadea6147"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". A solution is to use zig in German and tig in Dutch for 10"
}], "Subsection",ExpressionUUID->"65a83a15-c11f-4a43-a6c2-9249435669ae"],

Cell[TextData[{
 "Like English \[OpenCurlyDoubleQuote]-ty\[CloseCurlyDoubleQuote], German \
uses \[OpenCurlyDoubleQuote]-zig\[CloseCurlyDoubleQuote] at the end of 20, \
(30,) 40 through 90. Dutch has \[OpenCurlyDoubleQuote]-tig\
\[CloseCurlyDoubleQuote]. Thus we may use ",
 StyleBox["zig",
  FontSlant->"Italic"],
 " for 10 in German and ",
 StyleBox["tig",
  FontSlant->"Italic"],
 " for 10 in Dutch. For me, this flash of insight in 2012 was a major step \
for accepting that there is scope for a full use of the place value system \
(in Holland). The changes in pronunciation are least with zig and tig."
}], "Text",ExpressionUUID->"e872fda4-52e0-4e7d-b8d7-eb0ead78c40b"],

Cell[TextData[{
 "June 2018 brought this new discovery for me: Van Bree (1987:259) explains \
that Dutch -",
 StyleBox["tig ",
  FontSlant->"Italic"],
 "derives from Proto-German or Gothic ",
 StyleBox["tigus ",
  FontSlant->"Italic"],
 "(\[OpenCurlyDoubleQuote]multiple of ten\[CloseCurlyDoubleQuote]) and \
Menninger (1958:139) explains this for German ",
 StyleBox["-zig, ",
  FontSlant->"Italic"],
 "and translates ",
 StyleBox["tigus ",
  FontSlant->"Italic"],
 "as \[OpenCurlyDoubleQuote]Zehnheit\[CloseCurlyDoubleQuote]. For the English \
world perhaps a useful reference might be https://www.etymonline.com/word/-ty"
}], "Text",ExpressionUUID->"817c9d41-294a-478d-b056-67e21f08e5df"],

Cell["\<\
Thus, what for me in 2012 was an insight using the existing regularity in \
names of numbers, actually derives from a structure that already existed and \
which is highlighted now. Potentially such structure was encouraged by the \
influence of Latin.\
\>", "Text",ExpressionUUID->"db978a86-57c6-41ee-bce6-cef8dedfc973"],

Cell["\<\
Germans or Dutch who have a problem with zig or tig - with the new phenomenon \
of \[OpenCurlyDoubleQuote]Zehnsucht\[CloseCurlyDoubleQuote] -  and who still \
want to make full use of the place value system, could also consider \
borrowing \[OpenCurlyDoubleQuote]ten\[CloseCurlyDoubleQuote] from English, or \
use scientific \[OpenCurlyDoubleQuote]deca\[CloseCurlyDoubleQuote] (though \
with two syllables). Or Germans could use \[OpenCurlyDoubleQuote]tien\
\[CloseCurlyDoubleQuote] from Dutch, and the Dutch \
\[OpenCurlyDoubleQuote]zehn\[CloseCurlyDoubleQuote] from German. In Dutch \
\[OpenCurlyDoubleQuote]tig\[CloseCurlyDoubleQuote] already is used sometimes \
in the sense of \[OpenCurlyDoubleQuote]some unknown very big number\
\[CloseCurlyDoubleQuote] and the change to tig = 10 can still be made.\
\>", "Text",ExpressionUUID->"c701a2ec-90ac-4cd9-ad82-d683d9aa9222"],

Cell[TextData[{
 "For the following, observe the usefulness of the trailing dot again, that \
helps identify the difference between \[OpenCurlyDoubleQuote]zig ",
 StyleBox["&",
  FontSize->14],
 " neun\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]neun\[CenterDot]zig\[CloseCurlyDoubleQuote]. If you \
reading this, remember that the routines speak the numbers as well."
}], "Text",ExpressionUUID->"d744dd1c-40e1-4eb3-a340-92ff331ce3d5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueTable", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"19", ",", " ", "90"}], "}"}], ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<German\>\""}]}], "]"}], 
  "     "}]], "Input",ExpressionUUID->"abba7013-1dca-49c5-80a4-672f0d315b27"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"19", "\<\" \"\>", "\<\"\[CenterDot]zig  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  neun\[CenterDot]\"\>", "\<\"10  \
 &   9\"\>", "\<\" \"\>", "\<\"neunzehn\"\>"},
      {"90", "\<\" \"\>", "\<\"neun\[CenterDot]zig\"\>", "\<\"9 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"neunzig\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Language -> "German", TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"400a08f8-a33a-4da8-b4fc-b8e52519de05"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueTable", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"19", ",", " ", "90"}], "}"}], ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Dutch\>\""}]}], "]"}], 
  "     "}]], "Input",ExpressionUUID->"899a99ab-efba-4caa-976c-ba88228f8fb8"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"19", "\<\" \"\>", "\<\"\[CenterDot]tig  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  negen\[CenterDot]\"\>", "\<\"10 \
  &   9\"\>", "\<\" \"\>", "\<\"negentien\"\>"},
      {"90", "\<\" \"\>", "\<\"negen\[CenterDot]tig\"\>", "\<\"9 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"negentig\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Language -> "Dutch", TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"6508713b-53c3-40a3-8a68-8c011d5fc48b"]
}, Open  ]],

Cell["\<\
The German association \[OpenCurlyDoubleQuote]Zwanzig-eins\
\[CloseCurlyDoubleQuote] are not fundamentalists in terms of the full place \
value system.\
\>", "Text",ExpressionUUID->"92a71f5e-0be8-4116-877d-007850de4617"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"21", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Simplify", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<German\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"09464dd1-9a80-4a98-90df-eeaeca32a8ba"],

Cell[BoxData[
 FormBox["\<\"zwei\[CenterDot]zig  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  ein\[CenterDot]ein\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"9294410b-0915-4a50-ab99-\
84f7c3425a03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"21", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", "  ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<German\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"e62893c9-a697-4854-bb66-05f6776422ca"],

Cell[BoxData[
 FormBox["\<\"zwei\[CenterDot]zig  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]ein\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"7691c5e0-d53d-49c9-960c-\
3542e1d9fee2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Comparison with English"
}], "Subsection",ExpressionUUID->"afc954b4-4c7a-44e8-91e3-42719305ec4a"],

Cell["\<\
Remarkably, the changes for English could well be larger than for German. \
E.g. 60 changes from \[OpenCurlyDoubleQuote]sixty\[CloseCurlyDoubleQuote] to \
\[OpenCurlyDoubleQuote]six\[CenterDot]ten\[CloseCurlyDoubleQuote]. An English \
speaking nation might prefer to change \[OpenCurlyDoubleQuote]ten\
\[CloseCurlyDoubleQuote] into \[OpenCurlyDoubleQuote]ty\
\[CloseCurlyDoubleQuote] and pronounce this as \[OpenCurlyDoubleQuote]t\
\[CloseCurlyDoubleQuote] or \
\[OpenCurlyDoubleQuote]tee\[CloseCurlyDoubleQuote] (like in Danish), which \
gives \[OpenCurlyDoubleQuote]six\[CenterDot]ty\[CloseCurlyDoubleQuote] again. \
This would actually minimise the changes, even allowing for the special \
twenty, thirty, forty and fifty. English would also re-introduce the \
\[OpenCurlyDoubleQuote]and\[CloseCurlyDoubleQuote] again that German never \
abolished. Kids find English easier than the reversed order in German, Dutch \
and Danish, which only shows how important that order is, and which likely \
does not give evidence on the \[OpenCurlyDoubleQuote]and\
\[CloseCurlyDoubleQuote]. My impression is that English would rather stick to \
\[OpenCurlyDoubleQuote]ten\[CloseCurlyDoubleQuote] and accept the \
consequences. But, with the available routines, we may create an alternative \
\[OpenCurlyDoubleQuote]Englishty\[CloseCurlyDoubleQuote] and check how it \
sounds.\
\>", "Text",ExpressionUUID->"eb4dd861-9252-478d-b30e-a28507b20601"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"11", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Englishty\>\""}], ",", " ", 
   RowBox[{"Show", " ", "\[Rule]", " ", "True"}]}], "]"}]], "Input",Expression\
UUID->"c46a8634-1e89-40f4-ba27-06993660b10b"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]tee <silence msec=\\\"300\\\"/>  &  \[CenterDot]one\
\"\>", TraditionalForm]], "Output",ExpressionUUID->"bd6fe087-9950-4401-a59b-\
707de02edee3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueTable", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "10", ",", " ", "11", ",", " ", "20", ",", " ", "21", ",", " ", "60", 
      ",", " ", "61"}], "}"}], ",", " ", 
    RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Englishty\>\""}]}], "]"}], 
  "     "}]], "Input",ExpressionUUID->"5f1623bf-6a3f-48b7-a5bf-c6b5ac4ce335"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"10", "\<\" \"\>", "\<\"\[CenterDot]ty\"\>", "\<\"10\"\>", "\<\" \
\"\>", "\<\"ten\"\>"},
      {"11", "\<\" \"\>", "\<\"\[CenterDot]ty  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]one\"\>", "\<\"10   \
&   1\"\>", "\<\" \"\>", "\<\"eleven\"\>"},
      {"20", "\<\" \"\>", "\<\"two\[CenterDot]ty\"\>", "\<\"2 \[CenterDot] 10\
\"\>", "\<\" \"\>", "\<\"twenty\"\>"},
      {"21", "\<\" \"\>", "\<\"two\[CenterDot]ty  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]one\"\>", "\<\"2 \
\[CenterDot] 10   &   1\"\>", "\<\" \"\>", "\<\"twenty one\"\>"},
      {"60", "\<\" \"\>", "\<\"six\[CenterDot]ty\"\>", "\<\"6 \[CenterDot] 10\
\"\>", "\<\" \"\>", "\<\"sixty\"\>"},
      {"61", "\<\" \"\>", "\<\"six\[CenterDot]ty  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]one\"\>", "\<\"6 \
\[CenterDot] 10   &   1\"\>", "\<\" \"\>", "\<\"sixty one\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Language -> "Englishty", TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"3ad90110-0c76-41bb-b16c-4ae0e1ac822c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". When 10 might be changed anyway"
}], "Subsection",ExpressionUUID->"8c24a141-068a-4778-9b39-a001f9071c2b"],

Cell["\<\
I was surprised to see that Finnish 10 is quite a long word. When adapting to \
the full use of the place value system anyway, one might imagine that there \
is a Finnish National Committee on the Pronunciation of 10 that chooses a \
shorter word.\
\>", "Text",ExpressionUUID->"a5bad86a-1d32-4c4f-af67-2728cdf56654"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"10", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Finnish\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"1863b457-920f-4c51-b633-c72b5536ed94"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","rul",
    "\"No list of rules found for \\!\\(\\*FormBox[\\\"\\\\\\\"language\\\\\\\
\"\\\", TraditionalForm]\\) \\!\\(\\*FormBox[\\\"\\\\\\\"Finnish\\\\\\\"\\\", \
TraditionalForm]\\)\"",2,132,67,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"5724fd86-6d20-430b-8108-0b8ff6714081"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","int",
    "\"Initialisation with IntegerName and WordTranslation: please wait\"",2,
    132,68,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"13f4ecf1-d646-4ae6-be11-2d8b74ee9d1b"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValueRules","wrn",
    "\"Warning: automated translation of \\!\\(\\*FormBox[\\\"\\\\\\\"Finnish\
\\\\\\\"\\\", TraditionalForm]\\) and not carefully checked on conflicts and \
peculiarities\"",2,132,69,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValueRules"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"1122a5d1-ff02-4816-98ce-f1a772ecb415"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]kymmenen\"\>", TraditionalForm]], "Output",Expressio\
nUUID->"24171bc2-554a-4658-aee0-8fae3ba60900"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Peculiarities in natural language"
}], "Subsection",ExpressionUUID->"15eed914-d9f3-4fca-9ed3-aa261e4e1c19"],

Cell["\<\
Current German makes a distinction between \[OpenCurlyDoubleQuote]eins\
\[CloseCurlyDoubleQuote] for 1 separately and \[OpenCurlyDoubleQuote]ein\
\[CloseCurlyDoubleQuote] for further use. Current German uses \
\[OpenCurlyDoubleQuote]sieben\[CloseCurlyDoubleQuote] for 7 separately, and \
uses \[OpenCurlyDoubleQuote]sieb\[CloseCurlyDoubleQuote] for combinations. \
Such deviations happen in natural language but a systematic use has only one \
application. I took what currently are most frequent: ein and sieb. (Danish \
has \[OpenCurlyDoubleQuote]syv\[CloseCurlyDoubleQuote].)\
\>", "Text",ExpressionUUID->"26e4b63f-984e-4275-8a4c-cb2e76e7cc8f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"77", ",", "  ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<German\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"0521fe64-a244-4d0c-be25-a819c640eb61"],

Cell[BoxData[
 FormBox["\<\"sieb\[CenterDot]zig  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  sieb\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"4f1746ae-cdae-4297-aef6-\
ac0bffe6b81e"]
}, Open  ]],

Cell["\<\
The advantage of the routine with the pronunciation and transliteration now \
clearly shows, in that we do not just have the words (for writing essays) but \
also have an approximation how it would sound in rehearsing in class in \
(original) kindergarten (German word), to help judge whether the suggestion \
to adapt \[OpenCurlyDoubleQuote]ein\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]sieb\[CloseCurlyDoubleQuote] could be acceptable to \
consider. \
\>", "Text",ExpressionUUID->"3280eb58-e72f-477f-b4d9-5229ff0b02de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PlaceValue", "[", 
    RowBox[{"#", ",", "  ", 
     RowBox[{"Language", " ", "\[Rule]", " ", "\"\<German\>\""}]}], "]"}], 
   "&"}], " ", "/@", " ", 
  RowBox[{"Range", "[", 
   RowBox[{"0", ",", " ", "10"}], "]"}]}]], "Input",ExpressionUUID->"32f85e7b-\
a692-4971-91e0-d26099e0bf89"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"null\[CenterDot]\"\>", ",", "\<\"\[CenterDot]ein\"\>", 
    ",", "\<\"zwei\[CenterDot]\"\>", ",", "\<\"drei\[CenterDot]\"\>", 
    ",", "\<\"vier\[CenterDot]\"\>", ",", "\<\"fuenf\[CenterDot]\"\>", 
    ",", "\<\"sechs\[CenterDot]\"\>", ",", "\<\"sieb\[CenterDot]\"\>", 
    ",", "\<\"acht\[CenterDot]\"\>", ",", "\<\"neun\[CenterDot]\"\>", 
    ",", "\<\"\[CenterDot]zig\"\>"}], "}"}], TraditionalForm]], "Output",Expre\
ssionUUID->"a8978de8-85d2-4869-a174-811bb5637831"]
}, Open  ]],

Cell["\<\
The present proposal clashes with some proposals at the \
\[OpenCurlyDoubleQuote]Zwanzigeins\[CloseCurlyDoubleQuote] movement on the \
numbers 0-20 that are important for education: zig for zehn, and thus also \
11-19 using zig, and zwei\[CenterDot]zig, to show the working of the place \
value system. Arbitrary in my implementation are: ein for eins, sieb for \
sieben, drei\[SZ]ig would also become drei\[CenterDot]zig. See Colignatus \
(2015b, 2018a). Remember also my distinction between the math language in \
school and the dialect of current language outside of school. Earlier I \
suggested that the 21 movement would become stronger if it included the full \
place value system alongside their original views, as one of the issues to \
consider. It appears that this actually has happened, and the board of \
\[OpenCurlyDoubleQuote]Zwanzigeins\[CloseCurlyDoubleQuote] informed me that \
they support research in this direction: \
https://zwanzigeins.jetzt/infos/normung-der-aussprache\
\>", "Text",ExpressionUUID->"2f24f670-a64c-4aa8-aedb-1e0fde297762"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Translate, transliterate and quality control"
}], "Section",ExpressionUUID->"3ee1103d-edd7-4756-94e8-8189c5ae17de"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Translate versus transliterate"
}], "Subsection",ExpressionUUID->"01e7a847-7b43-4798-a419-90b6e43d7e37"],

Cell[TextData[{
 "To Speak in another language, the user can adapt the $Language in the \
Preferences of ",
 StyleBox["Mathematica, ",
  FontSlant->"Italic"],
 "then restart. Both the numbers and words should be pronounced in the \
specified language, though in traditional manner. "
}], "Text",ExpressionUUID->"8a152ca3-3d2c-48fe-8e8d-a19a3b2f814d"],

Cell[TextData[{
 "There will be users who have ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "running under one specific language (e.g. $Language = \
\[OpenCurlyDoubleQuote]English\[CloseCurlyDoubleQuote]) and who still have \
interest in the pronunciation of the different languages. In that case, \
transliteration may help. The transliteration is provided in PlaceValueRules[\
\[OpenCurlyDoubleQuote]yourlanguage\[CloseCurlyDoubleQuote]] with the option \
\[OpenCurlyDoubleQuote]transliteratorlanguage\[CloseCurlyDoubleQuote] \[Rule] \
{...}."
}], "Text",ExpressionUUID->"8a6c69cf-de29-4f3a-9773-4070e68dcf88"],

Cell[TextData[{
 "PlaceValue and PlaceValueRules can also call WordTranslation from English \
to automatically supply the words of another languague. The call \
PlaceValueRules[Set, \[OpenCurlyDoubleQuote]youlanguage\
\[CloseCurlyDoubleQuote]]. This does not provide for the transliteration. One \
is advised to save the resulting \
PlaceValueRules[\[OpenCurlyDoubleQuote]yourlanguage\[CloseCurlyDoubleQuote]] \
because the initialisation takes some moments. The words for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "4"], TraditionalForm]],ExpressionUUID->
  "419f4dc5-6e6c-43f6-b124-4a3e57d741ee"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "63d6ad9c-d928-403d-ae38-504862542d4c"],
 " are generally missing and thus replaced by myriad and lakh."
}], "Text",ExpressionUUID->"10710c8d-587a-4cac-901d-dba2eb536f79"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Warning: automation does not guarantee quality"
}], "Subsection",ExpressionUUID->"f0249c88-dab5-4977-92b0-6e0142ed613a"],

Cell[TextData[{
 "PlaceValueRules[Set, \[OpenCurlyDoubleQuote]youlanguage\
\[CloseCurlyDoubleQuote]] issues a ",
 StyleBox["warning",
  FontWeight->"Bold"],
 " when the submitted language isn't in the list \
PlaceValueRules[\"Checked\"]. One may turn off the message or include a \
language in PlaceValueRules[\[OpenCurlyDoubleQuote]Checked\
\[CloseCurlyDoubleQuote]] provisionally, but it is better to actually check \
first (and then use AppendTo on the list of checked languages).  The package \
is conservative on giving the message but will repeat it on the tables, see \
below."
}], "Text",ExpressionUUID->"010c91e4-2ce1-42c9-a6ef-71227c9b97e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Checked in PlaceValueRules: English, German, French, Dutch and Danish"
}], "Subsection",ExpressionUUID->"b2e0f396-5a00-49f0-b101-a9025e7875f0"],

Cell[TextData[{
 "The package can be simple since we only require 2+10+6 = 18 \
transliterations per language, to pronounce the integers with absolute values \
less than ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "7"], TraditionalForm]],ExpressionUUID->
  "b71ee611-f6f2-4d7b-9337-07a4d3b13a0e"],
 "."
}], "Text",ExpressionUUID->"99a4988e-ce29-4454-b270-cbfd0ddc5c0f"],

Cell[TextData[{
 "The routine PlaceValue[",
 StyleBox["n",
  FontSlant->"Italic"],
 "] takes the true words and transliterations from the PlaceValueRules[\
\[OpenCurlyDoubleQuote]language\[CloseCurlyDoubleQuote]]. Implemented have \
only been English, German, French, Dutch and Danish, up to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "7"], TraditionalForm]],ExpressionUUID->
  "46200051-27c5-49e7-9a47-3f2b8f4dfff1"],
 ". They have been checked on name conflicts and language peculiars. Amplish \
and Englishty are variants of English that have a role in the exposition."
}], "Text",ExpressionUUID->"2be43225-585e-43f0-ae10-89ab6a30d337"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "\"\<Checked\>\"", "]"}]], "Input",Expression\
UUID->"2c00ea30-8142-47d1-a240-76b967b3fd2a"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"English\"\>", ",", "\<\"Amplish\"\>", ",", "\<\"Danish\"\>", 
    ",", "\<\"Dutch\"\>", ",", "\<\"Englishty\"\>", ",", "\<\"French\"\>", 
    ",", "\<\"German\"\>"}], "}"}], TraditionalForm]], "Output",ExpressionUUID\
->"e42ec22e-6582-445d-bb83-63cd801b979c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". German"
}], "Subsubsection",ExpressionUUID->"38d415b4-fdbd-4508-9f45-25be58ebf9d6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"9189", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<German\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"f67decc7-199b-4d24-8566-0aa06d416a9f"],

Cell[BoxData[
 FormBox["\<\"neun\[CenterDot]tausend  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]hundert  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  acht\[CenterDot]zig  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  neun\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"88027dfb-eda8-414b-a623-\
ce75aa5a4970"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "\"\<German\>\"", "]"}]], "Input",ExpressionU\
UID->"2840d524-7dd1-4ed3-923c-5f537313d50b"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"True", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"negativ\"\>"}], ",", 
       RowBox[{
       "And", "\[Rule]", \
"\<\"\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"null\"\>", ",", "\<\"ein\"\>", ",", "\<\"zwei\"\>", 
          ",", "\<\"drei\"\>", ",", "\<\"vier\"\>", ",", "\<\"fuenf\"\>", 
          ",", "\<\"sechs\"\>", ",", "\<\"sieb\"\>", ",", "\<\"acht\"\>", 
          ",", "\<\"neun\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"zig\"\>", ",", "\<\"hundert\"\>", 
          ",", "\<\"tausend\"\>", ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"million\"\>"}], "}"}]}]}], "}"}]}], ",", 
    RowBox[{"\<\"English\"\>", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"nayguhteef\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"oond\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"noul\"\>", ",", "\<\"ayen\"\>", 
          ",", "\<\"tsvwaayie\"\>", ",", "\<\"dryie\"\>", ",", "\<\"fear\"\>",
           ",", "\<\"fuihnf\"\>", ",", "\<\"sex\"\>", ",", "\<\"sieb\"\>", 
          ",", "\<\"akht\"\>", ",", "\<\"noin\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"tzeeg\"\>", ",", "\<\"hoondert\"\>", 
          ",", "\<\"tausand\"\>", ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"meelyohn\"\>"}], "}"}]}]}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"91770eac-296d-4121-82da-\
a12648b02328"]
}, Open  ]],

Cell["\<\
Above, we saw \[OpenCurlyDoubleQuote]zig\[CloseCurlyDoubleQuote] in German \
being transliterated by \[OpenCurlyDoubleQuote]tzeeg\[CloseCurlyDoubleQuote] \
in English, for the simple reason that the current setting of $Language is \
\[OpenCurlyDoubleQuote]English\[CloseCurlyDoubleQuote]. \
\>", "Text",ExpressionUUID->"6cce2895-3228-4df6-8d80-d69cee9c02db"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". French"
}], "Subsubsection",ExpressionUUID->"832ebfb2-5974-4d28-a9c0-769ad9c3c067"],

Cell[TextData[{
 "French can use ",
 StyleBox["dix.",
  FontSlant->"Italic"]
}], "Text",ExpressionUUID->"3b90c59d-b321-4604-9d1a-192d9291b7f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"9189", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<French\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"79502b1b-30f3-4162-8131-0952f9ebb1b0"],

Cell[BoxData[
 FormBox["\<\"neuf\[CenterDot]mille  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]cent  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  huit\[CenterDot]dix  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  neuf\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"f460b1dc-2207-4d16-a01a-\
4efc7a8679a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "\"\<French\>\"", "]"}]], "Input",ExpressionU\
UID->"e94c78a6-bc08-445a-a400-7f31f2270b97"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"True", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"negative\"\>"}], ",", 
       RowBox[{
       "And", "\[Rule]", \
"\<\"\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"zero\"\>", ",", "\<\"un\"\>", ",", "\<\"deux\"\>", 
          ",", "\<\"trois\"\>", ",", "\<\"quatre\"\>", ",", "\<\"cinq\"\>", 
          ",", "\<\"six\"\>", ",", "\<\"sept\"\>", ",", "\<\"huit\"\>", 
          ",", "\<\"neuf\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"dix\"\>", ",", "\<\"cent\"\>", ",", "\<\"mille\"\>", 
          ",", "\<\"myriade\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"million\"\>"}], "}"}]}]}], "}"}]}], ",", 
    RowBox[{"\<\"English\"\>", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"nayguhteef\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"ayh\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"zeyrouh\"\>", ",", "\<\"uhnn\"\>", ",", "\<\"duh\"\>", 
          ",", "\<\"trouwah\"\>", ",", "\<\"kahtruh\"\>", 
          ",", "\<\"saink\"\>", ",", "\<\"sees\"\>", ",", "\<\"seht\"\>", 
          ",", "\<\"weet\"\>", ",", "\<\"neuhf\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"dees\"\>", ",", "\<\"sun\"\>", ",", "\<\"meel\"\>", 
          ",", "\<\"meeri udd\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"meelyon\"\>"}], "}"}]}]}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"ef12f1ec-2c26-4a7c-bbcd-\
5cd791f85669"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Dutch"
}], "Subsubsection",ExpressionUUID->"cdcf0097-5d20-4a0d-a616-07b2ac3cb509"],

Cell["\<\
For Dutch, the design questions are alike those for German. The best solution \
would be to use \[OpenCurlyDoubleQuote]tig\[CloseCurlyDoubleQuote] for \
\[OpenCurlyDoubleQuote]tien\[CloseCurlyDoubleQuote].\
\>", "Text",ExpressionUUID->"0c266e02-8c45-4a5c-8838-b8bfc475a9c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"9189", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Dutch\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"4f4efcfa-796b-4add-bece-cf47576d7302"],

Cell[BoxData[
 FormBox["\<\"negen\[CenterDot]duizend  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]honderd  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  acht\[CenterDot]tig  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  negen\[CenterDot]\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"a724c41f-63c7-47ad-ab54-\
8d01673afe16"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueRules", "[", "\"\<Dutch\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "distinction", " ", "between", " ", "minus", " ", "and", " ", "min"}], 
   "*)"}]}]], "Input",ExpressionUUID->"30a39544-7391-48ec-a7e2-c899e85b3eea"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"True", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"min\"\>"}], ",", 
       RowBox[{
       "And", "\[Rule]", \
"\<\"\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"nul\"\>", ",", "\<\"een\"\>", ",", "\<\"twee\"\>", 
          ",", "\<\"drie\"\>", ",", "\<\"vier\"\>", ",", "\<\"vijf\"\>", 
          ",", "\<\"zes\"\>", ",", "\<\"zeven\"\>", ",", "\<\"acht\"\>", 
          ",", "\<\"negen\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"tig\"\>", ",", "\<\"honderd\"\>", 
          ",", "\<\"duizend\"\>", ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"miljoen\"\>"}], "}"}]}]}], "}"}]}], ",", 
    RowBox[{"\<\"English\"\>", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"min\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"n\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"nuhl\"\>", ",", "\<\"ayn\"\>", ",", "\<\"tway\"\>", 
          ",", "\<\"dree\"\>", ",", "\<\"fear\"\>", ",", "\<\"vaif\"\>", 
          ",", "\<\"zes\"\>", ",", "\<\"zayven\"\>", ",", "\<\"ahgt\"\>", 
          ",", "\<\"naigen\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"tikgh\"\>", ",", "\<\"hon dairt\"\>", 
          ",", "\<\"duuzand\"\>", ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"milyoon\"\>"}], "}"}]}]}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"fffb6fc1-5770-42c3-a59b-\
ec9aff4c8bc8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Danish"
}], "Subsubsection",ExpressionUUID->"053523e1-654e-48ba-89f6-411923a47822"],

Cell[TextData[{
 "Danish can use ",
 StyleBox["ti.",
  FontSlant->"Italic"]
}], "Text",ExpressionUUID->"4df5f4a5-61bc-4efe-af00-81c4a268509e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"9189", ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Danish\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"dad1df75-b586-4fa4-8e15-2b02e5cbd476"],

Cell[BoxData[
 FormBox["\<\"ni\[CenterDot]tusind  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\
\\)  \[CenterDot]hundrede  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  otte\
\[CenterDot]ti  \\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \
ni\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->"33effecc-\
dc5f-4b4d-91a4-c43a35e99dba"]
}, Open  ]],

Cell["\<\
For Danish, I transliterated listening to Google Translate. I might not hear \
subtleties that native speakers would hear. The connective \
\[OpenCurlyDoubleQuote]and\[CloseCurlyDoubleQuote] is \
\[OpenCurlyDoubleQuote]og\[CloseCurlyDoubleQuote], which reminds of German \
\[OpenCurlyDoubleQuote]auch\[CloseCurlyDoubleQuote] and Dutch \
\[OpenCurlyDoubleQuote]ook\[CloseCurlyDoubleQuote] meaning \
\[OpenCurlyDoubleQuote]also\[CloseCurlyDoubleQuote]. It is quite a diaspora.\
\>", "Text",ExpressionUUID->"2cc08103-b227-46f6-accb-046f6c76eb82"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "\"\<Danish\>\"", "]"}]], "Input",ExpressionU\
UID->"42922444-3ba0-4b26-865c-8df543852314"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"True", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"negativ\"\>"}], ",", 
       RowBox[{
       "And", "\[Rule]", \
"\<\"\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"nul\"\>", ",", "\<\"en\"\>", ",", "\<\"to\"\>", 
          ",", "\<\"tre\"\>", ",", "\<\"fire\"\>", ",", "\<\"fem\"\>", 
          ",", "\<\"seks\"\>", ",", "\<\"syv\"\>", ",", "\<\"otte\"\>", 
          ",", "\<\"ni\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"ti\"\>", ",", "\<\"hundrede\"\>", ",", "\<\"tusind\"\>",
           ",", "\<\"myriade\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"million\"\>"}], "}"}]}]}], "}"}]}], ",", 
    RowBox[{"\<\"English\"\>", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"nayguhtew\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"oh\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"nul\"\>", ",", "\<\"ayn\"\>", ",", "\<\"toh\"\>", 
          ",", "\<\"trya\"\>", ",", "\<\"fear\"\>", ",", "\<\"fem\"\>", 
          ",", "\<\"sex\"\>", ",", "\<\"suwe\"\>", ",", "\<\"ude\"\>", 
          ",", "\<\"knee\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"tee\"\>", ",", "\<\"hoonah\"\>", ",", "\<\"toosind\"\>",
           ",", "\<\"myriade\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"meelyohn\"\>"}], "}"}]}]}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"7a6a3dcc-f316-4ed3-8948-\
dab8c3514c51"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Using non-implemented languages, e.g. Italian and Spanish"
}], "Subsection",ExpressionUUID->"b2f4288a-04f5-4327-8500-517dde422bf7"],

Cell["Please remember that there is no automated transliteration.", "Text",ExpressionUUID->"d759384b-bb82-4dd3-a57e-a4e88b7cf746"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Italian"
}], "Subsubsection",ExpressionUUID->"88f18f74-cb43-416c-abf6-ba2909e5cc9d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueRules", "[", "\"\<Italian\>\"", "]"}], "   ", 
  RowBox[{"(*", "unknown", "*)"}]}]], "Input",ExpressionUUID->"1774f20d-ca64-\
475e-8a44-32491b6146ae"],

Cell[BoxData[
 FormBox[
  RowBox[{"PlaceValueRules", "(", "\<\"Italian\"\>", ")"}], 
  TraditionalForm]], "Output",ExpressionUUID->"ad32ab43-0880-40da-b00e-\
71fcda0f0ba8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"134", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Italian\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"7d19501a-d884-465f-afdb-5b325e164159"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","rul",
    "\"No list of rules found for \\!\\(\\*FormBox[\\\"\\\\\\\"language\\\\\\\
\"\\\", TraditionalForm]\\) \\!\\(\\*FormBox[\\\"\\\\\\\"Italian\\\\\\\"\\\", \
TraditionalForm]\\)\"",2,130,61,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"b21e037d-f35f-44c4-91bc-d15315291f4b"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","int",
    "\"Initialisation with IntegerName and WordTranslation: please wait\"",2,
    130,62,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"ab577691-014d-4091-8e0d-6c8b421c1e90"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValueRules","wrn",
    "\"Warning: automated translation of \\!\\(\\*FormBox[\\\"\\\\\\\"Italian\
\\\\\\\"\\\", TraditionalForm]\\) and not carefully checked on conflicts and \
peculiarities\"",2,130,63,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValueRules"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"76eb6e14-206a-418a-aded-6260fcae16d4"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]cento  e  tre\[CenterDot]dieci  e  quattro\
\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->"9a29d7dd-23f3-\
414d-b41b-6b1e1e0bc7c9"]
}, Open  ]],

Cell["\<\
After this initialisation, the call is much faster. The user must provide a \
transliteration of \[OpenCurlyDoubleQuote]e\[CloseCurlyDoubleQuote] but \
\[OpenCurlyDoubleQuote]con\[CloseCurlyDoubleQuote] already provides a more \
Italian sound.\
\>", "Text",ExpressionUUID->"93c17107-c6fe-40fc-8656-59b507b1aa68"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"134", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Italian\>\""}], ",", " ", 
   RowBox[{"And", " ", "\[Rule]", " ", "\"\<con\>\""}]}], "]"}]], "Input",Expr\
essionUUID->"76cfb269-fc9c-4bdc-afd1-2e5d6bec9b10"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]cento  con  tre\[CenterDot]dieci  con  quattro\
\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->"88725579-8306-\
4e41-b005-da076e305e2b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "\"\<Italian\>\"", "]"}]], "Input",Expression\
UUID->"41e448fa-9513-4470-82b2-163abd01c624"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"True", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"negativo\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"e\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"zero\"\>", ",", "\<\"uno\"\>", ",", "\<\"due\"\>", 
          ",", "\<\"tre\"\>", ",", "\<\"quattro\"\>", ",", "\<\"cinque\"\>", 
          ",", "\<\"sei\"\>", ",", "\<\"sette\"\>", ",", "\<\"otto\"\>", 
          ",", "\<\"nove\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"dieci\"\>", ",", "\<\"cento\"\>", ",", "\<\"cento\"\>", 
          ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"milione\"\>"}], "}"}]}]}], "}"}]}], ",", 
    RowBox[{"\<\"English\"\>", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"negativo\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"e\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"zero\"\>", ",", "\<\"uno\"\>", ",", "\<\"due\"\>", 
          ",", "\<\"tre\"\>", ",", "\<\"quattro\"\>", ",", "\<\"cinque\"\>", 
          ",", "\<\"sei\"\>", ",", "\<\"sette\"\>", ",", "\<\"otto\"\>", 
          ",", "\<\"nove\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"dieci\"\>", ",", "\<\"cento\"\>", ",", "\<\"cento\"\>", 
          ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"milione\"\>"}], "}"}]}]}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"eef707ca-ae76-4cf0-98d4-\
63da8c39a2e6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ".",
 
 CounterBox["Subsubsection"],
 ". Spanish"
}], "Subsubsection",ExpressionUUID->"37dc9384-541f-4e09-9b91-5b70d0c6e488"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PlaceValueRules", "[", "\"\<Spanish\>\"", "]"}], "  ", 
  RowBox[{"(*", "unknown", "*)"}]}]], "Input",ExpressionUUID->"2f6fc978-b1ad-\
49d4-a50a-05965bc3c75c"],

Cell[BoxData[
 FormBox[
  RowBox[{"PlaceValueRules", "(", "\<\"Spanish\"\>", ")"}], 
  TraditionalForm]], "Output",ExpressionUUID->"948784a5-34aa-4c4d-b91a-\
9c26aa399e16"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"134", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Spanish\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"dcccc43b-dc42-4468-aa6e-b5b815330a50"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","rul",
    "\"No list of rules found for \\!\\(\\*FormBox[\\\"\\\\\\\"language\\\\\\\
\"\\\", TraditionalForm]\\) \\!\\(\\*FormBox[\\\"\\\\\\\"Spanish\\\\\\\"\\\", \
TraditionalForm]\\)\"",2,131,64,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"72af805a-831f-4846-a6ba-592a4cf34a58"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","int",
    "\"Initialisation with IntegerName and WordTranslation: please wait\"",2,
    131,65,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"4a5adf17-ce29-407f-bb2e-17f2c836b657"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValueRules","wrn",
    "\"Warning: automated translation of \\!\\(\\*FormBox[\\\"\\\\\\\"Spanish\
\\\\\\\"\\\", TraditionalForm]\\) and not carefully checked on conflicts and \
peculiarities\"",2,131,66,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValueRules"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"723f0d25-d635-453f-91f5-f45ef7f5c976"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]cien  y  tres\[CenterDot]diez  y  \
cuatro\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->\
"5213a1aa-e4d2-42a6-b407-7330b69798c4"]
}, Open  ]],

Cell["\<\
After this initialisation, the call is much faster. A quick fix for \
pronunciation is perhaps this.\
\>", "Text",ExpressionUUID->"059efc25-d7a2-43c4-ab6a-bd330afec776"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"134", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Spanish\>\""}], ",", " ", 
   RowBox[{"And", " ", "\[Rule]", " ", "\"\<e\>\""}]}], "]"}]], "Input",Expres\
sionUUID->"1b037a0b-8278-4379-8e6a-611b520906ff"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]cien  e  tres\[CenterDot]diez  e  \
cuatro\[CenterDot]\"\>", TraditionalForm]], "Output",ExpressionUUID->\
"3ec0e127-e768-431e-9ec5-1dbbf34be64a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "\"\<Spanish\>\"", "]"}]], "Input",Expression\
UUID->"b136a48c-5793-4a19-b60e-2c0e3593aa3a"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"True", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"negativo\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"y\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"cero\"\>", ",", "\<\"uno\"\>", ",", "\<\"dos\"\>", 
          ",", "\<\"tres\"\>", ",", "\<\"cuatro\"\>", ",", "\<\"cinco\"\>", 
          ",", "\<\"seis\"\>", ",", "\<\"siete\"\>", ",", "\<\"ocho\"\>", 
          ",", "\<\"nueve\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"diez\"\>", ",", "\<\"cien\"\>", ",", "\<\"cien\"\>", 
          ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"mill\[OAcute]n\"\>"}], "}"}]}]}], "}"}]}], ",", 
    RowBox[{"\<\"English\"\>", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Negative", "\[Rule]", "\<\"negativo\"\>"}], ",", 
       RowBox[{"And", "\[Rule]", "\<\"y\"\>"}], ",", 
       RowBox[{"N", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"cero\"\>", ",", "\<\"uno\"\>", ",", "\<\"dos\"\>", 
          ",", "\<\"tres\"\>", ",", "\<\"cuatro\"\>", ",", "\<\"cinco\"\>", 
          ",", "\<\"seis\"\>", ",", "\<\"siete\"\>", ",", "\<\"ocho\"\>", 
          ",", "\<\"nueve\"\>"}], "}"}]}], ",", 
       RowBox[{"Power", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\<\"diez\"\>", ",", "\<\"cien\"\>", ",", "\<\"cien\"\>", 
          ",", "\<\"myriad\"\>", ",", "\<\"lakh\"\>", 
          ",", "\<\"mill\[OAcute]n\"\>"}], "}"}]}]}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"fe915fb9-8ed6-44b3-accf-\
af2fb1b33be0"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". A general comment"
}], "Subsection",ExpressionUUID->"ee4c75b0-7539-4577-9a0e-c28f042413f7"],

Cell["\<\
\[OpenCurlyDoubleQuote]Deux\[CloseCurlyDoubleQuote] in French has been \
transliterated here as \[OpenCurlyDoubleQuote]duh\[CloseCurlyDoubleQuote]. \
English has a closer sound in \[OpenCurlyDoubleQuote]bird\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]dirt\
\[CloseCurlyDoubleQuote]. I found no way to unpack this sound from \
\[OpenCurlyDoubleQuote]bird\[CloseCurlyDoubleQuote] and paste it into \
\[OpenCurlyDoubleQuote]d...h\[CloseCurlyDoubleQuote].\
\>", "Text",ExpressionUUID->"7d6a0592-5b86-47a5-ab22-1dfbc8b616ed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res", " ", "=", " ", 
  RowBox[{"WordData", "[", 
   RowBox[{"\"\<bird\>\"", ",", " ", "\"\<PhoneticForm\>\""}], 
   "]"}]}]], "Input",ExpressionUUID->"25a7dc20-d694-41a1-bd85-75c66ac187b7"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\"b\:02c8\:025dd\"\>",
   StripOnInput->False,
   FontFamily->"Arial Unicode MS"], TraditionalForm]], "Output",ExpressionUUID\
->"f37a8cd5-692c-4aa3-bf1a-333b71aa15c2"]
}, Open  ]],

Cell["InputForm:", "Text",ExpressionUUID->"1158a702-c85b-4c94-8ebb-53df75c3aede"],

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{"\<\"b\:02c8\:025dd\"\>", ",", " ", 
   RowBox[{"FontFamily", " ", "->", " ", "\<\"Arial Unicode MS\"\>"}]}], 
  "]"}]], "Output",ExpressionUUID->"f896e98f-360c-42c8-9430-9d81b0bc4741"],

Cell["Submitting this to Speak generates a blank.", "Text",ExpressionUUID->"aaee81a5-83dd-416f-8a36-9217e0df7543"],

Cell[BoxData[
 RowBox[{"Speak", "[", "\"\<'\:025d\>\"", "]"}]], "Input",ExpressionUUID->"2c8406f8-b88f-4c3f-84d6-6395b92da44e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpokenString", "[", "\"\<'\:025d\>\"", "]"}]], "Input",ExpressionUUI\
D->"3fd7012c-29e0-4fe5-b103-a89e287cd514"],

Cell[BoxData[
 FormBox["\<\"'\:025d\"\>", TraditionalForm]], "Output",ExpressionUUID->"a231bf6a-1900-4899-b89d-3999b154f70f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Speak", "[", "%", "]"}]], "Input",ExpressionUUID->"a2ccc052-359d-4e4b-8b91-7c5cca23cb4f"],

Cell["\<\
For transliteration it would be useful when such phonetic forms could also be \
submitted to Speak. \
\>", "Text",ExpressionUUID->"6aecaf9a-db1c-44b7-857f-1bf5a729d018"],

Cell["\<\
I don\[CloseCurlyQuote]t know anything about linguistics, and the following \
are some first discoveries. \
\>", "Text",ExpressionUUID->"7025e1a1-c3d7-4ffe-9fa5-c13636306cf1"],

Cell["\<\
In evolution, disregarding sign language, pronunciation came first, and \
writing was developed by encoding how someone pronounced something (beth = \
house with two rooms = B). In computer programming, the words and \
translations between languages were first, and the pronunciations came later. \
We take pronunciation as (conceptually) basic again since kids live in world \
of sound and only learn to read and write later on.\
\>", "Text",ExpressionUUID->"1489360c-5c1c-4b19-aee2-09088f561e74"],

Cell["\<\
The International Phonetic Alphabet (IPA). Wikipedia (a portal and no \
source): https://en.wikipedia.org/wiki/International_Phonetic_Alphabet.\
\>", "Text",ExpressionUUID->"7db4db2a-42cd-4b9c-8b85-843b715e5368"],

Cell["\<\
https://en.wikipedia.org/wiki/Orthography#Correspondence_with_pronunciation\
\>", "Text",ExpressionUUID->"6fbed2c5-d7c0-4a71-9f11-2ce38f3fa2d7"],

Cell["\<\
See also: http://www.wolframalpha.com/input/?i=pronunciation+of+bird\
\>", "Text",ExpressionUUID->"6525b59a-8b9f-4d53-b09b-69496269923d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Conversion tables"
}], "Section",ExpressionUUID->"c168a41f-32d5-4f0c-abdd-9cb740aeab16"],

Cell["\<\
The routine PlaceValueTable allows the automatic generation of tables of \
conversion, and thus comes with a big warning. Automated translations must be \
scrutinised for flukes. However, creating such tables is quite useful to \
start with the required close reading. For these tables, the message that an \
automated translation hasn\[CloseCurlyQuote]t been checked is a useful \
reminder at each call. Please do not turn this off, but do the checking and \
correcting, and then do an \
AppendTo[PlaceValueRules[\[OpenCurlyDoubleQuote]Checked\
\[CloseCurlyDoubleQuote]], \[OpenCurlyDoubleQuote]yournewlanguage\
\[CloseCurlyDoubleQuote]]].\
\>", "Text",ExpressionUUID->"4f3a3805-ed4d-405b-928f-7a13ab5e69d2"],

Cell["\<\
Standard conversion tables would be 0-10, 20-30, 30-40, etcetera. We can also \
consider other tables.\
\>", "Text",ExpressionUUID->"95181ce0-1462-4c6b-9061-ddd2a92e5161"],

Cell["The table of 7 in English.", "Text",ExpressionUUID->"56143c25-bfca-4139-b005-aadc707e6747"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueTable", "[", 
  RowBox[{"Range", "[", 
   RowBox[{"7", ",", " ", "70", ",", " ", "7"}], "]"}], "]"}]], "Input",Expres\
sionUUID->"9919f107-24b9-4768-b424-0a4fae46c84a"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"7", "\<\" \"\>", "\<\"seven\[CenterDot]\"\>", "\<\"7\"\>", "\<\" \
\"\>", "\<\"seven\"\>"},
      {"14", "\<\" \"\>", "\<\"\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  four\[CenterDot]\"\>", "\<\"10  \
 &   4\"\>", "\<\" \"\>", "\<\"fourteen\"\>"},
      {"21", "\<\" \"\>", "\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  \[CenterDot]one\"\>", "\<\"2 \
\[CenterDot] 10   &   1\"\>", "\<\" \"\>", "\<\"twenty one\"\>"},
      {"28", "\<\" \"\>", "\<\"two\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  eight\[CenterDot]\"\>", "\<\"2 \
\[CenterDot] 10   &   8\"\>", "\<\" \"\>", "\<\"twenty eight\"\>"},
      {"35", "\<\" \"\>", "\<\"three\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  five\[CenterDot]\"\>", "\<\"3 \
\[CenterDot] 10   &   5\"\>", "\<\" \"\>", "\<\"thirty five\"\>"},
      {"42", "\<\" \"\>", "\<\"four\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\
\",FontSize->10]\\)  two\[CenterDot]\"\>", "\<\"4 \[CenterDot] 10   &   \
2\"\>", "\<\" \"\>", "\<\"forty two\"\>"},
      {"49", "\<\" \"\>", "\<\"four\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\
\",FontSize->10]\\)  nine\[CenterDot]\"\>", "\<\"4 \[CenterDot] 10   &   \
9\"\>", "\<\" \"\>", "\<\"forty nine\"\>"},
      {"56", "\<\" \"\>", "\<\"five\[CenterDot]ten  \\!\\(\\*StyleBox[\\\"&\\\
\",FontSize->10]\\)  six\[CenterDot]\"\>", "\<\"5 \[CenterDot] 10   &   \
6\"\>", "\<\" \"\>", "\<\"fifty six\"\>"},
      {"63", "\<\" \"\>", "\<\"six\[CenterDot]ten  \
\\!\\(\\*StyleBox[\\\"&\\\",FontSize->10]\\)  three\[CenterDot]\"\>", "\<\"6 \
\[CenterDot] 10   &   3\"\>", "\<\" \"\>", "\<\"sixty three\"\>"},
      {"70", "\<\" \"\>", "\<\"seven\[CenterDot]ten\"\>", "\<\"7 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"seventy\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"2a28f329-eb0c-4a81-9aa9-a2ce76130a57"]
}, Open  ]],

Cell["The table of 7 in unchecked Spanish, installed above.", "Text",ExpressionUUID->"c4838151-dfa5-4f6b-b1b0-5bd2a913cf55"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueTable", "[", 
  RowBox[{
   RowBox[{"Range", "[", 
    RowBox[{"7", ",", " ", "70", ",", " ", "7"}], "]"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Spanish\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"35866e3a-2d51-4a93-8a43-bf59e019bd6c"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValueRules","wrn",
    "\"Warning: automated translation of \\!\\(\\*FormBox[\\\"\\\\\\\"Spanish\
\\\\\\\"\\\", TraditionalForm]\\) and not carefully checked on conflicts and \
peculiarities\"",2,133,70,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValueRules"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"c7a21c20-5153-45e8-b639-5d09a2a1cd33"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"7", "\<\" \"\>", "\<\"siete\[CenterDot]\"\>", "\<\"7\"\>", "\<\" \
\"\>", "\<\"siete\"\>"},
      {"14", "\<\" \"\>", "\<\"\[CenterDot]diez  y  cuatro\[CenterDot]\"\>", \
"\<\"10   &   4\"\>", "\<\" \"\>", "\<\"catorce\"\>"},
      {"21", "\<\" \"\>", "\<\"dos\[CenterDot]diez  y  \[CenterDot]uno\"\>", \
"\<\"2 \[CenterDot] 10   &   1\"\>", "\<\" \"\>", "\<\"veintiuno\"\>"},
      {"28", "\<\" \"\>", "\<\"dos\[CenterDot]diez  y  ocho\[CenterDot]\"\>", \
"\<\"2 \[CenterDot] 10   &   8\"\>", "\<\" \"\>", "\<\"veintiocho\"\>"},
      {"35", "\<\" \"\>", "\<\"tres\[CenterDot]diez  y  \
cinco\[CenterDot]\"\>", "\<\"3 \[CenterDot] 10   &   5\"\>", "\<\" \"\>", "\<\
\"treinta y cinco\"\>"},
      {"42", "\<\" \"\>", "\<\"cuatro\[CenterDot]diez  y  \
dos\[CenterDot]\"\>", "\<\"4 \[CenterDot] 10   &   2\"\>", "\<\" \"\>", \
"\<\"cuarenta y dos\"\>"},
      {"49", "\<\" \"\>", "\<\"cuatro\[CenterDot]diez  y  nueve\[CenterDot]\"\
\>", "\<\"4 \[CenterDot] 10   &   9\"\>", "\<\" \"\>", "\<\"cuarenta y \
nueve\"\>"},
      {"56", "\<\" \"\>", "\<\"cinco\[CenterDot]diez  y  \
seis\[CenterDot]\"\>", "\<\"5 \[CenterDot] 10   &   6\"\>", "\<\" \"\>", \
"\<\"cincuenta y seis\"\>"},
      {"63", "\<\" \"\>", "\<\"seis\[CenterDot]diez  y  \
tres\[CenterDot]\"\>", "\<\"6 \[CenterDot] 10   &   3\"\>", "\<\" \"\>", \
"\<\"sesenta y tres\"\>"},
      {"70", "\<\" \"\>", "\<\"siete\[CenterDot]diez\"\>", "\<\"7 \
\[CenterDot] 10\"\>", "\<\" \"\>", "\<\"setenta\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Language -> "Spanish", TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"8fb9d533-7681-4efc-ab23-bbc82ab1290f"]
}, Open  ]],

Cell["\<\
The package is conservative on the warning, and only generates it at \
installation and for these tables.\
\>", "Text",ExpressionUUID->"244ea9ad-4d38-46cf-97af-91499995d22b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValue", "[", 
  RowBox[{"1234", ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Spanish\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"08cce490-9f21-4e8e-9dc1-869a575f9577"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]cien  y  dos\[CenterDot]cien  y  \
tres\[CenterDot]diez  y  cuatro\[CenterDot]\"\>", TraditionalForm]], "Output",\
ExpressionUUID->"47b212eb-ea5a-4214-91cf-b9dccdd7ba92"]
}, Open  ]],

Cell["\<\
The table of 7 in unchecked Swedish. The warning is issued twice: first at \
installation and secondly at creating the Table.\
\>", "Text",ExpressionUUID->"64cd337a-da2b-46c1-9a28-9b3b2bc3173d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueTable", "[", 
  RowBox[{
   RowBox[{"Range", "[", 
    RowBox[{"7", ",", " ", "70", ",", " ", "7"}], "]"}], ",", " ", 
   RowBox[{"Language", " ", "\[Rule]", " ", "\"\<Swedish\>\""}]}], 
  "]"}]], "Input",ExpressionUUID->"6c650df3-5d1e-4c28-a6a2-2ce2794128a6"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValueRules","wrn",
    "\"Warning: automated translation of \\!\\(\\*FormBox[\\\"\\\\\\\"Swedish\
\\\\\\\"\\\", TraditionalForm]\\) and not carefully checked on conflicts and \
peculiarities\"",2,134,71,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValueRules"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"970f10b5-b318-4a46-af27-752ca6cf91f5"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","rul",
    "\"No list of rules found for \\!\\(\\*FormBox[\\\"\\\\\\\"language\\\\\\\
\"\\\", TraditionalForm]\\) \\!\\(\\*FormBox[\\\"\\\\\\\"Swedish\\\\\\\"\\\", \
TraditionalForm]\\)\"",2,134,72,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"8049b26d-18c7-49dd-ada0-de993b874ec2"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValue","int",
    "\"Initialisation with IntegerName and WordTranslation: please wait\"",2,
    134,73,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValue"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"a2b74a96-8aa4-4e8b-8aff-4f3d982a4671"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PlaceValueRules","wrn",
    "\"Warning: automated translation of \\!\\(\\*FormBox[\\\"\\\\\\\"Swedish\
\\\\\\\"\\\", TraditionalForm]\\) and not carefully checked on conflicts and \
peculiarities\"",2,134,74,32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PlaceValueRules"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"f7b6668a-4532-49f7-975d-4ba473694bb0"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Integer\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Place Value\"\>",
        HoldForm], 
       TagBox["\<\"PV Digits\"\>",
        HoldForm], 
       TagBox["\<\"\"\>",
        HoldForm], 
       TagBox["\<\"Traditional\"\>",
        HoldForm]},
      {"7", "\<\" \"\>", "\<\"sju\[CenterDot]\"\>", "\<\"7\"\>", "\<\" \"\>", \
"\<\"sju\"\>"},
      {"14", "\<\" \"\>", "\<\"\[CenterDot]tio  och  fyra\[CenterDot]\"\>", "\
\<\"10   &   4\"\>", "\<\" \"\>", "\<\"fjorton\"\>"},
      {"21", "\<\" \"\>", "\<\"tv\[ARing]\[CenterDot]tio  och  \
\[CenterDot]ett\"\>", "\<\"2 \[CenterDot] 10   &   1\"\>", "\<\" \"\>", \
"\<\"tjugo\[DiscretionaryHyphen]ett\"\>"},
      {"28", "\<\" \"\>", "\<\"tv\[ARing]\[CenterDot]tio  och  \[ARing]tta\
\[CenterDot]\"\>", "\<\"2 \[CenterDot] 10   &   8\"\>", "\<\" \"\>", \
"\<\"tjugo\[DiscretionaryHyphen]\[ARing]tta\"\>"},
      {"35", "\<\" \"\>", "\<\"tre\[CenterDot]tio  och  fem\[CenterDot]\"\>", \
"\<\"3 \[CenterDot] 10   &   5\"\>", "\<\" \"\>", "\<\"trettio\
\[DiscretionaryHyphen]fem\"\>"},
      {"42", "\<\" \"\>", "\<\"fyra\[CenterDot]tio  och  tv\[ARing]\
\[CenterDot]\"\>", "\<\"4 \[CenterDot] 10   &   2\"\>", "\<\" \"\>", \
"\<\"fyrtio\[DiscretionaryHyphen]tv\[ARing]\"\>"},
      {"49", "\<\" \"\>", "\<\"fyra\[CenterDot]tio  och  \
nio\[CenterDot]\"\>", "\<\"4 \[CenterDot] 10   &   9\"\>", "\<\" \"\>", \
"\<\"fyrtio\[DiscretionaryHyphen]nio\"\>"},
      {"56", "\<\" \"\>", "\<\"fem\[CenterDot]tio  och  sex\[CenterDot]\"\>", \
"\<\"5 \[CenterDot] 10   &   6\"\>", "\<\" \"\>", "\<\"femtio\
\[DiscretionaryHyphen]sex\"\>"},
      {"63", "\<\" \"\>", "\<\"sex\[CenterDot]tio  och  tre\[CenterDot]\"\>", \
"\<\"6 \[CenterDot] 10   &   3\"\>", "\<\" \"\>", "\<\"sextio\
\[DiscretionaryHyphen]tre\"\>"},
      {"70", "\<\" \"\>", "\<\"sju\[CenterDot]tio\"\>", "\<\"7 \[CenterDot] \
10\"\>", "\<\" \"\>", "\<\"sjuttio\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.6]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, Language -> "Swedish", TableSpacing -> {1.5, 3}, 
     TableHeadings -> {
      None, {"Integer", "", "Place Value", "PV Digits", "", 
        "Traditional"}}]]], TraditionalForm]], "Output",ExpressionUUID->\
"ae982ab3-9f60-4514-8458-cac49c288de5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ISO standard"
}], "Section",ExpressionUUID->"d3cf12ee-62c2-48a4-b92a-372ddc48e820"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". ISO and NEN"
}], "Subsection",ExpressionUUID->"4cdc9af9-226a-4275-99b3-825edb9062ff"],

Cell["\<\
Colignatus (2015b, 2018a) contains the definition for the full use of the \
place value system in a way that fits education. It should become an ISO \
standard, so that educators, researchs and textbook and software publishers \
have a persistent environment. This notebook with package implements this. \
The latter has some limitations on maximum place value million, and has some \
language particulars, but those are not material to the standard.\
\>", "Text",ExpressionUUID->"046bb360-d0a8-4eda-a770-4fa8a059c6ac"],

Cell["\<\
In Holland, NEN is the portal for International ISO: \
https://www.nen.nl/About-NEN.htm. They are no public utility so that the \
development of norms and standards must be paid for by users. They also have \
a crowd-funding option for such initiatives: https://nencrowd.nl. Before they \
allow their crowd-funding support, they want some guarantee that there is a \
community with an interest in the project. For this issue it would be \
researchers, the Ministry of Education and publishers. To my regret, I have \
met no interest yet.\
\>", "Text",ExpressionUUID->"1652af39-2473-4b9d-883a-280f2c21bff9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Open source journals"
}], "Subsection",ExpressionUUID->"fe0d8e24-0bd5-4b5b-beed-fb7cd73c67b8"],

Cell[TextData[{
 "Publication could be done in an open access journal, and the proper way to \
get open access journals is by the universities, see Gowers (2017) and my \
letter to VSNU, Colignatus (2016). Present (paywall) journals tend to be \
specialised on approaches to education and psychology, and may require field \
testing on actual implementation, and apparently are not open to the \
particular approach of ",
 StyleBox["redesign of mathematics education ",
  FontSlant->"Italic"],
 "that this notebook with package presents. Thus I observed that such \
journals can publish invalid research but will not publish or even report \
about this present proposal for improvement. Quis custodiet ipsos custodes ?"
}], "Text",ExpressionUUID->"5e24bdda-c7e0-4f4a-ba60-c200d7fc6896"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Conclusions"
}], "Section",ExpressionUUID->"9fea3833-7f93-4341-a4e2-9087a243f7d1"],

Cell["\<\
We already have the place value system in the numerals but not yet in \
pronunciation and written words. A unity of using the full place value system \
will work wonders in school. This is an issue of mathematics education, with \
the distinction between the language of arithmetic in school and its dialect \
of the common language outside of school. It is only a question whether the \
educational system would be willing to adapt. \
\>", "Text",ExpressionUUID->"6eb133d9-2fcf-480d-99f1-a9f03b882d2b"],

Cell[TextData[{
 "Colignatus (2015b, 2018a) gives the definition for a full use of the place \
value system for kindergarten and elementary school. This is simple by the \
nature of the issue. My own change from (2015b) to (2018a) on the \
\[OpenCurlyDoubleQuote]",
 StyleBox["&",
  FontSize->14],
 "\[CloseCurlyDoubleQuote] connective shows that this simplicity still can be \
quite involved, but also that the key design features have been \
well-considered. This notebook with package implements this system. There \
must be some features in the package that are arbitrary. The transliteration \
is only provided for some quick indications and not the key part. The \
notebook with package looks meagre compared to the wealth and subtlety that \
already exist for the pronunciation of the natural languages and current \
conventions on pronouncing the numbers. The awkward ways of the past are \
being hardcoded now. Hopefully some of those resources can be used to support \
the full use of the place value system."
}], "Text",ExpressionUUID->"7ed6ca34-ec4f-46e0-8f87-ffcb1dc21fd8"],

Cell["\<\
I have not seen this implementation of pronunciation elsewhere (except in \
Chinese though without the \
\[OpenCurlyDoubleQuote]and\[CloseCurlyDoubleQuote]), so please refer to these \
locations so that others can find the full documentation.\
\>", "Text",ExpressionUUID->"82c4c0eb-7bfc-4ffc-9c00-b7af1e70aa1f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Appendix. The package"
}], "Section",ExpressionUUID->"c0549602-ac28-4c2b-987f-322f04c5183b"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Key properties of PlaceValue"
}], "Subsection",ExpressionUUID->"e7674dc7-5add-457f-b534-cac7c9ba8f0e"],

Cell["\<\
The PlaceValue routine (PronounceInteger with Level \[Rule] 1) is the main \
routine. Key properties are:\
\>", "Text",ExpressionUUID->"ed667894-cb59-4cec-817a-e78825d828b1"],

Cell[CellGroupData[{

Cell["\<\
The Language \[Rule] \[OpenCurlyDoubleQuote]language\[CloseCurlyDoubleQuote] \
option selects the language, and determines how integers are written and \
spoken.\
\>", "Item",ExpressionUUID->"9cde69f2-0dfc-4075-9574-d740076f17b4"],

Cell["\<\
Implemented are English, German, French, Dutch and Danish, assuming that \
$Language (the transliterator) is English. Also given are Amplish (writes an \
ampersand in smaller FontSize) and Englishty (writing \
\[OpenCurlyDoubleQuote]ty\[CloseCurlyDoubleQuote] and speaking \
\[OpenCurlyDoubleQuote]tee\[CloseCurlyDoubleQuote] for 10). \
\>", "Item",ExpressionUUID->"e503ad79-b166-482d-b3a6-302fe6e00e52"],

Cell[TextData[{
 StyleBox["Written output",
  FontWeight->"Bold"],
 " is in the words of PlaceValueRules[\"language\"], option True \[Rule] \
{settings}."
}], "Item",ExpressionUUID->"1ac3e716-3c5b-4ad9-93fe-94da60e35bf5"],

Cell[TextData[{
 StyleBox["Spoken output",
  FontWeight->"Bold"],
 " is in the words of PlaceValueRules[\[OpenCurlyDoubleQuote]language\
\[CloseCurlyDoubleQuote]], option \[OpenCurlyDoubleQuote]transliterator\
\[CloseCurlyDoubleQuote] \[Rule] {settings}. These words are submitted to \
Speak. The transliterator that speaks this transliteration is $Language \
(often \[OpenCurlyDoubleQuote]English\[CloseCurlyDoubleQuote])."
}], "Item",ExpressionUUID->"d0a9f149-7fb0-4884-b59d-6f2fcd7e83dd"],

Cell[TextData[{
 "For each language  the user provides, in PlaceValueRules: (i) option True \
\[Rule] {",
 StyleBox["words ",
  FontWeight->"Bold"],
 "for the minus sign, \[OpenCurlyDoubleQuote]&\[CloseCurlyDoubleQuote], \
digits 0 ... 9 and values ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "1"], TraditionalForm]],ExpressionUUID->
  "6b3dd123-5cb8-4cc5-90df-15d9b2ba80ff"],
 ", ..., ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "6"], TraditionalForm]],ExpressionUUID->
  "fba206c9-3d0e-4e1c-8e9e-a1dfaeaf499e"],
 ", in the relevant language}, and (ii) option \
\[OpenCurlyDoubleQuote]transliterator\[CloseCurlyDoubleQuote] \[Rule] {",
 StyleBox["words",
  FontWeight->"Bold"],
 " for the same input as above but now as a transliteration in terms of that \
transliterator language (commonly $Language)}. See for example \
PlaceValueRules[\[OpenCurlyDoubleQuote]German\[CloseCurlyDoubleQuote]]."
}], "Item",ExpressionUUID->"b01fe2fb-a04c-48d8-89c5-08152e4106fc"],

Cell[TextData[{
 "If PlaceValue is called for a language ",
 StyleBox["lan",
  FontSlant->"Italic"],
 " that is not in PlaceValueRules[] then it calls PlaceValueRules[Set, ",
 StyleBox["lan",
  FontSlant->"Italic"],
 "]."
}], "Item",ExpressionUUID->"d78e3e87-0def-4536-bd77-7a387038ce0a"],

Cell["\<\
SpeakTransliteration \[Rule] \"language\" currently only works for $Language. \
Perhaps in the future it might be possible to have access to other languages \
without a restart.\
\>", "Item",ExpressionUUID->"e746e710-3377-45e0-ad39-f25e2e83da38"],

Cell[TextData[{
 "$Language has been set in the Preferences of ",
 StyleBox["Mathematica. ",
  FontSlant->"Italic"],
 "The user can set to to another language and do a restart. "
}], "Item",ExpressionUUID->"7c44094d-c70f-4f73-bd11-f10111847197"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Overview"
}], "Subsection",ExpressionUUID->"29301f00-dda4-4e50-9b30-6460abdc2667"],

Cell["The package has:", "Text",ExpressionUUID->"f6791705-8419-4a65-8e64-f1babcbdad45"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Cool`MathEd`PronounceInteger`*"}]], "Input",ExpressionUUID->"d0b603f6-b6d0-4e46-b0cb-185acfa96eaf"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["Cool`MathEd`PronounceInteger`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["Cool`MathEd`PronounceInteger`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["LatestPronunciation",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "LatestPronunciation", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PlaceValueDigits$Language",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValueDigits$Language", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PronounceInteger",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PronounceInteger", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"]},
        {
         ButtonBox["PartialPlaceValue",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PartialPlaceValue", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PlaceValueH",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValueH", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PronounceIntegerReadMe",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PronounceIntegerReadMe", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"]},
        {
         ButtonBox["PlaceValue",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValue", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PlaceValueIntegerName",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValueIntegerName", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PronounceIntegers",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PronounceIntegers", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"]},
        {
         ButtonBox["PlaceValueBlock",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValueBlock", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PlaceValueRules",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValueRules", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["SpeakTransliteration",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "SpeakTransliteration", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"]},
        {
         ButtonBox["PlaceValueDigits",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValueDigits", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], 
         ButtonBox["PlaceValueTable",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3973735558502-8910602", {
            "PlaceValueTable", "Cool`MathEd`PronounceInteger`"}},
          ButtonNote->"Cool`MathEd`PronounceInteger`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.31666666666666665`]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", \
"InfoCell",ExpressionUUID->"52be05e0-50ef-429a-a93b-e7a82dd6d87f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PronounceIntegerReadMe"}]], "Input",ExpressionUUID->"0f37c1f8-d579-4df6-bd17-ef854dea048a"],

Cell[BoxData["\<\"PronounceIntegerReadMe[] explains the package\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info3983735558502-8910602",ExpressionUUID->"44aee89a-a47e-4787-ad03-\
a8f1c8012f04"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PronounceIntegerReadMe", "[", "]"}]], "Input",ExpressionUUID->"ad6bcfca-b2de-422d-baf8-8013e84f73f2"],

Cell[BoxData[
 FormBox["\<\"Mathematica already provides for (i) IntegerName[n, \
\\\"language\\\"], (ii) IntegerName[n, \\\"DigitsWords\\\"] for blocks of \
three digits, and (iii) WordTranslation for \\\"negative\\\", and (iv) a \
wealth of expression in IntegerString. These all encode tradition: with 56 = \
fifty-six instead of ten\[CenterDot]five & six, except in IntegerString[n, \\\
\"TraditionalChineseDecimal\\\"]. Also, these all tend to hide the steps in \
the place value system that we want to show. Our routines are:\\n(1) \
PronounceInteger provides a switch between methods, and helps to focus on \
your preferred method\\n(2) PlaceValue (main routine): word based, so that \
the pronunciation is unambiguous for the particular language. It also allows \
transliteration (speaking foreign words with approximations in English)\\n(3) \
PlaceValueDigits: integer based, for when kids go from sounds to reading and \
writing numerals\\n(4)PlaceValueBlock: show in blocks of three digits (quite \
alike DigitsWords, but notice the differences).\\n(5) PlaceValueIntegerName \
builds around IntegerName DigitsWords for full place value speech\\nLikely, \
teaching is best done likely in order (2)-(5) so that first the individual \
steps are shown and then the block form. PM. A routine f stores what is \
spoken in LatestPronunciation[] and may display differently, see the \
documentation of f\"\>", TraditionalForm]], "Output",ExpressionUUID->\
"ef94b3b3-e193-4f10-81de-ccae1dc27a21"]
}, Open  ]],

Cell["\<\
The discussion in the notebook also uses - but not directly on pronunciation:\
\>", "Text",ExpressionUUID->"917d4b43-d97d-49fa-970a-c8c42981c480"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Cool`MathEd`CCSSMath`*"}]], "Input",ExpressionUUID->"1c64149a-19a5-4a2f-bc94-fb267cc6b855"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["Cool`MathEd`CCSSMath`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["Cool`MathEd`CCSSMath`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["CCSSMathContent",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info4003735558503-8910602", {
            "CCSSMathContent", "Cool`MathEd`CCSSMath`"}},
          ButtonNote->"Cool`MathEd`CCSSMath`"], 
         ButtonBox["CCSSMathExercise",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info4003735558503-8910602", {
            "CCSSMathExercise", "Cool`MathEd`CCSSMath`"}},
          ButtonNote->"Cool`MathEd`CCSSMath`"]}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.475]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", \
"InfoCell",ExpressionUUID->"527caf87-b20a-466c-9ef8-22867d6bde62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "CCSSMathExercise"}]], "Input",ExpressionUUID->"4b274e71-e83d-4b43-8229-328a6d2ebc36"],

Cell[BoxData["\<\"CCSSMathExercise[n, ..., m, opts] passes the numbers on to \
a routine that recognises the CCSSMathContent labels in opts, see \
Options[CCSSMathExercise] and CCSSMathContent. When Show -> True then the \
CCSSMathContent on those labels is shown (default \
False)\\nCCSSMathExercice[n, m:10] for \\\"Grade\\\" -> \\\"Kindergarten\\\" \
or \\\"Grade 1\\\" counts from m to n. Defaults Speak -> False, IntegerDigits \
-> False (if True, the exercise question shows digits, but still speaks full \
place value)\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info4013735558503-8910602",ExpressionUUID->"250e61d2-53f5-4ef4-ac98-\
0dc75df0acd6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Switching routine"
}], "Subsection",ExpressionUUID->"45881424-15c8-4e48-8a5d-c327b1cc4d87"],

Cell["\<\
The PronounceInteger routine and its options were already shown above. \
\>", "Text",ExpressionUUID->"dde69074-e6c0-4739-807c-70733e2e6173"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PronounceInteger", "[", 
  RowBox[{"12", ",", " ", 
   RowBox[{"Level", " ", "\[Rule]", " ", "0"}], ",", " ", 
   RowBox[{"Method", " ", "\[Rule]", " ", "Random"}]}], "]"}]], "Input",Expres\
sionUUID->"449d992f-becc-45db-96b6-f97e2ba4d0c6"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "PronounceInteger","unk",
    "\"Unknown Level -> \\!\\(\\*FormBox[\\\"0\\\", TraditionalForm]\\) and \
Method -> \\!\\(\\*FormBox[\\\"Random\\\", TraditionalForm]\\)\"",2,280,42,
    32540151164407676168,"Local",
    "Cool`MathEd`PronounceInteger`PronounceInteger"},
   "MessageTemplate2"], TraditionalForm]], "Message", \
"MSG",ExpressionUUID->"2224b589-c201-4c9e-95cf-5c5a6a3a797e"],

Cell[BoxData[
 FormBox["$Failed", TraditionalForm]], "Output",ExpressionUUID->"b2f80ae6-3584-49c6-b804-81a3fdc023f3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 1"
}], "Subsection",ExpressionUUID->"9e090afc-5b40-46ba-bbbe-84df353a9f09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PlaceValue"}]], "Input",ExpressionUUID->"cb38588e-f811-4c25-b63f-0babc8615c06"],

Cell[BoxData["\<\"PlaceValue[n] gives n in the full place value system, as \
text or in Speak, and the latter with pauses for hearing and possible \
transliteration in the system default language (e.g. $Language = English). n \
is in (-10^7, 10^7).\\nThe routine is also called with PronounceInteger[n, \
Level -> 1]\\nOptions with defaults are:\\nLanguage -> \\\"Amplish\\\" uses \
PlaceValueRules[\\\"Amplish\\\"], see there\\nWordTranslation -> Automatic \
calls IntegerName and WordTranslation when the language is not available in \
PlaceValueRules, which takes some time for initialisation and does not \
provide for transliteration\\nSpeakTransliteration :> $Language (often \
\\\"English\\\"), see there\\nSpeak -> True,\\nLength -> 300, an integer for \
the duration of pause between the positions,\\nJoin -> \\\"\[CenterDot]\\\" \
(unpronounced center dot) between the texts of the weight and place \
value\\nSimplify -> True eliminates terms with 0 weights and replaces 1 P by \
P, for P = 1, 10, ..., 10^6\\nShow -> False does not show the input for \
Speak, so that one reads the words in the language itself and hears the \
transliteration (while reading affects hearing)\\nPronounceInteger[Options, \
\\\"Reset\\\"] resets the options to loading time\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info3593735575597-8910602",ExpressionUUID->"0f6bbdc2-a4bc-42a6-9b77-\
59d8e12ca49b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PlaceValue", "]"}]], "Input",ExpressionUUID->"5f7fdb80-d3dd-4354-ae35-cc41717ea9f7"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Join", "\[Rule]", "\<\"\[CenterDot]\"\>"}], ",", 
    RowBox[{"Language", "\[Rule]", "\<\"Amplish\"\>"}], ",", 
    RowBox[{"Length", "\[Rule]", "300"}], ",", 
    RowBox[{"Show", "\[Rule]", "False"}], ",", 
    RowBox[{"Simplify", "\[Rule]", "True"}], ",", 
    RowBox[{"Speak", "\[Rule]", "True"}], ",", 
    RowBox[{"WordTranslation", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"SpeakTransliteration", "\[RuleDelayed]", "$Language"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"f8949c9a-8d75-4fa2-8626-\
d9df0f0231be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SpeakTransliteration"}]], "Input",ExpressionUUID->"0c6ae97f-f605-41f1-9bad-a92130267931"],

Cell[BoxData["\<\"SpeakTransliteration is an option of PlaceValue with \
default $Language. It selects the relevant setting from the PlaceValueRules. \
If the Language option is equal to the transliterator ($Language) then \
writing and speaking will be done from the True rule. When the option \
Language is set to another value, then the integers are written from True but \
spoken by the transliterator\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info3613735575612-8910602",ExpressionUUID->"e13df783-445e-4071-99e9-\
f881ad080c9b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PlaceValueRules"}]], "Input",ExpressionUUID->"c1c81767-b98c-4440-9706-f43c7afe7d28"],

Cell[BoxData["\<\"PlaceValueRules[\\\"Language\\\"] = {True -> t, \
\\\"OtherLanguage\\\" -> f}, with t = {Negative -> string, And -> \\\"&\\\", \
N -> {strings for 0...9}, Power -> {strings for 10, ..., 10^6}}, for the true \
way of writing and pronunciation (when this original language = $Language), \
and f = {... similar ...} for the transliteration into the actual $Language. \
See the examples for \\\"English\\\" (f is not required given $Language = \
\\\"English\\\") and \\\"Dutch\\\" (t <> f).\\nNegative -> how the sign of a \
negative number is written or pronounced\\nAnd-> what string is used to \
separate the product terms of weights and place values\\nN -> {names how the \
digits 0 ... 9 are written or pronounced}\\nPower -> {names how 10 ... 10^6 \
are written or pronounced}.\\nSee SpeakTransliteration for checking on \
$Language.\\nImplemented are English, German, French, Dutch and Danish (with \
some guessing on transliteration). The language Amplish has True -> with an \
ampersand in a smaller font, and otherwise English. Englishty has ty for 10 \
pronounced as tee. The languages have (Greek) myriad for 10^4 and (Indian) \
lakh for 10^5\\nPlaceValueRules[] contains the list of languages for which \
there is transliteration\\nPlaceValueRules[Select, item, lan, \
translit:\\\"English\\\"] selects for lan the item (e.g. Power) from both \
True and translit, and gives a rule or list of rules (true -> \
transliteration) for replacement\\nPlaceValueRules[Set, \\\"ToLanguage\\\", \
FromLanguage:\\\"English\\\"] uses IntegerName for the digits and \
WordTranslation for \\\"negative\\\", \\\"and\\\" and \\\"million\\\" and \
imposes myriad and lakh. These routines may take time, and thus one is \
advised to save the result. There is no automation for the \
transliteration\\nPlaceValueRules[Check, \\\"Language\\\"] for another \
language than in PlaceValueRules[\\\"Checked\\\"] will issue a warning that \
the place value pronunciation is generated by automation and hasn't been \
checked on conflicts. When you have done the checking then this list can be \
adapted manually or by AppendTo\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info4553735576149-8910602",ExpressionUUID->"17688de7-b7f0-4071-be46-\
ac018389f3e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "]"}]], "Input",ExpressionUUID->"d3d9b2c4-813d-4f1d-a91f-7bcacf458f20"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"Amplish\"\>", ",", "\<\"Danish\"\>", ",", "\<\"Dutch\"\>", 
    ",", "\<\"Englishty\"\>", ",", "\<\"French\"\>", ",", "\<\"German\"\>", 
    ",", "\<\"Finnish\"\>", ",", "\<\"Italian\"\>", ",", "\<\"Spanish\"\>", 
    ",", "\<\"Swedish\"\>"}], "}"}], TraditionalForm]], "Output",ExpressionUUI\
D->"4ec3f9ed-50b6-4a59-a665-5c1fdcd67b5a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", "\"\<Checked\>\"", "]"}]], "Input",Expression\
UUID->"70ed344f-13c3-4335-9097-f4a6cde1744b"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"English\"\>", ",", "\<\"Amplish\"\>", ",", "\<\"Danish\"\>", 
    ",", "\<\"Dutch\"\>", ",", "\<\"Englishty\"\>", ",", "\<\"French\"\>", 
    ",", "\<\"German\"\>"}], "}"}], TraditionalForm]], "Output",ExpressionUUID\
->"f2c9fb31-a0a9-4977-8010-5ecad6c836bd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueRules", "[", 
  RowBox[{"Select", ",", " ", "Power", ",", " ", "\"\<French\>\""}], 
  "]"}]], "Input",ExpressionUUID->"9a435544-7e65-4d5c-a657-2f98bc032443"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\<\"dix\"\>", "\[Rule]", "\<\"dees\"\>"}], ",", 
    RowBox[{"\<\"cent\"\>", "\[Rule]", "\<\"sun\"\>"}], ",", 
    RowBox[{"\<\"mille\"\>", "\[Rule]", "\<\"meel\"\>"}], ",", 
    RowBox[{"\<\"myriade\"\>", "\[Rule]", "\<\"meeri udd\"\>"}], ",", 
    RowBox[{"\<\"lakh\"\>", "\[Rule]", "\<\"lakh\"\>"}], ",", 
    RowBox[{"\<\"million\"\>", "\[Rule]", "\<\"meelyon\"\>"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"8ed10bc7-38b4-4728-9c2f-\
0e5ce07176ac"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 2"
}], "Subsection",ExpressionUUID->"59acad8f-05ca-4bd2-ba48-de4e8511535c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PlaceValueDigits"}]], "Input",ExpressionUUID->"9d0f2d00-5ef7-4dc0-a199-38389bf31188"],

Cell[BoxData["\<\"PlaceValueDigits[n] pronounces n by PlaceValue[n] and \
displays by PlaceValueDigits$Language[n]\\nOptions are passed on to said \
routines, and see their own options, like Simplify and Show\\nOwn options are \
Speak -> True (default), Print -> True (default) prints the outcome of \
PlaceValue[n]. LatestPronunciation[Print] stores what is printed\\nThe \
routine is also called with PronounceInteger[n, Level -> 2]\"\>"], "Print", \
"PrintUsage",
 CellTags->
  "Info4083735558503-8910602",ExpressionUUID->"ea864b82-5f2c-4ed0-a510-\
bc9d66ba210e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PlaceValueDigits", "]"}]], "Input",ExpressionUUID->"255cf577-acb2-4127-8b2d-b2c3ec0f76b7"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Speak", "\[Rule]", "True"}], ",", 
    RowBox[{"Print", "\[Rule]", "True"}]}], "}"}], TraditionalForm]], "Output",\
ExpressionUUID->"4f1fc342-6ad1-4a30-982c-19c442319606"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PlaceValueDigits$Language"}]], "Input",ExpressionUUID->"f6362f80-14bf-4b29-a13b-4625820567ce"],

Cell[BoxData["\<\"PlaceValueDigits$Language[n] pronounces n by using digits \
for the place values rather than words (PlaceValue): n can be as large as \
Mathematica allows, but also relies on how $Language pronounces those \
integers. In English 2 100 is pronounced as \\\"two one-hundred\\\". Option \
Simplify -> True (default) for handling of 0 and 1 weights, StepMonitor -> \
False (default) whether to show an intermediate step, Length -> 300 (default) \
for the pause, Join -> \\\"\[CenterDot]\\\" (default) for connection of terms \
in display (not spoken), Speak -> True (default).\\nThe routine is also \
called as a subroutine by PlaceValueDigits[n], which is also called by \
PronounceInteger[n, Level -> 2]\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info4103735558503-8910602",ExpressionUUID->"e2f9876f-c24c-4203-bb04-\
4613820eb877"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PlaceValueDigits$Language", "]"}]], "Input",Expressi\
onUUID->"afb5e6cc-5907-46e4-bbef-8401cbf413e6"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"And", "\[Rule]", "\<\"&\"\>"}], ",", 
    RowBox[{"Join", "\[Rule]", "\<\"\[CenterDot]\"\>"}], ",", 
    RowBox[{"Length", "\[Rule]", "300"}], ",", 
    RowBox[{"Simplify", "\[Rule]", "True"}], ",", 
    RowBox[{"Speak", "\[Rule]", "True"}], ",", 
    RowBox[{"StepMonitor", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"6ef57646-4b9f-4263-ae92-\
ad8090adaea4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueDigits$Language", "[", 
  RowBox[{"22324443224", ",", " ", 
   RowBox[{"And", " ", "\[Rule]", " ", "\"\<,\>\""}], ",", " ", 
   RowBox[{"Speak", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",Expressi\
onUUID->"c710106a-b25c-4a21-b8e7-68f9c009a235"],

Cell[BoxData[
 FormBox["\<\"2 \[CenterDot] 10000000000    \[CenterDot]   2 \[CenterDot] \
1000000000    \[CenterDot]   3 \[CenterDot] 100000000    \[CenterDot]   2 \
\[CenterDot] 10000000    \[CenterDot]   4 \[CenterDot] 1000000    \
\[CenterDot]   4 \[CenterDot] 100000    \[CenterDot]   4 \[CenterDot] 10000   \
 \[CenterDot]   3 \[CenterDot] 1000    \[CenterDot]   2 \[CenterDot] 100    \
\[CenterDot]   2 \[CenterDot] 10    \[CenterDot]   4\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"9593f48c-9a2e-4608-8f3f-\
b3effe5cc66f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 3"
}], "Subsection",ExpressionUUID->"e7b8c0f9-6cd9-450c-975f-a492c49f2cc5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PlaceValueBlock"}]], "Input",ExpressionUUID->"674b6dbb-46c5-4170-b751-6e426cfc4e4c"],

Cell[BoxData["\<\"PlaceValueBlock[n] pronounces n in digit blocks of 3, and \
within those blocks in place value manner.\\nThe routine is also called with \
PronounceInteger[n, Level -> 3]\\nFor example 123456 = {{1 hundred & 2 ten & \
3}, thousand} & {4 hundred & 5 ten & 6}. This is like common usage except for \
the integers in 11-99. Option Length -> 300 (default) puts \\\"&\\\" in the \
middle of that pause. Option Power -> {...} by default replaces 100 by \
hundred, 1000 by thousand and 10^6 by million. (This is not done in \
PlaceValueDigits$Language, because there are more words, like for the digits, \
and including the awkward 10^4 and 10^5). The numbers 11-99 use the options \
of PlaceValueDigits$Language, namely to display in numbers and not words. If \
your $Language is not \\\"English\\\", then you might consider to adapt the \
settings manually. The following is an automation \
though:\\nPlaceValueBlock[SetOptions, \\\"language\\\"] sets the options to \
stated \\\"language\\\", using WordTranslation from the current language in \
the Options (default \\\"English\\\")\\nPlaceValueBlock[Options, \
\\\"Reset\\\"] resets to the Options at loading\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info4133735558504-8910602",ExpressionUUID->"5b9abc04-267c-4cec-9627-\
db42ec1e6410"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PlaceValueBlock", "]"}]], "Input",ExpressionUUID->"ef33d593-1d04-47f2-bcd5-a1b11e0bf998"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"And", "\[Rule]", "\<\"&\"\>"}], ",", 
    RowBox[{"Join", "\[Rule]", "\<\"\[CenterDot]\"\>"}], ",", 
    RowBox[{"Language", "\[Rule]", "\<\"Amplish\"\>"}], ",", 
    RowBox[{"Length", "\[Rule]", "300"}], ",", 
    RowBox[{"Power", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1000000", "\[Rule]", "\<\"million\"\>"}], ",", 
       RowBox[{"1000", "\[Rule]", "\<\"thousand\"\>"}], ",", 
       RowBox[{"100", "\[Rule]", "\<\"hundred\"\>"}]}], "}"}]}], ",", 
    RowBox[{"Simplify", "\[Rule]", "True"}], ",", 
    RowBox[{"Speak", "\[Rule]", "True"}]}], "}"}], TraditionalForm]], "Output",\
ExpressionUUID->"7ecf078d-9df8-4392-bbfa-917561644da8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueBlock", "[", "123456", "]"}]], "Input",ExpressionUUID->"121ac5d7-33b6-4f8f-996f-a134f3c23253"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"1 \[CenterDot] 100\"\>", ",", "\<\" & \"\>", 
        ",", "\<\"2 \[CenterDot] 10    &    3\"\>"}], "}"}], ",", "1000"}], 
     "}"}], ",", "\<\" & \"\>", ",", 
    RowBox[{"{", 
     RowBox[{"\<\"4 \[CenterDot] 100\"\>", ",", "\<\" & \"\>", 
      ",", "\<\"5 \[CenterDot] 10    &    6\"\>"}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"7ca0803b-5c63-4da2-a145-\
39b4f0f82916"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"0a1da0eb-a54e-47a9-8d5c-0af54ff3b4f2"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"1 \[CenterDot] hundred\"\>", ",", "\<\" & \"\>", 
        ",", "\<\"2 \[CenterDot] 10    &    3\"\>"}], "}"}], 
      ",", "\<\"thousand\"\>"}], "}"}], ",", "\<\" & \"\>", ",", 
    RowBox[{"{", 
     RowBox[{"\<\"4 \[CenterDot] hundred\"\>", ",", "\<\" & \"\>", 
      ",", "\<\"5 \[CenterDot] 10    &    6\"\>"}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"51f14d46-a293-49dc-87ef-\
ba1a21ba54c4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level 4"
}], "Subsection",ExpressionUUID->"746d72e2-5e49-4098-9d9e-1e35db5e8d95"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PlaceValueIntegerName"}]], "Input",ExpressionUUID->"4021e7f4-ef95-45e3-bfc5-723d4c39deed"],

Cell[BoxData["\<\"PlaceValueIntegerName[n] lets IntegerName[n, \
\\\"DigitsWords\\\"] make the blocks of 3 digits, and then calls PlaceValue \
on these digits. IntegerName DigitsWords uses text for Abs[n] < 1000, and we \
follow this. The block bases of thousand, million etcetera are translated by \
WordTranslation. The text displayed has blocks of digits, with block bases \
separated by option And -> \\\", \\\" (default). This option is not passed on \
to PlaceValue for speech of the blocks. The spoken text can be recovered from \
LatestPronunciation[]. Transliteration is called but will slow the \
execution\\nThe routine is also called with PronounceInteger[n, Level -> 4]\"\
\>"], "Print", "PrintUsage",
 CellTags->
  "Info4173735558504-8910602",ExpressionUUID->"f6ad94bf-b7e1-4ee2-802e-\
b38aa45353df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PlaceValueIntegerName", "]"}]], "Input",ExpressionUU\
ID->"25584464-a6cf-4af4-a520-b04c5ada5806"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Language", "\[Rule]", "\<\"English\"\>"}], ",", 
    RowBox[{"Speak", "\[Rule]", "True"}], ",", 
    RowBox[{"And", "\[Rule]", "\<\", \"\>"}]}], "}"}], 
  TraditionalForm]], "Output",ExpressionUUID->"ac6fa88d-116e-4612-a6c4-\
da970da21996"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlaceValueIntegerName", "[", "1234451011", "]"}]], "Input",Expressio\
nUUID->"7e079c6a-faa8-40a4-ba05-a2504fa9428d"],

Cell[BoxData[
 FormBox["\<\"1  billion,   234  million,   451  thousand,   11\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"e116d97f-f3a8-4037-a999-\
589481b9cea8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LatestPronunciation", "[", "]"}]], "Input",ExpressionUUID->"1e5b9ab8-bd07-434c-89e0-8f77e2f503e5"],

Cell[BoxData[
 FormBox["\<\"\[CenterDot]one  billion,   two\[CenterDot]hundred  &  three\
\[CenterDot]ten  &  four\[CenterDot]  million,   four\[CenterDot]hundred  &  \
five\[CenterDot]ten  &  \[CenterDot]one  thousand,   \[CenterDot]ten  &  \
\[CenterDot]one\"\>", TraditionalForm]], "Output",ExpressionUUID->"73399f7b-\
791b-4360-9953-9c5409c24dd9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 ". Level -4"
}], "Subsection",ExpressionUUID->"663bff99-b7bb-4656-a852-5e55511d4010"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "PartialPlaceValue"}]], "Input",ExpressionUUID->"5ace99c7-3c03-4b46-b877-3de530c3f9c0"],

Cell[BoxData["\<\"PartialPlaceValue[n] has the traditional pronunciation and \
words of the numbers 11-99, thus in opposite order of the place value system, \
when speaking the number from Left To Right, and morphing of words. It calls \
IntegerName with DigitsWords. If Abs[n] < 1000 then there are words only, and \
higher n get combinations of both digit blocks and words for digit block \
values (thousand, million). Option defaults are Language -> \\\"English\\\" \
and Speak -> True. Speak apparently fails on the hyphen and thus this \
replaced by a space. Speak[-10] says Minus 10 but IntegerName uses Negative \
10. There is no transliteration.\\nThe routine is also called with \
PronounceInteger[n, Level -> -4]\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info4213735558504-8910602",ExpressionUUID->"a653b300-a96f-4321-b74d-\
d881ea54c9f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PartialPlaceValue", "]"}]], "Input",ExpressionUUID->"130572c3-0344-4fe4-bf10-bedf88106436"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Language", "\[Rule]", "\<\"English\"\>"}], ",", 
    RowBox[{"Speak", "\[Rule]", "True"}]}], "}"}], TraditionalForm]], "Output",\
ExpressionUUID->"faa3d50a-1770-4e2c-9185-308138a7ccef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartialPlaceValue", "[", "1234451011", "]"}]], "Input",ExpressionUUI\
D->"439758cb-9c7c-4199-83f9-061eec79effc"],

Cell[BoxData[
 FormBox["\<\"1 billion 234 million 451 thousand 11\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"b3ae4cad-fcb6-4cce-8f0e-\
a9578cef7949"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LatestPronunciation", "[", "]"}], "  ", 
  RowBox[{"(*", 
   RowBox[{"in", " ", "traditional", " ", "manner"}], "*)"}]}]], "Input",Expre\
ssionUUID->"59ba6893-479c-4b1a-9a69-d38e914b8bc9"],

Cell[BoxData[
 FormBox["\<\"1 billion 234 million 451 thousand 11\"\>", 
  TraditionalForm]], "Output",ExpressionUUID->"a0782e0e-a4a5-445a-8c86-\
d579cacc9f16"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". ",
 "Literature"
}], "Section",ExpressionUUID->"3c2a51a1-0ed8-4f1a-ab10-a4992a3fe325"],

Cell["\<\
Thomas Colignatus is the scientific name of Thomas Cool, econometrician and \
teacher of mathematics, Scheveningen, Holland.\
\>", "Text",ExpressionUUID->"10e59b6a-168c-470e-a659-6610018c0b1d"],

Cell[TextData[{
 "Bree, C. van (1987), ",
 StyleBox["Historische grammatica van het Nederlands, ",
  FontSlant->"Italic"],
 "Foris Publications, \
https://dbnl.org/tekst/bree001hist02_01/bree001hist02_01.pdf"
}], "Text",ExpressionUUID->"27d98d3f-944a-4d6d-b0a7-bedd6c35c579"],

Cell[TextData[{
 "Bussi, M. G. B. & Sun X. H. (eds) (2018), ",
 StyleBox["Building the Foundation: Whole Numbers in the Primary Grades,",
  FontSlant->"Italic"],
 "The 23rd ICMI Study, Springer "
}], "Text",ExpressionUUID->"5de91ac8-7d0f-4f93-a0e2-9d295f49011c"],

Cell[TextData[{
 "Colignatus, Th. (2015a),",
 StyleBox[" A child wants nice and no mean numbers",
  FontSlant->"Italic"],
 ", \[LineSeparator](1) website: \
http://thomascool.eu/Papers/NiceNumbers/Index.html\n(2) PDF on Zenodo: \
https://zenodo.org/record/291979\n(3) Publisher for a print: \
https://www.mijnbestseller.nl/shop/index.php/catalog/product/view/id/118082/s/\
a-child-wants-nice-and-no-mean-numbers-79074-www-mijnbestseller-nl/"
}], "Text",ExpressionUUID->"46169e56-2d3b-450a-bb43-692b7f25c158"],

Cell[TextData[{
 "Colignatus, Th. (2015b, 2018a), ",
 StyleBox["The need for a standard for the mathematical pronunciation of the \
natural numbers. Suggested principles of design. Implementation for English, \
German, French, Dutch and Danish",
  FontSlant->"Italic"],
 ", https://doi.org/10.5281/zenodo.774866"
}], "Text",ExpressionUUID->"49c0299d-45ae-4c2f-a7a6-32f660113df8"],

Cell[TextData[{
 "Colignatus, Th. (2016), ",
 StyleBox["Letter to VSNU and others on membership dues and open access \
publishing, ",
  FontSlant->"Italic"],
 "https://boycottholland.wordpress.com/2016/10/12/letter-to-vsnu-and-others-\
on-membership-dues-and-open-access-publishing/"
}], "Text",ExpressionUUID->"d0e3c4f0-8f90-4d44-906a-4ee64fb2d69b"],

Cell[TextData[{
 "Colignatus, Th. (2018b),",
 StyleBox[" Tables for addition and subtraction with better use of the place \
value system,",
  FontSlant->"Italic"],
 " PDF  https://doi.org/10.5281/zenodo.1241349 and notebook with package \
https://doi.org/10.5281/zenodo.1241404 and \
http://community.wolfram.com/groups/-/m/t/1313408 (update May 5)"
}], "Text",ExpressionUUID->"bc17a31b-2ab7-4cd7-8f98-fe9c8f871945"],

Cell[TextData[{
 "Common Core Standards (2018), ",
 StyleBox["Number & Operations in Base Ten, ",
  FontSlant->"Italic"],
 "http://www.corestandards.org/Math/Content/NBT/ with also ",
 StyleBox["Understand place value",
  FontSlant->"Italic"]
}], "Text",ExpressionUUID->"e1653c2c-036e-4e42-8ebb-6d95e9fdc42c"],

Cell["\<\
Ejersbo, L. R., M. Misfeldt (2015), \[OpenCurlyDoubleQuote]The relationship \
between number names and number concepts\[CloseCurlyDoubleQuote], Paper \
presented at ICMI Sudy-23, Macau SAR, China. Included in Sun et al. (eds) \
(2015)\
\>", "Text",ExpressionUUID->"c66e3c1a-c1e3-4127-b3d1-010ea60b5495"],

Cell[TextData[{
 "Fateman, R. (2013), ",
 StyleBox["How can we speak math?, ",
  FontSlant->"Italic"],
 "https://people.eecs.berkeley.edu/~fateman/papers/speakmath.pdf"
}], "Text",ExpressionUUID->"ed0bf13f-85b3-4ea4-8074-6fbbaa395c05"],

Cell[TextData[{
 "Gowers, T. (2017), ",
 StyleBox["The end of an error?",
  FontSlant->"Italic"],
 ", https://www.the-tls.co.uk/articles/public/the-end-of-an-error-peer-review/"
}], "Text",ExpressionUUID->"da920385-c252-4034-8e5a-63eda75f3cbf"],

Cell[TextData[{
 "Menninger, K. (1958), ",
 StyleBox["Zahlwort und Ziffer: eine Kulturgeschichte der Zahl,",
  FontSlant->"Italic"],
 " Volumes 1-2, G\[ODoubleDot]ttingen: Vandenhoeck und Ruprecht 1979"
}], "Text",ExpressionUUID->"2f0521c8-5864-405a-9f6a-057bf75915e5"],

Cell["\<\
Sun, X., Kaur, B., & Novotna, J. (eds) (2015), \
\[OpenCurlyDoubleQuote]Conference proceedings of the ICMI study 23: Primary \
mathematics study on whole numbers\[CloseCurlyDoubleQuote], \
www.umac.mo/fed/ICMI23/doc/Proceedings_ICMI_STUDY_23_final.pdf\
\>", "Text",ExpressionUUID->"6a581ec2-6fa6-46ff-a9a9-dfca38f9c465"],

Cell[TextData[{
 "Uy, F.L. (2003), ",
 StyleBox["The Chinese Numeration System and Place Value",
  FontSlant->"Italic"],
 ", Teachting Children Mathematics, NCTM, p244-247 "
}], "Text",ExpressionUUID->"8b77a98f-fbf2-429c-baea-c3c1f78c38a2"],

Cell[TextData[{
 "Wolfram Research, Inc. (2017), ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", Version 11.2, http://www.wolfram.com"
}], "Text",ExpressionUUID->"b3848859-8297-4317-b834-1475853ce5d0"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{903, 880},
WindowMargins->{{Automatic, 257}, {Automatic, 14}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.3199999999999, 841.92}},
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 11, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info2763735558483-8910602"->{
  Cell[201478, 4773, 455, 11, 45, "Print",ExpressionUUID->"043ce143-e795-4438-95b6-2474e72c4506",
   CellTags->"Info2763735558483-8910602"]},
 "Info3203735558484-8910602"->{
  Cell[260793, 6429, 553, 9, 138, "Print",ExpressionUUID->"96dfcb63-cb9f-4512-8b27-21e5ca0fd224",
   CellTags->"Info3203735558484-8910602"]},
 "Info3563735558490-8910602"->{
  Cell[308436, 7740, 1090, 16, 368, "Print",ExpressionUUID->"2a1cb0a9-a9c7-4119-9f7f-ea39e103b018",
   CellTags->"Info3563735558490-8910602"]},
 "Info3593735575597-8910602"->{
  Cell[399525, 10175, 1395, 19, 368, "Print",ExpressionUUID->"0f6bbdc2-a4bc-42a6-9b77-59d8e12ca49b",
   CellTags->"Info3593735575597-8910602"]},
 "Info3613735575612-8910602"->{
  Cell[401843, 10223, 535, 8, 115, "Print",ExpressionUUID->"e13df783-445e-4071-99e9-f881ad080c9b",
   CellTags->"Info3613735575612-8910602"]},
 "Info3983735558502-8910602"->{
  Cell[393711, 10018, 193, 3, 45, "Print",ExpressionUUID->"44aee89a-a47e-4787-ad03-a8f1c8012f04",
   CellTags->"Info3983735558502-8910602"]},
 "Info4013735558503-8910602"->{
  Cell[397309, 10105, 655, 10, 138, "Print",ExpressionUUID->"250e61d2-53f5-4ef4-ac98-0dc75df0acd6",
   CellTags->"Info4013735558503-8910602"]},
 "Info4083735558503-8910602"->{
  Cell[406950, 10341, 566, 9, 138, "Print",ExpressionUUID->"ea864b82-5f2c-4ed0-a510-bc9d66ba210e",
   CellTags->"Info4083735558503-8910602"]},
 "Info4103735558503-8910602"->{
  Cell[408085, 10372, 849, 12, 161, "Print",ExpressionUUID->"e2f9876f-c24c-4203-bb04-4613820eb877",
   CellTags->"Info4103735558503-8910602"]},
 "Info4133735558504-8910602"->{
  Cell[410791, 10444, 1304, 18, 276, "Print",ExpressionUUID->"5b9abc04-267c-4cec-9627-db42ec1e6410",
   CellTags->"Info4133735558504-8910602"]},
 "Info4173735558504-8910602"->{
  Cell[414746, 10550, 814, 12, 161, "Print",ExpressionUUID->"f6ad94bf-b7e1-4ee2-802e-b38aa45353df",
   CellTags->"Info4173735558504-8910602"]},
 "Info4213735558504-8910602"->{
  Cell[417262, 10624, 852, 12, 184, "Print",ExpressionUUID->"a653b300-a96f-4321-b74d-d881ea54c9f3",
   CellTags->"Info4213735558504-8910602"]},
 "Info4553735576149-8910602"->{
  Cell[402531, 10239, 2257, 31, 506, "Print",ExpressionUUID->"17688de7-b7f0-4071-be46-ac018389f3e7",
   CellTags->"Info4553735576149-8910602"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info2763735558483-8910602", 424585, 10825},
 {"Info3203735558484-8910602", 424759, 10828},
 {"Info3563735558490-8910602", 424933, 10831},
 {"Info3593735575597-8910602", 425109, 10834},
 {"Info3613735575612-8910602", 425286, 10837},
 {"Info3983735558502-8910602", 425461, 10840},
 {"Info4013735558503-8910602", 425635, 10843},
 {"Info4083735558503-8910602", 425811, 10846},
 {"Info4103735558503-8910602", 425986, 10849},
 {"Info4133735558504-8910602", 426162, 10852},
 {"Info4173735558504-8910602", 426339, 10855},
 {"Info4213735558504-8910602", 426515, 10858},
 {"Info4553735576149-8910602", 426691, 10861}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[583, 22, 149, 2, 156, "Title",ExpressionUUID->"1110965b-e406-4b23-913b-caea1b8db153"],
Cell[735, 26, 143, 4, 78, "Text",ExpressionUUID->"53ed3239-cdce-41cb-b773-aba1913d217e"],
Cell[881, 32, 107, 0, 34, "Text",ExpressionUUID->"0e72e460-d5c2-4623-8c7c-914108df3a35"],
Cell[991, 34, 120, 1, 34, "Text",ExpressionUUID->"fd7c1fec-9270-429c-b869-d24a813d2bf5"],
Cell[1114, 37, 1378, 20, 232, "Text",ExpressionUUID->"ad785611-7ca3-4938-9ef3-2c5520759846"],
Cell[2495, 59, 120, 1, 34, "Text",ExpressionUUID->"bfac5d35-3658-4d6b-8202-ca48f8263c33"],
Cell[2618, 62, 203, 3, 56, "Text",ExpressionUUID->"bb284214-0fc2-49e8-8783-d70e26c02d2d"],
Cell[2824, 67, 119, 1, 34, "Text",ExpressionUUID->"410f56da-6bcc-41dc-ad2b-8e5f44c4faeb"],
Cell[2946, 70, 130, 0, 34, "Text",ExpressionUUID->"2006687d-7625-4c76-8526-ab0dcee587d0"],
Cell[3079, 72, 117, 1, 34, "Text",ExpressionUUID->"f9d66bff-0256-4b09-9bb1-a1e6890e5898"],
Cell[3199, 75, 146, 2, 34, "Text",ExpressionUUID->"f12a40ba-f0ba-491b-b18e-9f796fee68d5"],
Cell[3348, 79, 125, 0, 34, "Text",ExpressionUUID->"dea07df1-1224-4b5d-8e1d-3612bfb6f06d"],
Cell[3476, 81, 180, 3, 34, "Text",ExpressionUUID->"72af0cb7-c546-4d8d-ad6b-bb11169c4a7e"],
Cell[3659, 86, 181, 3, 34, "Text",ExpressionUUID->"c5f2f81c-b24f-4f87-b55b-c6602af526ce"],
Cell[3843, 91, 163, 3, 34, "Text",ExpressionUUID->"3b00d2ea-a9ce-41b5-bb91-81476e193c94"],
Cell[4009, 96, 266, 4, 56, "Text",ExpressionUUID->"ef5b0bb9-c5e9-4621-8174-2b0405737f4f"],
Cell[CellGroupData[{
Cell[4300, 104, 85, 0, 53, "Subsection",ExpressionUUID->"246d232d-27ac-42de-8b3b-54d84ccb08b4"],
Cell[4388, 106, 141, 4, 44, "Subsubsection",ExpressionUUID->"96dc55f3-0879-496d-a4d5-f5c96ddaf69d"],
Cell[4532, 112, 147, 4, 36, "Subsubsection",ExpressionUUID->"31c6b92a-f153-42aa-bb73-0c970917047a"],
Cell[4682, 118, 172, 4, 36, "Subsubsection",ExpressionUUID->"0bd3d71c-73fb-4c95-b401-167410e659bd"],
Cell[4857, 124, 159, 4, 36, "Subsubsection",ExpressionUUID->"d5259709-c0f1-464c-bc2c-6ba8d68dedcc"],
Cell[5019, 130, 159, 4, 36, "Subsubsection",ExpressionUUID->"4b7bfaf4-0ecd-4b0e-ba14-efcd40b01b1f"],
Cell[5181, 136, 173, 4, 36, "Subsubsection",ExpressionUUID->"d6a90818-0a19-4129-a1eb-954517d1e1f3"],
Cell[5357, 142, 146, 4, 36, "Subsubsection",ExpressionUUID->"2fab279a-da74-420e-8abc-ca0e2f78a17d"],
Cell[5506, 148, 141, 4, 36, "Subsubsection",ExpressionUUID->"bc9def86-9846-40bd-98cc-5641ae8bd57f"],
Cell[5650, 154, 140, 4, 36, "Subsubsection",ExpressionUUID->"6bb1c1f9-2ead-443d-8ca5-673d435c5403"],
Cell[5793, 160, 150, 4, 36, "Subsubsection",ExpressionUUID->"ab0ffa05-b85b-403d-8acc-8fa2c7f52163"],
Cell[5946, 166, 139, 4, 36, "Subsubsection",ExpressionUUID->"ae5bbdd6-7cd3-4399-95e9-a705654b086a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6122, 175, 148, 2, 53, "Subsection",ExpressionUUID->"52ee38c9-fbc5-45c8-be38-006fa5ca0a2e"],
Cell[CellGroupData[{
Cell[6295, 181, 104, 0, 44, "Subsubsection",ExpressionUUID->"d075f3e1-6e4f-4249-81d3-a501a169675b"],
Cell[CellGroupData[{
Cell[6424, 185, 123416, 2777, 12908, "Input",ExpressionUUID->"4112cb82-c406-4110-8422-7e3c3855a3b7",
 InitializationCell->True],
Cell[129843, 2964, 317, 7, 21, "Message",ExpressionUUID->"c1f7fedc-513e-44cd-9d2d-390b9ac4bdcf"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[130209, 2977, 96, 0, 36, "Subsubsection",ExpressionUUID->"99653670-056e-4c55-bfa7-b66c61a7319c"],
Cell[130308, 2979, 29442, 670, 4871, "Input",ExpressionUUID->"9c565fd4-0e21-4f4e-914f-f64cbcc3a450",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[159799, 3655, 157, 6, 53, "Section",ExpressionUUID->"0dd112e9-598c-413c-aea5-87e8e977a8fe",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[159981, 3665, 166, 7, 53, "Subsection",ExpressionUUID->"1e1ec74f-a963-41a0-bf1d-5e0ff7b6927f"],
Cell[160150, 3674, 113, 0, 34, "Text",ExpressionUUID->"487e95d3-28c2-43e6-83fa-fddef96c9531"],
Cell[160266, 3676, 186, 5, 34, "Text",ExpressionUUID->"ecf6d698-d179-4414-a345-996fee89356a"],
Cell[160455, 3683, 105, 0, 34, "Text",ExpressionUUID->"d83e9444-11fc-4c1f-befd-d348d97c1ab8"],
Cell[CellGroupData[{
Cell[160585, 3687, 139, 3, 28, "Input",ExpressionUUID->"b9dcefdb-9fe4-4f8f-847f-9f18b2978ce1"],
Cell[160727, 3692, 207, 4, 32, "Output",ExpressionUUID->"8156d6e1-a676-4fb8-8900-21c5c0009b71"]
}, Open  ]],
Cell[160949, 3699, 526, 9, 56, "Text",ExpressionUUID->"3b3fea65-ab55-4762-802c-b187f741cd44"],
Cell[161478, 3710, 411, 6, 78, "Text",ExpressionUUID->"86c94d93-d624-4106-ba73-7a61a8a33b6f"],
Cell[CellGroupData[{
Cell[161914, 3720, 285, 6, 28, "Input",ExpressionUUID->"53c959e0-9559-4b74-9c48-2ab62059dfe4"],
Cell[162202, 3728, 210, 4, 32, "Output",ExpressionUUID->"66243b1f-423a-4e55-a32d-e7f44be6ce47"]
}, Open  ]],
Cell[162427, 3735, 587, 13, 56, "Text",ExpressionUUID->"b3ff9fa1-655c-4d10-9789-5fc7e5406571"],
Cell[CellGroupData[{
Cell[163039, 3752, 222, 5, 28, "Input",ExpressionUUID->"ba1b1cb9-663a-4da7-b328-64618ca93e42"],
Cell[163264, 3759, 1494, 41, 52, "Output",ExpressionUUID->"7f29fdbb-c195-4ca8-b094-98151ca53b70"]
}, Open  ]],
Cell[CellGroupData[{
Cell[164795, 3805, 297, 6, 28, "Input",ExpressionUUID->"f921f5a4-ea27-49d0-a128-424b071ec5e3"],
Cell[165095, 3813, 1556, 42, 52, "Output",ExpressionUUID->"067942c9-3657-4650-b80e-63765c88c237"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[166700, 3861, 185, 7, 53, "Subsection",ExpressionUUID->"91e94ea6-b1db-4cfb-9b27-f9d6d9649e43"],
Cell[166888, 3870, 530, 7, 100, "Text",ExpressionUUID->"49eba1e0-8fa2-43d4-9e07-329ee218e128"],
Cell[167421, 3879, 411, 9, 56, "Text",ExpressionUUID->"bc6494a7-ef26-4e3f-997e-e800f0f656c2"],
Cell[CellGroupData[{
Cell[167857, 3892, 168, 3, 31, "Item",ExpressionUUID->"6d69999e-ce2b-498d-a6ff-d9f5120156cd"],
Cell[168028, 3897, 175, 3, 31, "Item",ExpressionUUID->"341704d0-c22f-44d6-91a0-b78a7448644a"]
}, Open  ]],
Cell[168218, 3903, 504, 9, 78, "Text",ExpressionUUID->"fa841478-fd6b-4c4c-aaac-57b00491c9f5"],
Cell[168725, 3914, 477, 11, 78, "Text",ExpressionUUID->"54d34f58-6386-44c1-9016-830bdbcc1311"],
Cell[169205, 3927, 366, 5, 78, "Text",ExpressionUUID->"1e329243-b5c9-4a00-a177-a126f8a0d8b9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169608, 3937, 195, 7, 53, "Subsection",ExpressionUUID->"bba2cd9b-2289-4a33-a057-9849ebc5f9ca"],
Cell[169806, 3946, 858, 18, 122, "Text",ExpressionUUID->"4fb0f751-25d5-45a2-8abf-16ca40aeef87"],
Cell[170667, 3966, 363, 5, 78, "Text",ExpressionUUID->"303a250e-8a73-42af-b1fa-f58f84b6c2ee"],
Cell[171033, 3973, 786, 11, 144, "Text",ExpressionUUID->"2264fa0f-616e-4eec-bcd6-4b86a0108e0e"],
Cell[171822, 3986, 265, 4, 56, "Text",ExpressionUUID->"7bfe0b1f-a7e9-46bb-8aa3-4c6145f6dd41"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172124, 3995, 201, 7, 53, "Subsection",ExpressionUUID->"a73b2d3b-ce13-4734-892c-77f397e0e0ec"],
Cell[172328, 4004, 773, 11, 122, "Text",ExpressionUUID->"ff0a68e1-2a0b-43ce-ab01-a5b4aeb32a95"],
Cell[173104, 4017, 756, 16, 122, "Text",ExpressionUUID->"735852bd-f236-422a-b9c1-5a381234cf5a"],
Cell[173863, 4035, 228, 5, 31, "Item",ExpressionUUID->"94f8756e-daaa-4e4f-8790-d1ba35e77ae0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174128, 4045, 183, 7, 53, "Subsection",ExpressionUUID->"b6c1b807-a846-4ff4-87e3-416ceca123d3"],
Cell[174314, 4054, 726, 11, 122, "Text",ExpressionUUID->"89fd7572-8524-486a-8e7e-9d8e0220d5e3"],
Cell[CellGroupData[{
Cell[175065, 4069, 331, 6, 51, "Item",ExpressionUUID->"0230ee19-1dfe-45c6-aa79-c8d4a4c16134"],
Cell[175399, 4077, 143, 2, 31, "Item",ExpressionUUID->"600ae17d-0b29-421d-ba4c-bbfdc78eca52"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[175591, 4085, 199, 7, 53, "Subsection",ExpressionUUID->"988f6a96-55af-4e9f-a24a-bf4f1559c21f"],
Cell[175793, 4094, 797, 11, 144, "Text",ExpressionUUID->"45afc111-e0ee-475c-8ca7-df42cdc34b2e"],
Cell[176593, 4107, 426, 8, 78, "Text",ExpressionUUID->"09e6f83a-a972-4c7c-a94f-1092fd9e6fb4"],
Cell[177022, 4117, 407, 6, 78, "Text",ExpressionUUID->"d25bab45-7bbc-466b-85b8-0256bc341be2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177466, 4128, 193, 7, 53, "Subsection",ExpressionUUID->"7cc5b000-8bc3-4631-834d-ba9036bf91e9"],
Cell[177662, 4137, 847, 16, 122, "Text",ExpressionUUID->"380647f6-90cd-41e8-845e-72ad21b02db7"],
Cell[178512, 4155, 708, 10, 122, "Text",ExpressionUUID->"906bc46f-aada-418b-a5e9-e8800c06cdd9"],
Cell[179223, 4167, 335, 7, 56, "Text",ExpressionUUID->"e8711d02-2fae-4d4b-bc90-55088a17eb88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179595, 4179, 177, 7, 53, "Subsection",ExpressionUUID->"e929eedc-11e0-4ff2-bc7d-7d0e918cd8f8"],
Cell[179775, 4188, 847, 16, 144, "Text",ExpressionUUID->"fcad33ca-c784-42f4-b3c2-83710c406a75"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[180671, 4210, 135, 4, 67, "Section",ExpressionUUID->"c29187d0-3770-4c0e-976a-29922c1313d1"],
Cell[180809, 4216, 466, 8, 78, "Text",ExpressionUUID->"3805e500-f573-49a4-963c-4ea6f59cb210"],
Cell[CellGroupData[{
Cell[181300, 4228, 175, 7, 53, "Subsection",ExpressionUUID->"0445ed59-fdf5-44ad-91c0-486d8862e318"],
Cell[181478, 4237, 487, 7, 100, "Text",ExpressionUUID->"2a8331c4-6590-4bd5-b739-d5833ec4f1c7"],
Cell[CellGroupData[{
Cell[181990, 4248, 256, 6, 28, "Input",ExpressionUUID->"df2b09f7-8abb-4fca-875a-71ab7c893f58"],
Cell[182249, 4256, 206, 4, 32, "Output",ExpressionUUID->"0625218f-5c93-4339-997b-9d62ac583feb"]
}, Open  ]],
Cell[182470, 4263, 173, 3, 34, "Text",ExpressionUUID->"46250b33-7cde-4fd4-bc77-ad74dbf650b2"],
Cell[CellGroupData[{
Cell[182668, 4270, 122, 1, 28, "Input",ExpressionUUID->"ece5902d-17cb-49da-9fea-f45b679bcec7"],
Cell[182793, 4273, 188, 3, 32, "Output",ExpressionUUID->"1cece410-dfa8-4492-8502-51812205dfc9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[183030, 4282, 163, 7, 53, "Subsection",ExpressionUUID->"43c76aa7-07f4-436d-8b20-3f2b045a4f45"],
Cell[183196, 4291, 875, 12, 122, "Text",ExpressionUUID->"c556b3db-951d-4eae-ab26-b6f6d47f30e7"],
Cell[CellGroupData[{
Cell[184096, 4307, 196, 4, 28, "Input",ExpressionUUID->"7de09d7b-40fa-4e60-a213-0dc437fde753"],
Cell[184295, 4313, 133, 1, 32, "Output",ExpressionUUID->"e40bd333-ea67-44d6-93df-dd35caacf148"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184465, 4319, 262, 5, 28, "Input",ExpressionUUID->"70412bae-e9f3-4fe1-9179-ca3e61113aad"],
Cell[184730, 4326, 138, 2, 32, "Output",ExpressionUUID->"bf8f1673-685b-4834-8d61-923ddeaeb138"]
}, Open  ]],
Cell[184883, 4331, 151, 2, 34, "Text",ExpressionUUID->"6f2b26f8-4529-4bb4-94db-d32981b75c83"],
Cell[CellGroupData[{
Cell[185059, 4337, 263, 5, 28, "Input",ExpressionUUID->"552adb81-1644-4af8-8132-0b59ef18807f"],
Cell[185325, 4344, 209, 4, 32, "Output",ExpressionUUID->"fa1175ce-45f4-4971-89cb-abea54ef8d12"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[185583, 4354, 180, 7, 53, "Subsection",ExpressionUUID->"7b35ad4d-dce9-46ae-93d5-fb183b16ecd1"],
Cell[185766, 4363, 236, 5, 34, "Text",ExpressionUUID->"8cb59db9-b2df-4a89-9d55-3b509f1619f3"],
Cell[CellGroupData[{
Cell[186027, 4372, 127, 1, 28, "Input",ExpressionUUID->"5f51e00c-0bc5-479b-81d0-c887dcb2a780"],
Cell[186157, 4375, 144, 2, 32, "Output",ExpressionUUID->"eb1ba351-6390-4a42-9620-58fb3fe9cd4a"]
}, Open  ]],
Cell[186316, 4380, 123, 0, 34, "Text",ExpressionUUID->"4f934c31-d37f-410a-b26c-68ffcb643f04"],
Cell[CellGroupData[{
Cell[186464, 4384, 120, 1, 28, "Input",ExpressionUUID->"73860c66-4e9c-40c8-8da3-d00cfa7280cf"],
Cell[186587, 4387, 277, 5, 32, "Output",ExpressionUUID->"4e72be79-d1c0-460d-8df4-47bcf3cad7ad"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[186913, 4398, 170, 7, 53, "Subsection",ExpressionUUID->"5c6e1d23-19c9-4620-b079-49de39a95326"],
Cell[187086, 4407, 520, 9, 56, "Text",ExpressionUUID->"f5bfa632-1452-48c6-bd91-1bd60e955ce9"],
Cell[CellGroupData[{
Cell[187631, 4420, 679, 12, 91, "Item",ExpressionUUID->"b5d7dede-c018-431c-945a-77ec7b526585"],
Cell[188313, 4434, 339, 8, 51, "Item",ExpressionUUID->"a0bdb8b3-cafa-4e8f-9375-d0d2624bd52d"]
}, Open  ]],
Cell[188667, 4445, 1051, 20, 144, "Text",ExpressionUUID->"7f5a2dfd-f772-4430-95da-210a2a05c975"],
Cell[189721, 4467, 1426, 35, 166, "Text",ExpressionUUID->"a9559296-90a2-4556-ae52-1632331a0a79"],
Cell[191150, 4504, 522, 9, 78, "Text",ExpressionUUID->"243dde8e-401a-4829-af2c-5cbbaf22091e"],
Cell[191675, 4515, 915, 13, 166, "Text",ExpressionUUID->"ba77a262-9e02-4ebe-84dd-0597f36b987b"],
Cell[CellGroupData[{
Cell[192615, 4532, 270, 7, 28, "Input",ExpressionUUID->"647cab1b-2283-4126-b662-8853cec28d0a"],
Cell[192888, 4541, 207, 4, 32, "Output",ExpressionUUID->"6cb79d3e-47e9-4306-b69c-a0939ca9f769"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193132, 4550, 211, 4, 28, "Input",ExpressionUUID->"196f9d1e-2cf1-4aed-9156-b3c6027910fa"],
Cell[193346, 4556, 162, 3, 32, "Output",ExpressionUUID->"c2621e02-8ba2-476c-ae03-768468c801aa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[193557, 4565, 186, 7, 53, "Subsection",ExpressionUUID->"cc063477-9ac1-4798-94c4-fbbceb0a1278"],
Cell[193746, 4574, 98, 0, 34, "Text",ExpressionUUID->"5a0fbbb8-b8ab-48cb-b50f-d4ef212c772f"],
Cell[CellGroupData[{
Cell[193869, 4578, 200, 3, 28, "Input",ExpressionUUID->"4b9163b8-9c51-4603-a7b4-b84101e2540a"],
Cell[194072, 4583, 312, 5, 52, "Output",ExpressionUUID->"dd2dbb38-7ea1-451a-833b-5d0615950e08"]
}, Open  ]],
Cell[194399, 4591, 584, 8, 78, "Text",ExpressionUUID->"08304d7b-3d76-4aff-908d-1f6809b6d510"],
Cell[194986, 4601, 562, 8, 78, "Text",ExpressionUUID->"4de7d702-3eeb-4f8f-a8fb-376252a8507e"],
Cell[195551, 4611, 1010, 14, 144, "Text",ExpressionUUID->"eeb8064d-bee0-4297-814c-af1e28145b19"],
Cell[196564, 4627, 407, 6, 78, "Text",ExpressionUUID->"346ef331-a884-4afc-90c3-9f73028bf231"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197008, 4638, 170, 7, 53, "Subsection",ExpressionUUID->"01f3cc8e-5b87-4a67-a39a-aa2c6385aa6f"],
Cell[197181, 4647, 1216, 26, 144, "Text",ExpressionUUID->"42b1b1a8-8cd2-400e-afea-8e1af079e58c"],
Cell[CellGroupData[{
Cell[198422, 4677, 201, 4, 28, "Input",ExpressionUUID->"d1960197-0d36-4bba-a4e6-db9d9e48dd54"],
Cell[198626, 4683, 140, 2, 32, "Output",ExpressionUUID->"d2d7747f-5e7d-4580-9b47-8def21be22e6"]
}, Open  ]],
Cell[198781, 4688, 231, 4, 56, "Text",ExpressionUUID->"c206a2e1-6ad8-4ae0-8fb1-1abcc8cde826"]
}, Open  ]],
Cell[CellGroupData[{
Cell[199049, 4697, 163, 7, 53, "Subsection",ExpressionUUID->"eb6e4bef-9ea3-4c61-88f3-59b52d4c1375"],
Cell[199215, 4706, 479, 9, 56, "Text",ExpressionUUID->"89d5c969-dfa9-43ee-ac0b-b4a575c1451f"],
Cell[CellGroupData[{
Cell[199719, 4719, 146, 3, 28, "Input",ExpressionUUID->"e2e59768-238c-40db-9e76-ccea608d0a32"],
Cell[199868, 4724, 130, 1, 32, "Output",ExpressionUUID->"c37a6f46-2661-4731-9641-b6eafa57232d"]
}, Open  ]],
Cell[200013, 4728, 153, 2, 34, "Text",ExpressionUUID->"2500b78d-e9cb-402f-be8b-1528e441fa9e"],
Cell[CellGroupData[{
Cell[200191, 4734, 282, 6, 28, "Input",ExpressionUUID->"7a2beffd-2778-47c7-87d4-047f3d5e6ca9"],
Cell[200476, 4742, 219, 4, 32, "Output",ExpressionUUID->"174e5f35-ff6a-491e-a084-b56a0b00c3a4"]
}, Open  ]],
Cell[200710, 4749, 637, 17, 78, "Text",ExpressionUUID->"3a094066-ab51-4c99-8d9f-58d319b13d09"],
Cell[CellGroupData[{
Cell[201372, 4770, 103, 1, 28, "Input",ExpressionUUID->"b3e80d07-da23-4663-954c-8e571179f2f9"],
Cell[201478, 4773, 455, 11, 45, "Print",ExpressionUUID->"043ce143-e795-4438-95b6-2474e72c4506",
 CellTags->"Info2763735558483-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201970, 4789, 188, 5, 28, "Input",ExpressionUUID->"27dc0cbc-b833-4b8f-b770-2455e0f0b5c9"],
Cell[202161, 4796, 202, 6, 32, "Output",ExpressionUUID->"60d53781-b256-49d9-a7bd-7820f95ddb75"]
}, Open  ]],
Cell[202378, 4805, 113, 1, 28, "Input",ExpressionUUID->"edc64ae3-7042-430b-9a89-8082677eb6c0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[202540, 4812, 160, 4, 67, "Section",ExpressionUUID->"9bc235b9-232e-43d1-bb84-f4341e0d750e"],
Cell[CellGroupData[{
Cell[202725, 4820, 186, 7, 53, "Subsection",ExpressionUUID->"94b27791-69d3-4415-b3e1-3c192d0e4922"],
Cell[202914, 4829, 452, 7, 56, "Text",ExpressionUUID->"d647f5d3-6533-4748-b118-5fba05fbad57"],
Cell[203369, 4838, 110, 0, 34, "Text",ExpressionUUID->"26b3fe64-adf5-43cf-8b81-b019296f6831"],
Cell[203482, 4840, 287, 4, 56, "Text",ExpressionUUID->"179da817-2c98-46ef-9433-fb7f09d357b9"],
Cell[203772, 4846, 641, 9, 122, "Text",ExpressionUUID->"2c6eaaaf-c4f9-45bb-8365-e2c7daada348"],
Cell[204416, 4857, 386, 6, 78, "Text",ExpressionUUID->"2beb69e7-54ae-491b-a5e4-0fa11b2236ee"],
Cell[204805, 4865, 630, 10, 100, "Text",ExpressionUUID->"5ed6f032-3142-4ea7-bcfe-7accdfbad360"],
Cell[CellGroupData[{
Cell[205460, 4879, 374, 10, 28, "Input",ExpressionUUID->"65d786cb-b678-4d96-b490-4fca86d2f7db"],
Cell[205837, 4891, 333, 8, 32, "Output",ExpressionUUID->"53b54c6c-1738-4075-8779-03fe98f6ba02"]
}, Open  ]],
Cell[206185, 4902, 342, 5, 56, "Text",ExpressionUUID->"81f968cb-c384-4e77-975a-8307036dd988"],
Cell[206530, 4909, 559, 9, 78, "Text",ExpressionUUID->"5f39bdd4-c055-4e60-bca1-fbe25173a2ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207126, 4923, 214, 7, 53, "Subsection",ExpressionUUID->"6b048eb2-34bd-4579-b6e6-528db64337fb"],
Cell[207343, 4932, 147, 2, 34, "Text",ExpressionUUID->"935a18bf-5fa4-4c76-a5e5-8baf49a2c194"],
Cell[207493, 4936, 1112, 15, 188, "Text",ExpressionUUID->"63040f28-5111-4761-ab97-152fb962842c"],
Cell[208608, 4953, 892, 16, 144, "Text",ExpressionUUID->"9c6c37ec-3fc8-4bfe-bd35-fd76c70fa01c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209537, 4974, 166, 7, 53, "Subsection",ExpressionUUID->"9aca25fe-dd40-4e70-aa44-a575bf12270b"],
Cell[209706, 4983, 106, 0, 34, "Text",ExpressionUUID->"0aef7ed1-9670-47f4-bf3a-506f159b53d0"],
Cell[CellGroupData[{
Cell[209837, 4987, 353, 5, 71, "ItemNumbered",ExpressionUUID->"346e11b5-772f-464d-a12d-938d9d5c0696"],
Cell[210193, 4994, 360, 5, 71, "ItemNumbered",ExpressionUUID->"9d9bfa05-4fe2-4349-beb1-4d886b35efe8"],
Cell[210556, 5001, 464, 6, 71, "ItemNumbered",ExpressionUUID->"6ef8f8e7-2545-4100-b21a-e4e959bba670"]
}, Open  ]],
Cell[211035, 5010, 989, 15, 166, "Text",ExpressionUUID->"b0e2ae2e-6dbe-452a-92fd-2835cf97f689"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212061, 5030, 170, 7, 53, "Subsection",ExpressionUUID->"bfb9559f-90b0-46a6-8e2e-c20ce34c8adc"],
Cell[212234, 5039, 197, 5, 34, "Text",ExpressionUUID->"69ab1a50-14a3-4e08-b46d-b1d2f18bf95b"],
Cell[CellGroupData[{
Cell[212456, 5048, 231, 3, 51, "Item",ExpressionUUID->"d37940bf-bb42-40e6-8bd3-14df0ada7f69"],
Cell[212690, 5053, 145, 2, 31, "Item",ExpressionUUID->"899de977-6de4-42e7-8a92-c6eccdaa6fc1"],
Cell[212838, 5057, 285, 4, 51, "Item",ExpressionUUID->"c1d95ff5-b1b5-4f23-a87c-9f0f0c4d47b8"],
Cell[213126, 5063, 258, 4, 51, "Item",ExpressionUUID->"17403635-c9b7-4087-bb58-4c3891aa67c0"],
Cell[213387, 5069, 178, 3, 31, "Item",ExpressionUUID->"ff4337a3-91d0-4ccf-9ad9-b5c681e94283"],
Cell[213568, 5074, 637, 9, 111, "Item",ExpressionUUID->"5d17c17d-0c00-4c6f-894a-c72c899dbccc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[214266, 5090, 147, 4, 67, "Section",ExpressionUUID->"4a412ffe-af5c-46b1-94b9-ff88bd86348c"],
Cell[CellGroupData[{
Cell[214438, 5098, 163, 7, 53, "Subsection",ExpressionUUID->"20099128-3e67-47b6-ab16-8b027a5da642"],
Cell[214604, 5107, 849, 12, 166, "Text",ExpressionUUID->"0c977753-9ad9-4eba-aa84-192f09d146f5"],
Cell[215456, 5121, 145, 2, 34, "Text",ExpressionUUID->"694eda90-70c4-4ebf-828c-2b9d550a1261"],
Cell[215604, 5125, 471, 8, 78, "Text",ExpressionUUID->"8d3bf81f-7434-46b4-b7e2-501e3479a8b9"],
Cell[216078, 5135, 567, 8, 100, "Text",ExpressionUUID->"85084bd2-33ad-41ef-bf0f-c6aa929ca7d7"],
Cell[216648, 5145, 240, 5, 34, "Text",ExpressionUUID->"f7e1b50b-d5a2-424e-b350-af9bc11bf905"],
Cell[CellGroupData[{
Cell[216913, 5154, 366, 8, 28, "Input",ExpressionUUID->"d8907cdd-9117-4abf-9abd-569d01b6354c"],
Cell[217282, 5164, 200, 3, 32, "Output",ExpressionUUID->"5f2ab644-988e-42eb-8e22-3068140b9b33"]
}, Open  ]],
Cell[217497, 5170, 208, 4, 34, "Text",ExpressionUUID->"964d9393-3efe-4d24-aa28-55be8c51b878"],
Cell[CellGroupData[{
Cell[217730, 5178, 430, 9, 28, "Input",ExpressionUUID->"746055d1-97de-4e7e-8148-b399c36dc8db"],
Cell[218163, 5189, 183, 3, 32, "Output",ExpressionUUID->"328bc891-5796-4f38-a362-18cc17b7b207"]
}, Open  ]],
Cell[218361, 5195, 108, 0, 34, "Text",ExpressionUUID->"b2117fb7-6441-43e6-bc03-5e076953c376"],
Cell[CellGroupData[{
Cell[218494, 5199, 321, 7, 28, "Input",ExpressionUUID->"5890e320-5a7e-4d3e-a600-8466ba0b5d9b"],
Cell[218818, 5208, 347, 5, 23, "Print",ExpressionUUID->"564da209-d86f-4223-8134-c4d18c8b41f0"],
Cell[219168, 5215, 183, 3, 32, "Output",ExpressionUUID->"4c3388b0-feda-47b7-9fb2-922b5bedec29"]
}, Open  ]],
Cell[219366, 5221, 376, 7, 56, "Text",ExpressionUUID->"63fcc16b-acb8-4168-9277-5b59083f19c1"],
Cell[CellGroupData[{
Cell[219767, 5232, 368, 8, 28, "Input",ExpressionUUID->"82340650-ca07-4857-8144-a77135944e01"],
Cell[220138, 5242, 523, 14, 32, "Output",ExpressionUUID->"34052035-bee6-422c-8f83-e99b24137354"]
}, Open  ]],
Cell[220676, 5259, 214, 5, 34, "Text",ExpressionUUID->"71d3ac8e-55ef-436d-bbe0-7b5b0dc888e9"],
Cell[CellGroupData[{
Cell[220915, 5268, 368, 8, 28, "Input",ExpressionUUID->"f38f47df-64e4-4a7f-98eb-f4fe94489899"],
Cell[221286, 5278, 140, 2, 32, "Output",ExpressionUUID->"548f51b9-0c29-4156-8cfa-2efbcd4d6942"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221463, 5285, 122, 1, 28, "Input",ExpressionUUID->"df51ef84-b5b1-46c8-a3e0-e427d0aee6a9"],
Cell[221588, 5288, 269, 4, 32, "Output",ExpressionUUID->"4d7816e7-5ebf-4f2c-bafa-b22af234bee0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[221906, 5298, 170, 7, 53, "Subsection",ExpressionUUID->"b6075ff2-9966-426c-8684-dc5859e78e67"],
Cell[CellGroupData[{
Cell[222101, 5309, 222, 10, 44, "Subsubsection",ExpressionUUID->"00dd9bf8-be7d-463f-9e4c-e0c53cff59b5"],
Cell[222326, 5321, 458, 6, 100, "Text",ExpressionUUID->"9cee747e-50db-4809-9a37-b2bd523b3e50"],
Cell[222787, 5329, 427, 6, 78, "Text",ExpressionUUID->"f6813346-eb48-4311-9c18-fb96113eca9c"],
Cell[CellGroupData[{
Cell[223239, 5339, 331, 9, 28, "Input",ExpressionUUID->"91dc0935-4e39-4372-84ef-ef8e6680f05a"],
Cell[223573, 5350, 527, 9, 32, "Output",ExpressionUUID->"3c2ed4d4-b86c-40fa-9fbc-5c90f5f20abe"]
}, Open  ]],
Cell[224115, 5362, 209, 3, 56, "Text",ExpressionUUID->"8cd7c4c1-8db9-4992-9338-7c852a45cad6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[224361, 5370, 226, 10, 44, "Subsubsection",ExpressionUUID->"609d3b65-d60a-49ea-9be8-c10fef60f024"],
Cell[CellGroupData[{
Cell[224612, 5384, 234, 6, 28, "Input",ExpressionUUID->"065ba12a-ca68-4f5d-b0a4-654e6a2e8450"],
Cell[224849, 5392, 557, 8, 90, "Output",ExpressionUUID->"4e59eb58-ea9f-4bc6-8e53-7ecb9c20fe3e"]
}, Open  ]],
Cell[225421, 5403, 1034, 18, 122, "Text",ExpressionUUID->"b2ae56d9-c3a6-41ed-9d2e-15b94e57888d"],
Cell[226458, 5423, 160, 3, 34, "Text",ExpressionUUID->"648e850d-8e3a-4447-80f4-9a49d62e8f46"],
Cell[CellGroupData[{
Cell[226643, 5430, 262, 7, 28, "Input",ExpressionUUID->"35de6c14-80a0-4170-854a-b68a845b5d86"],
Cell[226908, 5439, 1119, 28, 116, "Output",ExpressionUUID->"053d7979-2d7b-4d56-8f5a-60eacccfecb6"]
}, Open  ]],
Cell[228042, 5470, 92, 0, 34, "Text",ExpressionUUID->"32ee2273-cdf3-4c01-b71b-49551cc11abb"],
Cell[CellGroupData[{
Cell[228159, 5474, 415, 12, 28, "Input",ExpressionUUID->"1dcd136e-c3ba-49c1-9aef-ebb80b4012e1"],
Cell[228577, 5488, 1118, 28, 116, "Output",ExpressionUUID->"7c9c9708-c735-46d3-9f41-f1f09b2c227e"]
}, Open  ]],
Cell[229710, 5519, 243, 4, 34, "Text",ExpressionUUID->"eb2121f3-2532-4724-847f-2306d4556c29"],
Cell[CellGroupData[{
Cell[229978, 5527, 142, 3, 28, "Input",ExpressionUUID->"e1730899-887e-4900-9b2e-0ea1ffb66249"],
Cell[230123, 5532, 192, 3, 32, "Output",ExpressionUUID->"63d8b033-286e-4029-84ac-eef7de50f1ed"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[230364, 5541, 238, 10, 44, "Subsubsection",ExpressionUUID->"0de9ce23-f82f-4d55-affa-822226b49844"],
Cell[230605, 5553, 252, 4, 56, "Text",ExpressionUUID->"9bb5582d-85b2-4419-b335-e00f782268d3"],
Cell[CellGroupData[{
Cell[230882, 5561, 239, 5, 28, "Input",ExpressionUUID->"b81b6343-d8b6-423b-8fa8-3b2a693f2385"],
Cell[231124, 5568, 625, 9, 52, "Output",ExpressionUUID->"a0b248a0-7e58-414d-9840-156fdf40c640"]
}, Open  ]],
Cell[231764, 5580, 115, 0, 34, "Text",ExpressionUUID->"a7a13187-88ce-4f32-9925-299c97142882"],
Cell[CellGroupData[{
Cell[231904, 5584, 263, 7, 28, "Input",ExpressionUUID->"62e9ab46-c5f6-41f6-b120-e6ce80282555"],
Cell[232170, 5593, 1111, 27, 82, "Output",ExpressionUUID->"50d37373-76cc-43b8-b2b2-0640c0225d34"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[233342, 5627, 213, 7, 53, "Subsection",ExpressionUUID->"7171cda5-7314-4844-a237-3ce0ab43dae2"],
Cell[233558, 5636, 180, 3, 34, "Text",ExpressionUUID->"e0d63fa3-e2e9-46cf-98e6-1117524b421c"],
Cell[CellGroupData[{
Cell[233763, 5643, 231, 10, 44, "Subsubsection",ExpressionUUID->"e93157d5-55bd-41a7-8ffa-9b43a5d631be"],
Cell[233997, 5655, 320, 5, 56, "Text",ExpressionUUID->"51339582-505d-4c0a-a70b-fa346043fe10"],
Cell[CellGroupData[{
Cell[234342, 5664, 299, 6, 28, "Input",ExpressionUUID->"a97a72a1-e7ae-44d6-8317-3412ba2382b2"],
Cell[234644, 5672, 119, 1, 32, "Output",ExpressionUUID->"e8fec481-1fb2-41df-b461-72fc955aed7c"]
}, Open  ]],
Cell[234778, 5676, 271, 4, 56, "Text",ExpressionUUID->"68d7e4f7-f987-458a-8db0-3515b993a368"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235086, 5685, 251, 10, 44, "Subsubsection",ExpressionUUID->"8ebb4aa7-c54c-4a55-8676-cfc71de6a025"],
Cell[235340, 5697, 549, 8, 100, "Text",ExpressionUUID->"2f008cf7-cdf0-4d9a-b947-54175c8c8e86"],
Cell[CellGroupData[{
Cell[235914, 5709, 328, 8, 28, "Input",ExpressionUUID->"69d36f59-9a44-4946-b193-92140f35a7ae"],
Cell[236245, 5719, 137, 2, 23, "Print",ExpressionUUID->"0a13abbe-e1f1-4a05-a9c2-0be87ded9779"],
Cell[236385, 5723, 119, 1, 32, "Output",ExpressionUUID->"b75fd066-4c5f-4cf6-b46f-8e07b9be3f86"]
}, Open  ]],
Cell[236519, 5727, 175, 3, 34, "Text",ExpressionUUID->"ff5fb0e6-1e17-4fa2-a4cb-3db8bb7941bd"],
Cell[CellGroupData[{
Cell[236719, 5734, 263, 5, 28, "Input",ExpressionUUID->"9c9cafbd-da33-478c-a456-4065f9fc36bb"],
Cell[236985, 5741, 248, 6, 32, "Output",ExpressionUUID->"fbf7ab07-6a57-4f74-b93d-04a87a91c581"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[237282, 5753, 248, 10, 44, "Subsubsection",ExpressionUUID->"9652df6a-7977-4c8e-9f14-1029bfe6a62c"],
Cell[237533, 5765, 258, 4, 56, "Text",ExpressionUUID->"553827b3-29db-4fd8-92cc-539687e082fd"],
Cell[237794, 5771, 388, 5, 78, "Text",ExpressionUUID->"c9530776-4cdd-432e-97c4-699efc470239"],
Cell[CellGroupData[{
Cell[238207, 5780, 329, 6, 28, "Input",ExpressionUUID->"ed5e9ce3-6cba-419e-ac75-4ee741f64488"],
Cell[238539, 5788, 139, 2, 23, "Print",ExpressionUUID->"595bf77b-23d5-4ddb-8545-9136ae3748c8"],
Cell[238681, 5792, 136, 2, 32, "Output",ExpressionUUID->"68683e03-434a-46dc-84e8-09612c93181c"]
}, Open  ]],
Cell[238832, 5797, 493, 9, 78, "Text",ExpressionUUID->"6f80745c-f5fa-44c4-ac8b-bd37bba5421d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[239362, 5811, 221, 10, 44, "Subsubsection",ExpressionUUID->"5bea8501-aad3-4c16-bb76-1f68329c71cf"],
Cell[239586, 5823, 322, 6, 56, "Text",ExpressionUUID->"3b9aef76-e058-465a-a8a9-9810d0a5910a"],
Cell[CellGroupData[{
Cell[239933, 5833, 200, 3, 28, "Input",ExpressionUUID->"fddcc00c-b76f-467c-b782-5a2a77d044d3"],
Cell[240136, 5838, 260, 4, 52, "Output",ExpressionUUID->"46869671-519a-43da-afee-84b8c7fe52a9"]
}, Open  ]],
Cell[240411, 5845, 342, 5, 56, "Text",ExpressionUUID->"f4d8a76f-cba7-461c-bd31-ffcb9019004c"],
Cell[240756, 5852, 836, 12, 122, "Text",ExpressionUUID->"2dac7f7e-47fe-4a8d-b7cf-78c9b39f6dc6"],
Cell[241595, 5866, 277, 4, 56, "Text",ExpressionUUID->"45fe0134-4c59-4f96-a74f-8e4a34574701"],
Cell[CellGroupData[{
Cell[241897, 5874, 125, 1, 28, "Input",ExpressionUUID->"c18bd992-16b8-4b2b-8258-347bdfabe396"],
Cell[242025, 5877, 132, 1, 23, "Print",ExpressionUUID->"130edf95-d811-43ff-9749-4f2405a898a8"],
Cell[242160, 5880, 120, 1, 32, "Output",ExpressionUUID->"803120c3-2a9e-453a-9040-fddcfbed113e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[242317, 5886, 216, 4, 28, "Input",ExpressionUUID->"62685af1-a9f5-42be-9110-283cecd078ff"],
Cell[242536, 5892, 132, 1, 23, "Print",ExpressionUUID->"b82508f5-a283-47f4-a047-022aea9277fd"],
Cell[242671, 5895, 120, 1, 32, "Output",ExpressionUUID->"40c7ba99-759e-416a-a2df-6377096d85ed"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[242840, 5902, 224, 10, 44, "Subsubsection",ExpressionUUID->"d722c049-1f66-4458-9438-b9a0719bb9a6"],
Cell[243067, 5914, 602, 8, 100, "Text",ExpressionUUID->"d982c666-1b30-4f9a-9343-30700e1454d7"],
Cell[CellGroupData[{
Cell[243694, 5926, 200, 3, 28, "Input",ExpressionUUID->"a9e156fa-e7f7-453f-8b11-286107c21333"],
Cell[243897, 5931, 295, 4, 52, "Output",ExpressionUUID->"f5097882-a022-4d48-9d1d-ae7080433ce2"]
}, Open  ]],
Cell[244207, 5938, 106, 0, 34, "Text",ExpressionUUID->"81ef40d8-8690-4dea-9767-3478150e6e33"],
Cell[CellGroupData[{
Cell[244338, 5942, 394, 10, 28, "Input",ExpressionUUID->"9198b1e4-f9e3-4c44-8018-102e5ecb0f95"],
Cell[244735, 5954, 164, 4, 32, "Output",ExpressionUUID->"539d41a6-3bab-46ee-84c4-5b285c988cc8"]
}, Open  ]],
Cell[244914, 5961, 154, 2, 34, "Text",ExpressionUUID->"1a3fff84-58fd-42d5-a150-35ddce1433eb"],
Cell[CellGroupData[{
Cell[245093, 5967, 394, 8, 28, "Input",ExpressionUUID->"92dc2178-eb30-4555-a43b-69b5b5a5adde"],
Cell[245490, 5977, 296, 4, 52, "Output",ExpressionUUID->"390bae47-9475-4bc8-b517-f65c442c66c7"]
}, Open  ]],
Cell[245801, 5984, 171, 3, 34, "Text",ExpressionUUID->"32c7683e-588f-48fa-8be1-b0cdfcf8e207"],
Cell[CellGroupData[{
Cell[245997, 5991, 122, 1, 28, "Input",ExpressionUUID->"e1cbe624-113a-4866-b622-21fa117a1e18"],
Cell[246122, 5994, 469, 7, 52, "Output",ExpressionUUID->"20c3ef7d-89ef-4a52-8b13-bb25a87f45b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246628, 6006, 294, 6, 28, "Input",ExpressionUUID->"50a4dd90-121c-4d0a-aee1-9ee1727eb044"],
Cell[246925, 6014, 200, 3, 23, "Print",ExpressionUUID->"57baf03f-6a8f-45c4-842f-3414915083ca"],
Cell[247128, 6019, 128, 1, 32, "Output",ExpressionUUID->"a1fd3c4a-d77b-4af1-9a9d-3652246f200f"]
}, Open  ]],
Cell[247271, 6023, 264, 6, 56, "Text",ExpressionUUID->"695e9a4b-8a0c-4782-8f4c-a1fbec7d6846"],
Cell[CellGroupData[{
Cell[247560, 6033, 209, 4, 28, "Input",ExpressionUUID->"778d8007-2f12-4286-b661-1ebce43a7347"],
Cell[247772, 6039, 283, 7, 32, "Output",ExpressionUUID->"b6a5914e-4f8b-4c58-aa62-d689c25bfdfa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[248104, 6052, 210, 10, 44, "Subsubsection",ExpressionUUID->"b0c59fac-3b79-4458-95a5-46f5cd50cd6b"],
Cell[CellGroupData[{
Cell[248339, 6066, 198, 3, 28, "Input",ExpressionUUID->"82fc7d7d-e766-4cf7-9e4d-ac23154dc2a2"],
Cell[248540, 6071, 331, 5, 71, "Output",ExpressionUUID->"c513b212-1867-44b9-bb0e-9b45f7c77861"]
}, Open  ]],
Cell[248886, 6079, 200, 3, 34, "Text",ExpressionUUID->"a22580b8-1a64-45c9-8655-c40fcaf5bba1"],
Cell[CellGroupData[{
Cell[249111, 6086, 363, 9, 28, "Input",ExpressionUUID->"d8c58980-68ae-4810-8670-666e2f66ba60"],
Cell[249477, 6097, 160, 4, 32, "Output",ExpressionUUID->"a2f0ede1-fea3-41b6-866b-e0024d0ceb2e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[249674, 6106, 431, 9, 28, "Input",ExpressionUUID->"c199917b-34a1-4d9e-b593-53458073f86a"],
Cell[250108, 6117, 296, 4, 52, "Output",ExpressionUUID->"0d50918c-e843-48db-8b7d-7ad25e5c67b5"]
}, Open  ]],
Cell[250419, 6124, 245, 4, 56, "Text",ExpressionUUID->"10ee2aba-0e42-4b6c-ba32-78c64915ad7b"],
Cell[250667, 6130, 266, 4, 56, "Text",ExpressionUUID->"c6571559-3bea-4132-a184-dc485be3866c"],
Cell[CellGroupData[{
Cell[250958, 6138, 264, 5, 28, "Input",ExpressionUUID->"98036e58-347d-4066-9499-cba85784c5b5"],
Cell[251225, 6145, 138, 2, 23, "Print",ExpressionUUID->"02e07513-bdb0-4380-8cc8-03d438a2eb65"],
Cell[251366, 6149, 137, 2, 32, "Output",ExpressionUUID->"a7927da9-1af3-4be8-9d93-9830c47617a8"]
}, Open  ]],
Cell[251518, 6154, 264, 6, 56, "Text",ExpressionUUID->"fac85fff-a7ff-480c-bf2e-1938294dca2c"],
Cell[CellGroupData[{
Cell[251807, 6164, 209, 4, 28, "Input",ExpressionUUID->"745167d9-693c-4458-8456-2f61cdaeae70"],
Cell[252019, 6170, 230, 6, 32, "Output",ExpressionUUID->"7ca81047-f3a1-47dd-9af8-9cb60beedc8c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[252298, 6182, 213, 10, 44, "Subsubsection",ExpressionUUID->"2bbf40a1-a00e-4476-ad05-6fe8c0b1a077"],
Cell[CellGroupData[{
Cell[252536, 6196, 198, 3, 28, "Input",ExpressionUUID->"e1d99c5a-c53d-43bd-9388-83c933321112"],
Cell[252737, 6201, 331, 5, 71, "Output",ExpressionUUID->"df6d65ac-90c7-43ba-8395-07b86747da31"]
}, Open  ]],
Cell[253083, 6209, 172, 3, 34, "Text",ExpressionUUID->"ed2351a8-ce52-49e4-b679-21fbc89ab550"],
Cell[CellGroupData[{
Cell[253280, 6216, 222, 6, 28, "Input",ExpressionUUID->"580fc20e-5d8d-46af-9a3b-fc5af60ef4e3"],
Cell[253505, 6224, 160, 4, 32, "Output",ExpressionUUID->"2960ec3d-ec78-4778-8f7e-811f3e55a9de"]
}, Open  ]],
Cell[253680, 6231, 260, 4, 56, "Text",ExpressionUUID->"9eddf69b-39d1-4e4c-9d3b-957103fd8764"],
Cell[CellGroupData[{
Cell[253965, 6239, 431, 9, 28, "Input",ExpressionUUID->"132950b4-57d1-4a64-852e-d544916e305b"],
Cell[254399, 6250, 298, 4, 52, "Output",ExpressionUUID->"972baa13-f46a-4509-b1c4-1b900aad6a77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254734, 6259, 122, 1, 28, "Input",ExpressionUUID->"18d64e6b-0bce-42da-a555-b6d4217fb64d"],
Cell[254859, 6262, 510, 7, 52, "Output",ExpressionUUID->"f4841150-e8fa-4a72-aa02-2a891604ebd3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255406, 6274, 264, 5, 28, "Input",ExpressionUUID->"ac01a06d-89b7-468b-93df-c6b02c12edbf"],
Cell[255673, 6281, 206, 4, 23, "Print",ExpressionUUID->"94f5635a-d808-4200-acbf-bca31f9ddc54"],
Cell[255882, 6287, 145, 2, 32, "Output",ExpressionUUID->"4daf9995-0220-4e29-a365-3765c2ed23f6"]
}, Open  ]],
Cell[256042, 6292, 264, 6, 56, "Text",ExpressionUUID->"1c8dda7a-b411-4251-a10c-1977836433c7"],
Cell[CellGroupData[{
Cell[256331, 6302, 209, 4, 28, "Input",ExpressionUUID->"248ee813-082e-41e5-ba68-09855e6ca3e9"],
Cell[256543, 6308, 306, 8, 32, "Output",ExpressionUUID->"3b20cbe2-ccf9-420e-8ed0-fa9349c77148"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[256898, 6322, 211, 10, 44, "Subsubsection",ExpressionUUID->"46528caa-27d2-4cfe-87cf-4052604cf2aa"],
Cell[CellGroupData[{
Cell[257134, 6336, 200, 3, 28, "Input",ExpressionUUID->"06e3744c-610c-44ab-acf6-6ea405b68fd7"],
Cell[257337, 6341, 312, 5, 52, "Output",ExpressionUUID->"fffe576c-d47a-4d08-963f-dc95ec56f10a"]
}, Open  ]],
Cell[257664, 6349, 262, 4, 34, "Text",ExpressionUUID->"b92ffefc-3c12-4575-9d5e-a3429281e93d"],
Cell[CellGroupData[{
Cell[257951, 6357, 295, 6, 28, "Input",ExpressionUUID->"2808490d-434f-4223-9c5f-64c0c3d85d64"],
Cell[258249, 6365, 2391, 56, 212, "Output",ExpressionUUID->"4df7738c-7629-4f49-ac0e-f592ce8bd879"]
}, Open  ]],
Cell[CellGroupData[{
Cell[260677, 6426, 113, 1, 28, "Input",ExpressionUUID->"ee9f1025-d55a-4048-adda-8686d2046cec"],
Cell[260793, 6429, 553, 9, 138, "Print",ExpressionUUID->"96dfcb63-cb9f-4512-8b27-21e5ca0fd224",
 CellTags->"Info3203735558484-8910602"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[261395, 6444, 229, 10, 44, "Subsubsection",ExpressionUUID->"591deedf-0e88-449e-a19a-bddc2dd6bc64"],
Cell[261627, 6456, 317, 8, 34, "Text",ExpressionUUID->"bc0e795b-6a79-43ea-8319-ba760a8dfea2"],
Cell[CellGroupData[{
Cell[261969, 6468, 198, 3, 28, "Input",ExpressionUUID->"ac814927-5f81-4f18-b903-ecf189dc5015"],
Cell[262170, 6473, 337, 5, 71, "Output",ExpressionUUID->"5bd87bf8-7c0c-48b7-9ad4-57e380326195"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262544, 6483, 268, 6, 28, "Input",ExpressionUUID->"f596ef5c-4719-40bc-b80c-f6aa99c4641a"],
Cell[262815, 6491, 184, 5, 32, "Output",ExpressionUUID->"8e74a459-15f5-4434-9c4b-5777eb4dd4d8"]
}, Open  ]],
Cell[263014, 6499, 122, 0, 34, "Text",ExpressionUUID->"681f2c5f-018a-4523-90dc-f56c9fabbd95"],
Cell[CellGroupData[{
Cell[263161, 6503, 396, 8, 28, "Input",ExpressionUUID->"8c0196a6-2d3c-498f-997c-93bce5d7cc49"],
Cell[263560, 6513, 300, 4, 52, "Output",ExpressionUUID->"3bf086ff-37f9-4b48-9ce1-ed294ab67686"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263897, 6522, 122, 1, 28, "Input",ExpressionUUID->"4e888634-e0fd-4ca1-ac43-f1362c3faaf2"],
Cell[264022, 6525, 526, 7, 52, "Output",ExpressionUUID->"50ca85c5-658b-425c-a5bc-c8f4188b5dff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[264585, 6537, 295, 6, 28, "Input",ExpressionUUID->"ee736929-c8f7-47f7-976b-25a1970ddbab"],
Cell[264883, 6545, 204, 3, 23, "Print",ExpressionUUID->"060cb966-4ff5-440c-98c9-ffdb6f09d258"],
Cell[265090, 6550, 147, 2, 32, "Output",ExpressionUUID->"62dfa048-ced0-4078-90bc-eb4d0000e499"]
}, Open  ]],
Cell[265252, 6555, 264, 6, 56, "Text",ExpressionUUID->"18c15f9a-a436-43c5-b940-206436e943c2"],
Cell[CellGroupData[{
Cell[265541, 6565, 209, 4, 28, "Input",ExpressionUUID->"0e32f3eb-aef4-4fdb-9f7d-cc6cac1f416e"],
Cell[265753, 6571, 310, 8, 32, "Output",ExpressionUUID->"75c468fb-4016-417e-903c-dfef234f9a0a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[266112, 6585, 211, 10, 44, "Subsubsection",ExpressionUUID->"05484817-48c1-45ee-a43c-591854ebf263"],
Cell[CellGroupData[{
Cell[266348, 6599, 231, 6, 28, "Input",ExpressionUUID->"034cf3d3-c2f9-4a6d-a1ed-64dced0bb330"],
Cell[266582, 6607, 265, 4, 52, "Output",ExpressionUUID->"a379467f-55ab-43c1-b6c0-d94a81c0cd9e"]
}, Open  ]],
Cell[266862, 6614, 2355, 37, 342, "Text",ExpressionUUID->"3c860288-f9b8-4606-bada-4ec2c0ccfb34"],
Cell[CellGroupData[{
Cell[269242, 6655, 125, 1, 28, "Input",ExpressionUUID->"f2d7dfb0-e103-424a-a21d-4eb821a7765f"],
Cell[269370, 6658, 1392, 40, 52, "Output",ExpressionUUID->"b163b91a-771c-45a3-b371-ebe2381bc91e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[270799, 6703, 206, 4, 28, "Input",ExpressionUUID->"5d269c41-c069-4858-8d78-e42db63545cb"],
Cell[271008, 6709, 1616, 43, 52, "Output",ExpressionUUID->"7c913e5b-4d6c-4494-9004-fd4b36d1c2f6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[272673, 6758, 218, 10, 44, "Subsubsection",ExpressionUUID->"8eb32512-3527-4892-8ece-be2eb6806b10"],
Cell[CellGroupData[{
Cell[272916, 6772, 206, 4, 28, "Input",ExpressionUUID->"d68013cb-997c-4413-945f-2bc1e2bfe156"],
Cell[273125, 6778, 390, 6, 71, "Output",ExpressionUUID->"06ee8e2e-96c2-40fa-ba9c-23a2cf6a95fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[273552, 6789, 238, 5, 28, "Input",ExpressionUUID->"987589d0-ae9a-485b-8a5e-e65187e2395c"],
Cell[273793, 6796, 204, 3, 23, "Print",ExpressionUUID->"51d1256e-8361-4789-95fd-0402f26cb673"],
Cell[274000, 6801, 146, 2, 32, "Output",ExpressionUUID->"8f54addc-c8ec-4671-826d-862c6dc8ed59"]
}, Open  ]],
Cell[CellGroupData[{
Cell[274183, 6808, 305, 6, 28, "Input",ExpressionUUID->"c3f9859a-da0b-454e-b66b-5e27f28484f3"],
Cell[274491, 6816, 275, 4, 23, "Print",ExpressionUUID->"c6a76f4a-11c2-4801-a247-06784347dcc1"],
Cell[274769, 6822, 187, 3, 32, "Output",ExpressionUUID->"1eebc6f6-cd44-4648-b5d4-5adc82b9f7eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[274993, 6830, 231, 6, 28, "Input",ExpressionUUID->"63a94733-70e4-470c-9fb3-cfbe385fd083"],
Cell[275227, 6838, 339, 5, 71, "Output",ExpressionUUID->"294b49b4-f8c4-43ba-9e51-6ee28a765b31"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275603, 6848, 229, 6, 28, "Input",ExpressionUUID->"715f91be-5329-436c-bba1-fcd25b73bbf8"],
Cell[275835, 6856, 232, 4, 52, "Output",ExpressionUUID->"b21d8dee-33d2-4f13-b380-afc51f38aa93"]
}, Open  ]],
Cell[CellGroupData[{
Cell[276104, 6865, 229, 6, 28, "Input",ExpressionUUID->"6ea02b12-bd0a-4866-8199-af242193f653"],
Cell[276336, 6873, 268, 4, 52, "Output",ExpressionUUID->"ff866c11-e477-4d20-b6de-6ce6262f9000"]
}, Open  ]],
Cell[276619, 6880, 321, 5, 56, "Text",ExpressionUUID->"2bec78bd-5339-4af1-b598-cfee68f92045"],
Cell[276943, 6887, 105, 0, 34, "Text",ExpressionUUID->"50aeabdd-2ac4-4b0c-8937-f899fea1eb05"],
Cell[CellGroupData[{
Cell[277073, 6891, 304, 6, 28, "Input",ExpressionUUID->"1d0e4ddc-7f3e-4f9e-855c-095c37b7c101"],
Cell[277380, 6899, 188, 3, 23, "Print",ExpressionUUID->"f2a98d8e-e590-406b-91ab-072aefdcfaee"],
Cell[277571, 6904, 173, 3, 32, "Output",ExpressionUUID->"6ad64a62-0c37-47c2-931a-e9bdaeefcee0"]
}, Open  ]],
Cell[277759, 6910, 1006, 18, 122, "Text",ExpressionUUID->"e484ecd1-e9cd-4b74-9490-cfcd7459473d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[278802, 6933, 223, 10, 44, "Subsubsection",ExpressionUUID->"1483cda4-d9d3-4a44-9125-55e79daf70a2"],
Cell[279028, 6945, 148, 2, 34, "Text",ExpressionUUID->"8fb764ca-8d43-4617-905f-2155f5179324"],
Cell[CellGroupData[{
Cell[279201, 6951, 192, 3, 28, "Input",ExpressionUUID->"dc2bbbc6-1a9d-4a8c-87c8-37e66c9319bf"],
Cell[279396, 6956, 398, 6, 52, "Output",ExpressionUUID->"29c8efc7-c16e-43e8-8da2-12f929849255"]
}, Open  ]],
Cell[CellGroupData[{
Cell[279831, 6967, 193, 3, 28, "Input",ExpressionUUID->"60611759-60fc-4002-81b5-9007fa4e39e6"],
Cell[280027, 6972, 470, 7, 71, "Output",ExpressionUUID->"37a1df66-eb29-48dc-8592-a20af64de3b9"]
}, Open  ]],
Cell[280512, 6982, 414, 6, 78, "Text",ExpressionUUID->"f0044f46-e979-47e0-b55a-37539ea30660"],
Cell[CellGroupData[{
Cell[280951, 6992, 373, 7, 28, "Input",ExpressionUUID->"934f8134-8089-4ab5-8457-25ec2d90df05"],
Cell[CellGroupData[{
Cell[281349, 7003, 170, 3, 23, "Print",ExpressionUUID->"490b7cae-66b6-4b0b-a6a8-30d40fd1d8d8"],
Cell[281522, 7008, 188, 3, 23, "Print",ExpressionUUID->"69e8ea8f-a3cf-45ba-95fb-db103f55dde2"]
}, Open  ]],
Cell[281725, 7014, 173, 3, 32, "Output",ExpressionUUID->"b3847a16-e2df-467b-9f3c-fa69156f76a6"]
}, Open  ]],
Cell[281913, 7020, 923, 18, 122, "Text",ExpressionUUID->"b49077ca-6b02-4a88-9378-78a023dc473c"],
Cell[CellGroupData[{
Cell[282861, 7042, 231, 5, 28, "Input",ExpressionUUID->"eda2b5a8-d45d-42d9-84d3-40fc487dd85f"],
Cell[283095, 7049, 283, 4, 23, "Print",ExpressionUUID->"5a4c5ea1-553f-4d47-ad25-c2e0a8aff11b"],
Cell[283381, 7055, 296, 4, 32, "Output",ExpressionUUID->"9230a58e-c345-40e3-9b00-23248d50a1cd"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[283738, 7066, 186, 7, 53, "Subsection",ExpressionUUID->"5128a79c-86b8-48b6-b623-08d20270bbdf"],
Cell[283927, 7075, 147, 2, 34, "Text",ExpressionUUID->"c2b45a0e-2aa3-40e0-8c14-79c24ad4a49e"],
Cell[284077, 7079, 672, 15, 78, "Text",ExpressionUUID->"67dc3e69-6c39-4b26-bbc2-7ab2ba49f189"],
Cell[CellGroupData[{
Cell[284774, 7098, 168, 3, 28, "Input",ExpressionUUID->"4d528889-e970-4416-aa32-b09af8bf0023"],
Cell[284945, 7103, 523, 14, 32, "Output",ExpressionUUID->"e272cea3-8282-4d80-ba26-ff5e5ebaee6d"]
}, Open  ]],
Cell[285483, 7120, 174, 3, 34, "Text",ExpressionUUID->"c554c114-b47f-40f3-9b51-4e3cf55a7a37"],
Cell[CellGroupData[{
Cell[285682, 7127, 291, 6, 28, "Input",ExpressionUUID->"595ffcb3-f424-4cb1-8e18-46769d31881d"],
Cell[285976, 7135, 518, 14, 32, "Output",ExpressionUUID->"71c2a99d-0c0f-4349-9bed-3c6c13007666"]
}, Open  ]],
Cell[286509, 7152, 880, 12, 100, "Text",ExpressionUUID->"da3a354f-d534-42c7-acca-362c64379bd4"],
Cell[287392, 7166, 309, 6, 56, "Text",ExpressionUUID->"3eb0a9a7-16ca-4685-914c-d29535248cf6"],
Cell[CellGroupData[{
Cell[287726, 7176, 377, 9, 28, "Input",ExpressionUUID->"de96333a-9b11-4195-9ebc-23479e453499"],
Cell[288106, 7187, 10576, 272, 244, "Output",ExpressionUUID->"53390e67-c232-4044-90f0-6a4d2d3fe66f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[298731, 7465, 173, 7, 53, "Subsection",ExpressionUUID->"d409d666-f9d1-46f3-aa29-4da3bf7bbffd"],
Cell[298907, 7474, 870, 13, 144, "Text",ExpressionUUID->"da8c6be7-17e1-4cff-a50c-842f679eefeb"],
Cell[CellGroupData[{
Cell[299802, 7491, 221, 4, 28, "Input",ExpressionUUID->"5b8764a3-6e8c-4b03-9a32-9c2b0cfcfa52"],
Cell[300026, 7497, 208, 4, 32, "Output",ExpressionUUID->"83ea1dd0-4ed5-4a58-aaf2-9b38cce9295d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300271, 7506, 317, 8, 28, "Input",ExpressionUUID->"2bd840c2-18df-421b-a83d-7fae286434db"],
Cell[300591, 7516, 132, 1, 32, "Output",ExpressionUUID->"4cdef6a9-df46-453e-8567-1f01e33584ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300760, 7522, 122, 1, 28, "Input",ExpressionUUID->"7fcea02b-7f21-4e3e-900d-47b4226b5420"],
Cell[300885, 7525, 215, 3, 32, "Output",ExpressionUUID->"2679c25c-b185-45e8-8205-4e9e1d3c0a14"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301137, 7533, 155, 3, 28, "Input",ExpressionUUID->"c42d101d-bab2-4128-8efb-b45e73012779"],
Cell[301295, 7538, 155, 3, 32, "Output",ExpressionUUID->"17412603-e159-43f7-ac63-14075829e6a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301487, 7546, 122, 1, 28, "Input",ExpressionUUID->"4274ff67-c668-4cc8-9111-bdd071eaf35b"],
Cell[301612, 7549, 218, 3, 32, "Output",ExpressionUUID->"8e17b798-16e4-44bb-ae6f-4822248b6839"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301867, 7557, 312, 6, 28, "Input",ExpressionUUID->"1fbcdf36-a6c4-47a3-a8df-925333cbc222"],
Cell[302182, 7565, 169, 3, 32, "Output",ExpressionUUID->"374f0cc8-eb72-45bc-936b-02a02ddbaa9b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302388, 7573, 122, 1, 28, "Input",ExpressionUUID->"c5a24b7b-395e-4fa4-82a2-7e0a34cae9bc"],
Cell[302513, 7576, 565, 8, 32, "Output",ExpressionUUID->"44488c95-7736-4003-ae7e-c81dc0ebab65"]
}, Open  ]],
Cell[303093, 7587, 181, 3, 34, "Text",ExpressionUUID->"db3f5bbf-c03d-4fc3-a206-7609c7f62278"],
Cell[CellGroupData[{
Cell[303299, 7594, 235, 4, 28, "Input",ExpressionUUID->"58fcf938-df65-47f5-82ae-435d84c6211f"],
Cell[303537, 7600, 192, 5, 32, "Output",ExpressionUUID->"6a6e1324-e3e1-4eba-bda3-1424c1a1e7dd"]
}, Open  ]],
Cell[303744, 7608, 771, 13, 100, "Text",ExpressionUUID->"9e362fc2-62e4-455e-805a-f553bdfd505f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304552, 7626, 190, 7, 53, "Subsection",ExpressionUUID->"d0938189-c7e5-4bda-9fa5-57b5c97b1aa0"],
Cell[304745, 7635, 904, 16, 144, "Text",ExpressionUUID->"3d0321a8-af34-4234-a28b-4749ab365ea4"],
Cell[CellGroupData[{
Cell[305674, 7655, 147, 3, 28, "Input",ExpressionUUID->"66096ffe-2cfb-4998-8ffb-66cb9c9bda4b"],
Cell[305824, 7660, 144, 2, 32, "Output",ExpressionUUID->"5905d083-d635-45e8-843a-cad15cb91eea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306005, 7667, 150, 3, 28, "Input",ExpressionUUID->"d24aa631-6f58-45e2-9291-8fdacbf19ae2"],
Cell[306158, 7672, 136, 2, 32, "Output",ExpressionUUID->"6e17b94c-8a09-4053-b7c1-b137262ca554"]
}, Open  ]],
Cell[306309, 7677, 262, 4, 56, "Text",ExpressionUUID->"cc4f1ced-1e77-49bd-9ab6-a24660a9c72c"],
Cell[CellGroupData[{
Cell[306596, 7685, 237, 5, 28, "Input",ExpressionUUID->"0be9186f-13c1-4f3e-b14e-e76e400455e4"],
Cell[306836, 7692, 180, 3, 32, "Output",ExpressionUUID->"9b0c905c-9737-4142-a2a2-9abdbb507816"]
}, Open  ]],
Cell[307031, 7698, 258, 6, 28, "Input",ExpressionUUID->"ee89d6d4-a3f1-438c-bf71-e23c93f43a0f"],
Cell[307292, 7706, 336, 5, 78, "Text",ExpressionUUID->"c627f30b-2015-4aca-b6b1-b805270b303b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[307665, 7716, 193, 7, 53, "Subsection",ExpressionUUID->"8bad2782-878a-4ef6-8f2e-da2214184846"],
Cell[307861, 7725, 433, 8, 78, "Text",ExpressionUUID->"1a2d834a-ae54-4442-ab29-d5a50c3228a2"],
Cell[CellGroupData[{
Cell[308319, 7737, 114, 1, 28, "Input",ExpressionUUID->"02f7d83f-2908-4ffd-aae2-724910e5223b"],
Cell[308436, 7740, 1090, 16, 368, "Print",ExpressionUUID->"2a1cb0a9-a9c7-4119-9f7f-ea39e103b018",
 CellTags->"Info3563735558490-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[309563, 7761, 130, 1, 28, "Input",ExpressionUUID->"98a4f569-1aee-47e5-8829-45fa1c76a3b5"],
Cell[309696, 7764, 659, 15, 79, "Output",ExpressionUUID->"ec09b18f-84a8-4055-8849-34944ad32d69"]
}, Open  ]],
Cell[310370, 7782, 738, 11, 122, "Text",ExpressionUUID->"cbc6375d-546d-402e-906c-51ed00e06447"],
Cell[CellGroupData[{
Cell[311133, 7797, 125, 1, 28, "Input",ExpressionUUID->"bfc1c241-c9f9-434b-ad6c-da83d88a4256"],
Cell[311261, 7800, 200, 3, 32, "Output",ExpressionUUID->"660ca2e7-7459-4e21-aad8-9406d9997325"]
}, Open  ]],
Cell[311476, 7806, 485, 9, 56, "Text",ExpressionUUID->"636e9d70-0ae5-41df-bff6-ea9bb25233fb"],
Cell[CellGroupData[{
Cell[311986, 7819, 274, 5, 28, "Input",ExpressionUUID->"e96e8982-3d26-4816-b456-bc8ceddddb9a"],
Cell[312263, 7826, 1543, 42, 52, "Output",ExpressionUUID->"c7676061-10fd-4579-a72e-0d34adf99869"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[313867, 7875, 170, 5, 67, "Section",ExpressionUUID->"bc449713-0b45-4467-a8ea-429d8541c9a7",
 PageBreakAbove->True],
Cell[CellGroupData[{
Cell[314062, 7884, 203, 7, 53, "Subsection",ExpressionUUID->"f73020d9-1320-49f5-8228-6af9c32d7eba"],
Cell[314268, 7893, 205, 3, 34, "Text",ExpressionUUID->"8db0c156-f703-41f6-a2fd-a2bb88c73380"],
Cell[314476, 7898, 280, 4, 56, "Text",ExpressionUUID->"12594fa6-be6c-4c2c-9b16-9ddeadea6147"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314793, 7907, 213, 7, 53, "Subsection",ExpressionUUID->"65a83a15-c11f-4a43-a6c2-9249435669ae"],
Cell[315009, 7916, 675, 13, 78, "Text",ExpressionUUID->"e872fda4-52e0-4e7d-b8d7-eb0ead78c40b"],
Cell[315687, 7931, 691, 17, 78, "Text",ExpressionUUID->"817c9d41-294a-478d-b056-67e21f08e5df"],
Cell[316381, 7950, 330, 5, 56, "Text",ExpressionUUID->"db978a86-57c6-41ee-bce6-cef8dedfc973"],
Cell[316714, 7957, 884, 12, 100, "Text",ExpressionUUID->"c701a2ec-90ac-4cd9-ad82-d683d9aa9222"],
Cell[317601, 7971, 444, 8, 56, "Text",ExpressionUUID->"d744dd1c-40e1-4eb3-a340-92ff331ce3d5"],
Cell[CellGroupData[{
Cell[318070, 7983, 296, 7, 28, "Input",ExpressionUUID->"abba7013-1dca-49c5-80a4-672f0d315b27"],
Cell[318369, 7992, 1600, 43, 72, "Output",ExpressionUUID->"400a08f8-a33a-4da8-b4fc-b8e52519de05"]
}, Open  ]],
Cell[CellGroupData[{
Cell[320006, 8040, 295, 7, 28, "Input",ExpressionUUID->"899a99ab-efba-4caa-976c-ba88228f8fb8"],
Cell[320304, 8049, 1603, 43, 72, "Output",ExpressionUUID->"6508713b-53c3-40a3-8a68-8c011d5fc48b"]
}, Open  ]],
Cell[321922, 8095, 230, 4, 34, "Text",ExpressionUUID->"92a71f5e-0be8-4116-877d-007850de4617"],
Cell[CellGroupData[{
Cell[322177, 8103, 339, 6, 28, "Input",ExpressionUUID->"09464dd1-9a80-4a98-90df-eeaeca32a8ba"],
Cell[322519, 8111, 210, 4, 32, "Output",ExpressionUUID->"9294410b-0915-4a50-ab99-84f7c3425a03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322766, 8120, 274, 5, 28, "Input",ExpressionUUID->"e62893c9-a697-4854-bb66-05f6776422ca"],
Cell[323043, 8127, 207, 4, 32, "Output",ExpressionUUID->"7691c5e0-d53d-49c9-960c-3542e1d9fee2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[323299, 8137, 178, 7, 53, "Subsection",ExpressionUUID->"afc954b4-4c7a-44e8-91e3-42719305ec4a"],
Cell[323480, 8146, 1444, 21, 166, "Text",ExpressionUUID->"eb4dd861-9252-478d-b30e-a28507b20601"],
Cell[CellGroupData[{
Cell[324949, 8171, 273, 5, 28, "Input",ExpressionUUID->"c46a8634-1e89-40f4-ba27-06993660b10b"],
Cell[325225, 8178, 185, 3, 32, "Output",ExpressionUUID->"bd6fe087-9950-4401-a59b-707de02edee3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325447, 8186, 376, 9, 28, "Input",ExpressionUUID->"5f1623bf-6a3f-48b7-a5bf-c6b5ac4ce335"],
Cell[325826, 8197, 2199, 53, 152, "Output",ExpressionUUID->"3ad90110-0c76-41bb-b16c-4ae0e1ac822c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[328074, 8256, 186, 7, 53, "Subsection",ExpressionUUID->"8c24a141-068a-4778-9b39-a001f9071c2b"],
Cell[328263, 8265, 326, 5, 56, "Text",ExpressionUUID->"a5bad86a-1d32-4c4f-af67-2728cdf56654"],
Cell[CellGroupData[{
Cell[328614, 8274, 211, 4, 28, "Input",ExpressionUUID->"1863b457-920f-4c51-b633-c72b5536ed94"],
Cell[328828, 8280, 449, 9, 21, "Message",ExpressionUUID->"5724fd86-6d20-430b-8108-0b8ff6714081"],
Cell[329280, 8291, 347, 8, 21, "Message",ExpressionUUID->"13f4ecf1-d646-4ae6-be11-2d8b74ee9d1b"],
Cell[329630, 8301, 452, 9, 21, "Message",ExpressionUUID->"1122a5d1-ff02-4816-98ce-f1a772ecb415"],
Cell[330085, 8312, 140, 2, 32, "Output",ExpressionUUID->"24171bc2-554a-4658-aee0-8fae3ba60900"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[330274, 8320, 188, 7, 53, "Subsection",ExpressionUUID->"15eed914-d9f3-4fca-9ed3-aa261e4e1c19"],
Cell[330465, 8329, 657, 9, 78, "Text",ExpressionUUID->"26e4b63f-984e-4275-8a4c-cb2e76e7cc8f"],
Cell[CellGroupData[{
Cell[331147, 8342, 211, 4, 28, "Input",ExpressionUUID->"0521fe64-a244-4d0c-be25-a819c640eb61"],
Cell[331361, 8348, 208, 4, 32, "Output",ExpressionUUID->"4f1746ae-cdae-4297-aef6-ac0bffe6b81e"]
}, Open  ]],
Cell[331584, 8355, 542, 8, 78, "Text",ExpressionUUID->"3280eb58-e72f-477f-b4d9-5229ff0b02de"],
Cell[CellGroupData[{
Cell[332151, 8367, 332, 9, 28, "Input",ExpressionUUID->"32f85e7b-a692-4971-91e0-d26099e0bf89"],
Cell[332486, 8378, 528, 9, 32, "Output",ExpressionUUID->"a8978de8-85d2-4869-a174-811bb5637831"]
}, Open  ]],
Cell[333029, 8390, 1073, 15, 188, "Text",ExpressionUUID->"2f24f670-a64c-4aa8-aedb-1e0fde297762"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[334151, 8411, 161, 4, 67, "Section",ExpressionUUID->"3ee1103d-edd7-4756-94e8-8189c5ae17de"],
Cell[CellGroupData[{
Cell[334337, 8419, 185, 7, 53, "Subsection",ExpressionUUID->"01e7a847-7b43-4798-a419-90b6e43d7e37"],
Cell[334525, 8428, 350, 7, 56, "Text",ExpressionUUID->"8a152ca3-3d2c-48fe-8e8d-a19a3b2f814d"],
Cell[334878, 8437, 621, 11, 78, "Text",ExpressionUUID->"8a6c69cf-de29-4f3a-9773-4070e68dcf88"],
Cell[335502, 8450, 884, 18, 100, "Text",ExpressionUUID->"10710c8d-587a-4cac-901d-dba2eb536f79"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336423, 8473, 201, 7, 53, "Subsection",ExpressionUUID->"f0249c88-dab5-4977-92b0-6e0142ed613a"],
Cell[336627, 8482, 651, 12, 100, "Text",ExpressionUUID->"010c91e4-2ce1-42c9-a6ef-71227c9b97e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337315, 8499, 224, 7, 53, "Subsection",ExpressionUUID->"b2e0f396-5a00-49f0-b101-a9025e7875f0"],
Cell[337542, 8508, 378, 9, 56, "Text",ExpressionUUID->"99a4988e-ce29-4454-b270-cbfd0ddc5c0f"],
Cell[337923, 8519, 649, 13, 78, "Text",ExpressionUUID->"2be43225-585e-43f0-ae10-89ab6a30d337"],
Cell[CellGroupData[{
Cell[338597, 8536, 139, 2, 28, "Input",ExpressionUUID->"2c00ea30-8142-47d1-a240-76b967b3fd2a"],
Cell[338739, 8540, 315, 6, 32, "Output",ExpressionUUID->"e42ec22e-6582-445d-bb83-63cd801b979c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[339091, 8551, 202, 10, 44, "Subsubsection",ExpressionUUID->"38d415b4-fdbd-4508-9f45-25be58ebf9d6"],
Cell[CellGroupData[{
Cell[339318, 8565, 275, 5, 28, "Input",ExpressionUUID->"f67decc7-199b-4d24-8566-0aa06d416a9f"],
Cell[339596, 8572, 350, 6, 32, "Output",ExpressionUUID->"88027dfb-eda8-414b-a623-ce75aa5a4970"]
}, Open  ]],
Cell[CellGroupData[{
Cell[339983, 8583, 138, 2, 28, "Input",ExpressionUUID->"2840d524-7dd1-4ed3-923c-5f537313d50b"],
Cell[340124, 8587, 1759, 39, 90, "Output",ExpressionUUID->"91770eac-296d-4121-82da-a12648b02328"]
}, Open  ]],
Cell[341898, 8629, 368, 5, 56, "Text",ExpressionUUID->"6cce2895-3228-4df6-8d80-d69cee9c02db"]
}, Open  ]],
Cell[CellGroupData[{
Cell[342303, 8639, 202, 10, 44, "Subsubsection",ExpressionUUID->"832ebfb2-5974-4d28-a9c0-769ad9c3c067"],
Cell[342508, 8651, 143, 4, 34, "Text",ExpressionUUID->"3b90c59d-b321-4604-9d1a-192d9291b7f5"],
Cell[CellGroupData[{
Cell[342676, 8659, 275, 5, 28, "Input",ExpressionUUID->"79502b1b-30f3-4162-8131-0952f9ebb1b0"],
Cell[342954, 8666, 345, 6, 32, "Output",ExpressionUUID->"f460b1dc-2207-4d16-a01a-4efc7a8679a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343336, 8677, 138, 2, 28, "Input",ExpressionUUID->"e94c78a6-bc08-445a-a400-7f31f2270b97"],
Cell[343477, 8681, 1750, 39, 90, "Output",ExpressionUUID->"ef12f1ec-2c26-4a7c-bbcd-5cd791f85669"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[345276, 8726, 201, 10, 44, "Subsubsection",ExpressionUUID->"cdcf0097-5d20-4a0d-a616-07b2ac3cb509"],
Cell[345480, 8738, 284, 4, 34, "Text",ExpressionUUID->"0c266e02-8c45-4a5c-8838-b8bfc475a9c8"],
Cell[CellGroupData[{
Cell[345789, 8746, 274, 5, 28, "Input",ExpressionUUID->"4f4efcfa-796b-4add-bece-cf47576d7302"],
Cell[346066, 8753, 352, 6, 32, "Output",ExpressionUUID->"a724c41f-63c7-47ad-ab54-8d01673afe16"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346455, 8764, 269, 6, 28, "Input",ExpressionUUID->"30a39544-7391-48ec-a7e2-c899e85b3eea"],
Cell[346727, 8772, 1738, 39, 90, "Output",ExpressionUUID->"fffb6fc1-5770-42c3-a59b-ec9aff4c8bc8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[348514, 8817, 202, 10, 44, "Subsubsection",ExpressionUUID->"053523e1-654e-48ba-89f6-411923a47822"],
Cell[348719, 8829, 142, 4, 34, "Text",ExpressionUUID->"4df5f4a5-61bc-4efe-af00-81c4a268509e"],
Cell[CellGroupData[{
Cell[348886, 8837, 275, 5, 28, "Input",ExpressionUUID->"dad1df75-b586-4fa4-8e15-2b02e5cbd476"],
Cell[349164, 8844, 342, 5, 32, "Output",ExpressionUUID->"33effecc-dc5f-4b4d-91a4-c43a35e99dba"]
}, Open  ]],
Cell[349521, 8852, 553, 8, 56, "Text",ExpressionUUID->"2cc08103-b227-46f6-accb-046f6c76eb82"],
Cell[CellGroupData[{
Cell[350099, 8864, 138, 2, 28, "Input",ExpressionUUID->"42922444-3ba0-4b26-865c-8df543852314"],
Cell[350240, 8868, 1729, 39, 90, "Output",ExpressionUUID->"7a6a3dcc-f316-4ed3-8948-dab8c3514c51"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[352030, 8914, 212, 7, 53, "Subsection",ExpressionUUID->"b2f4288a-04f5-4327-8500-517dde422bf7"],
Cell[352245, 8923, 130, 0, 34, "Text",ExpressionUUID->"d759384b-bb82-4dd3-a57e-a4e88b7cf746"],
Cell[CellGroupData[{
Cell[352400, 8927, 203, 10, 44, "Subsubsection",ExpressionUUID->"88f18f74-cb43-416c-abf6-ba2909e5cc9d"],
Cell[CellGroupData[{
Cell[352628, 8941, 195, 4, 28, "Input",ExpressionUUID->"1774f20d-ca64-475e-8a44-32491b6146ae"],
Cell[352826, 8947, 172, 4, 32, "Output",ExpressionUUID->"ad32ab43-0880-40da-b00e-71fcda0f0ba8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353035, 8956, 212, 4, 28, "Input",ExpressionUUID->"7d19501a-d884-465f-afdb-5b325e164159"],
Cell[353250, 8962, 449, 9, 21, "Message",ExpressionUUID->"b21e037d-f35f-44c4-91bc-d15315291f4b"],
Cell[353702, 8973, 347, 8, 21, "Message",ExpressionUUID->"ab577691-014d-4091-8e0d-6c8b421c1e90"],
Cell[354052, 8983, 452, 9, 21, "Message",ExpressionUUID->"76eb6e14-206a-418a-aded-6260fcae16d4"],
Cell[354507, 8994, 188, 3, 32, "Output",ExpressionUUID->"9a29d7dd-23f3-414d-b41b-6b1e1e0bc7c9"]
}, Open  ]],
Cell[354710, 9000, 322, 5, 56, "Text",ExpressionUUID->"93c17107-c6fe-40fc-8656-59b507b1aa68"],
Cell[CellGroupData[{
Cell[355057, 9009, 278, 5, 28, "Input",ExpressionUUID->"76cfb269-fc9c-4bdc-afd1-2e5d6bec9b10"],
Cell[355338, 9016, 192, 3, 32, "Output",ExpressionUUID->"88725579-8306-4e41-b005-da076e305e2b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355567, 9024, 139, 2, 28, "Input",ExpressionUUID->"41e448fa-9513-4470-82b2-163abd01c624"],
Cell[355709, 9028, 1690, 37, 71, "Output",ExpressionUUID->"eef707ca-ae76-4cf0-98d4-63da8c39a2e6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[357448, 9071, 203, 10, 44, "Subsubsection",ExpressionUUID->"37dc9384-541f-4e09-9b91-5b70d0c6e488"],
Cell[CellGroupData[{
Cell[357676, 9085, 194, 4, 28, "Input",ExpressionUUID->"2f6fc978-b1ad-49d4-a50a-05965bc3c75c"],
Cell[357873, 9091, 172, 4, 32, "Output",ExpressionUUID->"948784a5-34aa-4c4d-b91a-9c26aa399e16"]
}, Open  ]],
Cell[CellGroupData[{
Cell[358082, 9100, 212, 4, 28, "Input",ExpressionUUID->"dcccc43b-dc42-4468-aa6e-b5b815330a50"],
Cell[358297, 9106, 449, 9, 21, "Message",ExpressionUUID->"72af805a-831f-4846-a6ba-592a4cf34a58"],
Cell[358749, 9117, 347, 8, 21, "Message",ExpressionUUID->"4a5adf17-ce29-407f-bb2e-17f2c836b657"],
Cell[359099, 9127, 452, 9, 21, "Message",ExpressionUUID->"723f0d25-d635-453f-91f5-f45ef7f5c976"],
Cell[359554, 9138, 186, 3, 32, "Output",ExpressionUUID->"5213a1aa-e4d2-42a6-b407-7330b69798c4"]
}, Open  ]],
Cell[359755, 9144, 179, 3, 34, "Text",ExpressionUUID->"059efc25-d7a2-43c4-ab6a-bd330afec776"],
Cell[CellGroupData[{
Cell[359959, 9151, 276, 5, 28, "Input",ExpressionUUID->"1b037a0b-8278-4379-8e6a-611b520906ff"],
Cell[360238, 9158, 186, 3, 32, "Output",ExpressionUUID->"3ec0e127-e768-431e-9ec5-1dbbf34be64a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360461, 9166, 139, 2, 28, "Input",ExpressionUUID->"b136a48c-5793-4a19-b60e-2c0e3593aa3a"],
Cell[360603, 9170, 1700, 37, 71, "Output",ExpressionUUID->"fe915fb9-8ed6-44b3-accf-af2fb1b33be0"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[362364, 9214, 172, 7, 53, "Subsection",ExpressionUUID->"ee4c75b0-7539-4577-9a0e-c28f042413f7"],
Cell[362539, 9223, 540, 8, 56, "Text",ExpressionUUID->"7d6a0592-5b86-47a5-ab22-1dfbc8b616ed"],
Cell[CellGroupData[{
Cell[363104, 9235, 214, 4, 28, "Input",ExpressionUUID->"25a7dc20-d694-41a1-bd85-75c66ac187b7"],
Cell[363321, 9241, 206, 5, 33, "Output",ExpressionUUID->"f37a8cd5-692c-4aa3-bf1a-333b71aa15c2"]
}, Open  ]],
Cell[363542, 9249, 81, 0, 34, "Text",ExpressionUUID->"1158a702-c85b-4c94-8ebb-53df75c3aede"],
Cell[363626, 9251, 233, 4, 32, "Output",ExpressionUUID->"f896e98f-360c-42c8-9430-9d81b0bc4741"],
Cell[363862, 9257, 114, 0, 34, "Text",ExpressionUUID->"aaee81a5-83dd-416f-8a36-9217e0df7543"],
Cell[363979, 9259, 127, 1, 28, "Input",ExpressionUUID->"2c8406f8-b88f-4c3f-84d6-6395b92da44e"],
Cell[CellGroupData[{
Cell[364131, 9264, 136, 2, 28, "Input",ExpressionUUID->"3fd7012c-29e0-4fe5-b103-a89e287cd514"],
Cell[364270, 9268, 125, 1, 32, "Output",ExpressionUUID->"a231bf6a-1900-4899-b89d-3999b154f70f"]
}, Open  ]],
Cell[364410, 9272, 113, 1, 28, "Input",ExpressionUUID->"a2ccc052-359d-4e4b-8b91-7c5cca23cb4f"],
Cell[364526, 9275, 179, 3, 34, "Text",ExpressionUUID->"6aecaf9a-db1c-44b7-857f-1bf5a729d018"],
Cell[364708, 9280, 185, 3, 34, "Text",ExpressionUUID->"7025e1a1-c3d7-4ffe-9fa5-c13636306cf1"],
Cell[364896, 9285, 508, 7, 100, "Text",ExpressionUUID->"1489360c-5c1c-4b19-aee2-09088f561e74"],
Cell[365407, 9294, 222, 3, 56, "Text",ExpressionUUID->"7db4db2a-42cd-4b9c-8b85-843b715e5368"],
Cell[365632, 9299, 154, 2, 34, "Text",ExpressionUUID->"6fbed2c5-d7c0-4a71-9f11-2ce38f3fa2d7"],
Cell[365789, 9303, 147, 2, 34, "Text",ExpressionUUID->"6525b59a-8b9f-4d53-b09b-69496269923d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[365985, 9311, 134, 4, 67, "Section",ExpressionUUID->"c168a41f-32d5-4f0c-abdd-9cb740aeab16"],
Cell[366122, 9317, 719, 11, 122, "Text",ExpressionUUID->"4f3a3805-ed4d-405b-928f-7a13ab5e69d2"],
Cell[366844, 9330, 181, 3, 34, "Text",ExpressionUUID->"95181ce0-1462-4c6b-9061-ddd2a92e5161"],
Cell[367028, 9335, 97, 0, 34, "Text",ExpressionUUID->"56143c25-bfca-4139-b005-aadc707e6747"],
Cell[CellGroupData[{
Cell[367150, 9339, 202, 4, 28, "Input",ExpressionUUID->"9919f107-24b9-4768-b424-0a4fae46c84a"],
Cell[367355, 9345, 3064, 66, 232, "Output",ExpressionUUID->"2a28f329-eb0c-4a81-9aa9-a2ce76130a57"]
}, Open  ]],
Cell[370434, 9414, 124, 0, 34, "Text",ExpressionUUID->"c4838151-dfa5-4f6b-b1b0-5bd2a913cf55"],
Cell[CellGroupData[{
Cell[370583, 9418, 294, 6, 28, "Input",ExpressionUUID->"35866e3a-2d51-4a93-8a43-bf59e019bd6c"],
Cell[370880, 9426, 452, 9, 21, "Message",ExpressionUUID->"c7a21c20-5153-45e8-b639-5d09a2a1cd33"],
Cell[371335, 9437, 2775, 63, 232, "Output",ExpressionUUID->"8fb9d533-7681-4efc-ab23-bbc82ab1290f"]
}, Open  ]],
Cell[374125, 9503, 184, 3, 34, "Text",ExpressionUUID->"244ea9ad-4d38-46cf-97af-91499995d22b"],
Cell[CellGroupData[{
Cell[374334, 9510, 213, 4, 28, "Input",ExpressionUUID->"08cce490-9f21-4e8e-9dc1-869a575f9577"],
Cell[374550, 9516, 210, 3, 32, "Output",ExpressionUUID->"47b212eb-ea5a-4214-91cf-b9dccdd7ba92"]
}, Open  ]],
Cell[374775, 9522, 204, 3, 34, "Text",ExpressionUUID->"64cd337a-da2b-46c1-9a28-9b3b2bc3173d"],
Cell[CellGroupData[{
Cell[375004, 9529, 294, 6, 28, "Input",ExpressionUUID->"6c650df3-5d1e-4c28-a6a2-2ce2794128a6"],
Cell[375301, 9537, 452, 9, 21, "Message",ExpressionUUID->"970f10b5-b318-4a46-af27-752ca6cf91f5"],
Cell[375756, 9548, 449, 9, 21, "Message",ExpressionUUID->"8049b26d-18c7-49dd-ada0-de993b874ec2"],
Cell[376208, 9559, 347, 8, 21, "Message",ExpressionUUID->"a2b74a96-8aa4-4e8b-8aff-4f3d982a4671"],
Cell[376558, 9569, 452, 9, 21, "Message",ExpressionUUID->"f7b6668a-4532-49f7-975d-4ba473694bb0"],
Cell[377013, 9580, 2929, 65, 235, "Output",ExpressionUUID->"ae982ab3-9f60-4514-8458-cac49c288de5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[379991, 9651, 129, 4, 67, "Section",ExpressionUUID->"d3cf12ee-62c2-48a4-b92a-372ddc48e820"],
Cell[CellGroupData[{
Cell[380145, 9659, 166, 7, 53, "Subsection",ExpressionUUID->"4cdc9af9-226a-4275-99b3-825edb9062ff"],
Cell[380314, 9668, 529, 7, 100, "Text",ExpressionUUID->"046bb360-d0a8-4eda-a770-4fa8a059c6ac"],
Cell[380846, 9677, 616, 9, 122, "Text",ExpressionUUID->"1652af39-2473-4b9d-883a-280f2c21bff9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381499, 9691, 175, 7, 53, "Subsection",ExpressionUUID->"fe0d8e24-0bd5-4b5b-beed-fb7cd73c67b8"],
Cell[381677, 9700, 786, 12, 144, "Text",ExpressionUUID->"5e24bdda-c7e0-4f4a-ba60-c200d7fc6896"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[382512, 9718, 133, 5, 67, "Section",ExpressionUUID->"9fea3833-7f93-4341-a4e2-9087a243f7d1"],
Cell[382648, 9725, 513, 7, 100, "Text",ExpressionUUID->"6eb133d9-2fcf-480d-99f1-a9f03b882d2b"],
Cell[383164, 9734, 1086, 17, 188, "Text",ExpressionUUID->"7ed6ca34-ec4f-46e0-8f87-ffcb1dc21fd8"],
Cell[384253, 9753, 321, 5, 56, "Text",ExpressionUUID->"82c4c0eb-7bfc-4ffc-9c00-b7af1e70aa1f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[384611, 9763, 138, 4, 67, "Section",ExpressionUUID->"c0549602-ac28-4c2b-987f-322f04c5183b"],
Cell[CellGroupData[{
Cell[384774, 9771, 183, 7, 53, "Subsection",ExpressionUUID->"e7674dc7-5add-457f-b534-cac7c9ba8f0e"],
Cell[384960, 9780, 184, 3, 34, "Text",ExpressionUUID->"ed667894-cb59-4cec-817a-e78825d828b1"],
Cell[CellGroupData[{
Cell[385169, 9787, 240, 4, 31, "Item",ExpressionUUID->"9cde69f2-0dfc-4075-9574-d740076f17b4"],
Cell[385412, 9793, 414, 6, 51, "Item",ExpressionUUID->"e503ad79-b166-482d-b3a6-302fe6e00e52"],
Cell[385829, 9801, 221, 5, 31, "Item",ExpressionUUID->"1ac3e716-3c5b-4ad9-93fe-94da60e35bf5"],
Cell[386053, 9808, 491, 8, 51, "Item",ExpressionUUID->"d0a9f149-7fb0-4884-b59d-6f2fcd7e83dd"],
Cell[386547, 9818, 980, 23, 91, "Item",ExpressionUUID->"b01fe2fb-a04c-48d8-89c5-08152e4106fc"],
Cell[387530, 9843, 288, 8, 31, "Item",ExpressionUUID->"d78e3e87-0def-4536-bd77-7a387038ce0a"],
Cell[387821, 9853, 256, 4, 51, "Item",ExpressionUUID->"e746e710-3377-45e0-ad39-f25e2e83da38"],
Cell[388080, 9859, 245, 5, 31, "Item",ExpressionUUID->"7c44094d-c70f-4f73-bd11-f10111847197"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[388374, 9870, 163, 7, 53, "Subsection",ExpressionUUID->"29301f00-dda4-4e50-9b30-6460abdc2667"],
Cell[388540, 9879, 87, 0, 34, "Text",ExpressionUUID->"f6791705-8419-4a65-8e64-f1babcbdad45"],
Cell[CellGroupData[{
Cell[388652, 9883, 128, 1, 28, "Input",ExpressionUUID->"d0b603f6-b6d0-4e46-b0cb-185acfa96eaf"],
Cell[388783, 9886, 4768, 124, 148, "Print",ExpressionUUID->"52be05e0-50ef-429a-a93b-e7a82dd6d87f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393588, 10015, 120, 1, 28, "Input",ExpressionUUID->"0f37c1f8-d579-4df6-bd17-ef854dea048a"],
Cell[393711, 10018, 193, 3, 45, "Print",ExpressionUUID->"44aee89a-a47e-4787-ad03-a8f1c8012f04",
 CellTags->"Info3983735558502-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393941, 10026, 125, 1, 28, "Input",ExpressionUUID->"ad6bcfca-b2de-422d-baf8-8013e84f73f2"],
Cell[394069, 10029, 1498, 20, 242, "Output",ExpressionUUID->"ef94b3b3-e193-4f10-81de-ccae1dc27a21"]
}, Open  ]],
Cell[395582, 10052, 156, 2, 34, "Text",ExpressionUUID->"917d4b43-d97d-49fa-970a-c8c42981c480"],
Cell[CellGroupData[{
Cell[395763, 10058, 120, 1, 28, "Input",ExpressionUUID->"1c64149a-19a5-4a2f-bc94-fb267cc6b855"],
Cell[395886, 10061, 1269, 36, 56, "Print",ExpressionUUID->"527caf87-b20a-466c-9ef8-22867d6bde62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397192, 10102, 114, 1, 28, "Input",ExpressionUUID->"4b274e71-e83d-4b43-8229-328a6d2ebc36"],
Cell[397309, 10105, 655, 10, 138, "Print",ExpressionUUID->"250e61d2-53f5-4ef4-ac98-0dc75df0acd6",
 CellTags->"Info4013735558503-8910602"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[398013, 10121, 172, 7, 53, "Subsection",ExpressionUUID->"45881424-15c8-4e48-8a5d-c327b1cc4d87"],
Cell[398188, 10130, 150, 2, 34, "Text",ExpressionUUID->"dde69074-e6c0-4739-807c-70733e2e6173"],
Cell[CellGroupData[{
Cell[398363, 10136, 264, 5, 28, "Input",ExpressionUUID->"449d992f-becc-45db-96b6-f97e2ba4d0c6"],
Cell[398630, 10143, 428, 9, 21, "Message",ExpressionUUID->"2224b589-c201-4c9e-95cf-5c5a6a3a797e"],
Cell[399061, 10154, 117, 1, 32, "Output",ExpressionUUID->"b2f80ae6-3584-49c6-b804-81a3fdc023f3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[399227, 10161, 162, 7, 53, "Subsection",ExpressionUUID->"9e090afc-5b40-46ba-bbbe-84df353a9f09"],
Cell[CellGroupData[{
Cell[399414, 10172, 108, 1, 28, "Input",ExpressionUUID->"cb38588e-f811-4c25-b63f-0babc8615c06"],
Cell[399525, 10175, 1395, 19, 368, "Print",ExpressionUUID->"0f6bbdc2-a4bc-42a6-9b77-59d8e12ca49b",
 CellTags->"Info3593735575597-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[400957, 10199, 124, 1, 28, "Input",ExpressionUUID->"5f7fdb80-d3dd-4354-ae35-cc41717ea9f7"],
Cell[401084, 10202, 601, 13, 57, "Output",ExpressionUUID->"f8949c9a-8d75-4fa2-8626-d9df0f0231be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401722, 10220, 118, 1, 28, "Input",ExpressionUUID->"0c6ae97f-f605-41f1-9bad-a92130267931"],
Cell[401843, 10223, 535, 8, 115, "Print",ExpressionUUID->"e13df783-445e-4071-99e9-f881ad080c9b",
 CellTags->"Info3613735575612-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[402415, 10236, 113, 1, 28, "Input",ExpressionUUID->"c1c81767-b98c-4440-9706-f43c7afe7d28"],
Cell[402531, 10239, 2257, 31, 506, "Print",ExpressionUUID->"17688de7-b7f0-4071-be46-ac018389f3e7",
 CellTags->"Info4553735576149-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404825, 10275, 118, 1, 28, "Input",ExpressionUUID->"d3d9b2c4-813d-4f1d-a91f-7bcacf458f20"],
Cell[404946, 10278, 392, 7, 32, "Output",ExpressionUUID->"4ec3f9ed-50b6-4a59-a665-5c1fdcd67b5a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[405375, 10290, 139, 2, 28, "Input",ExpressionUUID->"70ed344f-13c3-4335-9097-f4a6cde1744b"],
Cell[405517, 10294, 315, 6, 32, "Output",ExpressionUUID->"f2c9fb31-a0a9-4977-8010-5ecad6c836bd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[405869, 10305, 191, 3, 28, "Input",ExpressionUUID->"9a435544-7e65-4d5c-a657-2f98bc032443"],
Cell[406063, 10310, 534, 11, 32, "Output",ExpressionUUID->"8ed10bc7-38b4-4728-9c2f-0e5ce07176ac"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[406646, 10327, 162, 7, 53, "Subsection",ExpressionUUID->"59acad8f-05ca-4bd2-ba48-de4e8511535c"],
Cell[CellGroupData[{
Cell[406833, 10338, 114, 1, 28, "Input",ExpressionUUID->"9d0f2d00-5ef7-4dc0-a199-38389bf31188"],
Cell[406950, 10341, 566, 9, 138, "Print",ExpressionUUID->"ea864b82-5f2c-4ed0-a510-bc9d66ba210e",
 CellTags->"Info4083735558503-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[407553, 10355, 130, 1, 28, "Input",ExpressionUUID->"255cf577-acb2-4127-8b2d-b2c3ec0f76b7"],
Cell[407686, 10358, 236, 6, 32, "Output",ExpressionUUID->"4f1fc342-6ad1-4a30-982c-19c442319606"]
}, Open  ]],
Cell[CellGroupData[{
Cell[407959, 10369, 123, 1, 28, "Input",ExpressionUUID->"f6362f80-14bf-4b29-a13b-4625820567ce"],
Cell[408085, 10372, 849, 12, 161, "Print",ExpressionUUID->"e2f9876f-c24c-4203-bb04-4613820eb877",
 CellTags->"Info4103735558503-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408971, 10389, 141, 2, 28, "Input",ExpressionUUID->"afb5e6cc-5907-46e4-bbef-8401cbf413e6"],
Cell[409115, 10393, 459, 11, 32, "Output",ExpressionUUID->"6ef57646-4b9f-4263-ae92-ad8090adaea4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[409611, 10409, 286, 5, 28, "Input",ExpressionUUID->"c710106a-b25c-4a21-b8e7-68f9c009a235"],
Cell[409900, 10416, 539, 8, 52, "Output",ExpressionUUID->"9593f48c-9a2e-4608-8f3f-b3effe5cc66f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[410488, 10430, 162, 7, 53, "Subsection",ExpressionUUID->"e7b8c0f9-6cd9-450c-975f-a492c49f2cc5"],
Cell[CellGroupData[{
Cell[410675, 10441, 113, 1, 28, "Input",ExpressionUUID->"674b6dbb-46c5-4170-b751-6e426cfc4e4c"],
Cell[410791, 10444, 1304, 18, 276, "Print",ExpressionUUID->"5b9abc04-267c-4cec-9627-db42ec1e6410",
 CellTags->"Info4133735558504-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[412132, 10467, 129, 1, 28, "Input",ExpressionUUID->"ef33d593-1d04-47f2-bcd5-a1b11e0bf998"],
Cell[412264, 10470, 727, 16, 52, "Output",ExpressionUUID->"7ecf078d-9df8-4392-bbfa-917561644da8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413028, 10491, 128, 1, 28, "Input",ExpressionUUID->"121ac5d7-33b6-4f8f-996f-a134f3c23253"],
Cell[413159, 10494, 523, 14, 32, "Output",ExpressionUUID->"7ca0803b-5c63-4da2-a145-39b4f0f82916"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413719, 10513, 122, 1, 28, "Input",ExpressionUUID->"0a1da0eb-a54e-47a9-8d5c-0af54ff3b4f2"],
Cell[413844, 10516, 544, 14, 32, "Output",ExpressionUUID->"51f14d46-a293-49dc-87ef-ba1a21ba54c4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[414437, 10536, 162, 7, 53, "Subsection",ExpressionUUID->"746d72e2-5e49-4098-9d9e-1e35db5e8d95"],
Cell[CellGroupData[{
Cell[414624, 10547, 119, 1, 28, "Input",ExpressionUUID->"4021e7f4-ef95-45e3-bfc5-723d4c39deed"],
Cell[414746, 10550, 814, 12, 161, "Print",ExpressionUUID->"f6ad94bf-b7e1-4ee2-802e-b38aa45353df",
 CellTags->"Info4173735558504-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[415597, 10567, 137, 2, 28, "Input",ExpressionUUID->"25584464-a6cf-4af4-a520-b04c5ada5806"],
Cell[415737, 10571, 305, 8, 32, "Output",ExpressionUUID->"ac6fa88d-116e-4612-a6c4-da970da21996"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416079, 10584, 140, 2, 28, "Input",ExpressionUUID->"7e079c6a-faa8-40a4-ba05-a2504fa9428d"],
Cell[416222, 10588, 172, 3, 32, "Output",ExpressionUUID->"e116d97f-f3a8-4037-a999-589481b9cea8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416431, 10596, 122, 1, 28, "Input",ExpressionUUID->"1e5b9ab8-bd07-434c-89e0-8f77e2f503e5"],
Cell[416556, 10599, 351, 5, 32, "Output",ExpressionUUID->"73399f7b-791b-4360-9953-9c5409c24dd9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[416956, 10610, 163, 7, 53, "Subsection",ExpressionUUID->"663bff99-b7bb-4656-a852-5e55511d4010"],
Cell[CellGroupData[{
Cell[417144, 10621, 115, 1, 28, "Input",ExpressionUUID->"5ace99c7-3c03-4b46-b877-3de530c3f9c0"],
Cell[417262, 10624, 852, 12, 184, "Print",ExpressionUUID->"a653b300-a96f-4321-b74d-d881ea54c9f3",
 CellTags->"Info4213735558504-8910602"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418151, 10641, 131, 1, 28, "Input",ExpressionUUID->"130572c3-0344-4fe4-bf10-bedf88106436"],
Cell[418285, 10644, 250, 6, 32, "Output",ExpressionUUID->"faa3d50a-1770-4e2c-9185-308138a7ccef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418572, 10655, 136, 2, 28, "Input",ExpressionUUID->"439758cb-9c7c-4199-83f9-061eec79effc"],
Cell[418711, 10659, 160, 3, 32, "Output",ExpressionUUID->"b3ae4cad-fcb6-4cce-8f0e-a9578cef7949"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418908, 10667, 223, 5, 28, "Input",ExpressionUUID->"59ba6893-479c-4b1a-9a69-d38e914b8bc9"],
Cell[419134, 10674, 160, 3, 32, "Output",ExpressionUUID->"a0782e0e-a4a5-445a-8c86-d579cacc9f16"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[419355, 10684, 132, 5, 67, "Section",ExpressionUUID->"3c2a51a1-0ed8-4f1a-ab10-a4992a3fe325"],
Cell[419490, 10691, 203, 3, 56, "Text",ExpressionUUID->"10e59b6a-168c-470e-a659-6610018c0b1d"],
Cell[419696, 10696, 275, 6, 56, "Text",ExpressionUUID->"27d98d3f-944a-4d6d-b0a7-bedd6c35c579"],
Cell[419974, 10704, 262, 5, 56, "Text",ExpressionUUID->"5de91ac8-7d0f-4f93-a0e2-9d295f49011c"],
Cell[420239, 10711, 508, 9, 122, "Text",ExpressionUUID->"46169e56-2d3b-450a-bb43-692b7f25c158"],
Cell[420750, 10722, 379, 7, 56, "Text",ExpressionUUID->"49c0299d-45ae-4c2f-a7a6-32f660113df8"],
Cell[421132, 10731, 350, 7, 78, "Text",ExpressionUUID->"d0e3c4f0-8f90-4d44-906a-4ee64fb2d69b"],
Cell[421485, 10740, 416, 8, 78, "Text",ExpressionUUID->"bc17a31b-2ab7-4cd7-8f98-fe9c8f871945"],
Cell[421904, 10750, 309, 7, 56, "Text",ExpressionUUID->"e1653c2c-036e-4e42-8ebb-6d95e9fdc42c"],
Cell[422216, 10759, 313, 5, 56, "Text",ExpressionUUID->"c66e3c1a-c1e3-4127-b3d1-010ea60b5495"],
Cell[422532, 10766, 235, 5, 34, "Text",ExpressionUUID->"ed0bf13f-85b3-4ea4-8074-6fbbaa395c05"],
Cell[422770, 10773, 244, 5, 34, "Text",ExpressionUUID->"da920385-c252-4034-8e5a-63eda75f3cbf"],
Cell[423017, 10780, 269, 5, 56, "Text",ExpressionUUID->"2f0521c8-5864-405a-9f6a-057bf75915e5"],
Cell[423289, 10787, 330, 5, 56, "Text",ExpressionUUID->"6a581ec2-6fa6-46ff-a9a9-dfca38f9c465"],
Cell[423622, 10794, 240, 5, 34, "Text",ExpressionUUID->"8b77a98f-fbf2-429c-baea-c3c1f78c38a2"],
Cell[423865, 10801, 209, 5, 34, "Text",ExpressionUUID->"b3848859-8297-4317-b834-1475853ce5d0"]
}, Open  ]]
}, Open  ]]
}
]
*)

